| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.AttachmentDescriptionFlagBits
Synopsis
- type AttachmentDescriptionFlags = AttachmentDescriptionFlagBits
- newtype AttachmentDescriptionFlagBits where
- AttachmentDescriptionFlagBits Flags
- pattern ATTACHMENT_DESCRIPTION_MAY_ALIAS_BIT :: AttachmentDescriptionFlagBits
- pattern ATTACHMENT_DESCRIPTION_RESOLVE_ENABLE_TRANSFER_FUNCTION_BIT_KHR :: AttachmentDescriptionFlagBits
- pattern ATTACHMENT_DESCRIPTION_RESOLVE_SKIP_TRANSFER_FUNCTION_BIT_KHR :: AttachmentDescriptionFlagBits
Documentation
newtype AttachmentDescriptionFlagBits Source #
VkAttachmentDescriptionFlagBits - Bitmask specifying additional properties of an attachment
Description
ATTACHMENT_DESCRIPTION_MAY_ALIAS_BITspecifies that the attachment aliases the same device memory as other attachments.
ATTACHMENT_DESCRIPTION_RESOLVE_SKIP_TRANSFER_FUNCTION_BIT_KHRspecifies that resolve operations happening to an sRGB encoded attachment must not convert samples from nonlinear to linear before averaging.ATTACHMENT_DESCRIPTION_RESOLVE_ENABLE_TRANSFER_FUNCTION_BIT_KHRspecifies that resolve operations happening to an sRGB encoded attachment must convert samples from nonlinear to linear before averaging.
See Also
Constructors
| AttachmentDescriptionFlagBits Flags |
Bundled Patterns