vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Core10.Enums.AttachmentLoadOp

Synopsis

Documentation

newtype AttachmentLoadOp Source #

VkAttachmentLoadOp - Specify how contents of an attachment are treated at the beginning of the subpass where it is first used

Description

See Also

VK_VERSION_1_0, AttachmentDescription, AttachmentDescription2, RenderingAttachmentInfo

Constructors

AttachmentLoadOp Int32 

Instances

Instances details
Eq AttachmentLoadOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentLoadOp

Ord AttachmentLoadOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentLoadOp

Storable AttachmentLoadOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentLoadOp

Read AttachmentLoadOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentLoadOp

Show AttachmentLoadOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentLoadOp

Zero AttachmentLoadOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentLoadOp