| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.CommandBufferResetFlagBits
Documentation
newtype CommandBufferResetFlagBits Source #
VkCommandBufferResetFlagBits - Bitmask controlling behavior of a command buffer reset
Description
COMMAND_BUFFER_RESET_RELEASE_RESOURCES_BITspecifies that most or all memory resources currently owned by the command buffer should be returned to the parent command pool. If this flag is not set, then the command buffer may hold onto memory resources and reuse them when recording commands.commandBufferis moved to the initial state.
See Also
Constructors
| CommandBufferResetFlagBits Flags |
Bundled Patterns
| pattern COMMAND_BUFFER_RESET_RELEASE_RESOURCES_BIT :: CommandBufferResetFlagBits |