| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.CommandBufferUsageFlagBits
Synopsis
- type CommandBufferUsageFlags = CommandBufferUsageFlagBits
- newtype CommandBufferUsageFlagBits where
Documentation
newtype CommandBufferUsageFlagBits Source #
VkCommandBufferUsageFlagBits - Bitmask specifying usage behavior for command buffer
Description
COMMAND_BUFFER_USAGE_ONE_TIME_SUBMIT_BITspecifies that each recording of the command buffer will only be submitted once, and the command buffer will be reset and recorded again between each submission.
COMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BITspecifies that a secondary command buffer is considered to be entirely inside a render pass. If this is a primary command buffer, then this bit is ignored.COMMAND_BUFFER_USAGE_SIMULTANEOUS_USE_BITspecifies that a command buffer can be resubmitted to any queue of the same queue family while it is in the pending state, and recorded into multiple primary command buffers.
See Also
Constructors
| CommandBufferUsageFlagBits Flags |
Bundled Patterns