| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.ComponentSwizzle
Synopsis
- newtype ComponentSwizzle where
- ComponentSwizzle Int32
- pattern COMPONENT_SWIZZLE_IDENTITY :: ComponentSwizzle
- pattern COMPONENT_SWIZZLE_ZERO :: ComponentSwizzle
- pattern COMPONENT_SWIZZLE_ONE :: ComponentSwizzle
- pattern COMPONENT_SWIZZLE_R :: ComponentSwizzle
- pattern COMPONENT_SWIZZLE_G :: ComponentSwizzle
- pattern COMPONENT_SWIZZLE_B :: ComponentSwizzle
- pattern COMPONENT_SWIZZLE_A :: ComponentSwizzle
Documentation
newtype ComponentSwizzle Source #
VkComponentSwizzle - Specify how a component is swizzled
Description
COMPONENT_SWIZZLE_IDENTITYspecifies that the component is set to the identity swizzle.
COMPONENT_SWIZZLE_ZEROspecifies that the component is set to zero.COMPONENT_SWIZZLE_ONEspecifies that the component is set to either 1 or 1.0, depending on whether the type of the image view format is integer or floating-point respectively, as determined by the Format Definition section for eachFormat.COMPONENT_SWIZZLE_Rspecifies that the component is set to the value of the R component of the image.COMPONENT_SWIZZLE_Gspecifies that the component is set to the value of the G component of the image.COMPONENT_SWIZZLE_Bspecifies that the component is set to the value of the B component of the image.COMPONENT_SWIZZLE_Aspecifies that the component is set to the value of the A component of the image.
Setting the identity swizzle on a component is equivalent to setting the identity mapping on that component. That is:
| Component | Identity Mapping |
|---|---|
components.r | COMPONENT_SWIZZLE_R |
components.g | COMPONENT_SWIZZLE_G |
components.b | COMPONENT_SWIZZLE_B |
components.a | COMPONENT_SWIZZLE_A |
Component Mappings Equivalent To COMPONENT_SWIZZLE_IDENTITY
See Also
Constructors
| ComponentSwizzle Int32 |
Bundled Patterns
| pattern COMPONENT_SWIZZLE_IDENTITY :: ComponentSwizzle | |
| pattern COMPONENT_SWIZZLE_ZERO :: ComponentSwizzle | |
| pattern COMPONENT_SWIZZLE_ONE :: ComponentSwizzle | |
| pattern COMPONENT_SWIZZLE_R :: ComponentSwizzle | |
| pattern COMPONENT_SWIZZLE_G :: ComponentSwizzle | |
| pattern COMPONENT_SWIZZLE_B :: ComponentSwizzle | |
| pattern COMPONENT_SWIZZLE_A :: ComponentSwizzle |