| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.DependencyFlagBits
Synopsis
- type DependencyFlags = DependencyFlagBits
- newtype DependencyFlagBits where
- DependencyFlagBits Flags
- pattern DEPENDENCY_BY_REGION_BIT :: DependencyFlagBits
- pattern DEPENDENCY_ASYMMETRIC_EVENT_BIT_KHR :: DependencyFlagBits
- pattern DEPENDENCY_QUEUE_FAMILY_OWNERSHIP_TRANSFER_USE_ALL_STAGES_BIT_KHR :: DependencyFlagBits
- pattern DEPENDENCY_FEEDBACK_LOOP_BIT_EXT :: DependencyFlagBits
- pattern DEPENDENCY_VIEW_LOCAL_BIT :: DependencyFlagBits
- pattern DEPENDENCY_DEVICE_GROUP_BIT :: DependencyFlagBits
Documentation
type DependencyFlags = DependencyFlagBits Source #
newtype DependencyFlagBits Source #
VkDependencyFlagBits - Bitmask specifying how execution and memory dependencies are formed
Description
DEPENDENCY_BY_REGION_BITspecifies that dependencies will be split into multiple framebuffer-local regions according to the (x,y,layer,sample) coordinates.
DEPENDENCY_VIEW_LOCAL_BITspecifies that dependencies will be split into multiple framebuffer-local regions according to the view.DEPENDENCY_DEVICE_GROUP_BITspecifies that dependencies are non-device-local.DEPENDENCY_FEEDBACK_LOOP_BIT_EXTspecifies that the render pass will write to and read from the same image with feedback loop enabled.DEPENDENCY_QUEUE_FAMILY_OWNERSHIP_TRANSFER_USE_ALL_STAGES_BIT_KHRspecifies that source and destination stages are not ignored when performing a queue family ownership transfer.DEPENDENCY_ASYMMETRIC_EVENT_BIT_KHRspecifies thatcmdSetEvent2must only include the source stage mask of the first synchronization scope, and thatcmdWaitEvents2must specify the complete barrier.
See Also
Constructors
| DependencyFlagBits Flags |
Bundled Patterns