| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.DescriptorPoolCreateFlagBits
Synopsis
- type DescriptorPoolCreateFlags = DescriptorPoolCreateFlagBits
- newtype DescriptorPoolCreateFlagBits where
- DescriptorPoolCreateFlagBits Flags
- pattern DESCRIPTOR_POOL_CREATE_FREE_DESCRIPTOR_SET_BIT :: DescriptorPoolCreateFlagBits
- pattern DESCRIPTOR_POOL_CREATE_ALLOW_OVERALLOCATION_POOLS_BIT_NV :: DescriptorPoolCreateFlagBits
- pattern DESCRIPTOR_POOL_CREATE_ALLOW_OVERALLOCATION_SETS_BIT_NV :: DescriptorPoolCreateFlagBits
- pattern DESCRIPTOR_POOL_CREATE_HOST_ONLY_BIT_EXT :: DescriptorPoolCreateFlagBits
- pattern DESCRIPTOR_POOL_CREATE_UPDATE_AFTER_BIND_BIT :: DescriptorPoolCreateFlagBits
Documentation
newtype DescriptorPoolCreateFlagBits Source #
VkDescriptorPoolCreateFlagBits - Bitmask specifying certain supported operations on a descriptor pool
Description
DESCRIPTOR_POOL_CREATE_FREE_DESCRIPTOR_SET_BITspecifies that descriptor sets can return their individual allocations to the pool, i.e. all ofallocateDescriptorSets,freeDescriptorSets, andresetDescriptorPoolare allowed. Otherwise, descriptor sets allocated from the pool must not be individually freed back to the pool, i.e. onlyallocateDescriptorSetsandresetDescriptorPoolare allowed.
DESCRIPTOR_POOL_CREATE_UPDATE_AFTER_BIND_BITspecifies that descriptor sets allocated from this pool can include bindings with theDESCRIPTOR_BINDING_UPDATE_AFTER_BIND_BITbit set. It is valid to allocate descriptor sets that have bindings that do not set theDESCRIPTOR_BINDING_UPDATE_AFTER_BIND_BITbit from a pool that hasDESCRIPTOR_POOL_CREATE_UPDATE_AFTER_BIND_BITset.DESCRIPTOR_POOL_CREATE_HOST_ONLY_BIT_EXTspecifies that this descriptor pool and the descriptor sets allocated from it reside entirely in host memory and cannot be bound. Similar to descriptor sets allocated without this flag, applications can copy-from and copy-to descriptors sets allocated from this descriptor pool. Descriptor sets allocated from this pool are partially exempt from the external synchronization requirement inupdateDescriptorSetWithTemplateKHRandupdateDescriptorSets. Descriptor sets and their descriptors can be updated concurrently in different threads, though the same descriptor must not be updated concurrently by two threads.DESCRIPTOR_POOL_CREATE_ALLOW_OVERALLOCATION_SETS_BIT_NVspecifies that the implementation should allow the application to allocate more thanDescriptorPoolCreateInfo::maxSetsdescriptor set objects from the descriptor pool as available resources allow. The implementation may use themaxSetsvalue to allocate the initial available sets, but using zero is permitted.DESCRIPTOR_POOL_CREATE_ALLOW_OVERALLOCATION_POOLS_BIT_NVspecifies that the implementation should allow the application to allocate more descriptors from the pool than was specified by theDescriptorPoolSize::descriptorCountfor any descriptor type as specified byDescriptorPoolCreateInfo::poolSizeCountandDescriptorPoolCreateInfo::pPoolSizes, as available resources allow. The implementation may use thedescriptorCountfor each descriptor type to allocate the initial pool, but the application is allowed to set thepoolSizeCountto zero, or any of thedescriptorCountvalues in thepPoolSizesarray to zero.
See Also
Constructors
| DescriptorPoolCreateFlagBits Flags |
Bundled Patterns