| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.FramebufferCreateFlagBits
Synopsis
Documentation
newtype FramebufferCreateFlagBits Source #
VkFramebufferCreateFlagBits - Bitmask specifying framebuffer properties
Description
FRAMEBUFFER_CREATE_IMAGELESS_BITspecifies that image views are not specified, and only attachment compatibility information will be provided via aFramebufferAttachmentImageInfostructure.
See Also
Constructors
| FramebufferCreateFlagBits Flags |
Bundled Patterns
| pattern FRAMEBUFFER_CREATE_IMAGELESS_BIT :: FramebufferCreateFlagBits |