| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.ImageUsageFlagBits
Synopsis
- type ImageUsageFlags = ImageUsageFlagBits
- newtype ImageUsageFlagBits where
- ImageUsageFlagBits Flags
- pattern IMAGE_USAGE_TRANSFER_SRC_BIT :: ImageUsageFlagBits
- pattern IMAGE_USAGE_TRANSFER_DST_BIT :: ImageUsageFlagBits
- pattern IMAGE_USAGE_SAMPLED_BIT :: ImageUsageFlagBits
- pattern IMAGE_USAGE_STORAGE_BIT :: ImageUsageFlagBits
- pattern IMAGE_USAGE_COLOR_ATTACHMENT_BIT :: ImageUsageFlagBits
- pattern IMAGE_USAGE_DEPTH_STENCIL_ATTACHMENT_BIT :: ImageUsageFlagBits
- pattern IMAGE_USAGE_TRANSIENT_ATTACHMENT_BIT :: ImageUsageFlagBits
- pattern IMAGE_USAGE_INPUT_ATTACHMENT_BIT :: ImageUsageFlagBits
- pattern IMAGE_USAGE_TILE_MEMORY_BIT_QCOM :: ImageUsageFlagBits
- pattern IMAGE_USAGE_TENSOR_ALIASING_BIT_ARM :: ImageUsageFlagBits
- pattern IMAGE_USAGE_SAMPLE_BLOCK_MATCH_BIT_QCOM :: ImageUsageFlagBits
- pattern IMAGE_USAGE_SAMPLE_WEIGHT_BIT_QCOM :: ImageUsageFlagBits
- pattern IMAGE_USAGE_INVOCATION_MASK_BIT_HUAWEI :: ImageUsageFlagBits
- pattern IMAGE_USAGE_ATTACHMENT_FEEDBACK_LOOP_BIT_EXT :: ImageUsageFlagBits
- pattern IMAGE_USAGE_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHR :: ImageUsageFlagBits
- pattern IMAGE_USAGE_FRAGMENT_DENSITY_MAP_BIT_EXT :: ImageUsageFlagBits
- pattern IMAGE_USAGE_HOST_TRANSFER_BIT :: ImageUsageFlagBits
Documentation
type ImageUsageFlags = ImageUsageFlagBits Source #
newtype ImageUsageFlagBits Source #
VkImageUsageFlagBits - Bitmask specifying intended usage of an image
Description
IMAGE_USAGE_TRANSFER_SRC_BITspecifies that the image can be used as the source of a transfer command.
IMAGE_USAGE_TRANSFER_DST_BITspecifies that the image can be used as the destination of a transfer command.IMAGE_USAGE_SAMPLED_BITspecifies that the image can be used to create aImageViewsuitable for occupying aDescriptorSetslot either of typeDESCRIPTOR_TYPE_SAMPLED_IMAGEorDESCRIPTOR_TYPE_COMBINED_IMAGE_SAMPLER, and be sampled by a shader.IMAGE_USAGE_STORAGE_BITspecifies that the image can be used to create aImageViewsuitable for occupying aDescriptorSetslot of typeDESCRIPTOR_TYPE_STORAGE_IMAGE.IMAGE_USAGE_COLOR_ATTACHMENT_BITspecifies that the image can be used to create aImageViewsuitable for use as a color or resolve attachment in aFramebuffer.IMAGE_USAGE_DEPTH_STENCIL_ATTACHMENT_BITspecifies that the image can be used to create aImageViewsuitable for use as a depth/stencil or depth/stencil resolve attachment in aFramebuffer.IMAGE_USAGE_TRANSIENT_ATTACHMENT_BITspecifies that implementations may support using memory allocations with theMEMORY_PROPERTY_LAZILY_ALLOCATED_BITto back an image with this usage. This bit can be set for any image that can be used to create aImageViewsuitable for use as a color, resolve, depth/stencil, or input attachment.IMAGE_USAGE_INPUT_ATTACHMENT_BITspecifies that the image can be used to create aImageViewsuitable for occupyingDescriptorSetslot of typeDESCRIPTOR_TYPE_INPUT_ATTACHMENT; be read from a shader as an input attachment; and be used as an input attachment in a framebuffer.IMAGE_USAGE_FRAGMENT_DENSITY_MAP_BIT_EXTspecifies that the image can be used to create aImageViewsuitable for use as a fragment density map image.IMAGE_USAGE_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHRspecifies that the image can be used to create aImageViewsuitable for use as a fragment shading rate attachment or shading rate image- VK_IMAGE_USAGE_VIDEO_DECODE_DST_BIT_KHR specifies that the image can be used as a decode output picture in a video decode operation.
- VK_IMAGE_USAGE_VIDEO_DECODE_SRC_BIT_KHR is reserved for future use.
- VK_IMAGE_USAGE_VIDEO_DECODE_DPB_BIT_KHR specifies that the image can be used as an output reconstructed picture or an input reference picture in a video decode operation.
- VK_IMAGE_USAGE_VIDEO_ENCODE_DST_BIT_KHR is reserved for future use.
- VK_IMAGE_USAGE_VIDEO_ENCODE_SRC_BIT_KHR specifies that the image can be used as an encode input picture in a video encode operation.
- VK_IMAGE_USAGE_VIDEO_ENCODE_DPB_BIT_KHR specifies that the image can be used as an output reconstructed picture or an input reference picture in a video encode operation.
IMAGE_USAGE_ATTACHMENT_FEEDBACK_LOOP_BIT_EXTspecifies that the image can be used as a color or depth/stencil attachment with feedback loop enabled.IMAGE_USAGE_TILE_MEMORY_BIT_QCOMspecifies that the image can be bound toDeviceMemoryallocated from aMemoryHeapwith theMEMORY_HEAP_TILE_MEMORY_BIT_QCOMproperty.IMAGE_USAGE_HOST_TRANSFER_BITspecifies that the image can be used with host copy commands and host layout transitions.- VK_IMAGE_USAGE_VIDEO_ENCODE_QUANTIZATION_DELTA_MAP_BIT_KHR specifies that the image can be used as a quantization delta map in a video encode operation.
- VK_IMAGE_USAGE_VIDEO_ENCODE_EMPHASIS_MAP_BIT_KHR specifies that the image can be used as an emphasis map in a video encode operation.
IMAGE_USAGE_HOST_TRANSFER_BIT_EXTspecifies that the image can be used with host copy commands and host layout transitions.IMAGE_USAGE_TENSOR_ALIASING_BIT_ARMspecifies that the image can be transitioned to theIMAGE_LAYOUT_TENSOR_ALIASING_ARMlayout. See https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#resources-memory-aliasing for a complete set of rules for tensor/image aliasing.
See Also
Constructors
| ImageUsageFlagBits Flags |
Bundled Patterns