| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.ImageViewCreateFlagBits
Synopsis
- type ImageViewCreateFlags = ImageViewCreateFlagBits
- newtype ImageViewCreateFlagBits where
- ImageViewCreateFlagBits Flags
- pattern IMAGE_VIEW_CREATE_FRAGMENT_DENSITY_MAP_DEFERRED_BIT_EXT :: ImageViewCreateFlagBits
- pattern IMAGE_VIEW_CREATE_DESCRIPTOR_BUFFER_CAPTURE_REPLAY_BIT_EXT :: ImageViewCreateFlagBits
- pattern IMAGE_VIEW_CREATE_FRAGMENT_DENSITY_MAP_DYNAMIC_BIT_EXT :: ImageViewCreateFlagBits
Documentation
newtype ImageViewCreateFlagBits Source #
VkImageViewCreateFlagBits - Bitmask specifying additional parameters of an image view
Description
IMAGE_VIEW_CREATE_FRAGMENT_DENSITY_MAP_DYNAMIC_BIT_EXTspecifies that the fragment density map will be read by device duringPIPELINE_STAGE_FRAGMENT_DENSITY_PROCESS_BIT_EXT
IMAGE_VIEW_CREATE_FRAGMENT_DENSITY_MAP_DEFERRED_BIT_EXTspecifies that the fragment density map will be read by the host duringendCommandBufferfor the primary command buffer that the render pass is recorded intoIMAGE_VIEW_CREATE_DESCRIPTOR_BUFFER_CAPTURE_REPLAY_BIT_EXTspecifies that the image view can be used with descriptor buffers when capturing and replaying (e.g. for trace capture and replay), seeOpaqueCaptureDescriptorDataCreateInfoEXTfor more detail.
See Also
Constructors
| ImageViewCreateFlagBits Flags |
Bundled Patterns