| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.InstanceCreateFlagBits
Synopsis
Documentation
newtype InstanceCreateFlagBits Source #
VkInstanceCreateFlagBits - Bitmask specifying behavior of the instance
Description
INSTANCE_CREATE_ENUMERATE_PORTABILITY_BIT_KHRspecifies that the instance will enumerate available Vulkan Portability-compliant physical devices and groups in addition to the Vulkan physical devices and groups that are enumerated by default.
See Also
Constructors
| InstanceCreateFlagBits Flags |
Bundled Patterns
| pattern INSTANCE_CREATE_ENUMERATE_PORTABILITY_BIT_KHR :: InstanceCreateFlagBits |