| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.MemoryHeapFlagBits
Synopsis
- type MemoryHeapFlags = MemoryHeapFlagBits
- newtype MemoryHeapFlagBits where
Documentation
type MemoryHeapFlags = MemoryHeapFlagBits Source #
newtype MemoryHeapFlagBits Source #
VkMemoryHeapFlagBits - Bitmask specifying attribute flags for a heap
Description
MEMORY_HEAP_DEVICE_LOCAL_BITspecifies that the heap corresponds to device-local memory. Device-local memory may have different performance characteristics than host-local memory, and may support different memory property flags.
MEMORY_HEAP_MULTI_INSTANCE_BITspecifies that in a logical device representing more than one physical device, there is a per-physical device instance of the heap memory. By default, an allocation from such a heap will be replicated to each physical device’s instance of the heap.MEMORY_HEAP_TILE_MEMORY_BIT_QCOMbit specifies that the heap corresponds to tile memory.
See Also
Constructors
| MemoryHeapFlagBits Flags |
Bundled Patterns
| pattern MEMORY_HEAP_DEVICE_LOCAL_BIT :: MemoryHeapFlagBits | |
| pattern MEMORY_HEAP_TILE_MEMORY_BIT_QCOM :: MemoryHeapFlagBits | |
| pattern MEMORY_HEAP_SEU_SAFE_BIT :: MemoryHeapFlagBits | |
| pattern MEMORY_HEAP_MULTI_INSTANCE_BIT :: MemoryHeapFlagBits |