| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.MemoryMapFlagBits
Synopsis
- type MemoryMapFlags = MemoryMapFlagBits
- newtype MemoryMapFlagBits where
Documentation
type MemoryMapFlags = MemoryMapFlagBits Source #
newtype MemoryMapFlagBits Source #
VkMemoryMapFlagBits - Bitmask specifying additional parameters of a memory map
Description
MEMORY_MAP_PLACED_BIT_EXTrequests that the implementation place the memory map at the virtual address specified by the application viaMemoryMapPlacedInfoEXT::pPlacedAddress, replacing any existing mapping at that address. This flag must not be used withmapMemoryas there is no way to specify the placement address.
See Also
Constructors
| MemoryMapFlagBits Flags |
Bundled Patterns
| pattern MEMORY_MAP_PLACED_BIT_EXT :: MemoryMapFlagBits |