| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.PipelineCacheCreateFlagBits
Synopsis
- type PipelineCacheCreateFlags = PipelineCacheCreateFlagBits
- newtype PipelineCacheCreateFlagBits where
- PipelineCacheCreateFlagBits Flags
- pattern PIPELINE_CACHE_CREATE_INTERNALLY_SYNCHRONIZED_MERGE_BIT_KHR :: PipelineCacheCreateFlagBits
- pattern PIPELINE_CACHE_CREATE_USE_APPLICATION_STORAGE_BIT :: PipelineCacheCreateFlagBits
- pattern PIPELINE_CACHE_CREATE_READ_ONLY_BIT :: PipelineCacheCreateFlagBits
- pattern PIPELINE_CACHE_CREATE_EXTERNALLY_SYNCHRONIZED_BIT :: PipelineCacheCreateFlagBits
Documentation
newtype PipelineCacheCreateFlagBits Source #
VkPipelineCacheCreateFlagBits - Bitmask specifying the behavior of the pipeline cache
Description
PIPELINE_CACHE_CREATE_EXTERNALLY_SYNCHRONIZED_BITspecifies that all commands that modify the createdPipelineCachewill be externally synchronized. When set, the implementation may skip any unnecessary processing needed to support simultaneous modification from multiple threads where allowed.
PIPELINE_CACHE_CREATE_INTERNALLY_SYNCHRONIZED_MERGE_BIT_KHRspecifies that when the createdPipelineCacheis used as thedstCacheparameter ofmergePipelineCaches, it does not need to be externally synchronized. This flag is mutually exclusive withPIPELINE_CACHE_CREATE_EXTERNALLY_SYNCHRONIZED_BIT.
See Also
VK_EXT_pipeline_creation_cache_control,
VK_KHR_maintenance8,
VK_VERSION_1_3,
PipelineCacheCreateFlags
Constructors
| PipelineCacheCreateFlagBits Flags |
Bundled Patterns