| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.PipelineLayoutCreateFlagBits
Documentation
newtype PipelineLayoutCreateFlagBits Source #
VkPipelineLayoutCreateFlagBits - Pipeline layout creation flag bits
Description
PIPELINE_LAYOUT_CREATE_INDEPENDENT_SETS_BIT_EXTspecifies that implementations must ensure that the properties and/or absence of a particular descriptor set do not influence any other properties of the pipeline layout. This allows pipelines libraries linked withoutPIPELINE_CREATE_LINK_TIME_OPTIMIZATION_BIT_EXTto be created with a subset of the total descriptor sets.
See Also
Constructors
| PipelineLayoutCreateFlagBits Flags |
Bundled Patterns
| pattern PIPELINE_LAYOUT_CREATE_INDEPENDENT_SETS_BIT_EXT :: PipelineLayoutCreateFlagBits |