vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Core10.Enums.PrimitiveTopology

Synopsis

Documentation

newtype PrimitiveTopology Source #

VkPrimitiveTopology - Supported primitive topologies

Description

Each primitive topology, and its construction from a list of vertices, is described in detail below with a supporting diagram, according to the following key:

VertexA point in 3-dimensional space. Positions chosen within the diagrams are arbitrary and for illustration only.
Vertex NumberSequence position of a vertex within the provided vertex data.
Provoking VertexProvoking vertex within the main primitive. The tail is angled towards the relevant primitive. Used in flat shading.
Primitive EdgeAn edge connecting the points of a main primitive.
Adjacency EdgePoints connected by these lines do not contribute to a main primitive, and are only accessible in a geometry shader.
Winding Order The relative order in which vertices are defined within a primitive, used in the facing determination. This ordering has no specific start or end point.

The diagrams are supported with mathematical definitions where the vertices (v) and primitives (p) are numbered starting from 0; v0 is the first vertex in the provided data and p0 is the first primitive in the set of primitives defined by the vertices and topology.

See Also

VK_VERSION_1_0, PipelineInputAssemblyStateCreateInfo, cmdSetPrimitiveTopology, cmdSetPrimitiveTopology

Constructors

PrimitiveTopology Int32 

Instances

Instances details
Eq PrimitiveTopology Source # 
Instance details

Defined in Vulkan.Core10.Enums.PrimitiveTopology

Ord PrimitiveTopology Source # 
Instance details

Defined in Vulkan.Core10.Enums.PrimitiveTopology

Storable PrimitiveTopology Source # 
Instance details

Defined in Vulkan.Core10.Enums.PrimitiveTopology

Read PrimitiveTopology Source # 
Instance details

Defined in Vulkan.Core10.Enums.PrimitiveTopology

Show PrimitiveTopology Source # 
Instance details

Defined in Vulkan.Core10.Enums.PrimitiveTopology

Zero PrimitiveTopology Source # 
Instance details

Defined in Vulkan.Core10.Enums.PrimitiveTopology