| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.QueryPoolCreateFlagBits
Synopsis
Documentation
newtype QueryPoolCreateFlagBits Source #
VkQueryPoolCreateFlagBits - Bitmask specifying query pool properties
Description
QUERY_POOL_CREATE_RESET_BIT_KHRspecifies that queries in the query pool are initialized on creation and do not need to be reset before first use.
See Also
Constructors
| QueryPoolCreateFlagBits Flags |
Bundled Patterns
| pattern QUERY_POOL_CREATE_RESET_BIT_KHR :: QueryPoolCreateFlagBits |