| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.QueryResultFlagBits
Synopsis
- type QueryResultFlags = QueryResultFlagBits
- newtype QueryResultFlagBits where
Documentation
newtype QueryResultFlagBits Source #
VkQueryResultFlagBits - Bitmask specifying how and when query results are returned
Description
QUERY_RESULT_64_BITspecifies the results will be written as an array of 64-bit unsigned integer values. If this bit is not set, the results will be written as an array of 32-bit unsigned integer values.
QUERY_RESULT_WAIT_BITspecifies that Vulkan will wait for each query’s status to become available before retrieving its results.QUERY_RESULT_WITH_AVAILABILITY_BITspecifies that the availability status accompanies the results.QUERY_RESULT_PARTIAL_BITspecifies that returning partial results is acceptable.- VK_QUERY_RESULT_WITH_STATUS_BIT_KHR specifies that the last value returned in the query is a VkQueryResultStatusKHR value. See result status query for information on how an application can determine whether the use of this flag bit is supported.
See Also
Constructors
| QueryResultFlagBits Flags |
Bundled Patterns
| pattern QUERY_RESULT_64_BIT :: QueryResultFlagBits | |
| pattern QUERY_RESULT_WAIT_BIT :: QueryResultFlagBits | |
| pattern QUERY_RESULT_WITH_AVAILABILITY_BIT :: QueryResultFlagBits | |
| pattern QUERY_RESULT_PARTIAL_BIT :: QueryResultFlagBits |