| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.SamplerCreateFlagBits
Synopsis
- type SamplerCreateFlags = SamplerCreateFlagBits
- newtype SamplerCreateFlagBits where
- SamplerCreateFlagBits Flags
- pattern SAMPLER_CREATE_IMAGE_PROCESSING_BIT_QCOM :: SamplerCreateFlagBits
- pattern SAMPLER_CREATE_NON_SEAMLESS_CUBE_MAP_BIT_EXT :: SamplerCreateFlagBits
- pattern SAMPLER_CREATE_DESCRIPTOR_BUFFER_CAPTURE_REPLAY_BIT_EXT :: SamplerCreateFlagBits
- pattern SAMPLER_CREATE_SUBSAMPLED_COARSE_RECONSTRUCTION_BIT_EXT :: SamplerCreateFlagBits
- pattern SAMPLER_CREATE_SUBSAMPLED_BIT_EXT :: SamplerCreateFlagBits
Documentation
newtype SamplerCreateFlagBits Source #
VkSamplerCreateFlagBits - Bitmask specifying additional parameters of sampler
Description
-
SAMPLER_CREATE_SUBSAMPLED_BIT_EXTspecifies that the sampler will read from an image created withflagscontainingIMAGE_CREATE_SUBSAMPLED_BIT_EXT.
SAMPLER_CREATE_SUBSAMPLED_COARSE_RECONSTRUCTION_BIT_EXTspecifies that the implementation may use approximations when reconstructing a full color value for texture access from a subsampled image.SAMPLER_CREATE_NON_SEAMLESS_CUBE_MAP_BIT_EXTspecifies that cube map edge handling is not performed.-
SAMPLER_CREATE_IMAGE_PROCESSING_BIT_QCOMspecifies that the sampler will read from images using onlyOpImageSampleWeightedQCOM,OpImageBoxFilterQCOM,OpImageBlockMatchGatherSSDQCOM,OpImageBlockMatchGatherSADQCOM,OpImageBlockMatchWindowSSDQCOM,OpImageBlockMatchWindowSADQCOM,OpImageBlockMatchSSDQCOM, orOpImageBlockMatchSADQCOM.
The approximations used when
SAMPLER_CREATE_SUBSAMPLED_COARSE_RECONSTRUCTION_BIT_EXT is specified
are implementation defined. Some implementations may interpolate
between fragment density levels in a subsampled image. In that case,
this bit may be used to decide whether the interpolation factors are
calculated per fragment or at a coarser granularity.
SAMPLER_CREATE_DESCRIPTOR_BUFFER_CAPTURE_REPLAY_BIT_EXTspecifies that the sampler can be used with descriptor buffers when capturing and replaying (e.g. for trace capture and replay), seeOpaqueCaptureDescriptorDataCreateInfoEXTfor more detail.
See Also
Constructors
| SamplerCreateFlagBits Flags |
Bundled Patterns