| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.SparseImageFormatFlagBits
Synopsis
- type SparseImageFormatFlags = SparseImageFormatFlagBits
- newtype SparseImageFormatFlagBits where
Documentation
newtype SparseImageFormatFlagBits Source #
VkSparseImageFormatFlagBits - Bitmask specifying additional information about a sparse image resource
Description
SPARSE_IMAGE_FORMAT_SINGLE_MIPTAIL_BITspecifies that the image uses a single mip tail region for all array layers.
SPARSE_IMAGE_FORMAT_ALIGNED_MIP_SIZE_BITspecifies that the first mip level whose dimensions are not integer multiples of the corresponding dimensions of the sparse image block begins the mip tail region.SPARSE_IMAGE_FORMAT_NONSTANDARD_BLOCK_SIZE_BITspecifies that the image uses non-standard sparse image block dimensions, and theimageGranularityvalues do not match the standard sparse image block dimensions for the given format.
See Also
Constructors
| SparseImageFormatFlagBits Flags |
Bundled Patterns