| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.StencilFaceFlagBits
Synopsis
- pattern STENCIL_FRONT_AND_BACK :: StencilFaceFlagBits
- type StencilFaceFlags = StencilFaceFlagBits
- newtype StencilFaceFlagBits where
Documentation
pattern STENCIL_FRONT_AND_BACK :: StencilFaceFlagBits Source #
newtype StencilFaceFlagBits Source #
VkStencilFaceFlagBits - Bitmask specifying sets of stencil state for which to update the compare mask
Description
STENCIL_FACE_FRONT_BITspecifies that only the front set of stencil state is updated.
STENCIL_FACE_BACK_BITspecifies that only the back set of stencil state is updated.STENCIL_FACE_FRONT_AND_BACKis the combination ofSTENCIL_FACE_FRONT_BITandSTENCIL_FACE_BACK_BIT, and specifies that both sets of stencil state are updated.
See Also
Constructors
| StencilFaceFlagBits Flags |
Bundled Patterns
| pattern STENCIL_FACE_FRONT_BIT :: StencilFaceFlagBits | |
| pattern STENCIL_FACE_BACK_BIT :: StencilFaceFlagBits | |
| pattern STENCIL_FACE_FRONT_AND_BACK :: StencilFaceFlagBits |