vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Core11.Enums.ChromaLocation

Synopsis

Documentation

newtype ChromaLocation Source #

VkChromaLocation - Position of downsampled chroma samples

Description

  • CHROMA_LOCATION_MIDPOINT specifies that downsampled chroma samples are located half way between each even luma sample and the nearest higher odd luma sample.

See Also

VK_KHR_sampler_ycbcr_conversion, VK_VERSION_1_1, AndroidHardwareBufferFormatProperties2ANDROID, AndroidHardwareBufferFormatPropertiesANDROID, BufferCollectionPropertiesFUCHSIA, VkNativeBufferFormatPropertiesOHOS, PhysicalDeviceExternalFormatResolvePropertiesANDROID, SamplerYcbcrConversionCreateInfo, ScreenBufferFormatPropertiesQNX

Constructors

ChromaLocation Int32 

Instances

Instances details
Eq ChromaLocation Source # 
Instance details

Defined in Vulkan.Core11.Enums.ChromaLocation

Ord ChromaLocation Source # 
Instance details

Defined in Vulkan.Core11.Enums.ChromaLocation

Storable ChromaLocation Source # 
Instance details

Defined in Vulkan.Core11.Enums.ChromaLocation

Read ChromaLocation Source # 
Instance details

Defined in Vulkan.Core11.Enums.ChromaLocation

Show ChromaLocation Source # 
Instance details

Defined in Vulkan.Core11.Enums.ChromaLocation

Zero ChromaLocation Source # 
Instance details

Defined in Vulkan.Core11.Enums.ChromaLocation