| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core11.Enums.ExternalSemaphoreFeatureFlagBits
Synopsis
Documentation
newtype ExternalSemaphoreFeatureFlagBits Source #
VkExternalSemaphoreFeatureFlagBits - Bitfield describing features of an external semaphore handle type
Description
EXTERNAL_SEMAPHORE_FEATURE_EXPORTABLE_BITspecifies that handles of this type can be exported from Vulkan semaphore objects.
EXTERNAL_SEMAPHORE_FEATURE_IMPORTABLE_BITspecifies that handles of this type can be imported as Vulkan semaphore objects.
See Also
VK_KHR_external_semaphore_capabilities,
VK_VERSION_1_1,
ExternalSemaphoreFeatureFlags
Constructors
| ExternalSemaphoreFeatureFlagBits Flags |
Bundled Patterns
| pattern EXTERNAL_SEMAPHORE_FEATURE_EXPORTABLE_BIT :: ExternalSemaphoreFeatureFlagBits | |
| pattern EXTERNAL_SEMAPHORE_FEATURE_IMPORTABLE_BIT :: ExternalSemaphoreFeatureFlagBits |