| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core11.Enums.FenceImportFlagBits
Synopsis
- type FenceImportFlags = FenceImportFlagBits
- newtype FenceImportFlagBits where
Documentation
newtype FenceImportFlagBits Source #
VkFenceImportFlagBits - Bitmask specifying additional parameters of fence payload import
Description
FENCE_IMPORT_TEMPORARY_BITspecifies that the fence payload will be imported only temporarily, as described in Importing Fence Payloads, regardless of the permanence ofhandleType.
See Also
Constructors
| FenceImportFlagBits Flags |
Bundled Patterns
| pattern FENCE_IMPORT_TEMPORARY_BIT :: FenceImportFlagBits |