| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core11.Enums.MemoryAllocateFlagBits
Synopsis
- type MemoryAllocateFlags = MemoryAllocateFlagBits
- newtype MemoryAllocateFlagBits where
- MemoryAllocateFlagBits Flags
- pattern MEMORY_ALLOCATE_DEVICE_MASK_BIT :: MemoryAllocateFlagBits
- pattern MEMORY_ALLOCATE_ZERO_INITIALIZE_BIT_EXT :: MemoryAllocateFlagBits
- pattern MEMORY_ALLOCATE_DEVICE_ADDRESS_CAPTURE_REPLAY_BIT :: MemoryAllocateFlagBits
- pattern MEMORY_ALLOCATE_DEVICE_ADDRESS_BIT :: MemoryAllocateFlagBits
Documentation
newtype MemoryAllocateFlagBits Source #
VkMemoryAllocateFlagBits - Bitmask specifying flags for a device memory allocation
Description
MEMORY_ALLOCATE_DEVICE_MASK_BITspecifies that memory will be allocated for the devices inMemoryAllocateFlagsInfo::deviceMask.
MEMORY_ALLOCATE_DEVICE_ADDRESS_BITspecifies that the memory can be attached to a buffer object created with theBUFFER_USAGE_SHADER_DEVICE_ADDRESS_BITusage flag set.MEMORY_ALLOCATE_DEVICE_ADDRESS_CAPTURE_REPLAY_BITspecifies that the memory’s address can be saved and reused on a subsequent run (e.g. for trace capture and replay), seeBufferOpaqueCaptureAddressCreateInfofor more detail. If this bit is set,MEMORY_ALLOCATE_DEVICE_ADDRESS_BITmust also be set.MEMORY_ALLOCATE_ZERO_INITIALIZE_BIT_EXTspecifies that the memory will be zeroed automatically by the implementation before application is able to access it.
See Also
Constructors
| MemoryAllocateFlagBits Flags |
Bundled Patterns