| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core11.Enums.PeerMemoryFeatureFlagBits
Synopsis
- type PeerMemoryFeatureFlags = PeerMemoryFeatureFlagBits
- newtype PeerMemoryFeatureFlagBits where
- PeerMemoryFeatureFlagBits Flags
- pattern PEER_MEMORY_FEATURE_COPY_SRC_BIT :: PeerMemoryFeatureFlagBits
- pattern PEER_MEMORY_FEATURE_COPY_DST_BIT :: PeerMemoryFeatureFlagBits
- pattern PEER_MEMORY_FEATURE_GENERIC_SRC_BIT :: PeerMemoryFeatureFlagBits
- pattern PEER_MEMORY_FEATURE_GENERIC_DST_BIT :: PeerMemoryFeatureFlagBits
Documentation
newtype PeerMemoryFeatureFlagBits Source #
VkPeerMemoryFeatureFlagBits - Bitmask specifying supported peer memory features
Description
PEER_MEMORY_FEATURE_COPY_SRC_BITspecifies that the memory can be accessed as the source of anyvkCmdCopy*command.
PEER_MEMORY_FEATURE_COPY_DST_BITspecifies that the memory can be accessed as the destination of anyvkCmdCopy*command.PEER_MEMORY_FEATURE_GENERIC_SRC_BITspecifies that the memory can be read as any memory access type.PEER_MEMORY_FEATURE_GENERIC_DST_BITspecifies that the memory can be written as any memory access type. Shader atomics are considered to be writes.
The peer memory features of a memory heap also apply to any accesses that may be performed during image layout transitions.
PEER_MEMORY_FEATURE_COPY_DST_BIT must be supported for all host
local heaps and for at least one device-local memory heap.
If a device does not support a peer memory feature, it is still valid to use a resource that includes both local and peer memory bindings with the corresponding access type as long as only the local bindings are actually accessed. For example, an application doing split-frame rendering would use framebuffer attachments that include both local and peer memory bindings, but would scissor the rendering to only update local memory.
See Also
Constructors
| PeerMemoryFeatureFlagBits Flags |
Bundled Patterns