| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core11.Enums.PointClippingBehavior
Synopsis
Documentation
newtype PointClippingBehavior Source #
VkPointClippingBehavior - Enum specifying the point clipping behavior
Description
POINT_CLIPPING_BEHAVIOR_ALL_CLIP_PLANESspecifies that the primitive is discarded if the vertex lies outside any clip plane, including the planes bounding the view volume.
POINT_CLIPPING_BEHAVIOR_USER_CLIP_PLANES_ONLYspecifies that the primitive is discarded only if the vertex lies outside any user clip plane.
See Also
VK_KHR_maintenance2,
VK_VERSION_1_1,
PhysicalDevicePointClippingProperties,
PhysicalDeviceVulkan11Properties
Constructors
| PointClippingBehavior Int32 |
Bundled Patterns
| pattern POINT_CLIPPING_BEHAVIOR_ALL_CLIP_PLANES :: PointClippingBehavior | |
| pattern POINT_CLIPPING_BEHAVIOR_USER_CLIP_PLANES_ONLY :: PointClippingBehavior |