| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core11.Enums.SemaphoreImportFlagBits
Synopsis
Documentation
newtype SemaphoreImportFlagBits Source #
VkSemaphoreImportFlagBits - Bitmask specifying additional parameters of semaphore payload import
Description
These bits have the following meanings:
SEMAPHORE_IMPORT_TEMPORARY_BITspecifies that the semaphore payload will be imported only temporarily, as described in Importing Semaphore Payloads, regardless of the permanence ofhandleType.
See Also
VK_KHR_external_semaphore,
VK_VERSION_1_1,
SemaphoreImportFlags
Constructors
| SemaphoreImportFlagBits Flags |
Bundled Patterns
| pattern SEMAPHORE_IMPORT_TEMPORARY_BIT :: SemaphoreImportFlagBits |