| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core12.Enums.SamplerReductionMode
Synopsis
- newtype SamplerReductionMode where
- SamplerReductionMode Int32
- pattern SAMPLER_REDUCTION_MODE_WEIGHTED_AVERAGE :: SamplerReductionMode
- pattern SAMPLER_REDUCTION_MODE_MIN :: SamplerReductionMode
- pattern SAMPLER_REDUCTION_MODE_MAX :: SamplerReductionMode
- pattern SAMPLER_REDUCTION_MODE_WEIGHTED_AVERAGE_RANGECLAMP_QCOM :: SamplerReductionMode
Documentation
newtype SamplerReductionMode Source #
VkSamplerReductionMode - Specify reduction mode for texture filtering
Description
SAMPLER_REDUCTION_MODE_WEIGHTED_AVERAGEspecifies that texel values are combined by computing a weighted average of values in the footprint, using weights as specified in the image operations chapter.
SAMPLER_REDUCTION_MODE_MINspecifies that texel values are combined by taking the component-wise minimum of values in the footprint with non-zero weights.SAMPLER_REDUCTION_MODE_MAXspecifies that texel values are combined by taking the component-wise maximum of values in the footprint with non-zero weights.SAMPLER_REDUCTION_MODE_WEIGHTED_AVERAGE_RANGECLAMP_QCOMspecifies values are combined as described bySAMPLER_REDUCTION_MODE_WEIGHTED_AVERAGE, followed by a texel range clamp.
See Also
VK_EXT_sampler_filter_minmax,
VK_VERSION_1_2,
SamplerReductionModeCreateInfo
Constructors
| SamplerReductionMode Int32 |
Bundled Patterns