| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core12.Enums.SemaphoreWaitFlagBits
Synopsis
- type SemaphoreWaitFlags = SemaphoreWaitFlagBits
- newtype SemaphoreWaitFlagBits where
Documentation
newtype SemaphoreWaitFlagBits Source #
VkSemaphoreWaitFlagBits - Bitmask specifying additional parameters of a semaphore wait operation
Description
SEMAPHORE_WAIT_ANY_BITspecifies that the semaphore wait condition is that at least one of the semaphores inSemaphoreWaitInfo::pSemaphoreshas reached the value specified by the corresponding element ofSemaphoreWaitInfo::pValues. IfSEMAPHORE_WAIT_ANY_BITis not set, the semaphore wait condition is that all of the semaphores inSemaphoreWaitInfo::pSemaphoreshave reached the value specified by the corresponding element ofSemaphoreWaitInfo::pValues.
See Also
VK_KHR_timeline_semaphore,
VK_VERSION_1_2,
SemaphoreWaitFlags
Constructors
| SemaphoreWaitFlagBits Flags |
Bundled Patterns
| pattern SEMAPHORE_WAIT_ANY_BIT :: SemaphoreWaitFlagBits |