| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core12.Enums.ShaderFloatControlsIndependence
Synopsis
- newtype ShaderFloatControlsIndependence where
Documentation
newtype ShaderFloatControlsIndependence Source #
VkShaderFloatControlsIndependence - Bitmask specifying whether, and how, shader float controls can be set separately
Description
SHADER_FLOAT_CONTROLS_INDEPENDENCE_32_BIT_ONLYspecifies that shader float controls for 32-bit floating-point can be set independently; other bit widths must be set identically to each other.
SHADER_FLOAT_CONTROLS_INDEPENDENCE_ALLspecifies that shader float controls for all bit widths can be set independently.SHADER_FLOAT_CONTROLS_INDEPENDENCE_NONEspecifies that shader float controls for all bit widths must be set identically.
See Also
VK_KHR_shader_float_controls,
VK_VERSION_1_2,
PhysicalDeviceFloatControlsProperties,
PhysicalDeviceVulkan12Properties
Constructors
| ShaderFloatControlsIndependence Int32 |
Bundled Patterns