| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core13.Enums.FormatFeatureFlags2
Synopsis
- type FormatFeatureFlags2 = FormatFeatureFlagBits2
- newtype FormatFeatureFlagBits2 where
- FormatFeatureFlagBits2 Flags64
- pattern FORMAT_FEATURE_2_SAMPLED_IMAGE_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_STORAGE_IMAGE_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_STORAGE_IMAGE_ATOMIC_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_UNIFORM_TEXEL_BUFFER_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_STORAGE_TEXEL_BUFFER_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_STORAGE_TEXEL_BUFFER_ATOMIC_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_VERTEX_BUFFER_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_COLOR_ATTACHMENT_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_COLOR_ATTACHMENT_BLEND_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_DEPTH_STENCIL_ATTACHMENT_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_BLIT_SRC_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_BLIT_DST_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_SAMPLED_IMAGE_FILTER_LINEAR_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_TRANSFER_SRC_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_TRANSFER_DST_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_SAMPLED_IMAGE_FILTER_MINMAX_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_MIDPOINT_CHROMA_SAMPLES_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_SAMPLED_IMAGE_YCBCR_CONVERSION_LINEAR_FILTER_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_SAMPLED_IMAGE_YCBCR_CONVERSION_SEPARATE_RECONSTRUCTION_FILTER_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_FORCEABLE_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_DISJOINT_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_COSITED_CHROMA_SAMPLES_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_STORAGE_READ_WITHOUT_FORMAT_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_STORAGE_WRITE_WITHOUT_FORMAT_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_SAMPLED_IMAGE_DEPTH_COMPARISON_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_STENCIL_COPY_ON_TRANSFER_QUEUE_BIT_KHR :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_STENCIL_COPY_ON_COMPUTE_QUEUE_BIT_KHR :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_DEPTH_COPY_ON_TRANSFER_QUEUE_BIT_KHR :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_DEPTH_COPY_ON_COMPUTE_QUEUE_BIT_KHR :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_COPY_IMAGE_INDIRECT_DST_BIT_KHR :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_TENSOR_DATA_GRAPH_BIT_ARM :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_OPTICAL_FLOW_COST_BIT_NV :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_OPTICAL_FLOW_VECTOR_BIT_NV :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_OPTICAL_FLOW_IMAGE_BIT_NV :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_TENSOR_IMAGE_ALIASING_BIT_ARM :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_TENSOR_SHADER_BIT_ARM :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_BOX_FILTER_SAMPLED_BIT_QCOM :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_BLOCK_MATCHING_BIT_QCOM :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_WEIGHT_SAMPLED_IMAGE_BIT_QCOM :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_WEIGHT_IMAGE_BIT_QCOM :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_LINEAR_COLOR_ATTACHMENT_BIT_NV :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_ACCELERATION_STRUCTURE_RADIUS_BUFFER_BIT_NV :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHR :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_FRAGMENT_DENSITY_MAP_BIT_EXT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_ACCELERATION_STRUCTURE_VERTEX_BUFFER_BIT_KHR :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_HOST_IMAGE_TRANSFER_BIT :: FormatFeatureFlagBits2
- pattern FORMAT_FEATURE_2_SAMPLED_IMAGE_FILTER_CUBIC_BIT :: FormatFeatureFlagBits2
Documentation
newtype FormatFeatureFlagBits2 Source #
VkFormatFeatureFlagBits2 - Bitmask specifying features supported by a buffer
Description
The following bits may be set in linearTilingFeatures and
optimalTilingFeatures, specifying that the features are supported by
images or image views or
sampler Y′CBCR conversion objects
created with the queried
getPhysicalDeviceFormatProperties2::format:
FORMAT_FEATURE_2_SAMPLED_IMAGE_BITspecifies that an image view can be sampled from.FORMAT_FEATURE_2_STORAGE_IMAGE_BITspecifies that an image view can be used as a storage image.FORMAT_FEATURE_2_STORAGE_IMAGE_ATOMIC_BITspecifies that an image view can be used as storage image that supports atomic operations.FORMAT_FEATURE_2_COLOR_ATTACHMENT_BITspecifies that an image view can be used as a framebuffer color attachment and as an input attachment.FORMAT_FEATURE_2_COLOR_ATTACHMENT_BLEND_BITspecifies that an image view can be used as a framebuffer color attachment that supports blending.FORMAT_FEATURE_2_DEPTH_STENCIL_ATTACHMENT_BITspecifies that an image view can be used as a framebuffer depth/stencil attachment and as an input attachment.FORMAT_FEATURE_2_BLIT_SRC_BITspecifies that an image can be used as thesrcImageforcmdBlitImage2andcmdBlitImage.FORMAT_FEATURE_2_BLIT_DST_BITspecifies that an image can be used as thedstImageforcmdBlitImage2andcmdBlitImage.FORMAT_FEATURE_2_SAMPLED_IMAGE_FILTER_LINEAR_BITspecifies that ifFORMAT_FEATURE_2_SAMPLED_IMAGE_BITis also set, an image view can be used with a sampler that has either ofmagFilterorminFilterset toFILTER_LINEAR, ormipmapModeset toSAMPLER_MIPMAP_MODE_LINEAR. IfFORMAT_FEATURE_2_BLIT_SRC_BITis also set, an image can be used as thesrcImageforcmdBlitImage2andcmdBlitImagewith afilterofFILTER_LINEAR. This bit must only be exposed for formats that also support theFORMAT_FEATURE_2_SAMPLED_IMAGE_BITorFORMAT_FEATURE_2_BLIT_SRC_BIT.If the format being queried is a depth/stencil format, this bit only specifies that the depth aspect (not the stencil aspect) of an image of this format supports linear filtering. Where depth comparison is supported it may be linear filtered whether this bit is present or not, but where this bit is not present the filtered value may be computed in an implementation-dependent manner which differs from the normal rules of linear filtering. The resulting value must be in the range [0,1] and should be proportional to, or a weighted average of, the number of comparison passes or failures.
FORMAT_FEATURE_2_TRANSFER_SRC_BITspecifies that an image can be used as a source image for copy commands.FORMAT_FEATURE_2_TRANSFER_DST_BITspecifies that an image can be used as a destination image for copy commands and clear commands.FORMAT_FEATURE_2_SAMPLED_IMAGE_FILTER_MINMAX_BITspecifiesImagecan be used as a sampled image with a min or maxSamplerReductionMode. This bit must only be exposed for formats that also support theFORMAT_FEATURE_2_SAMPLED_IMAGE_BIT.FORMAT_FEATURE_2_SAMPLED_IMAGE_FILTER_CUBIC_BITspecifies thatImagecan be used with a sampler that has either ofmagFilterorminFilterset toFILTER_CUBIC_EXT, or be the source image for a blit withfilterset toFILTER_CUBIC_EXT. This bit must only be exposed for formats that also support theFORMAT_FEATURE_2_SAMPLED_IMAGE_BIT. If the format being queried is a depth/stencil format, this only specifies that the depth aspect is cubic filterable.FORMAT_FEATURE_2_MIDPOINT_CHROMA_SAMPLES_BITspecifies that an application can define a sampler Y′CBCR conversion using this format as a source, and that an image of this format can be used with aSamplerYcbcrConversionCreateInfoxChromaOffsetand/oryChromaOffsetofCHROMA_LOCATION_MIDPOINT. Otherwise bothxChromaOffsetandyChromaOffsetmust beCHROMA_LOCATION_COSITED_EVEN. If a format does not incorporate chroma downsampling (it is not a “422” or “420” format) but the implementation supports sampler Y′CBCR conversion for this format, the implementation must setFORMAT_FEATURE_2_MIDPOINT_CHROMA_SAMPLES_BIT.FORMAT_FEATURE_2_COSITED_CHROMA_SAMPLES_BITspecifies that an application can define a sampler Y′CBCR conversion using this format as a source, and that an image of this format can be used with aSamplerYcbcrConversionCreateInfoxChromaOffsetand/oryChromaOffsetofCHROMA_LOCATION_COSITED_EVEN. Otherwise bothxChromaOffsetandyChromaOffsetmust beCHROMA_LOCATION_MIDPOINT. If neitherFORMAT_FEATURE_2_COSITED_CHROMA_SAMPLES_BITnorFORMAT_FEATURE_2_MIDPOINT_CHROMA_SAMPLES_BITis set, the application must not define a sampler Y′CBCR conversion using this format as a source.FORMAT_FEATURE_2_SAMPLED_IMAGE_YCBCR_CONVERSION_LINEAR_FILTER_BITspecifies that an application can define a sampler Y′CBCR conversion using this format as a source withchromaFilterset toFILTER_LINEAR.FORMAT_FEATURE_2_SAMPLED_IMAGE_YCBCR_CONVERSION_SEPARATE_RECONSTRUCTION_FILTER_BITspecifies that the format can have different chroma, min, and mag filters.FORMAT_FEATURE_2_SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_BITspecifies that reconstruction is explicit, as described in https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#textures-chroma-reconstruction. If this bit is not present, reconstruction is implicit by default.FORMAT_FEATURE_2_SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_FORCEABLE_BITspecifies that reconstruction can be forcibly made explicit by settingSamplerYcbcrConversionCreateInfo::forceExplicitReconstructiontoTRUE. If the format being queried supportsFORMAT_FEATURE_2_SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_BITit must also supportFORMAT_FEATURE_2_SAMPLED_IMAGE_YCBCR_CONVERSION_CHROMA_RECONSTRUCTION_EXPLICIT_FORCEABLE_BIT.FORMAT_FEATURE_2_DISJOINT_BITspecifies that a multi-planar image can have theIMAGE_CREATE_DISJOINT_BITset during image creation. An implementation must not setFORMAT_FEATURE_2_DISJOINT_BITfor single-plane formats.FORMAT_FEATURE_2_FRAGMENT_DENSITY_MAP_BIT_EXTspecifies that an image view can be used as a fragment density map attachment.FORMAT_FEATURE_2_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHRspecifies that an image view can be used as a fragment shading rate attachment. An implementation must not set this feature for formats with a numeric format other thanUINT, or set it as a buffer feature.- VK_FORMAT_FEATURE_2_VIDEO_DECODE_OUTPUT_BIT_KHR specifies that an image view with this format can be used as a decode output picture in video decode operations.
- VK_FORMAT_FEATURE_2_VIDEO_DECODE_DPB_BIT_KHR specifies that an image view with this format can be used as an output reconstructed picture or an input reference picture in video decode operations.
- VK_FORMAT_FEATURE_2_VIDEO_ENCODE_INPUT_BIT_KHR specifies that an image view with this format can be used as an encode input picture in video encode operations.
- VK_FORMAT_FEATURE_2_VIDEO_ENCODE_DPB_BIT_KHR specifies that an image view with this format can be used as an output reconstructed picture or an input reference picture in video encode operations.
FORMAT_FEATURE_2_DEPTH_COPY_ON_COMPUTE_QUEUE_BIT_KHRspecifies that the depth aspect of this format can be copied using a queue family that supportsQUEUE_COMPUTE_BITbut does not supportQUEUE_GRAPHICS_BIT.FORMAT_FEATURE_2_DEPTH_COPY_ON_TRANSFER_QUEUE_BIT_KHRspecifies that the depth aspect of this format can be copied using a queue family that supportsQUEUE_TRANSFER_BITbut does not supportQUEUE_GRAPHICS_BITorQUEUE_COMPUTE_BIT.FORMAT_FEATURE_2_STENCIL_COPY_ON_COMPUTE_QUEUE_BIT_KHRspecifies that the stencil aspect of this format can be copied using a queue family that supportsQUEUE_COMPUTE_BITbut does not supportQUEUE_GRAPHICS_BIT.FORMAT_FEATURE_2_STENCIL_COPY_ON_TRANSFER_QUEUE_BIT_KHRspecifies that the stencil aspect of this format can be copied using a queue family that supportsQUEUE_TRANSFER_BITbut does not supportQUEUE_GRAPHICS_BITorQUEUE_COMPUTE_BIT.Specific video profiles may have additional restrictions on the format and other image creation parameters corresponding to image views used by video coding operations that can be enumerated using the vkGetPhysicalDeviceVideoFormatPropertiesKHR command.
FORMAT_FEATURE_2_STORAGE_READ_WITHOUT_FORMAT_BITspecifies that image views or buffer views created with this format can be used as storage images or storage texel buffers respectively for read operations without specifying a format.FORMAT_FEATURE_2_STORAGE_WRITE_WITHOUT_FORMAT_BITspecifies that image views or buffer views created with this format can be used as storage images or storage texel buffers respectively for write operations without specifying a format.FORMAT_FEATURE_2_SAMPLED_IMAGE_DEPTH_COMPARISON_BITspecifies that image views created with this format can be used for depth comparison performed byOpImage*Dref*instructions.FORMAT_FEATURE_2_LINEAR_COLOR_ATTACHMENT_BIT_NVspecifies that the format is supported as a renderable Linear Color Attachment. This bit will be set for renderable color formats in thelinearTilingFeatures. This must not be set in theoptimalTilingFeaturesorbufferFeaturesmembers.FORMAT_FEATURE_2_WEIGHT_IMAGE_BIT_QCOMspecifies that image views created with this format can be used as the weight image input to weight image sampling operations.FORMAT_FEATURE_2_WEIGHT_SAMPLED_IMAGE_BIT_QCOMspecifies that image views created with this format can be sampled in weight image sampling operations.FORMAT_FEATURE_2_BLOCK_MATCHING_BIT_QCOMspecifies that image views created with this format can be used in block matching operations.FORMAT_FEATURE_2_BOX_FILTER_SAMPLED_BIT_QCOMspecifies that image views created with this format can be sampled in box filter sampling operations.FORMAT_FEATURE_2_HOST_IMAGE_TRANSFER_BITspecifies that an image can be created with theIMAGE_USAGE_HOST_TRANSFER_BITusage flag set.FORMAT_FEATURE_2_COPY_IMAGE_INDIRECT_DST_BIT_KHRspecifies that aImagecan be used as destination for indirect copies.- VK_FORMAT_FEATURE_2_VIDEO_ENCODE_QUANTIZATION_DELTA_MAP_BIT_KHR specifies that an image view with this format can be used as a quantization delta map in video encode operations.
VK_FORMAT_FEATURE_2_VIDEO_ENCODE_EMPHASIS_MAP_BIT_KHR specifies that an image view with this format can be used as an emphasis map in video encode operations.
Video encode quantization maps have additional restrictions specific to the video profile they are used with that can be enumerated using the vkGetPhysicalDeviceVideoFormatPropertiesKHR command.
The following bits may be set in bufferFeatures, specifying that the
features are supported by buffers or
buffer views created with the queried
getPhysicalDeviceFormatProperties2::format:
FORMAT_FEATURE_2_UNIFORM_TEXEL_BUFFER_BITspecifies that the format can be used to create a buffer view that can be bound to aDESCRIPTOR_TYPE_UNIFORM_TEXEL_BUFFERdescriptor.FORMAT_FEATURE_2_STORAGE_TEXEL_BUFFER_BITspecifies that the format can be used to create a buffer view that can be bound to aDESCRIPTOR_TYPE_STORAGE_TEXEL_BUFFERdescriptor.FORMAT_FEATURE_2_STORAGE_TEXEL_BUFFER_ATOMIC_BITspecifies that atomic operations are supported onDESCRIPTOR_TYPE_STORAGE_TEXEL_BUFFERwith this format.FORMAT_FEATURE_2_VERTEX_BUFFER_BITspecifies that the format can be used as a vertex attribute format (VertexInputAttributeDescription::format).FORMAT_FEATURE_2_ACCELERATION_STRUCTURE_VERTEX_BUFFER_BIT_KHRspecifies that the format can be used as the vertex format when creating an acceleration structure (AccelerationStructureGeometryTrianglesDataKHR::vertexFormat). This format can also be used as the vertex format in host memory when doing host acceleration structure builds.FORMAT_FEATURE_2_ACCELERATION_STRUCTURE_RADIUS_BUFFER_BIT_NVspecifies that the format can be used as the radius format when creating an acceleration structure (AccelerationStructureGeometryLinearSweptSpheresDataNV::radiusFormatorAccelerationStructureGeometrySpheresDataNV::radiusFormat). This format can also be used as the radius format in host memory when doing host acceleration structure builds.FORMAT_FEATURE_2_STORAGE_READ_WITHOUT_FORMAT_BITspecifies that buffer views created with this format can be used as storage texel buffers for read operations without specifying a format.FORMAT_FEATURE_2_STORAGE_WRITE_WITHOUT_FORMAT_BITspecifies that buffer views created with this format can be used as storage texel buffers for write operations without specifying a format.FORMAT_FEATURE_2_OPTICAL_FLOW_IMAGE_BIT_NVspecifies that an image view with this format can be used as an input or reference to optical flow operationsFORMAT_FEATURE_2_OPTICAL_FLOW_VECTOR_BIT_NVspecifies that an image view with this format can be used as a flow vector map (either as hint, output or global flow) for optical flow operationsFORMAT_FEATURE_2_OPTICAL_FLOW_COST_BIT_NVspecifies that an image view with this format can be used as an output cost map for optical flow operations
See Also
VK_KHR_format_feature_flags2,
VK_VERSION_1_3,
FormatFeatureFlags2
Constructors
| FormatFeatureFlagBits2 Flags64 |
Bundled Patterns