| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core13.Enums.PipelineCreationFeedbackFlagBits
Synopsis
- type PipelineCreationFeedbackFlags = PipelineCreationFeedbackFlagBits
- newtype PipelineCreationFeedbackFlagBits where
- PipelineCreationFeedbackFlagBits Flags
- pattern PIPELINE_CREATION_FEEDBACK_VALID_BIT :: PipelineCreationFeedbackFlagBits
- pattern PIPELINE_CREATION_FEEDBACK_APPLICATION_PIPELINE_CACHE_HIT_BIT :: PipelineCreationFeedbackFlagBits
- pattern PIPELINE_CREATION_FEEDBACK_BASE_PIPELINE_ACCELERATION_BIT :: PipelineCreationFeedbackFlagBits
Documentation
newtype PipelineCreationFeedbackFlagBits Source #
VkPipelineCreationFeedbackFlagBits - Bitmask specifying pipeline or pipeline stage creation feedback
Description
PIPELINE_CREATION_FEEDBACK_VALID_BITspecifies that the feedback information is valid.
PIPELINE_CREATION_FEEDBACK_APPLICATION_PIPELINE_CACHE_HIT_BITspecifies that a readily usable pipeline or pipeline stage was found in thepipelineCachespecified by the application in the pipeline creation command.An implementation should set the
PIPELINE_CREATION_FEEDBACK_APPLICATION_PIPELINE_CACHE_HIT_BITbit if it was able to avoid the large majority of pipeline or pipeline stage creation work by using thepipelineCacheparameter ofcreateGraphicsPipelines,createRayTracingPipelinesKHR,createRayTracingPipelinesNV,createDataGraphPipelinesARM, orcreateComputePipelines. When an implementation sets this bit for the entire pipeline, it may leave it unset for any stage.Implementations are encouraged to provide a meaningful signal to applications using this bit. The intention is to communicate to the application that the pipeline or pipeline stage was created “as fast as it gets” using the pipeline cache provided by the application. If an implementation uses an internal cache, it is discouraged from setting this bit as the feedback would be unactionable.
PIPELINE_CREATION_FEEDBACK_BASE_PIPELINE_ACCELERATION_BITspecifies that the base pipeline specified by thebasePipelineHandleorbasePipelineIndexmember of theVk*PipelineCreateInfostructure was used to accelerate the creation of the pipeline.An implementation should set the
PIPELINE_CREATION_FEEDBACK_BASE_PIPELINE_ACCELERATION_BITbit if it was able to avoid a significant amount of work by using the base pipeline.While “significant amount of work” is subjective, implementations are encouraged to provide a meaningful signal to applications using this bit. For example, a 1% reduction in duration may not warrant setting this bit, while a 50% reduction would.
See Also
VK_EXT_pipeline_creation_feedback,
VK_VERSION_1_3,
PipelineCreationFeedback,
PipelineCreationFeedbackCreateInfo,
PipelineCreationFeedbackFlags
Constructors
| PipelineCreationFeedbackFlagBits Flags |
Bundled Patterns