| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core13.Enums.PipelineStageFlags2
Synopsis
- pattern PIPELINE_STAGE_2_TRANSFER_BIT :: PipelineStageFlagBits2
- type PipelineStageFlags2 = PipelineStageFlagBits2
- newtype PipelineStageFlagBits2 where
- PipelineStageFlagBits2 Flags64
- pattern PIPELINE_STAGE_2_NONE :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_TOP_OF_PIPE_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_DRAW_INDIRECT_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_VERTEX_INPUT_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_VERTEX_SHADER_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_TESSELLATION_CONTROL_SHADER_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_TESSELLATION_EVALUATION_SHADER_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_GEOMETRY_SHADER_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_FRAGMENT_SHADER_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_EARLY_FRAGMENT_TESTS_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_LATE_FRAGMENT_TESTS_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_COLOR_ATTACHMENT_OUTPUT_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_COMPUTE_SHADER_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_ALL_TRANSFER_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_BOTTOM_OF_PIPE_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_HOST_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_ALL_GRAPHICS_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_ALL_COMMANDS_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_COPY_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_RESOLVE_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_BLIT_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_CLEAR_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_INDEX_INPUT_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_VERTEX_ATTRIBUTE_INPUT_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_PRE_RASTERIZATION_SHADERS_BIT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_MEMORY_DECOMPRESSION_BIT_EXT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_COPY_INDIRECT_BIT_KHR :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_DATA_GRAPH_BIT_ARM :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_CONVERT_COOPERATIVE_VECTOR_MATRIX_BIT_NV :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_OPTICAL_FLOW_BIT_NV :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_CLUSTER_CULLING_SHADER_BIT_HUAWEI :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_MICROMAP_BUILD_BIT_EXT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_ACCELERATION_STRUCTURE_COPY_BIT_KHR :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_INVOCATION_MASK_BIT_HUAWEI :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_SUBPASS_SHADER_BIT_HUAWEI :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_MESH_SHADER_BIT_EXT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_TASK_SHADER_BIT_EXT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_FRAGMENT_DENSITY_PROCESS_BIT_EXT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_RAY_TRACING_SHADER_BIT_KHR :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_ACCELERATION_STRUCTURE_BUILD_BIT_KHR :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHR :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_COMMAND_PREPROCESS_BIT_EXT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_CONDITIONAL_RENDERING_BIT_EXT :: PipelineStageFlagBits2
- pattern PIPELINE_STAGE_2_TRANSFORM_FEEDBACK_BIT_EXT :: PipelineStageFlagBits2
Documentation
newtype PipelineStageFlagBits2 Source #
VkPipelineStageFlagBits2 - Pipeline stage flags for VkPipelineStageFlags2
Description
PIPELINE_STAGE_2_NONEspecifies no stages of execution.
PIPELINE_STAGE_2_DRAW_INDIRECT_BITspecifies the stage of the pipeline where indirect command parameters are consumed. This stage also includes reading commands written bycmdPreprocessGeneratedCommandsNV. This stage also includes reading commands written bycmdPreprocessGeneratedCommandsEXT.PIPELINE_STAGE_2_TASK_SHADER_BIT_EXTspecifies the task shader stage.PIPELINE_STAGE_2_MESH_SHADER_BIT_EXTspecifies the mesh shader stage.PIPELINE_STAGE_2_INDEX_INPUT_BITspecifies the stage of the pipeline where index buffers are consumed.PIPELINE_STAGE_2_VERTEX_ATTRIBUTE_INPUT_BITspecifies the stage of the pipeline where vertex buffers are consumed.PIPELINE_STAGE_2_VERTEX_INPUT_BITis equivalent to the logical OR of:PIPELINE_STAGE_2_VERTEX_SHADER_BITspecifies the vertex shader stage.PIPELINE_STAGE_2_TESSELLATION_CONTROL_SHADER_BITspecifies the tessellation control shader stage.PIPELINE_STAGE_2_TESSELLATION_EVALUATION_SHADER_BITspecifies the tessellation evaluation shader stage.PIPELINE_STAGE_2_GEOMETRY_SHADER_BITspecifies the geometry shader stage.PIPELINE_STAGE_2_PRE_RASTERIZATION_SHADERS_BITis equivalent to specifying all supported pre-rasterization shader stages:PIPELINE_STAGE_2_FRAGMENT_SHADER_BITspecifies the fragment shader stage.PIPELINE_STAGE_2_EARLY_FRAGMENT_TESTS_BITspecifies the stage of the pipeline where early fragment tests (depth and stencil tests before fragment shading) are performed. This stage also includes render pass load operations for framebuffer attachments with a depth/stencil format.PIPELINE_STAGE_2_LATE_FRAGMENT_TESTS_BITspecifies the stage of the pipeline where late fragment tests (depth and stencil tests after fragment shading) are performed. This stage also includes render pass store operations for framebuffer attachments with a depth/stencil format.PIPELINE_STAGE_2_COLOR_ATTACHMENT_OUTPUT_BITspecifies the stage of the pipeline where final color values are output from the pipeline. This stage includes blending, logic operations, render pass load and store operations for color attachments, render pass multisample resolve operations, andcmdClearAttachments.PIPELINE_STAGE_2_COMPUTE_SHADER_BITspecifies the compute shader stage.PIPELINE_STAGE_2_HOST_BITspecifies a pseudo-stage indicating execution on the host of reads/writes of device memory. This stage is not invoked by any commands recorded in a command buffer.PIPELINE_STAGE_2_COPY_BITspecifies the execution of all copy commands, includingcmdCopyQueryPoolResults.PIPELINE_STAGE_2_BLIT_BITspecifies the execution ofcmdBlitImage.PIPELINE_STAGE_2_RESOLVE_BITspecifies the execution ofcmdResolveImage.PIPELINE_STAGE_2_CLEAR_BITspecifies the execution of clear commands, with the exception ofcmdClearAttachments.PIPELINE_STAGE_2_ALL_TRANSFER_BITis equivalent to specifying all of:PIPELINE_STAGE_2_RAY_TRACING_SHADER_BIT_KHRspecifies the execution of the ray tracing shader stages.PIPELINE_STAGE_2_ACCELERATION_STRUCTURE_BUILD_BIT_KHRspecifies the execution of acceleration structure commands or acceleration structure copy commands.PIPELINE_STAGE_2_ACCELERATION_STRUCTURE_COPY_BIT_KHRspecifies the execution of acceleration structure copy commands.PIPELINE_STAGE_2_ALL_GRAPHICS_BITspecifies the execution of all graphics pipeline stages, and is equivalent to the logical OR of:PIPELINE_STAGE_2_DRAW_INDIRECT_BITPIPELINE_STAGE_2_COPY_INDIRECT_BIT_KHRPIPELINE_STAGE_2_TASK_SHADER_BIT_EXTPIPELINE_STAGE_2_MESH_SHADER_BIT_EXTPIPELINE_STAGE_2_VERTEX_INPUT_BITPIPELINE_STAGE_2_VERTEX_SHADER_BITPIPELINE_STAGE_2_TESSELLATION_CONTROL_SHADER_BITPIPELINE_STAGE_2_TESSELLATION_EVALUATION_SHADER_BITPIPELINE_STAGE_2_GEOMETRY_SHADER_BITPIPELINE_STAGE_2_FRAGMENT_SHADER_BITPIPELINE_STAGE_2_EARLY_FRAGMENT_TESTS_BITPIPELINE_STAGE_2_LATE_FRAGMENT_TESTS_BITPIPELINE_STAGE_2_COLOR_ATTACHMENT_OUTPUT_BITPIPELINE_STAGE_2_CONDITIONAL_RENDERING_BIT_EXTPIPELINE_STAGE_2_TRANSFORM_FEEDBACK_BIT_EXTPIPELINE_STAGE_2_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHRPIPELINE_STAGE_2_FRAGMENT_DENSITY_PROCESS_BIT_EXTPIPELINE_STAGE_2_SUBPASS_SHADER_BIT_HUAWEIPIPELINE_STAGE_2_INVOCATION_MASK_BIT_HUAWEIPIPELINE_STAGE_2_CLUSTER_CULLING_SHADER_BIT_HUAWEI
PIPELINE_STAGE_2_ALL_COMMANDS_BITspecifies all operations performed by all commands supported on the queue it is used with.PIPELINE_STAGE_2_CONDITIONAL_RENDERING_BIT_EXTspecifies the stage of the pipeline where the predicate of conditional rendering is consumed.PIPELINE_STAGE_2_TRANSFORM_FEEDBACK_BIT_EXTspecifies the stage of the pipeline where vertex attribute output values are written to the transform feedback buffers.PIPELINE_STAGE_2_COMMAND_PREPROCESS_BIT_NVspecifies the stage of the pipeline where device-side generation of commands viacmdPreprocessGeneratedCommandsNVis handled.PIPELINE_STAGE_2_COMMAND_PREPROCESS_BIT_EXTspecifies the stage of the pipeline where device-side generation of commands viacmdPreprocessGeneratedCommandsEXTis handled.PIPELINE_STAGE_2_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHRspecifies the stage of the pipeline where the fragment shading rate attachment or shading rate image is read to determine the fragment shading rate for portions of a rasterized primitive.PIPELINE_STAGE_2_FRAGMENT_DENSITY_PROCESS_BIT_EXTspecifies the stage of the pipeline where the fragment density map is read to generate the fragment areas.PIPELINE_STAGE_2_INVOCATION_MASK_BIT_HUAWEIspecifies the stage of the pipeline where the invocation mask image is read by the implementation to optimize the ray dispatch.- VK_PIPELINE_STAGE_2_VIDEO_DECODE_BIT_KHR specifies the execution of video decode operations.
- VK_PIPELINE_STAGE_2_VIDEO_ENCODE_BIT_KHR specifies the execution of video encode operations.
PIPELINE_STAGE_2_OPTICAL_FLOW_BIT_NVspecifies the stage of the pipeline where optical flow operation are performed.PIPELINE_STAGE_2_SUBPASS_SHADER_BIT_HUAWEIspecifies the subpass shading shader stage.PIPELINE_STAGE_2_MICROMAP_BUILD_BIT_EXTspecifies the execution of micromap commands.PIPELINE_STAGE_2_CLUSTER_CULLING_SHADER_BIT_HUAWEIspecifies the cluster culling shader stage.PIPELINE_STAGE_2_CONVERT_COOPERATIVE_VECTOR_MATRIX_BIT_NVspecifies the execution ofcmdConvertCooperativeVectorMatrixNV.PIPELINE_STAGE_2_COPY_INDIRECT_BIT_KHRspecifies the stage of the pipeline where indirect copy commands (vkCmdCopyMemoryIndirect* and vkCmdCopyMemoryToImageIndirect*) parameters are consumed.PIPELINE_STAGE_2_TOP_OF_PIPE_BITis equivalent toPIPELINE_STAGE_2_ALL_COMMANDS_BITwithAccessFlags2set to0when specified in the second synchronization scope, but equivalent toPIPELINE_STAGE_2_NONEin the first scope.PIPELINE_STAGE_2_BOTTOM_OF_PIPE_BITis equivalent toPIPELINE_STAGE_2_ALL_COMMANDS_BITwithAccessFlags2set to0when specified in the first synchronization scope, but equivalent toPIPELINE_STAGE_2_NONEin the second scope.
The TOP and BOTTOM pipeline stages are legacy, and applications
should prefer PIPELINE_STAGE_2_ALL_COMMANDS_BIT and
PIPELINE_STAGE_2_NONE.
The PipelineStageFlags2 bitmask goes beyond the 31 individual bit
flags allowable within a C99 enum, which is how
PipelineStageFlagBits is
defined. The first 31 values are common to both, and are
interchangeable.
See Also
VK_KHR_synchronization2,
VK_VERSION_1_3,
PipelineStageFlags2
Constructors
| PipelineStageFlagBits2 Flags64 |
Bundled Patterns