| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core13.Enums.ToolPurposeFlagBits
Synopsis
- type ToolPurposeFlags = ToolPurposeFlagBits
- newtype ToolPurposeFlagBits where
- ToolPurposeFlagBits Flags
- pattern TOOL_PURPOSE_VALIDATION_BIT :: ToolPurposeFlagBits
- pattern TOOL_PURPOSE_PROFILING_BIT :: ToolPurposeFlagBits
- pattern TOOL_PURPOSE_TRACING_BIT :: ToolPurposeFlagBits
- pattern TOOL_PURPOSE_ADDITIONAL_FEATURES_BIT :: ToolPurposeFlagBits
- pattern TOOL_PURPOSE_MODIFYING_FEATURES_BIT :: ToolPurposeFlagBits
- pattern TOOL_PURPOSE_DEBUG_MARKERS_BIT_EXT :: ToolPurposeFlagBits
- pattern TOOL_PURPOSE_DEBUG_REPORTING_BIT_EXT :: ToolPurposeFlagBits
Documentation
newtype ToolPurposeFlagBits Source #
VkToolPurposeFlagBits - Bitmask specifying the purposes of an active tool
Description
TOOL_PURPOSE_VALIDATION_BITspecifies that the tool provides validation of API usage.
TOOL_PURPOSE_PROFILING_BITspecifies that the tool provides profiling of API usage.TOOL_PURPOSE_TRACING_BITspecifies that the tool is capturing data about the application’s API usage, including anything from simple logging to capturing data for later replay.TOOL_PURPOSE_ADDITIONAL_FEATURES_BITspecifies that the tool provides additional API features/extensions on top of the underlying implementation.TOOL_PURPOSE_MODIFYING_FEATURES_BITspecifies that the tool modifies the API features/limits/extensions presented to the application.TOOL_PURPOSE_DEBUG_REPORTING_BIT_EXTspecifies that the tool reports additional information to the application via callbacks specified bycreateDebugReportCallbackEXTorcreateDebugUtilsMessengerEXTTOOL_PURPOSE_DEBUG_MARKERS_BIT_EXTspecifies that the tool consumes debug markers or object debug annotation, queue labels, or command buffer labels
See Also
Constructors
| ToolPurposeFlagBits Flags |
Bundled Patterns
| pattern TOOL_PURPOSE_VALIDATION_BIT :: ToolPurposeFlagBits | |
| pattern TOOL_PURPOSE_PROFILING_BIT :: ToolPurposeFlagBits | |
| pattern TOOL_PURPOSE_TRACING_BIT :: ToolPurposeFlagBits | |
| pattern TOOL_PURPOSE_ADDITIONAL_FEATURES_BIT :: ToolPurposeFlagBits | |
| pattern TOOL_PURPOSE_MODIFYING_FEATURES_BIT :: ToolPurposeFlagBits | |
| pattern TOOL_PURPOSE_DEBUG_MARKERS_BIT_EXT :: ToolPurposeFlagBits | |
| pattern TOOL_PURPOSE_DEBUG_REPORTING_BIT_EXT :: ToolPurposeFlagBits |