vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Core13.Promoted_From_VK_EXT_extended_dynamic_state

Synopsis

Documentation

cmdSetCullMode Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> CullModeFlags

cullMode specifies the cull mode property to use for drawing.

-> io () 

vkCmdSetCullMode - Set cull mode dynamically for a command buffer

Description

This command sets the cull mode for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_CULL_MODE set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the PipelineRasterizationStateCreateInfo::cullMode value used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetCullMode is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, CommandBuffer, CullModeFlags

cmdSetFrontFace Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> FrontFace

frontFace is a FrontFace value specifying the front-facing triangle orientation to be used for culling.

-> io () 

vkCmdSetFrontFace - Set front face orientation dynamically for a command buffer

Description

This command sets the front face orientation for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_FRONT_FACE set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the PipelineRasterizationStateCreateInfo::frontFace value used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetFrontFace is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, CommandBuffer, FrontFace

cmdSetPrimitiveTopology Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> PrimitiveTopology

primitiveTopology specifies the primitive topology to use for drawing.

-> io () 

vkCmdSetPrimitiveTopology - Set primitive topology state dynamically for a command buffer

Description

This command sets the primitive topology for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_PRIMITIVE_TOPOLOGY set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the PipelineInputAssemblyStateCreateInfo::topology value used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetPrimitiveTopology is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, CommandBuffer, PrimitiveTopology

cmdSetViewportWithCount Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> ("viewports" ::: Vector Viewport)

pViewports specifies the viewports to use for drawing.

-> io () 

vkCmdSetViewportWithCount - Set the viewport count and viewports dynamically for a command buffer

Description

This command sets the viewport count and viewports state for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_VIEWPORT_WITH_COUNT set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the corresponding PipelineViewportStateCreateInfo::viewportCount and pViewports values used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

  • pViewports must be a valid pointer to an array of viewportCount valid Viewport structures
  • commandBuffer must be in the recording state
  • The CommandPool that commandBuffer was allocated from must support QUEUE_GRAPHICS_BIT operations
  • This command must only be called outside of a video coding scope
  • viewportCount must be greater than 0

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetViewportWithCount is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, CommandBuffer, Viewport

cmdSetScissorWithCount Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> ("scissors" ::: Vector Rect2D)

pScissors specifies the scissors to use for drawing.

-> io () 

vkCmdSetScissorWithCount - Set the scissor count and scissor rectangular bounds dynamically for a command buffer

Description

This command sets the scissor count and scissor rectangular bounds state for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_SCISSOR_WITH_COUNT set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the corresponding PipelineViewportStateCreateInfo::scissorCount and pScissors values used to create the currently active pipeline.

Valid Usage

  • scissorCount must be between 1 and PhysicalDeviceLimits::maxViewports, inclusive
  • If the multiViewport feature is not enabled, scissorCount must be 1
  • The x and y members of offset member of any element of pScissors must be greater than or equal to 0
  • Evaluation of (offset.x + extent.width) must not cause a signed integer addition overflow for any element of pScissors
  • Evaluation of (offset.y + extent.height) must not cause a signed integer addition overflow for any element of pScissors
  • commandBuffer must not have CommandBufferInheritanceViewportScissorInfoNV::viewportScissor2D enabled

Valid Usage (Implicit)

  • pScissors must be a valid pointer to an array of scissorCount Rect2D structures
  • commandBuffer must be in the recording state
  • The CommandPool that commandBuffer was allocated from must support QUEUE_GRAPHICS_BIT operations
  • This command must only be called outside of a video coding scope
  • scissorCount must be greater than 0

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetScissorWithCount is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, CommandBuffer, Rect2D

cmdBindVertexBuffers2 Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command is recorded.

-> ("firstBinding" ::: Word32)

firstBinding is the index of the first vertex input binding whose state is updated by the command.

-> ("buffers" ::: Vector Buffer)

pBuffers is a pointer to an array of buffer handles.

-> ("offsets" ::: Vector DeviceSize)

pOffsets is a pointer to an array of buffer offsets.

-> ("sizes" ::: Vector DeviceSize)

pSizes is NULL or a pointer to an array of the size in bytes of vertex data bound from pBuffers.

-> ("strides" ::: Vector DeviceSize)

pStrides is NULL or a pointer to an array of buffer strides.

-> io () 

vkCmdBindVertexBuffers2 - Bind vertex buffers to a command buffer and dynamically set strides

Description

The values taken from elements i of pBuffers and pOffsets replace the current state for the vertex input binding firstBinding + i, for i in [0, bindingCount). The vertex input binding is updated to start at the offset indicated by pOffsets[i] from the start of the buffer pBuffers[i]. If pSizes is not NULL then pSizes[i] specifies the bound size of the vertex buffer starting from the corresponding elements of pBuffers[i] plus pOffsets[i]. If pSizes[i] is WHOLE_SIZE then the bound size is from pBuffers[i] plus pOffsets[i] to the end of the buffer pBuffers[i]. All vertex input attributes that use each of these bindings will use these updated addresses in their address calculations for subsequent drawing commands. If the nullDescriptor feature is enabled, elements of pBuffers can be NULL_HANDLE, and can be used by the vertex shader. If a vertex input attribute is bound to a vertex input binding that is NULL_HANDLE, the values taken from memory are considered to be zero, and missing G, B, or A components are filled with (0,0,1).

This command also dynamically sets the byte strides between consecutive elements within buffer pBuffers[i] to the corresponding pStrides[i] value when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_VERTEX_INPUT_BINDING_STRIDE set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, strides are specified by the VertexInputBindingDescription::stride values used to create the currently active pipeline.

If drawing using shader objects or if the bound pipeline state object was also created with the DYNAMIC_STATE_VERTEX_INPUT_EXT dynamic state enabled then cmdSetVertexInputEXT can be used instead of cmdBindVertexBuffers2 to set the stride.

Unlike the static state to set the same, pStrides must be between 0 and the maximum extent of the attributes in the binding. cmdSetVertexInputEXT does not have this restriction so can be used if other stride values are desired.

Valid Usage

  • firstBinding must be less than PhysicalDeviceLimits::maxVertexInputBindings
  • The sum of firstBinding and bindingCount must be less than or equal to PhysicalDeviceLimits::maxVertexInputBindings
  • If pSizes is not NULL, all elements of pOffsets must be less than the size of the corresponding element in pBuffers
  • If pSizes is not NULL, all elements of pOffsets plus pSizes , where pSizes is not WHOLE_SIZE, must be less than or equal to the size of the corresponding element in pBuffers
  • All elements of pBuffers must have been created with the BUFFER_USAGE_VERTEX_BUFFER_BIT usage flag set
  • Each element of pBuffers that is non-sparse must be bound completely and contiguously to a single DeviceMemory object
  • If the nullDescriptor feature is not enabled, all elements of pBuffers must not be NULL_HANDLE
  • If an element of pBuffers is NULL_HANDLE, then the corresponding element of pOffsets must be zero
  • If pStrides is not NULL each element of pStrides must be less than or equal to PhysicalDeviceLimits::maxVertexInputBindingStride
  • If pStrides is not NULL each element of pStrides must be either 0 or greater than or equal to the maximum extent of all vertex input attributes fetched from the corresponding binding, where the extent is calculated as the VertexInputAttributeDescription::offset plus VertexInputAttributeDescription::format size

Valid Usage (Implicit)

  • pBuffers must be a valid pointer to an array of bindingCount valid or NULL_HANDLE Buffer handles
  • pOffsets must be a valid pointer to an array of bindingCount DeviceSize values
  • If pSizes is not NULL, pSizes must be a valid pointer to an array of bindingCount DeviceSize values
  • If pStrides is not NULL, pStrides must be a valid pointer to an array of bindingCount DeviceSize values
  • commandBuffer must be in the recording state
  • The CommandPool that commandBuffer was allocated from must support QUEUE_GRAPHICS_BIT operations
  • This command must only be called outside of a video coding scope
  • If any of pSizes, or pStrides are not NULL, bindingCount must be greater than 0
  • Both of commandBuffer, and the elements of pBuffers that are valid handles of non-ignored parameters must have been created, allocated, or retrieved from the same Device

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdBindVertexBuffers2 is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, Buffer, CommandBuffer, DeviceSize

cmdSetDepthTestEnable Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> ("depthTestEnable" ::: Bool)

depthTestEnable specifies if the depth test is enabled.

-> io () 

vkCmdSetDepthTestEnable - Set depth test enable dynamically for a command buffer

Description

This command sets the depth test enable for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_DEPTH_TEST_ENABLE set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the PipelineDepthStencilStateCreateInfo::depthTestEnable value used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetDepthTestEnable is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, Bool32, CommandBuffer

cmdSetDepthWriteEnable Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> ("depthWriteEnable" ::: Bool)

depthWriteEnable specifies if depth writes are enabled.

-> io () 

vkCmdSetDepthWriteEnable - Set depth write enable dynamically for a command buffer

Description

This command sets the depth write enable for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_DEPTH_WRITE_ENABLE set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the PipelineDepthStencilStateCreateInfo::depthWriteEnable value used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetDepthWriteEnable is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, Bool32, CommandBuffer

cmdSetDepthCompareOp Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> ("depthCompareOp" ::: CompareOp)

depthCompareOp is a CompareOp value specifying the comparison operator used for the Depth Comparison step of the depth test.

-> io () 

vkCmdSetDepthCompareOp - Set depth comparison operator dynamically for a command buffer

Description

This command sets the depth comparison operator for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_DEPTH_COMPARE_OP set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the PipelineDepthStencilStateCreateInfo::depthCompareOp value used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetDepthCompareOp is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, CommandBuffer, CompareOp

cmdSetDepthBoundsTestEnable Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> ("depthBoundsTestEnable" ::: Bool)

depthBoundsTestEnable specifies if the depth bounds test is enabled.

-> io () 

vkCmdSetDepthBoundsTestEnable - Set depth bounds test enable dynamically for a command buffer

Description

This command sets the depth bounds enable for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_DEPTH_BOUNDS_TEST_ENABLE set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the PipelineDepthStencilStateCreateInfo::depthBoundsTestEnable value used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetDepthBoundsTestEnable is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, Bool32, CommandBuffer

cmdSetStencilTestEnable Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> ("stencilTestEnable" ::: Bool)

stencilTestEnable specifies if the stencil test is enabled.

-> io () 

vkCmdSetStencilTestEnable - Set stencil test enable dynamically for a command buffer

Description

This command sets the stencil test enable for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_STENCIL_TEST_ENABLE set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the PipelineDepthStencilStateCreateInfo::stencilTestEnable value used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetStencilTestEnable is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, Bool32, CommandBuffer

cmdSetStencilOp Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> ("faceMask" ::: StencilFaceFlags)

faceMask is a bitmask of StencilFaceFlagBits specifying the set of stencil state for which to update the stencil operation.

-> ("failOp" ::: StencilOp)

failOp is a StencilOp value specifying the action performed on samples that fail the stencil test.

-> ("passOp" ::: StencilOp)

passOp is a StencilOp value specifying the action performed on samples that pass both the depth and stencil tests.

-> ("depthFailOp" ::: StencilOp)

depthFailOp is a StencilOp value specifying the action performed on samples that pass the stencil test and fail the depth test.

-> CompareOp

compareOp is a CompareOp value specifying the comparison operator used in the stencil test.

-> io () 

vkCmdSetStencilOp - Set stencil operation dynamically for a command buffer

Description

This command sets the stencil operation for subsequent drawing commands when when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_STENCIL_OP set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the corresponding PipelineDepthStencilStateCreateInfo::failOp, passOp, depthFailOp, and compareOp values used to create the currently active pipeline, for both front and back faces.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetStencilOp is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state, VK_EXT_shader_object, VK_VERSION_1_3, CommandBuffer, CompareOp, StencilFaceFlags, StencilOp

newtype DynamicState Source #

VkDynamicState - Indicate which dynamic state is taken from dynamic state commands

Description

See Also

VK_VERSION_1_0, PipelineDynamicStateCreateInfo

Constructors

DynamicState Int32 

Bundled Patterns

pattern DYNAMIC_STATE_ALPHA_TO_COVERAGE_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_ALPHA_TO_ONE_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_ATTACHMENT_FEEDBACK_LOOP_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_BLEND_CONSTANTS :: DynamicState 
pattern DYNAMIC_STATE_COLOR_BLEND_ADVANCED_EXT :: DynamicState 
pattern DYNAMIC_STATE_COLOR_BLEND_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_COLOR_BLEND_EQUATION_EXT :: DynamicState 
pattern DYNAMIC_STATE_COLOR_WRITE_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_COLOR_WRITE_MASK_EXT :: DynamicState 
pattern DYNAMIC_STATE_CONSERVATIVE_RASTERIZATION_MODE_EXT :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_MODULATION_MODE_NV :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_REDUCTION_MODE_NV :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_TO_COLOR_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_TO_COLOR_LOCATION_NV :: DynamicState 
pattern DYNAMIC_STATE_CULL_MODE :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_BIAS :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_BIAS_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_BOUNDS :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_BOUNDS_TEST_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_CLAMP_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_CLAMP_RANGE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_CLIP_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_CLIP_NEGATIVE_ONE_TO_ONE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_COMPARE_OP :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_TEST_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_WRITE_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_DISCARD_RECTANGLE_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DISCARD_RECTANGLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DISCARD_RECTANGLE_MODE_EXT :: DynamicState 
pattern DYNAMIC_STATE_EXCLUSIVE_SCISSOR_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_EXCLUSIVE_SCISSOR_NV :: DynamicState 
pattern DYNAMIC_STATE_EXTRA_PRIMITIVE_OVERESTIMATION_SIZE_EXT :: DynamicState 
pattern DYNAMIC_STATE_FRAGMENT_SHADING_RATE_KHR :: DynamicState 
pattern DYNAMIC_STATE_FRONT_FACE :: DynamicState 
pattern DYNAMIC_STATE_LINE_RASTERIZATION_MODE_EXT :: DynamicState 
pattern DYNAMIC_STATE_LINE_STIPPLE :: DynamicState 
pattern DYNAMIC_STATE_LINE_STIPPLE_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_LINE_WIDTH :: DynamicState 
pattern DYNAMIC_STATE_LOGIC_OP_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_LOGIC_OP_EXT :: DynamicState 
pattern DYNAMIC_STATE_PATCH_CONTROL_POINTS_EXT :: DynamicState 
pattern DYNAMIC_STATE_POLYGON_MODE_EXT :: DynamicState 
pattern DYNAMIC_STATE_PRIMITIVE_RESTART_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_PRIMITIVE_TOPOLOGY :: DynamicState 
pattern DYNAMIC_STATE_PROVOKING_VERTEX_MODE_EXT :: DynamicState 
pattern DYNAMIC_STATE_RASTERIZATION_SAMPLES_EXT :: DynamicState 
pattern DYNAMIC_STATE_RASTERIZATION_STREAM_EXT :: DynamicState 
pattern DYNAMIC_STATE_RASTERIZER_DISCARD_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_RAY_TRACING_PIPELINE_STACK_SIZE_KHR :: DynamicState 
pattern DYNAMIC_STATE_REPRESENTATIVE_FRAGMENT_TEST_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_SAMPLE_LOCATIONS_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_SAMPLE_LOCATIONS_EXT :: DynamicState 
pattern DYNAMIC_STATE_SAMPLE_MASK_EXT :: DynamicState 
pattern DYNAMIC_STATE_SCISSOR :: DynamicState 
pattern DYNAMIC_STATE_SCISSOR_WITH_COUNT :: DynamicState 
pattern DYNAMIC_STATE_SHADING_RATE_IMAGE_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_STENCIL_COMPARE_MASK :: DynamicState 
pattern DYNAMIC_STATE_STENCIL_OP :: DynamicState 
pattern DYNAMIC_STATE_STENCIL_REFERENCE :: DynamicState 
pattern DYNAMIC_STATE_STENCIL_TEST_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_STENCIL_WRITE_MASK :: DynamicState 
pattern DYNAMIC_STATE_TESSELLATION_DOMAIN_ORIGIN_EXT :: DynamicState 
pattern DYNAMIC_STATE_VERTEX_INPUT_BINDING_STRIDE :: DynamicState 
pattern DYNAMIC_STATE_VERTEX_INPUT_EXT :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_COARSE_SAMPLE_ORDER_NV :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_SHADING_RATE_PALETTE_NV :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_SWIZZLE_NV :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_WITH_COUNT :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_W_SCALING_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_W_SCALING_NV :: DynamicState 

Instances

Instances details
Eq DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState

Ord DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState

Storable DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState

Read DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState

Show DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState

Zero DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState