vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Core13.Promoted_From_VK_EXT_extended_dynamic_state2

Synopsis

Documentation

cmdSetRasterizerDiscardEnable Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> ("rasterizerDiscardEnable" ::: Bool)

rasterizerDiscardEnable controls whether primitives are discarded immediately before the rasterization stage.

-> io () 

vkCmdSetRasterizerDiscardEnable - Control whether primitives are discarded before the rasterization stage dynamically for a command buffer

Description

This command sets the discard enable for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_RASTERIZER_DISCARD_ENABLE set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the PipelineRasterizationStateCreateInfo::rasterizerDiscardEnable value used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetRasterizerDiscardEnable is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state2, VK_EXT_shader_object, VK_VERSION_1_3, Bool32, CommandBuffer

cmdSetDepthBiasEnable Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> ("depthBiasEnable" ::: Bool)

depthBiasEnable controls whether to bias fragment depth values.

-> io () 

vkCmdSetDepthBiasEnable - Control whether to bias fragment depth values dynamically for a command buffer

Description

This command sets the depth bias enable for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_DEPTH_BIAS_ENABLE set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the PipelineRasterizationStateCreateInfo::depthBiasEnable value used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetDepthBiasEnable is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state2, VK_EXT_shader_object, VK_VERSION_1_3, Bool32, CommandBuffer

cmdSetPrimitiveRestartEnable Source #

Arguments

:: MonadIO io 
=> CommandBuffer

commandBuffer is the command buffer into which the command will be recorded.

-> ("primitiveRestartEnable" ::: Bool)

primitiveRestartEnable controls whether a special vertex index value is treated as restarting the assembly of primitives. It behaves in the same way as PipelineInputAssemblyStateCreateInfo::primitiveRestartEnable

-> io () 

vkCmdSetPrimitiveRestartEnable - Set primitive assembly restart state dynamically for a command buffer

Description

This command sets the primitive restart enable for subsequent drawing commands when drawing using shader objects, or when the graphics pipeline is created with DYNAMIC_STATE_PRIMITIVE_RESTART_ENABLE set in PipelineDynamicStateCreateInfo::pDynamicStates. Otherwise, this state is specified by the PipelineInputAssemblyStateCreateInfo::primitiveRestartEnable value used to create the currently active pipeline.

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_GRAPHICS_BIT State

Conditional Rendering

vkCmdSetPrimitiveRestartEnable is not affected by conditional rendering

See Also

VK_EXT_extended_dynamic_state2, VK_EXT_shader_object, VK_VERSION_1_3, Bool32, CommandBuffer

newtype DynamicState Source #

VkDynamicState - Indicate which dynamic state is taken from dynamic state commands

Description

See Also

VK_VERSION_1_0, PipelineDynamicStateCreateInfo

Constructors

DynamicState Int32 

Bundled Patterns

pattern DYNAMIC_STATE_ALPHA_TO_COVERAGE_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_ALPHA_TO_ONE_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_ATTACHMENT_FEEDBACK_LOOP_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_BLEND_CONSTANTS :: DynamicState 
pattern DYNAMIC_STATE_COLOR_BLEND_ADVANCED_EXT :: DynamicState 
pattern DYNAMIC_STATE_COLOR_BLEND_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_COLOR_BLEND_EQUATION_EXT :: DynamicState 
pattern DYNAMIC_STATE_COLOR_WRITE_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_COLOR_WRITE_MASK_EXT :: DynamicState 
pattern DYNAMIC_STATE_CONSERVATIVE_RASTERIZATION_MODE_EXT :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_MODULATION_MODE_NV :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_REDUCTION_MODE_NV :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_TO_COLOR_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_COVERAGE_TO_COLOR_LOCATION_NV :: DynamicState 
pattern DYNAMIC_STATE_CULL_MODE :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_BIAS :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_BIAS_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_BOUNDS :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_BOUNDS_TEST_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_CLAMP_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_CLAMP_RANGE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_CLIP_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_CLIP_NEGATIVE_ONE_TO_ONE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_COMPARE_OP :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_TEST_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_DEPTH_WRITE_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_DISCARD_RECTANGLE_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DISCARD_RECTANGLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_DISCARD_RECTANGLE_MODE_EXT :: DynamicState 
pattern DYNAMIC_STATE_EXCLUSIVE_SCISSOR_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_EXCLUSIVE_SCISSOR_NV :: DynamicState 
pattern DYNAMIC_STATE_EXTRA_PRIMITIVE_OVERESTIMATION_SIZE_EXT :: DynamicState 
pattern DYNAMIC_STATE_FRAGMENT_SHADING_RATE_KHR :: DynamicState 
pattern DYNAMIC_STATE_FRONT_FACE :: DynamicState 
pattern DYNAMIC_STATE_LINE_RASTERIZATION_MODE_EXT :: DynamicState 
pattern DYNAMIC_STATE_LINE_STIPPLE :: DynamicState 
pattern DYNAMIC_STATE_LINE_STIPPLE_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_LINE_WIDTH :: DynamicState 
pattern DYNAMIC_STATE_LOGIC_OP_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_LOGIC_OP_EXT :: DynamicState 
pattern DYNAMIC_STATE_PATCH_CONTROL_POINTS_EXT :: DynamicState 
pattern DYNAMIC_STATE_POLYGON_MODE_EXT :: DynamicState 
pattern DYNAMIC_STATE_PRIMITIVE_RESTART_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_PRIMITIVE_TOPOLOGY :: DynamicState 
pattern DYNAMIC_STATE_PROVOKING_VERTEX_MODE_EXT :: DynamicState 
pattern DYNAMIC_STATE_RASTERIZATION_SAMPLES_EXT :: DynamicState 
pattern DYNAMIC_STATE_RASTERIZATION_STREAM_EXT :: DynamicState 
pattern DYNAMIC_STATE_RASTERIZER_DISCARD_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_RAY_TRACING_PIPELINE_STACK_SIZE_KHR :: DynamicState 
pattern DYNAMIC_STATE_REPRESENTATIVE_FRAGMENT_TEST_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_SAMPLE_LOCATIONS_ENABLE_EXT :: DynamicState 
pattern DYNAMIC_STATE_SAMPLE_LOCATIONS_EXT :: DynamicState 
pattern DYNAMIC_STATE_SAMPLE_MASK_EXT :: DynamicState 
pattern DYNAMIC_STATE_SCISSOR :: DynamicState 
pattern DYNAMIC_STATE_SCISSOR_WITH_COUNT :: DynamicState 
pattern DYNAMIC_STATE_SHADING_RATE_IMAGE_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_STENCIL_COMPARE_MASK :: DynamicState 
pattern DYNAMIC_STATE_STENCIL_OP :: DynamicState 
pattern DYNAMIC_STATE_STENCIL_REFERENCE :: DynamicState 
pattern DYNAMIC_STATE_STENCIL_TEST_ENABLE :: DynamicState 
pattern DYNAMIC_STATE_STENCIL_WRITE_MASK :: DynamicState 
pattern DYNAMIC_STATE_TESSELLATION_DOMAIN_ORIGIN_EXT :: DynamicState 
pattern DYNAMIC_STATE_VERTEX_INPUT_BINDING_STRIDE :: DynamicState 
pattern DYNAMIC_STATE_VERTEX_INPUT_EXT :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_COARSE_SAMPLE_ORDER_NV :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_SHADING_RATE_PALETTE_NV :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_SWIZZLE_NV :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_WITH_COUNT :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_W_SCALING_ENABLE_NV :: DynamicState 
pattern DYNAMIC_STATE_VIEWPORT_W_SCALING_NV :: DynamicState 

Instances

Instances details
Eq DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState

Ord DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState

Storable DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState

Read DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState

Show DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState

Zero DynamicState Source # 
Instance details

Defined in Vulkan.Core10.Enums.DynamicState