| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core14.Enums.BufferUsageFlags2
Synopsis
- type BufferUsageFlags2 = BufferUsageFlagBits2
- newtype BufferUsageFlagBits2 where
- BufferUsageFlagBits2 Flags64
- pattern BUFFER_USAGE_2_TRANSFER_SRC_BIT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_TRANSFER_DST_BIT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_UNIFORM_TEXEL_BUFFER_BIT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_STORAGE_TEXEL_BUFFER_BIT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_UNIFORM_BUFFER_BIT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_STORAGE_BUFFER_BIT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_INDEX_BUFFER_BIT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_VERTEX_BUFFER_BIT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_INDIRECT_BUFFER_BIT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_PREPROCESS_BUFFER_BIT_EXT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_MEMORY_DECOMPRESSION_BIT_EXT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_TILE_MEMORY_BIT_QCOM :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_DATA_GRAPH_FOREIGN_DESCRIPTOR_BIT_ARM :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_COMPRESSED_DATA_DGF1_BIT_AMDX :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_MICROMAP_STORAGE_BIT_EXT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_MICROMAP_BUILD_INPUT_READ_ONLY_BIT_EXT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_PUSH_DESCRIPTORS_DESCRIPTOR_BUFFER_BIT_EXT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_RESOURCE_DESCRIPTOR_BUFFER_BIT_EXT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_SAMPLER_DESCRIPTOR_BUFFER_BIT_EXT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_ACCELERATION_STRUCTURE_STORAGE_BIT_KHR :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_ACCELERATION_STRUCTURE_BUILD_INPUT_READ_ONLY_BIT_KHR :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_VIDEO_ENCODE_SRC_BIT_KHR :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_VIDEO_ENCODE_DST_BIT_KHR :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_VIDEO_DECODE_DST_BIT_KHR :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_VIDEO_DECODE_SRC_BIT_KHR :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_TRANSFORM_FEEDBACK_COUNTER_BUFFER_BIT_EXT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_TRANSFORM_FEEDBACK_BUFFER_BIT_EXT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_SHADER_BINDING_TABLE_BIT_KHR :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_CONDITIONAL_RENDERING_BIT_EXT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_DESCRIPTOR_HEAP_BIT_EXT :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_EXECUTION_GRAPH_SCRATCH_BIT_AMDX :: BufferUsageFlagBits2
- pattern BUFFER_USAGE_2_SHADER_DEVICE_ADDRESS_BIT :: BufferUsageFlagBits2
Documentation
newtype BufferUsageFlagBits2 Source #
VkBufferUsageFlagBits2 - Bitmask controlling how a pipeline is created
Description
BUFFER_USAGE_2_TRANSFER_SRC_BITspecifies that the buffer can be used as the source of a transfer command (see the definition of https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#synchronization-pipeline-stages-transfer).
BUFFER_USAGE_2_TRANSFER_DST_BITspecifies that the buffer can be used as the destination of a transfer command.BUFFER_USAGE_2_UNIFORM_TEXEL_BUFFER_BITspecifies that the buffer can be used to create aBufferViewsuitable for occupying aDescriptorSetslot of typeDESCRIPTOR_TYPE_UNIFORM_TEXEL_BUFFER.BUFFER_USAGE_2_STORAGE_TEXEL_BUFFER_BITspecifies that the buffer can be used to create aBufferViewsuitable for occupying aDescriptorSetslot of typeDESCRIPTOR_TYPE_STORAGE_TEXEL_BUFFER.BUFFER_USAGE_2_UNIFORM_BUFFER_BITspecifies that the buffer can be used in aDescriptorBufferInfosuitable for occupying aDescriptorSetslot either of typeDESCRIPTOR_TYPE_UNIFORM_BUFFERorDESCRIPTOR_TYPE_UNIFORM_BUFFER_DYNAMIC.BUFFER_USAGE_2_STORAGE_BUFFER_BITspecifies that the buffer can be used in aDescriptorBufferInfosuitable for occupying aDescriptorSetslot either of typeDESCRIPTOR_TYPE_STORAGE_BUFFERorDESCRIPTOR_TYPE_STORAGE_BUFFER_DYNAMIC.BUFFER_USAGE_2_INDEX_BUFFER_BITspecifies that the buffer is suitable for passing as thebufferparameter tocmdBindIndexBuffer2andcmdBindIndexBuffer.BUFFER_USAGE_2_VERTEX_BUFFER_BITspecifies that the buffer is suitable for passing as an element of thepBuffersarray tocmdBindVertexBuffers.BUFFER_USAGE_2_INDIRECT_BUFFER_BITspecifies that the buffer is suitable for passing as thebufferparameter tocmdDrawIndirect,cmdDrawIndexedIndirect,cmdDrawMeshTasksIndirectNV,cmdDrawMeshTasksIndirectCountNV,cmdDrawMeshTasksIndirectEXT,cmdDrawMeshTasksIndirectCountEXT,cmdDrawClusterIndirectHUAWEI, orcmdDispatchIndirect. It is also suitable for passing as thebuffermember ofIndirectCommandsStreamNV, orsequencesCountBufferorsequencesIndexBufferorpreprocessedBuffermember ofGeneratedCommandsInfoNV. It is also suitable for passing as the underlying buffer of either thepreprocessAddressorsequenceCountAddressmembers ofGeneratedCommandsInfoEXT.BUFFER_USAGE_2_CONDITIONAL_RENDERING_BIT_EXTspecifies that the buffer is suitable for passing as thebufferparameter tocmdBeginConditionalRenderingEXT.BUFFER_USAGE_2_TRANSFORM_FEEDBACK_BUFFER_BIT_EXTspecifies that the buffer is suitable for using for binding as a transform feedback buffer withcmdBindTransformFeedbackBuffersEXT.BUFFER_USAGE_2_TRANSFORM_FEEDBACK_COUNTER_BUFFER_BIT_EXTspecifies that the buffer is suitable for using as a counter buffer withcmdBeginTransformFeedbackEXTandcmdEndTransformFeedbackEXT.BUFFER_USAGE_2_SAMPLER_DESCRIPTOR_BUFFER_BIT_EXTspecifies that the buffer is suitable to contain sampler and combined image sampler descriptors when bound as a descriptor buffer. Buffers containing combined image sampler descriptors must also specifyBUFFER_USAGE_2_RESOURCE_DESCRIPTOR_BUFFER_BIT_EXT.BUFFER_USAGE_2_RESOURCE_DESCRIPTOR_BUFFER_BIT_EXTspecifies that the buffer is suitable to contain resource descriptors when bound as a descriptor buffer.BUFFER_USAGE_2_PUSH_DESCRIPTORS_DESCRIPTOR_BUFFER_BIT_EXTspecifies that the buffer, when bound, can be used by the implementation to support push descriptors when using descriptor buffers.BUFFER_USAGE_2_TILE_MEMORY_BIT_QCOMspecifies that the buffer can be bound toDeviceMemoryallocated from aMemoryHeapwith theMEMORY_HEAP_TILE_MEMORY_BIT_QCOMproperty.BUFFER_USAGE_2_RAY_TRACING_BIT_NVspecifies that the buffer is suitable for use incmdTraceRaysNV.BUFFER_USAGE_2_SHADER_BINDING_TABLE_BIT_KHRspecifies that the buffer is suitable for use as a Shader Binding Table.BUFFER_USAGE_2_ACCELERATION_STRUCTURE_BUILD_INPUT_READ_ONLY_BIT_KHRspecifies that the buffer is suitable for use as a read-only input to an acceleration structure build.BUFFER_USAGE_2_ACCELERATION_STRUCTURE_STORAGE_BIT_KHRspecifies that the buffer is suitable for storage space for aAccelerationStructureKHR.BUFFER_USAGE_2_SHADER_DEVICE_ADDRESS_BITspecifies that the buffer can be used to retrieve a buffer device address viagetBufferDeviceAddressand use that address to access the buffer’s memory from a shader.BUFFER_USAGE_2_VIDEO_DECODE_SRC_BIT_KHRspecifies that the buffer can be used as the source video bitstream buffer in a video decode operation.BUFFER_USAGE_2_VIDEO_DECODE_DST_BIT_KHRis reserved for future use.BUFFER_USAGE_2_VIDEO_ENCODE_DST_BIT_KHRspecifies that the buffer can be used as the destination video bitstream buffer in a video encode operation.BUFFER_USAGE_2_VIDEO_ENCODE_SRC_BIT_KHRis reserved for future use.BUFFER_USAGE_2_EXECUTION_GRAPH_SCRATCH_BIT_AMDXspecifies that the buffer can be used for as scratch memory for execution graph dispatch.BUFFER_USAGE_2_PREPROCESS_BUFFER_BIT_EXTspecifies that the buffer can be used as a preprocess buffer for Device-Generated Commands.BUFFER_USAGE_2_COMPRESSED_DATA_DGF1_BIT_AMDXspecifies that the buffer is suitable as storage space for Dense Geometry Format data.BUFFER_USAGE_2_DATA_GRAPH_FOREIGN_DESCRIPTOR_BIT_ARMspecifies that the buffer is suitable to contain resource descriptors when bound as a descriptor buffer in command buffers allocated from a command pool that can target foreign data graph processing engines.BUFFER_USAGE_2_MEMORY_DECOMPRESSION_BIT_EXTspecifies that the buffer can be used as a destination buffer in memory decompression.BUFFER_USAGE_2_DESCRIPTOR_HEAP_BIT_EXTspecifies that the buffer can be used as a descriptor heap.
See Also
Constructors
| BufferUsageFlagBits2 Flags64 |
Bundled Patterns