| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core14.Enums.MemoryUnmapFlagBits
Synopsis
- type MemoryUnmapFlags = MemoryUnmapFlagBits
- newtype MemoryUnmapFlagBits where
Documentation
newtype MemoryUnmapFlagBits Source #
VkMemoryUnmapFlagBits - Bitmask specifying additional parameters of a memory unmap
Description
MEMORY_UNMAP_RESERVE_BIT_EXTrequests that virtual address range currently occupied by the memory map remain reserved after theunmapMemory2call completes. Future system memory map operations or calls tomapMemoryormapMemory2will not return addresses in that range unless the range has since been unreserved by the client or the mapping is explicitly placed in that range by callingmapMemory2withMEMORY_MAP_PLACED_BIT_EXT, or doing the system memory map equivalent. WhenMEMORY_UNMAP_RESERVE_BIT_EXTis set, the memory unmap operation may fail, in which case the memory object will remain host mapped andunmapMemory2will returnERROR_MEMORY_MAP_FAILED.
See Also
Constructors
| MemoryUnmapFlagBits Flags |
Bundled Patterns
| pattern MEMORY_UNMAP_RESERVE_BIT_EXT :: MemoryUnmapFlagBits |