| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core14.Enums.PipelineRobustnessBufferBehavior
Synopsis
- newtype PipelineRobustnessBufferBehavior where
- PipelineRobustnessBufferBehavior Int32
- pattern PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_DEVICE_DEFAULT :: PipelineRobustnessBufferBehavior
- pattern PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_DISABLED :: PipelineRobustnessBufferBehavior
- pattern PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS :: PipelineRobustnessBufferBehavior
- pattern PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2 :: PipelineRobustnessBufferBehavior
Documentation
newtype PipelineRobustnessBufferBehavior Source #
VkPipelineRobustnessBufferBehavior - Enum controlling the robustness of buffer accesses in a pipeline stage
Description
PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_DEVICE_DEFAULTspecifies that out of bounds buffer accesses follow the behavior of robust buffer access features enabled for the device.
PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_DISABLEDspecifies that buffer accesses must not be out of bounds.PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESSspecifies that buffer accesses conform to https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#shaders-robust-buffer-access guarantees.PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2specifies that buffer accesses conform to https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#shaders-robust-buffer-access2 guarantees.
See Also
VK_EXT_pipeline_robustness,
VK_VERSION_1_4,
Promoted_From_VK_EXT_pipeline_robustnessAdditionalFunctionality.PhysicalDevicePipelineRobustnessProperties',
PhysicalDeviceVulkan14Properties,
Promoted_From_VK_EXT_pipeline_robustnessAdditionalFunctionality.PipelineRobustnessCreateInfo'
Constructors
| PipelineRobustnessBufferBehavior Int32 |
Bundled Patterns