| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core14.Enums.PipelineRobustnessImageBehavior
Synopsis
- newtype PipelineRobustnessImageBehavior where
- PipelineRobustnessImageBehavior Int32
- pattern PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_DEVICE_DEFAULT :: PipelineRobustnessImageBehavior
- pattern PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_DISABLED :: PipelineRobustnessImageBehavior
- pattern PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESS :: PipelineRobustnessImageBehavior
- pattern PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESS_2 :: PipelineRobustnessImageBehavior
Documentation
newtype PipelineRobustnessImageBehavior Source #
VkPipelineRobustnessImageBehavior - Enum controlling the robustness of image accesses in a pipeline stage
Description
PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_DEVICE_DEFAULTspecifies that out of bounds image accesses follow the behavior of robust image access features enabled for the device.
PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_DISABLEDspecifies that image accesses must not be out of bounds.PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESSspecifies that image accesses conform to https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#shaders-robust-image-access guarantees.PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESS_2specifies that image accesses conform to https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#shaders-robust-image-access2 guarantees.
See Also
VK_EXT_pipeline_robustness,
VK_VERSION_1_4,
Promoted_From_VK_EXT_pipeline_robustnessAdditionalFunctionality.PhysicalDevicePipelineRobustnessProperties',
PhysicalDeviceVulkan14Properties,
Promoted_From_VK_EXT_pipeline_robustnessAdditionalFunctionality.PipelineRobustnessCreateInfo'
Constructors
| PipelineRobustnessImageBehavior Int32 |
Bundled Patterns