vulkan
Safe HaskellSafe-Inferred
LanguageHaskell2010

Vulkan.Extensions.VK_AMD_anti_lag

Description

Name

VK_AMD_anti_lag - device extension

VK_AMD_anti_lag

Name String
VK_AMD_anti_lag
Extension Type
Device extension
Registered Extension Number
477
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
None
Contact
  • Stu Smith
Extension Proposal
VK_AMD_anti_lag

Other Extension Metadata

Last Modified Date
2024-06-06
IP Status
No known IP claims.
Contributors
  • Tobias Hector, AMD
  • Stuart Smith, AMD
  • Arkadiusz Sarwa, AMD

Description

This extension automatically paces the CPU to make sure it does not get too far ahead of the GPU, reducing the latency between inputs received and updates on the screen. Additionally, Anti-Lag+ offers applications the ability to inform the driver when input processing begins, in order to align the timing of display updates, enabling even lower latency between receiving input and displaying on the screen.

New Commands

New Structures

New Enums

New Enum Constants

Version History

  • Revision 1, 2024-06-06 (Arkadiusz Sarw)

    • Initial version

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

antiLagUpdateAMD Source #

Arguments

:: forall io. MonadIO io 
=> Device

device is the logical device

-> AntiLagDataAMD

pData is a pointer to a AntiLagDataAMD structure containing latency reduction parameters.

-> io () 

vkAntiLagUpdateAMD - Provide information to reduce latency

Description

This command should be executed immediately before the application processes user input. If pData is not NULL and AntiLagDataAMD::presentationInfo is not NULL, this command should be executed again before queuePresentKHR, with pPresentationInfo set to matching values.

Valid Usage

  • The antiLag feature must be enabled

Valid Usage (Implicit)

  • device must be a valid Device handle

See Also

VK_AMD_anti_lag, AntiLagDataAMD, Device

data PhysicalDeviceAntiLagFeaturesAMD Source #

VkPhysicalDeviceAntiLagFeaturesAMD - Structure describing whether VK_AMD_anti_lag can be supported by an implementation.

Members

This structure describes the following feature:

Description

If the PhysicalDeviceAntiLagFeaturesAMD structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. PhysicalDeviceAntiLagFeaturesAMD can also be used in the pNext chain of DeviceCreateInfo to selectively enable these features.

Valid Usage (Implicit)

See Also

VK_AMD_anti_lag, Bool32, StructureType

Constructors

PhysicalDeviceAntiLagFeaturesAMD 

Fields

  • antiLag :: Bool

    antiLag indicates whether the implementation supports AMD Radeon™ Anti-Lag functionality. The antiLag feature only supports a single GPU and must not be enabled if DeviceGroupDeviceCreateInfo::physicalDeviceCount is greater than 1.

Instances

Instances details
Storable PhysicalDeviceAntiLagFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Show PhysicalDeviceAntiLagFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Eq PhysicalDeviceAntiLagFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

FromCStruct PhysicalDeviceAntiLagFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

ToCStruct PhysicalDeviceAntiLagFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Zero PhysicalDeviceAntiLagFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

data AntiLagDataAMD Source #

VkAntiLagDataAMD - Structure specifying the parameters for vkAntiLagUpdateAMD

Description

This structure specifies anti-lag parameters.

Valid Usage (Implicit)

See Also

VK_AMD_anti_lag, AntiLagModeAMD, AntiLagPresentationInfoAMD, StructureType, antiLagUpdateAMD

Constructors

AntiLagDataAMD 

Fields

data AntiLagPresentationInfoAMD Source #

VkAntiLagPresentationInfoAMD - Structure specifying information about stage

Description

This structure specifies information about the presentation stage for which anti-lag parameters are being set.

Valid Usage (Implicit)

See Also

VK_AMD_anti_lag, AntiLagDataAMD, AntiLagStageAMD, StructureType

Constructors

AntiLagPresentationInfoAMD 

Fields

Instances

Instances details
Storable AntiLagPresentationInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Show AntiLagPresentationInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Eq AntiLagPresentationInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

FromCStruct AntiLagPresentationInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

ToCStruct AntiLagPresentationInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Zero AntiLagPresentationInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

newtype AntiLagModeAMD Source #

VkAntiLagModeAMD - Set the status of the anti-lag feature

See Also

VK_AMD_anti_lag, AntiLagDataAMD

Constructors

AntiLagModeAMD Int32 

Bundled Patterns

pattern ANTI_LAG_MODE_DRIVER_CONTROL_AMD :: AntiLagModeAMD

ANTI_LAG_MODE_DRIVER_CONTROL_AMD specifies that anti-lag will be enabled or disabled depending on driver settings.

pattern ANTI_LAG_MODE_ON_AMD :: AntiLagModeAMD

ANTI_LAG_MODE_ON_AMD specifies that anti-lag will be enabled.

pattern ANTI_LAG_MODE_OFF_AMD :: AntiLagModeAMD

ANTI_LAG_MODE_OFF_AMD specifies that anti-lag will be disabled.

Instances

Instances details
Storable AntiLagModeAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Read AntiLagModeAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Show AntiLagModeAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Eq AntiLagModeAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Ord AntiLagModeAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Zero AntiLagModeAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

newtype AntiLagStageAMD Source #

VkAntiLagStageAMD - Report the application stage

See Also

VK_AMD_anti_lag, AntiLagPresentationInfoAMD

Constructors

AntiLagStageAMD Int32 

Bundled Patterns

pattern ANTI_LAG_STAGE_INPUT_AMD :: AntiLagStageAMD

ANTI_LAG_STAGE_INPUT_AMD specifies the stage before processing input.

pattern ANTI_LAG_STAGE_PRESENT_AMD :: AntiLagStageAMD

ANTI_LAG_STAGE_PRESENT_AMD specifies the stage before queuePresentKHR.

Instances

Instances details
Storable AntiLagStageAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Read AntiLagStageAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Show AntiLagStageAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Eq AntiLagStageAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Ord AntiLagStageAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

Zero AntiLagStageAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_anti_lag

pattern AMD_ANTI_LAG_SPEC_VERSION :: forall a. Integral a => a Source #

type AMD_ANTI_LAG_EXTENSION_NAME = "VK_AMD_anti_lag" Source #

pattern AMD_ANTI_LAG_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a Source #