vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_AMD_device_coherent_memory

Description

Name

VK_AMD_device_coherent_memory - device extension

VK_AMD_device_coherent_memory

Name String
VK_AMD_device_coherent_memory
Extension Type
Device extension
Registered Extension Number
230
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
Contact

Other Extension Metadata

Last Modified Date
2019-02-04
Contributors
  • Ping Fu, AMD
  • Timothy Lottes, AMD
  • Tobias Hector, AMD

Description

This extension adds the device coherent and device uncached memory types. Any device accesses to device coherent memory are automatically made visible to any other device access. Device uncached memory indicates to applications that caches are disabled for a particular memory type, which guarantees device coherence.

Device coherent and uncached memory are expected to have lower performance for general access than non-device coherent memory, but can be useful in certain scenarios; particularly so for debugging.

New Structures

New Enum Constants

Version History

  • Revision 1, 2019-02-04 (Tobias Hector)

    • Initial revision

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceCoherentMemoryFeaturesAMD Source #

VkPhysicalDeviceCoherentMemoryFeaturesAMD - Structure describing whether device coherent memory can be supported by an implementation

Members

This structure describes the following feature:

Description

If the PhysicalDeviceCoherentMemoryFeaturesAMD structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceCoherentMemoryFeaturesAMD, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_AMD_device_coherent_memory, Bool32, StructureType

Constructors

PhysicalDeviceCoherentMemoryFeaturesAMD 

Fields

Instances

Instances details
Eq PhysicalDeviceCoherentMemoryFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_device_coherent_memory

Storable PhysicalDeviceCoherentMemoryFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_device_coherent_memory

Show PhysicalDeviceCoherentMemoryFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_device_coherent_memory

FromCStruct PhysicalDeviceCoherentMemoryFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_device_coherent_memory

ToCStruct PhysicalDeviceCoherentMemoryFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_device_coherent_memory

Zero PhysicalDeviceCoherentMemoryFeaturesAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_device_coherent_memory

type AMD_DEVICE_COHERENT_MEMORY_EXTENSION_NAME = "VK_AMD_device_coherent_memory" Source #