vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_ARM_format_pack

Description

Name

VK_ARM_format_pack - device extension

VK_ARM_format_pack

Name String
VK_ARM_format_pack
Extension Type
Device extension
Registered Extension Number
610
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
Contact

Other Extension Metadata

Last Modified Date
2025-03-24
Interactions and External Dependencies; Contributors
  • Jan-Harald Fredriksen, Arm
  • Lisa Wu, Arm
  • Oivind Boge, Arm

Description

This extension adds support for additional 1-, 2- and 4-component formats with 10, 12, or 14 bits of components in 16-bit containers.

New Structures

New Enum Constants

What do we call this extension?

RESOLVED

Many existing extension have the format in the name, but in this case we want to expose multiple formats.

We will describe this set of formats as a “pack”.

Compatibility classes

RESOLVED
Should these additional formats be in the same compatibility class as any other formats? For single-plane formats, we put formats with the same number of bits (but different types) in the same class. Each multi-plane or subsampled format gets its own compatibility class. This is consistent with how existing formats are handled.

Format feature requirements

RESOLVED
The format feature queries could be used to determine what is supported on any given implementation, but it may be useful to establish a baseline requirement in the specification. For that purpose, we require a set of format features - sufficient to enable texture operations - to be supported for the added unsigned integer single-plane formats. Other formats and format features are optional.

Version History

  • Revision 1, 2025-03-24

    • Initial revision

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceFormatPackFeaturesARM Source #

VkPhysicalDeviceFormatPackFeaturesARM - Structure describing whether the additional formats feature is supported by an implementation

Members

This structure describes the following feature:

Description

If the PhysicalDeviceFormatPackFeaturesARM structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceFormatPackFeaturesARM, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_ARM_format_pack, Bool32, StructureType

Instances

Instances details
Eq PhysicalDeviceFormatPackFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_format_pack

Storable PhysicalDeviceFormatPackFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_format_pack

Show PhysicalDeviceFormatPackFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_format_pack

FromCStruct PhysicalDeviceFormatPackFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_format_pack

ToCStruct PhysicalDeviceFormatPackFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_format_pack

Zero PhysicalDeviceFormatPackFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_format_pack

type ARM_FORMAT_PACK_EXTENSION_NAME = "VK_ARM_format_pack" Source #