| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_acquire_drm_display
Description
Name
VK_EXT_acquire_drm_display - instance extension
VK_EXT_acquire_drm_display
- Name String
VK_EXT_acquire_drm_display
- Extension Type
- Instance extension
- Registered Extension Number
- 286
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_EXT_direct_mode_display
- Contact
- Drew DeVault sir@cmpwn.com
Other Extension Metadata
- Last Modified Date
- 2021-06-09
- IP Status
- No known IP claims.
- Contributors
- Simon Zeni, Status Holdings, Ltd.
Description
This extension allows an application to take exclusive control of a display using the Direct Rendering Manager (DRM) interface. When acquired, the display will be under full control of the application until the display is either released or the connector is unplugged.
New Commands
New Enum Constants
Issues
None.
Version History
Revision 1, 2021-05-11 (Simon Zeni)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- acquireDrmDisplayEXT :: MonadIO io => PhysicalDevice -> ("drmFd" ::: Int32) -> DisplayKHR -> io ()
- getDrmDisplayEXT :: MonadIO io => PhysicalDevice -> ("drmFd" ::: Int32) -> ("connectorId" ::: Word32) -> io DisplayKHR
- type EXT_ACQUIRE_DRM_DISPLAY_SPEC_VERSION = 1
- pattern EXT_ACQUIRE_DRM_DISPLAY_SPEC_VERSION :: Integral a => a
- type EXT_ACQUIRE_DRM_DISPLAY_EXTENSION_NAME = "VK_EXT_acquire_drm_display"
- pattern EXT_ACQUIRE_DRM_DISPLAY_EXTENSION_NAME :: (Eq a, IsString a) => a
- newtype DisplayKHR = DisplayKHR Word64
Documentation
Arguments
| :: MonadIO io | |
| => PhysicalDevice |
|
| -> ("drmFd" ::: Int32) |
|
| -> DisplayKHR |
|
| -> io () |
vkAcquireDrmDisplayEXT - Acquire access to a VkDisplayKHR using DRM
Description
All permissions necessary to control the display are granted to the
Vulkan instance associated with the provided physicalDevice until the
display is either released or the connector is unplugged. The provided
drmFd must correspond to the one owned by the physicalDevice. If
not, the error code ERROR_UNKNOWN must be
returned. The DRM FD must have DRM master permissions. If any error is
encountered during the acquisition of the display, the call must
return the error code
ERROR_INITIALIZATION_FAILED.
The provided DRM fd should not be closed before the display is released, attempting to do it may result in undefined behavior.
Return Codes
See Also
Arguments
| :: MonadIO io | |
| => PhysicalDevice |
|
| -> ("drmFd" ::: Int32) |
|
| -> ("connectorId" ::: Word32) |
|
| -> io DisplayKHR |
vkGetDrmDisplayEXT - Query the VkDisplayKHR corresponding to a DRM connector ID
Description
If there is no DisplayKHR corresponding to
the connectorId on the physicalDevice, the returning display
must be NULL_HANDLE. The provided drmFd
must correspond to the one owned by the physicalDevice. If not, the
error code ERROR_UNKNOWN must be
returned. Master permissions are not required, because the file
descriptor is just used for information gathering purposes. The given
connectorId must be a resource owned by the provided drmFd. If
not, the error code ERROR_UNKNOWN must be
returned. If any error is encountered during the identification of the
display, the call must return the error code
ERROR_INITIALIZATION_FAILED.
Return Codes
See Also
type EXT_ACQUIRE_DRM_DISPLAY_SPEC_VERSION = 1 Source #
pattern EXT_ACQUIRE_DRM_DISPLAY_SPEC_VERSION :: Integral a => a Source #
type EXT_ACQUIRE_DRM_DISPLAY_EXTENSION_NAME = "VK_EXT_acquire_drm_display" Source #
pattern EXT_ACQUIRE_DRM_DISPLAY_EXTENSION_NAME :: (Eq a, IsString a) => a Source #
newtype DisplayKHR Source #
VkDisplayKHR - Opaque handle to a display object
See Also
VK_DEFINE_NON_DISPATCHABLE_HANDLE,
VK_KHR_display,
DisplayPlanePropertiesKHR,
DisplayPropertiesKHR,
acquireDrmDisplayEXT,
acquireWinrtDisplayNV,
acquireXlibDisplayEXT,
createDisplayModeKHR,
displayPowerControlEXT,
getDisplayModeProperties2KHR,
getDisplayModePropertiesKHR,
getDisplayPlaneSupportedDisplaysKHR,
getDrmDisplayEXT,
getRandROutputDisplayEXT,
getWinrtDisplayNV,
registerDisplayEventEXT,
releaseDisplayEXT
Constructors
| DisplayKHR Word64 |