| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_depth_bias_control
Description
Name
VK_EXT_depth_bias_control - device extension
VK_EXT_depth_bias_control
- Name String
VK_EXT_depth_bias_control
- Extension Type
- Device extension
- Registered Extension Number
- 284
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Special Use
- Contact
- Extension Proposal
- VK_EXT_depth_bias_control
Other Extension Metadata
- Last Modified Date
- 2023-02-15
- IP Status
- No known IP claims.
- Contributors
- Joshua Ashton, VALVE
- Hans-Kristian Arntzen, VALVE
- Mike Blumenkrantz, VALVE
- Georg Lehmann, VALVE
- Piers Daniell, NVIDIA
- Lionel Landwerlin, INTEL
- Tobias Hector, AMD
- Ricardo Garcia, IGALIA
- Jan-Harald Fredriksen, ARM
- Shahbaz Youssefi, GOOGLE
- Tom Olson, ARM
Description
This extension adds a new structure, DepthBiasRepresentationInfoEXT,
that can be added to a pNext chain of
PipelineRasterizationStateCreateInfo
and allows setting the scaling and representation of depth bias for a
pipeline.
This state can also be set dynamically by using the new structure
mentioned above in combination with the new cmdSetDepthBias2EXT
command.
New Commands
New Structures
Extending
DepthBiasInfoEXT,PipelineRasterizationStateCreateInfo:Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enums
New Enum Constants
Version History
Revision 1, 2022-09-22 (Joshua Ashton)
- Initial draft.
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- cmdSetDepthBias2EXT :: forall (a :: [Type]) io. (Extendss DepthBiasInfoEXT a, PokeChain a, MonadIO io) => CommandBuffer -> DepthBiasInfoEXT a -> io ()
- data DepthBiasInfoEXT (es :: [Type]) = DepthBiasInfoEXT {}
- data DepthBiasRepresentationInfoEXT = DepthBiasRepresentationInfoEXT {}
- data PhysicalDeviceDepthBiasControlFeaturesEXT = PhysicalDeviceDepthBiasControlFeaturesEXT {}
- newtype DepthBiasRepresentationEXT where
- DepthBiasRepresentationEXT Int32
- pattern DEPTH_BIAS_REPRESENTATION_LEAST_REPRESENTABLE_VALUE_FORMAT_EXT :: DepthBiasRepresentationEXT
- pattern DEPTH_BIAS_REPRESENTATION_LEAST_REPRESENTABLE_VALUE_FORCE_UNORM_EXT :: DepthBiasRepresentationEXT
- pattern DEPTH_BIAS_REPRESENTATION_FLOAT_EXT :: DepthBiasRepresentationEXT
- type EXT_DEPTH_BIAS_CONTROL_SPEC_VERSION = 1
- pattern EXT_DEPTH_BIAS_CONTROL_SPEC_VERSION :: Integral a => a
- type EXT_DEPTH_BIAS_CONTROL_EXTENSION_NAME = "VK_EXT_depth_bias_control"
- pattern EXT_DEPTH_BIAS_CONTROL_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
Arguments
| :: forall (a :: [Type]) io. (Extendss DepthBiasInfoEXT a, PokeChain a, MonadIO io) | |
| => CommandBuffer |
|
| -> DepthBiasInfoEXT a |
|
| -> io () |
vkCmdSetDepthBias2EXT - Set depth bias factors and clamp dynamically for a command buffer
Description
This command is functionally identical to
cmdSetDepthBias, but includes
extensible sub-structures that include sType and pNext parameters,
allowing them to be more easily extended.
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
pDepthBiasInfomust be a valid pointer to a validDepthBiasInfoEXTstructure -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetDepthBias2EXT is not affected by conditional rendering
See Also
data DepthBiasInfoEXT (es :: [Type]) Source #
VkDepthBiasInfoEXT - Structure specifying depth bias parameters
Description
If pNext does not contain a DepthBiasRepresentationInfoEXT
structure, then this command is equivalent to including a
DepthBiasRepresentationInfoEXT with depthBiasExact set to
FALSE and depthBiasRepresentation set
to DEPTH_BIAS_REPRESENTATION_LEAST_REPRESENTABLE_VALUE_FORMAT_EXT.
Valid Usage
- If the
depthBiasClamp
feature is not enabled,
depthBiasClampmust be0.0
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_DEPTH_BIAS_INFO_EXT
-
pNextmust beNULLor a pointer to a valid instance ofDepthBiasRepresentationInfoEXT - The
sTypevalue of each structure in thepNextchain must be unique
See Also
VK_EXT_depth_bias_control,
StructureType, cmdSetDepthBias2EXT
Constructors
| DepthBiasInfoEXT | |
Fields
| |
Instances
data DepthBiasRepresentationInfoEXT Source #
VkDepthBiasRepresentationInfoEXT - Structure specifying depth bias parameters
Valid Usage
-
If the
leastRepresentableValueForceUnormRepresentation
feature is not enabled,
depthBiasRepresentationmust not beDEPTH_BIAS_REPRESENTATION_LEAST_REPRESENTABLE_VALUE_FORCE_UNORM_EXT
- If
the
floatRepresentation
feature is not enabled,
depthBiasRepresentationmust not beDEPTH_BIAS_REPRESENTATION_FLOAT_EXT - If the
depthBiasExact
feature is not enabled,
depthBiasExactmust beFALSE
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_DEPTH_BIAS_REPRESENTATION_INFO_EXT
-
depthBiasRepresentationmust be a validDepthBiasRepresentationEXTvalue
See Also
VK_EXT_depth_bias_control,
Bool32, DepthBiasRepresentationEXT,
StructureType
Constructors
| DepthBiasRepresentationInfoEXT | |
Fields
| |
Instances
data PhysicalDeviceDepthBiasControlFeaturesEXT Source #
VkPhysicalDeviceDepthBiasControlFeaturesEXT - Structure indicating support for depth bias scaling and representation control
Members
This structure describes the following feature:
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceDepthBiasControlFeaturesEXT | |
Fields
| |
Instances
newtype DepthBiasRepresentationEXT Source #
VkDepthBiasRepresentationEXT - Specify the depth bias representation
Description
DEPTH_BIAS_REPRESENTATION_LEAST_REPRESENTABLE_VALUE_FORMAT_EXTspecifies that the depth bias representation is a factor of the format’s r as described in https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#primsrast-depthbias-computation.
DEPTH_BIAS_REPRESENTATION_LEAST_REPRESENTABLE_VALUE_FORCE_UNORM_EXTspecifies that the depth bias representation is a factor of a constant r defined by the bit-size or mantissa of the format as described in https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#primsrast-depthbias-computation.DEPTH_BIAS_REPRESENTATION_FLOAT_EXTspecifies that the depth bias representation is a factor of constant r equal to 1.
See Also
Constructors
| DepthBiasRepresentationEXT Int32 |
Bundled Patterns
Instances
type EXT_DEPTH_BIAS_CONTROL_SPEC_VERSION = 1 Source #
pattern EXT_DEPTH_BIAS_CONTROL_SPEC_VERSION :: Integral a => a Source #
type EXT_DEPTH_BIAS_CONTROL_EXTENSION_NAME = "VK_EXT_depth_bias_control" Source #
pattern EXT_DEPTH_BIAS_CONTROL_EXTENSION_NAME :: (Eq a, IsString a) => a Source #