| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_image_compression_control_swapchain
Description
Name
VK_EXT_image_compression_control_swapchain - device extension
VK_EXT_image_compression_control_swapchain
- Name String
VK_EXT_image_compression_control_swapchain
- Extension Type
- Device extension
- Registered Extension Number
- 438
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_EXT_image_compression_control
- Contact
Other Extension Metadata
- Last Modified Date
- 2022-05-02
- IP Status
- No known IP claims.
- Contributors
- Jan-Harald Fredriksen, Arm
- Graeme Leese, Broadcom
- Andrew Garrard, Imagination
- Lisa Wu, Arm
- Peter Kohaut, Arm
- Ian Elliott, Google
Description
This extension enables fixed-rate image compression and adds the ability to control when this kind of compression can be applied to swapchain images.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
Version History
Revision 1, 2022-05-02 (Jan-Harald Fredriksen)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceImageCompressionControlSwapchainFeaturesEXT = PhysicalDeviceImageCompressionControlSwapchainFeaturesEXT {}
- type EXT_IMAGE_COMPRESSION_CONTROL_SWAPCHAIN_SPEC_VERSION = 1
- pattern EXT_IMAGE_COMPRESSION_CONTROL_SWAPCHAIN_SPEC_VERSION :: Integral a => a
- type EXT_IMAGE_COMPRESSION_CONTROL_SWAPCHAIN_EXTENSION_NAME = "VK_EXT_image_compression_control_swapchain"
- pattern EXT_IMAGE_COMPRESSION_CONTROL_SWAPCHAIN_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceImageCompressionControlSwapchainFeaturesEXT Source #
VkPhysicalDeviceImageCompressionControlSwapchainFeaturesEXT - Structure describing whether per-swapchain image compression controls can be supported by an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceImageCompressionControlSwapchainFeaturesEXT
structure is included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceImageCompressionControlSwapchainFeaturesEXT, it must
add an instance of the structure, with the desired feature members set
to TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
VK_EXT_image_compression_control_swapchain,
Bool32,
StructureType
Constructors
| PhysicalDeviceImageCompressionControlSwapchainFeaturesEXT | |
Fields | |
Instances
pattern EXT_IMAGE_COMPRESSION_CONTROL_SWAPCHAIN_SPEC_VERSION :: Integral a => a Source #
type EXT_IMAGE_COMPRESSION_CONTROL_SWAPCHAIN_EXTENSION_NAME = "VK_EXT_image_compression_control_swapchain" Source #
pattern EXT_IMAGE_COMPRESSION_CONTROL_SWAPCHAIN_EXTENSION_NAME :: (Eq a, IsString a) => a Source #