vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_image_view_min_lod

Description

Name

VK_EXT_image_view_min_lod - device extension

VK_EXT_image_view_min_lod

Name String
VK_EXT_image_view_min_lod
Extension Type
Device extension
Registered Extension Number
392
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
Contact

Other Extension Metadata

Last Modified Date
2021-11-09
IP Status
No known IP claims.
Contributors
  • Joshua Ashton, Valve
  • Hans-Kristian Arntzen, Valve
  • Samuel Iglesias Gonsalvez, Igalia
  • Tobias Hector, AMD
  • Faith Ekstrand, Intel
  • Tom Olson, ARM

Description

This extension allows applications to clamp the minimum LOD value during Image Level(s) Selection, Texel Gathering and Integer Texel Coordinate Operations with a given ImageView by ImageViewMinLodCreateInfoEXT::minLod.

This extension may be useful to restrict a ImageView to only mips which have been uploaded, and the use of fractional minLod can be useful for smoothly introducing new mip levels when using linear mipmap filtering.

New Structures

New Enum Constants

Version History

  • Revision 1, 2021-07-06 (Joshua Ashton)

    • Initial version

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceImageViewMinLodFeaturesEXT Source #

VkPhysicalDeviceImageViewMinLodFeaturesEXT - Structure describing whether clamping the min LOD of an image view is supported by the implementation

Members

This structure describes the following feature:

Description

If the PhysicalDeviceImageViewMinLodFeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceImageViewMinLodFeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_image_view_min_lod, Bool32, StructureType

Constructors

PhysicalDeviceImageViewMinLodFeaturesEXT 

Fields

Instances

Instances details
Eq PhysicalDeviceImageViewMinLodFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

Storable PhysicalDeviceImageViewMinLodFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

Show PhysicalDeviceImageViewMinLodFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

FromCStruct PhysicalDeviceImageViewMinLodFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

ToCStruct PhysicalDeviceImageViewMinLodFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

Zero PhysicalDeviceImageViewMinLodFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

data ImageViewMinLodCreateInfoEXT Source #

VkImageViewMinLodCreateInfoEXT - Structure describing the minimum LOD of an image view

Description

If the pNext chain includes a ImageViewMinLodCreateInfoEXT structure, then that structure includes a parameter specifying a value to clamp the minimum LOD value during Image Level(s) Selection, Texel Gathering and Integer Texel Coordinate Operations.

If the image view contains ImageViewMinLodCreateInfoEXT and it is used as part of a sampling operation:

minLodFloatimageView = minLod

otherwise:

minLodFloatimageView = 0.0

An integer variant of this parameter is also defined for sampling operations which access integer mipmap levels:

minLodIntegerimageView = ⌊minLodFloatimageView⌋

Valid Usage

  • If the minLod feature is not enabled, minLod must be 0.0
  • minLod must be less or equal to the index of the last mipmap level accessible to the view

Valid Usage (Implicit)

See Also

VK_EXT_image_view_min_lod, StructureType

Constructors

ImageViewMinLodCreateInfoEXT 

Fields

Instances

Instances details
Eq ImageViewMinLodCreateInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

Storable ImageViewMinLodCreateInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

Show ImageViewMinLodCreateInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

FromCStruct ImageViewMinLodCreateInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

ToCStruct ImageViewMinLodCreateInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

Zero ImageViewMinLodCreateInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_image_view_min_lod

type EXT_IMAGE_VIEW_MIN_LOD_EXTENSION_NAME = "VK_EXT_image_view_min_lod" Source #