vulkan
Safe HaskellSafe-Inferred
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_index_type_uint8

Description

Name

VK_EXT_index_type_uint8 - device extension

VK_EXT_index_type_uint8

Name String
VK_EXT_index_type_uint8
Extension Type
Device extension
Registered Extension Number
266
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
Deprecation State
Contact

Other Extension Metadata

Last Modified Date
2019-05-02
IP Status
No known IP claims.
Contributors
  • Jeff Bolz, NVIDIA

Description

This extension allows uint8_t indices to be used with cmdBindIndexBuffer.

Promotion to VK_KHR_index_type_uint8

All functionality in this extension is included in VK_KHR_index_type_uint8, with the suffix changed to KHR. The original enum names are still available as aliases of the KHR functionality.

New Structures

New Enum Constants

Version History

  • Revision 1, 2019-05-02 (Piers Daniell)

    • Internal revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

type EXT_INDEX_TYPE_UINT8_EXTENSION_NAME = "VK_EXT_index_type_uint8" Source #

pattern EXT_INDEX_TYPE_UINT8_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a Source #

data PhysicalDeviceIndexTypeUint8FeaturesKHR Source #

VkPhysicalDeviceIndexTypeUint8FeaturesKHR - Structure describing whether uint8 index type can be used

Members

This structure describes the following feature:

Description

If the PhysicalDeviceIndexTypeUint8FeaturesKHR structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. PhysicalDeviceIndexTypeUint8FeaturesKHR can also be used in the pNext chain of DeviceCreateInfo to selectively enable these features.

Valid Usage (Implicit)

See Also

VK_EXT_index_type_uint8, VK_KHR_index_type_uint8, Bool32, StructureType

Constructors

PhysicalDeviceIndexTypeUint8FeaturesKHR 

Fields

Instances

Instances details
Storable PhysicalDeviceIndexTypeUint8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_index_type_uint8

Show PhysicalDeviceIndexTypeUint8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_index_type_uint8

Eq PhysicalDeviceIndexTypeUint8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_index_type_uint8

FromCStruct PhysicalDeviceIndexTypeUint8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_index_type_uint8

ToCStruct PhysicalDeviceIndexTypeUint8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_index_type_uint8

Zero PhysicalDeviceIndexTypeUint8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_index_type_uint8