vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

Description

Name

VK_EXT_legacy_vertex_attributes - device extension

VK_EXT_legacy_vertex_attributes

Name String
VK_EXT_legacy_vertex_attributes
Extension Type
Device extension
Registered Extension Number
496
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_EXT_vertex_input_dynamic_state
Special Use
Contact
Extension Proposal
VK_EXT_legacy_vertex_attributes

Other Extension Metadata

Last Modified Date
2024-02-23
IP Status
No known IP claims.
Contributors
  • Mike Blumenkrantz, Valve
  • Piers Daniell, NVIDIA
  • Spencer Fricke, LunarG
  • Alyssa Rosenzweig, Valve

Description

This extension adds support for legacy features of (non-64-bit) vertex attributes as found in OpenGL:

  • Vertex attributes loaded from arbitrary buffer alignments
  • Vertex attributes using arbitrary strides
  • Vertex attributes where the component data type of the binding does not match the component numeric type of the shader input

These features are only usable with dynamic vertex input. Unaligned loads of vertex attributes may incur performance penalties, indicated with a property.

New Structures

New Enum Constants

Issues

  1. ) Should implementations convert float/integer values?

RESOLVED: No. When fetching an integer data type from float values or float data types from integer values, the resulting shader values are implementation-dependent.

Version History

  • Revision 1, 2024-02-16 (Mike Blumenkrantz)

    • Initial revision

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceLegacyVertexAttributesFeaturesEXT Source #

VkPhysicalDeviceLegacyVertexAttributesFeaturesEXT - Structure describing compatibility features for vertex attributes

Members

This structure describes the following features:

Description

If the PhysicalDeviceLegacyVertexAttributesFeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceLegacyVertexAttributesFeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_legacy_vertex_attributes, Bool32, StructureType

Constructors

PhysicalDeviceLegacyVertexAttributesFeaturesEXT 

Fields

  • legacyVertexAttributes :: Bool

    legacyVertexAttributes specifies whether compatibility features for vertex attributes are supported when using dynamic vertex input state.

Instances

Instances details
Eq PhysicalDeviceLegacyVertexAttributesFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

Storable PhysicalDeviceLegacyVertexAttributesFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

Show PhysicalDeviceLegacyVertexAttributesFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

FromCStruct PhysicalDeviceLegacyVertexAttributesFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

ToCStruct PhysicalDeviceLegacyVertexAttributesFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

Zero PhysicalDeviceLegacyVertexAttributesFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

data PhysicalDeviceLegacyVertexAttributesPropertiesEXT Source #

VkPhysicalDeviceLegacyVertexAttributesPropertiesEXT - Structure describing properties for legacy vertex attributes

Members

This structure describes the following features:

Description

If the PhysicalDeviceLegacyVertexAttributesPropertiesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceLegacyVertexAttributesPropertiesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_legacy_vertex_attributes, Bool32, StructureType

Constructors

PhysicalDeviceLegacyVertexAttributesPropertiesEXT 

Fields

  • nativeUnalignedPerformance :: Bool

    nativeUnalignedPerformance specifies whether unaligned vertex fetches do not incur significant performance penalties as compared to aligned fetches.

Instances

Instances details
Eq PhysicalDeviceLegacyVertexAttributesPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

Storable PhysicalDeviceLegacyVertexAttributesPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

Show PhysicalDeviceLegacyVertexAttributesPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

FromCStruct PhysicalDeviceLegacyVertexAttributesPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

ToCStruct PhysicalDeviceLegacyVertexAttributesPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

Zero PhysicalDeviceLegacyVertexAttributesPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_legacy_vertex_attributes

type EXT_LEGACY_VERTEX_ATTRIBUTES_EXTENSION_NAME = "VK_EXT_legacy_vertex_attributes" Source #