| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_load_store_op_none
Description
Name
VK_EXT_load_store_op_none - device extension
VK_EXT_load_store_op_none
- Name String
VK_EXT_load_store_op_none
- Extension Type
- Device extension
- Registered Extension Number
- 401
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- None
- Deprecation State
Promoted to VK_KHR_load_store_op_none extension
- Which in turn was promoted to Vulkan 1.4
- Contact
Other Extension Metadata
- Last Modified Date
- 2021-06-06
- Contributors
- Shahbaz Youssefi, Google
- Bill Licea-Kane, Qualcomm Technologies, Inc.
- Tobias Hector, AMD
Description
This extension incorporates ATTACHMENT_STORE_OP_NONE_EXT from
VK_QCOM_render_pass_store_ops, enabling applications to avoid
unnecessary synchronization when an attachment is not written during a
render pass.
Additionally, ATTACHMENT_LOAD_OP_NONE_EXT is introduced to avoid
unnecessary synchronization when an attachment is not used during a
render pass at all. In combination with ATTACHMENT_STORE_OP_NONE_EXT,
this is useful as an alternative to preserve attachments in applications
that cannot decide if an attachment will be used in a render pass until
after the necessary pipelines have been created.
Promotion to VK_KHR_load_store_op_none
All functionality in this extension is included in
VK_KHR_load_store_op_none, with the suffix changed to KHR. The
original enum names are still available as aliases of the KHR
functionality.
New Enum Constants
EXT_LOAD_STORE_OP_NONE_SPEC_VERSIONExtending
AttachmentLoadOp:Extending
AttachmentStoreOp:
While ATTACHMENT_STORE_OP_NONE
is part of Vulkan 1.3, this extension was not promoted to core either in
whole or in part. This functionality was promoted from
VK_KHR_dynamic_rendering.
Version History
Revision 1, 2021-06-06 (Shahbaz Youssefi)
- Initial revision, based on VK_QCOM_render_pass_store_ops.
- Added VK_ATTACHMENT_LOAD_OP_NONE_EXT.
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
pattern ATTACHMENT_LOAD_OP_NONE_EXT :: AttachmentLoadOp Source #
pattern ATTACHMENT_STORE_OP_NONE_EXT :: AttachmentStoreOp Source #
type EXT_LOAD_STORE_OP_NONE_SPEC_VERSION = 1 Source #
pattern EXT_LOAD_STORE_OP_NONE_SPEC_VERSION :: Integral a => a Source #
type EXT_LOAD_STORE_OP_NONE_EXTENSION_NAME = "VK_EXT_load_store_op_none" Source #
pattern EXT_LOAD_STORE_OP_NONE_EXTENSION_NAME :: (Eq a, IsString a) => a Source #