vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_non_seamless_cube_map

Description

Name

VK_EXT_non_seamless_cube_map - device extension

VK_EXT_non_seamless_cube_map

Name String
VK_EXT_non_seamless_cube_map
Extension Type
Device extension
Registered Extension Number
423
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
Special Uses
Contact
Extension Proposal
VK_EXT_non_seamless_cube_map

Other Extension Metadata

Last Modified Date
2021-09-04
IP Status
No known IP claims.
Contributors
  • Georg Lehmann

Description

This extension provides functionality to disable cube map edge handling on a per sampler level which matches the behavior of other graphics APIs.

This extension may be useful for building translation layers for those APIs or for porting applications that rely on this cube map behavior.

New Structures

New Enum Constants

Version History

  • Revision 1, 2021-09-04 (Georg Lehmann)

    • First Version

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceNonSeamlessCubeMapFeaturesEXT Source #

VkPhysicalDeviceNonSeamlessCubeMapFeaturesEXT - Structure describing features to disable seamless cube maps

Members

This structure describes the following feature:

Description

If the PhysicalDeviceNonSeamlessCubeMapFeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceNonSeamlessCubeMapFeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_non_seamless_cube_map, Bool32, StructureType

Constructors

PhysicalDeviceNonSeamlessCubeMapFeaturesEXT 

Fields

Instances

Instances details
Eq PhysicalDeviceNonSeamlessCubeMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_non_seamless_cube_map

Storable PhysicalDeviceNonSeamlessCubeMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_non_seamless_cube_map

Show PhysicalDeviceNonSeamlessCubeMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_non_seamless_cube_map

FromCStruct PhysicalDeviceNonSeamlessCubeMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_non_seamless_cube_map

ToCStruct PhysicalDeviceNonSeamlessCubeMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_non_seamless_cube_map

Zero PhysicalDeviceNonSeamlessCubeMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_non_seamless_cube_map

type EXT_NON_SEAMLESS_CUBE_MAP_EXTENSION_NAME = "VK_EXT_non_seamless_cube_map" Source #