| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_rasterization_order_attachment_access
Description
Name
VK_EXT_rasterization_order_attachment_access - device extension
VK_EXT_rasterization_order_attachment_access
- Name String
VK_EXT_rasterization_order_attachment_access
- Extension Type
- Device extension
- Registered Extension Number
- 464
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Contact
- Extension Proposal
- VK_EXT_rasterization_order_attachment_access
Other Extension Metadata
- Last Modified Date
- 2022-07-04
- IP Status
- No known IP claims.
- Contributors
- Tobias Hector, AMD
- Jan-Harald Fredriksen, Arm
Description
This extension extends the mechanism of input attachments to allow access to framebuffer attachments that are used both as input and as color or depth/stencil attachments from one fragment to the next, in rasterization order, without explicit synchronization.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enums
New Enum Constants
EXT_RASTERIZATION_ORDER_ATTACHMENT_ACCESS_SPEC_VERSIONExtending
PipelineColorBlendStateCreateFlagBits:Extending
PipelineDepthStencilStateCreateFlagBits:Extending
StructureType:Extending
SubpassDescriptionFlagBits:
Examples
None.
Version History
Revision 1, 2022-07-04 (Jan-Harald Fredriksen)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT = PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT {}
- type EXT_RASTERIZATION_ORDER_ATTACHMENT_ACCESS_SPEC_VERSION = 1
- pattern EXT_RASTERIZATION_ORDER_ATTACHMENT_ACCESS_SPEC_VERSION :: Integral a => a
- type EXT_RASTERIZATION_ORDER_ATTACHMENT_ACCESS_EXTENSION_NAME = "VK_EXT_rasterization_order_attachment_access"
- pattern EXT_RASTERIZATION_ORDER_ATTACHMENT_ACCESS_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT Source #
VkPhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT - Structure describing whether rasterization order attachment access can be supported by an implementation
Members
This structure describes the following features:
Description
If the PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT
structure is included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT, it must
add an instance of the structure, with the desired feature members set
to TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
VK_ARM_rasterization_order_attachment_access,
VK_EXT_rasterization_order_attachment_access,
Bool32,
StructureType
Constructors
| PhysicalDeviceRasterizationOrderAttachmentAccessFeaturesEXT | |
Fields | |
Instances
pattern EXT_RASTERIZATION_ORDER_ATTACHMENT_ACCESS_SPEC_VERSION :: Integral a => a Source #
type EXT_RASTERIZATION_ORDER_ATTACHMENT_ACCESS_EXTENSION_NAME = "VK_EXT_rasterization_order_attachment_access" Source #
pattern EXT_RASTERIZATION_ORDER_ATTACHMENT_ACCESS_EXTENSION_NAME :: (Eq a, IsString a) => a Source #