vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Description

Name

VK_EXT_ray_tracing_invocation_reorder - device extension

VK_EXT_ray_tracing_invocation_reorder

Name String
VK_EXT_ray_tracing_invocation_reorder
Extension Type
Device extension
Registered Extension Number
582
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_ray_tracing_pipeline
SPIR-V Dependencies
Contact
Extension Proposal
VK_EXT_ray_tracing_invocation_reorder

Other Extension Metadata

Last Modified Date
2025-11-12
Interactions and External Dependencies
Contributors
  • Eric Werness, NVIDIA
  • Ashwin Lele, NVIDIA
  • Daniel Koch, NVIDIA
  • Vikram Kushwaha, NVIDIA
  • Piers Daniell, NVIDIA
  • Stu Smith, AMD
  • Aaron Hagan, AMD
  • Tyler Nowicki, AMD
  • Sebastian Neubauer, AMD
  • Radoslaw Drabinski, Intel
  • Sven Woop, Intel
  • Aleksandra Krstic, QUALCOMM
  • Andrew Garrard, Imagination Technologies
  • Mathieu Robart, Arm Limited
  • Tom Olson, Khronos
  • Ralph Potter, Samsung Electronics
  • Antonio Caggiano, LunarG

Description

The ray tracing pipeline API provides some ability to reorder for locality, but it is useful to have more control over how the reordering happens and what information is included in the reordering. The shader API provides a hit object to contain result information from the hit which can be used as part of the explicit sorting plus options that contain an integer for hint bits to use to add more coherency.

New Structures

New Enums

New Enum Constants

Version History

  • Revision 1, 2025-11-12 (Eric Werness)

    • Internal development - forked from NV

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceRayTracingInvocationReorderFeaturesEXT Source #

VkPhysicalDeviceRayTracingInvocationReorderFeaturesEXT - Structure describing feature to control ray tracing invocation reordering

Members

This structure describes the following feature:

Description

If the PhysicalDeviceRayTracingInvocationReorderFeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceRayTracingInvocationReorderFeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_ray_tracing_invocation_reorder, Bool32, StructureType

Constructors

PhysicalDeviceRayTracingInvocationReorderFeaturesEXT 

Fields

Instances

Instances details
Eq PhysicalDeviceRayTracingInvocationReorderFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Storable PhysicalDeviceRayTracingInvocationReorderFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Show PhysicalDeviceRayTracingInvocationReorderFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

FromCStruct PhysicalDeviceRayTracingInvocationReorderFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

ToCStruct PhysicalDeviceRayTracingInvocationReorderFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Zero PhysicalDeviceRayTracingInvocationReorderFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

data PhysicalDeviceRayTracingInvocationReorderPropertiesEXT Source #

VkPhysicalDeviceRayTracingInvocationReorderPropertiesEXT - Structure describing shader module identifier properties of an implementation

Description

If rayTracingInvocationReorderReorderingHint is RAY_TRACING_INVOCATION_REORDER_MODE_REORDER_EXT there must exist conditions under which the ordered set of invocations before a reorder instruction is different than the ordered set of invocations after the reorder instruction. The ordering of a set of invocations is determined by the SubgroupId of an invocation’s subgroup and the SubGroupInvocationId of an invocation within that subgroup.

The reorder instructions are:

Because the extension changes how hits are managed there is a compatibility reason to expose the extension even when an implementation does not have sorting active.

If the PhysicalDeviceRayTracingInvocationReorderPropertiesEXT structure is included in the pNext chain of the PhysicalDeviceProperties2 structure passed to getPhysicalDeviceProperties2, it is filled in with each corresponding implementation-dependent property.

Valid Usage (Implicit)

See Also

VK_EXT_ray_tracing_invocation_reorder, RayTracingInvocationReorderModeEXT, StructureType

Constructors

PhysicalDeviceRayTracingInvocationReorderPropertiesEXT 

Fields

Instances

Instances details
Eq PhysicalDeviceRayTracingInvocationReorderPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Storable PhysicalDeviceRayTracingInvocationReorderPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Show PhysicalDeviceRayTracingInvocationReorderPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

FromCStruct PhysicalDeviceRayTracingInvocationReorderPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

ToCStruct PhysicalDeviceRayTracingInvocationReorderPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Zero PhysicalDeviceRayTracingInvocationReorderPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

newtype RayTracingInvocationReorderModeEXT Source #

VkRayTracingInvocationReorderModeEXT - Enum providing a hint on how the application may reorder

Description

See Also

VK_EXT_ray_tracing_invocation_reorder, VK_NV_ray_tracing_invocation_reorder, PhysicalDeviceRayTracingInvocationReorderPropertiesEXT, PhysicalDeviceRayTracingInvocationReorderPropertiesNV

Instances

Instances details
Eq RayTracingInvocationReorderModeEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Ord RayTracingInvocationReorderModeEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Storable RayTracingInvocationReorderModeEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Read RayTracingInvocationReorderModeEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Show RayTracingInvocationReorderModeEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

Zero RayTracingInvocationReorderModeEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ray_tracing_invocation_reorder

type EXT_RAY_TRACING_INVOCATION_REORDER_EXTENSION_NAME = "VK_EXT_ray_tracing_invocation_reorder" Source #