vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_scalar_block_layout

Description

Name

VK_EXT_scalar_block_layout - device extension

VK_EXT_scalar_block_layout

Name String
VK_EXT_scalar_block_layout
Extension Type
Device extension
Registered Extension Number
222
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
Deprecation State
Contact

Other Extension Metadata

Last Modified Date
2018-11-14
Contributors
  • Jeff Bolz
  • Jan-Harald Fredriksen
  • Graeme Leese
  • Faith Ekstrand
  • John Kessenich

Description

This extension enables C-like structure layout for SPIR-V blocks. It modifies the alignment rules for uniform buffers, storage buffers and push constants, allowing non-scalar types to be aligned solely based on the size of their components, without additional requirements.

Promotion to Vulkan 1.2

Vulkan APIs in this extension are included in core Vulkan 1.2, with the EXT suffix omitted. However, if Vulkan 1.2 is supported and this extension is not, the scalarBlockLayout capability is optional. External interactions defined by this extension, such as SPIR-V token names, retain their original names. The original Vulkan API names are still available as aliases of the core functionality.

Promotion to Vulkan 1.4

If Vulkan 1.4 is supported, support for the scalarBlockLayout capability is required.

New Structures

New Enum Constants

Version History

  • Revision 1, 2018-11-14 (Tobias Hector)

    • Initial draft

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Documentation

type EXT_SCALAR_BLOCK_LAYOUT_EXTENSION_NAME = "VK_EXT_scalar_block_layout" Source #