vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_shader_64bit_indexing

Description

Name

VK_EXT_shader_64bit_indexing - device extension

VK_EXT_shader_64bit_indexing

Name String
VK_EXT_shader_64bit_indexing
Extension Type
Device extension
Registered Extension Number
628
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
SPIR-V Dependencies
Contact
Extension Proposal
VK_EXT_shader_64bit_indexing

Other Extension Metadata

Last Modified Date
2025-05-02
Interactions and External Dependencies
Contributors
  • Jeff Bolz, NVIDIA

Description

This extension relaxes the maxStorageBufferRange limit, allowing more than 4GB to be accessed through a buffer binding (or through a buffer device address). It adds pipeline and shader creation flags that request 64-bit addressing support, and defines which addressing calculations use 64 bits of range.

New Structures

New Enum Constants

Version History

  • Revision 1, 2025-05-02 (Jeff Bolz)

    • Initial revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceShader64BitIndexingFeaturesEXT Source #

VkPhysicalDeviceShader64BitIndexingFeaturesEXT - Structure describing 64-bit indexing features that can be supported by an implementation

Members

This structure describes the following features:

Description

If the PhysicalDeviceShader64BitIndexingFeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceShader64BitIndexingFeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_shader_64bit_indexing, Bool32, StructureType

Constructors

PhysicalDeviceShader64BitIndexingFeaturesEXT 

Fields

Instances

Instances details
Eq PhysicalDeviceShader64BitIndexingFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_64bit_indexing

Storable PhysicalDeviceShader64BitIndexingFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_64bit_indexing

Show PhysicalDeviceShader64BitIndexingFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_64bit_indexing

FromCStruct PhysicalDeviceShader64BitIndexingFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_64bit_indexing

ToCStruct PhysicalDeviceShader64BitIndexingFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_64bit_indexing

Zero PhysicalDeviceShader64BitIndexingFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_64bit_indexing

type EXT_SHADER_64BIT_INDEXING_EXTENSION_NAME = "VK_EXT_shader_64bit_indexing" Source #

newtype ShaderCreateFlagBitsEXT Source #

VkShaderCreateFlagBitsEXT - Bitmask controlling how a shader object is created

Description

See Also

VK_EXT_shader_object, ShaderCreateFlagsEXT

Instances

Instances details
Bits ShaderCreateFlagBitsEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_object

FiniteBits ShaderCreateFlagBitsEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_object

Eq ShaderCreateFlagBitsEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_object

Ord ShaderCreateFlagBitsEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_object

Storable ShaderCreateFlagBitsEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_object

Read ShaderCreateFlagBitsEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_object

Show ShaderCreateFlagBitsEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_object

Zero ShaderCreateFlagBitsEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_object