vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_shader_float8

Description

Name

VK_EXT_shader_float8 - device extension

VK_EXT_shader_float8

Name String
VK_EXT_shader_float8
Extension Type
Device extension
Registered Extension Number
568
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
API Interactions
  • Interacts with VK_KHR_cooperative_matrix
SPIR-V Dependencies
Contact
Extension Proposal
VK_EXT_shader_float8

Other Extension Metadata

Last Modified Date
2025-04-16
IP Status
No known IP claims.
Contributors
  • Kévin Petit, Arm Ltd.
  • Stu Smith, AMD
  • Jeff Bolz, NVIDIA
  • Craig Graham, Samsung

Description

This extension enables support for 8-bit floating-point data types as defined in SPV_EXT_float8.

New Structures

New Enum Constants

If VK_KHR_cooperative_matrix is supported:

New SPIR-V Capabilities

Issues

1) Resolve interactions with the changes VK_KHR_shader_float16 makes to rules for denorm flushing (always allowed by default for all FP formats). How to describe the requirement to preserve subnormals?

+ RESOLVED: Subnormals are always preserved when converting FP8 values to IEEE 754 binary 16. In all other cases, subnormals may be flushed to zero.

+

Version History

  • Revision 1, 2025-04-16 (Kévin Petit)

    • Initial draft

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceShaderFloat8FeaturesEXT Source #

VkPhysicalDeviceShaderFloat8FeaturesEXT - Structure describing float8 features that can be supported by the implementation

Members

This structure describes the following features:

Description

If the PhysicalDeviceShaderFloat8FeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceShaderFloat8FeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_shader_float8, Bool32, StructureType

Constructors

PhysicalDeviceShaderFloat8FeaturesEXT 

Fields

  • shaderFloat8 :: Bool

    shaderFloat8 indicates whether the implementation supports shaders with the Float8EXT capability.

  • shaderFloat8CooperativeMatrix :: Bool

    shaderFloat8CooperativeMatrix indicates whether the implementation supports shaders with the Float8CooperativeMatrixEXT capability.

Instances

Instances details
Eq PhysicalDeviceShaderFloat8FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_float8

Storable PhysicalDeviceShaderFloat8FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_float8

Show PhysicalDeviceShaderFloat8FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_float8

FromCStruct PhysicalDeviceShaderFloat8FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_float8

ToCStruct PhysicalDeviceShaderFloat8FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_float8

Zero PhysicalDeviceShaderFloat8FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_float8

type EXT_SHADER_FLOAT8_EXTENSION_NAME = "VK_EXT_shader_float8" Source #

newtype ComponentTypeKHR Source #

VkComponentTypeKHR - Specify SPIR-V cooperative matrix component type

Description

See Also

VK_KHR_cooperative_matrix, VK_NV_cooperative_matrix, VK_NV_cooperative_vector, ConvertCooperativeVectorMatrixInfoNV, CooperativeMatrixFlexibleDimensionsPropertiesNV, CooperativeMatrixPropertiesKHR, CooperativeMatrixPropertiesNV, CooperativeVectorPropertiesNV

Constructors

ComponentTypeKHR Int32 

Instances

Instances details
Eq ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector

Ord ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector

Storable ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector

Read ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector

Show ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector

Zero ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector