vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_shader_image_atomic_int64

Description

Name

VK_EXT_shader_image_atomic_int64 - device extension

VK_EXT_shader_image_atomic_int64

Name String
VK_EXT_shader_image_atomic_int64
Extension Type
Device extension
Registered Extension Number
235
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
SPIR-V Dependencies
Contact

Other Extension Metadata

Last Modified Date
2020-07-14
IP Status
No known IP claims.
Interactions and External Dependencies
Contributors
  • Matthaeus Chajdas, AMD
  • Graham Wihlidal, Epic Games
  • Tobias Hector, AMD
  • Jeff Bolz, Nvidia
  • Faith Ekstrand, Intel

Description

This extension extends existing 64-bit integer atomic support to enable these operations on images as well.

When working with large 2- or 3-dimensional data sets (e.g. rasterization or screen-space effects), image accesses are generally more efficient than equivalent buffer accesses. This extension allows applications relying on 64-bit integer atomics in this manner to quickly improve performance with only relatively minor code changes.

64-bit integer atomic support is guaranteed for optimally tiled images with the FORMAT_R64_UINT and FORMAT_R64_SINT formats.

New Structures

New Enum Constants

Version History

  • Revision 1, 2020-07-14 (Tobias Hector)

    • Initial draft

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceShaderImageAtomicInt64FeaturesEXT Source #

VkPhysicalDeviceShaderImageAtomicInt64FeaturesEXT - Structure describing features supported by VK_EXT_shader_image_atomic_int64

Members

This structure describes the following features:

Description

If the VkPhysicalDeviceShaderAtomicInt64FeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by VkPhysicalDeviceShaderAtomicInt64FeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_shader_image_atomic_int64, Bool32, StructureType

Constructors

PhysicalDeviceShaderImageAtomicInt64FeaturesEXT 

Fields

  • shaderImageInt64Atomics :: Bool

    shaderImageInt64Atomics indicates whether shaders can support 64-bit unsigned and signed integer atomic operations on images.

  • sparseImageInt64Atomics :: Bool

    sparseImageInt64Atomics indicates whether 64-bit integer atomics can be used on sparse images.

Instances

Instances details
Eq PhysicalDeviceShaderImageAtomicInt64FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_image_atomic_int64

Storable PhysicalDeviceShaderImageAtomicInt64FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_image_atomic_int64

Show PhysicalDeviceShaderImageAtomicInt64FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_image_atomic_int64

FromCStruct PhysicalDeviceShaderImageAtomicInt64FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_image_atomic_int64

ToCStruct PhysicalDeviceShaderImageAtomicInt64FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_image_atomic_int64

Zero PhysicalDeviceShaderImageAtomicInt64FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_image_atomic_int64

type EXT_SHADER_IMAGE_ATOMIC_INT64_EXTENSION_NAME = "VK_EXT_shader_image_atomic_int64" Source #