vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_shader_long_vector

Description

Name

VK_EXT_shader_long_vector - device extension

VK_EXT_shader_long_vector

Name String
VK_EXT_shader_long_vector
Extension Type
Device extension
Registered Extension Number
636
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
Vulkan Version 1.2
API Interactions
  • Interacts with VK_KHR_workgroup_memory_explicit_layout
SPIR-V Dependencies
Contact
Extension Proposal
VK_EXT_shader_long_vector

Other Extension Metadata

Last Modified Date
2025-06-24
Interactions and External Dependencies
Contributors
  • Jeff Bolz, NVIDIA
  • Spencer Fricke, LunarG

Description

This extension adds support for using vector types with more than four components in SPIR-V.

Long vector types are defined by the SPV_EXT_long_vector SPIR-V extension and can be used with the GL_EXT_long_vector GLSL extension.

New Structures

New Enum Constants

New SPIR-V Capabilities

Version History

  • Revision 1, 2025-06-24 (Jeff Bolz)

    • Initial revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceShaderLongVectorFeaturesEXT Source #

VkPhysicalDeviceShaderLongVectorFeaturesEXT - Structure describing long vector features that can be supported by an implementation

Members

This structure describes the following features:

Description

If the PhysicalDeviceShaderLongVectorFeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceShaderLongVectorFeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_shader_long_vector, Bool32, StructureType

Constructors

PhysicalDeviceShaderLongVectorFeaturesEXT 

Fields

  • longVector :: Bool

    longVector indicates that the implementation supports the LongVectorEXT SPIR-V capability.

Instances

Instances details
Eq PhysicalDeviceShaderLongVectorFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

Storable PhysicalDeviceShaderLongVectorFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

Show PhysicalDeviceShaderLongVectorFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

FromCStruct PhysicalDeviceShaderLongVectorFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

ToCStruct PhysicalDeviceShaderLongVectorFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

Zero PhysicalDeviceShaderLongVectorFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

data PhysicalDeviceShaderLongVectorPropertiesEXT Source #

VkPhysicalDeviceShaderLongVectorPropertiesEXT - Structure describing long vector properties supported by an implementation

Description

If the PhysicalDeviceShaderLongVectorPropertiesEXT structure is included in the pNext chain of the PhysicalDeviceProperties2 structure passed to getPhysicalDeviceProperties2, it is filled in with each corresponding implementation-dependent property.

Valid Usage (Implicit)

See Also

VK_EXT_shader_long_vector, StructureType

Constructors

PhysicalDeviceShaderLongVectorPropertiesEXT 

Fields

Instances

Instances details
Eq PhysicalDeviceShaderLongVectorPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

Storable PhysicalDeviceShaderLongVectorPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

Show PhysicalDeviceShaderLongVectorPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

FromCStruct PhysicalDeviceShaderLongVectorPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

ToCStruct PhysicalDeviceShaderLongVectorPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

Zero PhysicalDeviceShaderLongVectorPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_shader_long_vector

type EXT_SHADER_LONG_VECTOR_EXTENSION_NAME = "VK_EXT_shader_long_vector" Source #