| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_shader_replicated_composites
Description
Name
VK_EXT_shader_replicated_composites - device extension
VK_EXT_shader_replicated_composites
- Name String
VK_EXT_shader_replicated_composites
- Extension Type
- Device extension
- Registered Extension Number
- 565
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- None
- SPIR-V Dependencies
- Contact
- Extension Proposal
- VK_EXT_shader_replicated_composites
- Last Modified Date
- 2024-02-08
- IP Status
- No known IP claims.
- Contributors
- Kévin Petit, Arm Ltd.
- Jeff Bolz, NVIDIA
- Piers Daniell, NVIDIA
This extension adds support for creating composites from a single value in SPIR-V modules, as defined by SPV_EXT_replicated_composites.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
New SPIR-V Capabilities
Version History
Revision 1, 2024-02-08 (Kévin Petit)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderReplicatedCompositesFeaturesEXT = PhysicalDeviceShaderReplicatedCompositesFeaturesEXT {}
- type EXT_SHADER_REPLICATED_COMPOSITES_SPEC_VERSION = 1
- pattern EXT_SHADER_REPLICATED_COMPOSITES_SPEC_VERSION :: forall a. Integral a => a
- type EXT_SHADER_REPLICATED_COMPOSITES_EXTENSION_NAME = "VK_EXT_shader_replicated_composites"
- pattern EXT_SHADER_REPLICATED_COMPOSITES_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderReplicatedCompositesFeaturesEXT Source #
VkPhysicalDeviceShaderReplicatedCompositesFeaturesEXT - Structure describing whether support for replicated composites in SPIR-V is enabled
Description
If the PhysicalDeviceShaderReplicatedCompositesFeaturesEXT structure
is included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. PhysicalDeviceShaderReplicatedCompositesFeaturesEXT can
also be used in the pNext chain of
DeviceCreateInfo to selectively enable these
features.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderReplicatedCompositesFeaturesEXT | |
Fields | |
Instances
pattern EXT_SHADER_REPLICATED_COMPOSITES_SPEC_VERSION :: forall a. Integral a => a Source #
type EXT_SHADER_REPLICATED_COMPOSITES_EXTENSION_NAME = "VK_EXT_shader_replicated_composites" Source #
pattern EXT_SHADER_REPLICATED_COMPOSITES_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a Source #