| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_shader_subgroup_partitioned
Description
Name
VK_EXT_shader_subgroup_partitioned - device extension
VK_EXT_shader_subgroup_partitioned
- Name String
VK_EXT_shader_subgroup_partitioned
- Extension Type
- Device extension
- Registered Extension Number
- 663
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- SPIR-V Dependencies
- Contact
Other Extension Metadata
- Last Modified Date
- 2025-11-12
- Interactions and External Dependencies
- This extension provides API support for GL_NV_shader_subgroup_partitioned
- Contributors
- Jeff Bolz, NVIDIA
Description
This extension enables support for a new class of
group operations
on
subgroups
via the
GL_NV_shader_subgroup_partitioned
GLSL extension and
SPV_EXT_shader_subgroup_partitioned
SPIR-V extension. Support for these new operations is advertised via the
SUBGROUP_FEATURE_PARTITIONED_BIT_EXT
bit. Note that there is not a new GLSL extension since
SPV_EXT_shader_subgroup_partitioned is compatible with
SPV_NV_shader_subgroup_partitioned, so the
GL_NV_shader_subgroup_partitioned GLSL extension can still be used.
This extension requires Vulkan 1.1, for general subgroup support.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
EXT_SHADER_SUBGROUP_PARTITIONED_SPEC_VERSIONExtending
StructureType:Extending
SubgroupFeatureFlagBits:
Version History
Revision 1, 2025-11-12 (Jeff Bolz)
- Promoted from
VK_NV_shader_subgroup_partitioned
- Promoted from
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderSubgroupPartitionedFeaturesEXT = PhysicalDeviceShaderSubgroupPartitionedFeaturesEXT {}
- type EXT_SHADER_SUBGROUP_PARTITIONED_SPEC_VERSION = 1
- pattern EXT_SHADER_SUBGROUP_PARTITIONED_SPEC_VERSION :: Integral a => a
- type EXT_SHADER_SUBGROUP_PARTITIONED_EXTENSION_NAME = "VK_EXT_shader_subgroup_partitioned"
- pattern EXT_SHADER_SUBGROUP_PARTITIONED_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderSubgroupPartitionedFeaturesEXT Source #
VkPhysicalDeviceShaderSubgroupPartitionedFeaturesEXT - Structure describing shader subgroup partitioned features that can be supported by an implementation
Members
This structure describes the following features:
Description
If the PhysicalDeviceShaderSubgroupPartitionedFeaturesEXT structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceShaderSubgroupPartitionedFeaturesEXT, it must add an
instance of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderSubgroupPartitionedFeaturesEXT | |
Fields
| |
Instances
pattern EXT_SHADER_SUBGROUP_PARTITIONED_SPEC_VERSION :: Integral a => a Source #
type EXT_SHADER_SUBGROUP_PARTITIONED_EXTENSION_NAME = "VK_EXT_shader_subgroup_partitioned" Source #
pattern EXT_SHADER_SUBGROUP_PARTITIONED_EXTENSION_NAME :: (Eq a, IsString a) => a Source #