| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_texture_compression_astc_3d
Description
Name
VK_EXT_texture_compression_astc_3d - device extension
VK_EXT_texture_compression_astc_3d
- Name String
VK_EXT_texture_compression_astc_3d
- Extension Type
- Device extension
- Registered Extension Number
- 289
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Contact
- Extension Proposal
- VK_EXT_texture_compression_astc_3d
Other Extension Metadata
- Last Modified Date
- 2025-06-09
- IP Status
- No known issues.
- Contributors
- Jan-Harald Fredriksen, Arm
Description
This extension adds support for 3D textures compressed using the Adaptive Scalable Texture Compression (ASTC) format.
These formats are compressed in 3D. As such, each slice will contain data for a Width x Height x Depth block of the texture. All transfer operations are done at the granularity of block dimensions.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
EXT_TEXTURE_COMPRESSION_ASTC_3D_SPEC_VERSIONExtending
Format:FORMAT_ASTC_3x3x3_SFLOAT_BLOCK_EXTFORMAT_ASTC_3x3x3_SRGB_BLOCK_EXTFORMAT_ASTC_3x3x3_UNORM_BLOCK_EXTFORMAT_ASTC_4x3x3_SFLOAT_BLOCK_EXTFORMAT_ASTC_4x3x3_SRGB_BLOCK_EXTFORMAT_ASTC_4x3x3_UNORM_BLOCK_EXTFORMAT_ASTC_4x4x3_SFLOAT_BLOCK_EXTFORMAT_ASTC_4x4x3_SRGB_BLOCK_EXTFORMAT_ASTC_4x4x3_UNORM_BLOCK_EXTFORMAT_ASTC_4x4x4_SFLOAT_BLOCK_EXTFORMAT_ASTC_4x4x4_SRGB_BLOCK_EXTFORMAT_ASTC_4x4x4_UNORM_BLOCK_EXTFORMAT_ASTC_5x4x4_SFLOAT_BLOCK_EXTFORMAT_ASTC_5x4x4_SRGB_BLOCK_EXTFORMAT_ASTC_5x4x4_UNORM_BLOCK_EXTFORMAT_ASTC_5x5x4_SFLOAT_BLOCK_EXTFORMAT_ASTC_5x5x4_SRGB_BLOCK_EXTFORMAT_ASTC_5x5x4_UNORM_BLOCK_EXTFORMAT_ASTC_5x5x5_SFLOAT_BLOCK_EXTFORMAT_ASTC_5x5x5_SRGB_BLOCK_EXTFORMAT_ASTC_5x5x5_UNORM_BLOCK_EXTFORMAT_ASTC_6x5x5_SFLOAT_BLOCK_EXTFORMAT_ASTC_6x5x5_SRGB_BLOCK_EXTFORMAT_ASTC_6x5x5_UNORM_BLOCK_EXTFORMAT_ASTC_6x6x5_SFLOAT_BLOCK_EXTFORMAT_ASTC_6x6x5_SRGB_BLOCK_EXTFORMAT_ASTC_6x6x5_UNORM_BLOCK_EXTFORMAT_ASTC_6x6x6_SFLOAT_BLOCK_EXTFORMAT_ASTC_6x6x6_SRGB_BLOCK_EXTFORMAT_ASTC_6x6x6_UNORM_BLOCK_EXT
Extending
StructureType:
Issues
None.
Version History
Revision 1, 2025-06-09 (Jan-Harald Fredriksen)
- Initial version
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceTextureCompressionASTC3DFeaturesEXT = PhysicalDeviceTextureCompressionASTC3DFeaturesEXT {}
- type EXT_TEXTURE_COMPRESSION_ASTC_3D_SPEC_VERSION = 1
- pattern EXT_TEXTURE_COMPRESSION_ASTC_3D_SPEC_VERSION :: Integral a => a
- type EXT_TEXTURE_COMPRESSION_ASTC_3D_EXTENSION_NAME = "VK_EXT_texture_compression_astc_3d"
- pattern EXT_TEXTURE_COMPRESSION_ASTC_3D_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceTextureCompressionASTC3DFeaturesEXT Source #
VkPhysicalDeviceTextureCompressionASTC3DFeaturesEXT - Structure describing ASTC 3D features that can be supported by an implementation
Members
This structure describes the following feature:
Description
If the VkPhysicalDeviceTextureCompressionASTC3DFeatures structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
VkPhysicalDeviceTextureCompressionASTC3DFeatures, it must add an
instance of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
Instances
pattern EXT_TEXTURE_COMPRESSION_ASTC_3D_SPEC_VERSION :: Integral a => a Source #
type EXT_TEXTURE_COMPRESSION_ASTC_3D_EXTENSION_NAME = "VK_EXT_texture_compression_astc_3d" Source #
pattern EXT_TEXTURE_COMPRESSION_ASTC_3D_EXTENSION_NAME :: (Eq a, IsString a) => a Source #