vulkan
Safe HaskellSafe-Inferred
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_vertex_attribute_robustness

Description

Name

VK_EXT_vertex_attribute_robustness - device extension

VK_EXT_vertex_attribute_robustness

Name String
VK_EXT_vertex_attribute_robustness
Extension Type
Device extension
Registered Extension Number
609
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
None
Contact

Other Extension Metadata

Last Modified Date
2024-11-01
IP Status
No known IP claims.
Contributors
  • Daniel Story, Nintendo

Description

It can be detrimental to performance for applications to have to define fake vertex attribute locations and buffer bindings for vertex shaders that may reference attribute locations for which there is no vertex data.

This extension allows applications to not have to specify fake vertex attribute locations, and if the vertex shader reads those attributes it will read (0,0,0,0) or (0,0,0,1).

New Structures

New Enum Constants

Issues

None

Version History

  • Revision 1, 2024-11-01 (Piers Daniell)

    • Internal revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceVertexAttributeRobustnessFeaturesEXT Source #

VkPhysicalDeviceVertexAttributeRobustnessFeaturesEXT - Structure describing whether the vertex attribute robustness feature is supported by an implementation

Members

This structure describes the following feature:

Description

If the PhysicalDeviceVertexAttributeRobustnessFeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. PhysicalDeviceVertexAttributeRobustnessFeaturesEXT can also be used in the pNext chain of DeviceCreateInfo to selectively enable these features.

Valid Usage (Implicit)

See Also

VK_EXT_vertex_attribute_robustness, Bool32, StructureType

Constructors

PhysicalDeviceVertexAttributeRobustnessFeaturesEXT 

Fields

  • vertexAttributeRobustness :: Bool

    vertexAttributeRobustness indicates that vertex shaders can read vertex attribute locations that have no vertex attribute description and the value returned is (0,0,0,0) or (0,0,0,1).

Instances

Instances details
Storable PhysicalDeviceVertexAttributeRobustnessFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_vertex_attribute_robustness

Show PhysicalDeviceVertexAttributeRobustnessFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_vertex_attribute_robustness

Eq PhysicalDeviceVertexAttributeRobustnessFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_vertex_attribute_robustness

FromCStruct PhysicalDeviceVertexAttributeRobustnessFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_vertex_attribute_robustness

ToCStruct PhysicalDeviceVertexAttributeRobustnessFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_vertex_attribute_robustness

Zero PhysicalDeviceVertexAttributeRobustnessFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_vertex_attribute_robustness

type EXT_VERTEX_ATTRIBUTE_ROBUSTNESS_EXTENSION_NAME = "VK_EXT_vertex_attribute_robustness" Source #