vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_ycbcr_2plane_444_formats

Description

Name

VK_EXT_ycbcr_2plane_444_formats - device extension

VK_EXT_ycbcr_2plane_444_formats

Name String
VK_EXT_ycbcr_2plane_444_formats
Extension Type
Device extension
Registered Extension Number
331
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
VK_KHR_sampler_ycbcr_conversion or Vulkan Version 1.1
Deprecation State
Contact

Other Extension Metadata

Last Modified Date
2020-07-28
IP Status
No known IP claims.
Contributors
  • Piers Daniell, NVIDIA
  • Ping Liu, Intel

Description

This extension adds some Y′CBCR formats that are in common use for video encode and decode, but were not part of the VK_KHR_sampler_ycbcr_conversion extension.

New Structures

New Enum Constants

Promotion to Vulkan 1.3

The format enumerants introduced by the extension are included in core Vulkan 1.3, with the EXT suffix omitted. However, runtime support for these formats is optional in core Vulkan 1.3, while if this extension is supported, runtime support is mandatory. The feature structure is not promoted. The original enum names are still available as aliases of the core functionality.

Version History

  • Revision 1, 2020-03-08 (Piers Daniell)

    • Initial draft

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT Source #

VkPhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT - Structure describing whether the implementation supports additional 2-plane 444 Y′CBCR formats

Members

This structure describes the following feature:

Description

If the PhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

Although the formats defined by the VK_EXT_ycbcr_2plane_444_formats were promoted to Vulkan 1.3 as optional formats, the PhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT structure was not promoted to Vulkan 1.3.

See Also

VK_EXT_ycbcr_2plane_444_formats, Bool32, StructureType

Constructors

PhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT 

Fields

Instances

Instances details
Eq PhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ycbcr_2plane_444_formats

Storable PhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ycbcr_2plane_444_formats

Show PhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ycbcr_2plane_444_formats

FromCStruct PhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ycbcr_2plane_444_formats

ToCStruct PhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ycbcr_2plane_444_formats

Zero PhysicalDeviceYcbcr2Plane444FormatsFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_ycbcr_2plane_444_formats

type EXT_YCBCR_2PLANE_444_FORMATS_EXTENSION_NAME = "VK_EXT_ycbcr_2plane_444_formats" Source #