vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_HUAWEI_hdr_vivid

Description

Name

VK_HUAWEI_hdr_vivid - device extension

VK_HUAWEI_hdr_vivid

Name String
VK_HUAWEI_hdr_vivid
Extension Type
Device extension
Registered Extension Number
591
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies

VK_KHR_get_physical_device_properties2      or

Vulkan Version 1.1 and VK_KHR_swapchain and VK_EXT_hdr_metadata

Contact

Other Extension Metadata

Last Modified Date
2024-10-08
IP Status
No known IP claims.
Contributors
  • Juntao Li, Huawei
  • Pan Gao, Huawei
  • Xiufeng Zhang, Huawei
  • Zehui Lin, Huawei

Description

This extension allows applications to assign HDR Vivid (T/UWA 005.1-2022) metadata to swapchains.

HDR Vivid is an HDR standard released by UWA (UHD World Association). It defines tone mapping from the metadata to better preserve the creator’s intentions and achieve better consistency across devices with different display capabilities.

New Structures

New Enum Constants

Version History

  • Revision 1, 2024-10-08 (Zehui Lin)

    • Initial version

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data HdrVividDynamicMetadataHUAWEI Source #

VkHdrVividDynamicMetadataHUAWEI - specify HDR Vivid dynamic metadata

Description

The HDR Vivid metadata is intended to be used as defined in the T/UWA 005.1-2022 specification. The validity and use of this data is outside the scope of Vulkan.

Valid Usage (Implicit)

See Also

VK_HUAWEI_hdr_vivid, StructureType

Constructors

HdrVividDynamicMetadataHUAWEI 

Fields

  • dynamicMetadataSize :: Word64

    dynamicMetadataSize is the size in bytes of the dynamic metadata.

    dynamicMetadataSize must be greater than 0

  • dynamicMetadata :: Ptr ()

    pDynamicMetadata is a pointer to the dynamic metadata.

    pDynamicMetadata must be a valid pointer to an array of dynamicMetadataSize bytes

Instances

Instances details
Storable HdrVividDynamicMetadataHUAWEI Source # 
Instance details

Defined in Vulkan.Extensions.VK_HUAWEI_hdr_vivid

Show HdrVividDynamicMetadataHUAWEI Source # 
Instance details

Defined in Vulkan.Extensions.VK_HUAWEI_hdr_vivid

FromCStruct HdrVividDynamicMetadataHUAWEI Source # 
Instance details

Defined in Vulkan.Extensions.VK_HUAWEI_hdr_vivid

ToCStruct HdrVividDynamicMetadataHUAWEI Source # 
Instance details

Defined in Vulkan.Extensions.VK_HUAWEI_hdr_vivid

Zero HdrVividDynamicMetadataHUAWEI Source # 
Instance details

Defined in Vulkan.Extensions.VK_HUAWEI_hdr_vivid

data PhysicalDeviceHdrVividFeaturesHUAWEI Source #

VkPhysicalDeviceHdrVividFeaturesHUAWEI - Structure describing whether HDR Vivid metadata is supported

Description

If the PhysicalDeviceHdrVividFeaturesHUAWEI structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceHdrVividFeaturesHUAWEI, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_HUAWEI_hdr_vivid, Bool32, StructureType

Constructors

PhysicalDeviceHdrVividFeaturesHUAWEI 

Fields

  • hdrVivid :: Bool

    hdrVivid specifies whether HDR Vivid metadata is supported.

Instances

Instances details
Eq PhysicalDeviceHdrVividFeaturesHUAWEI Source # 
Instance details

Defined in Vulkan.Extensions.VK_HUAWEI_hdr_vivid

Storable PhysicalDeviceHdrVividFeaturesHUAWEI Source # 
Instance details

Defined in Vulkan.Extensions.VK_HUAWEI_hdr_vivid

Show PhysicalDeviceHdrVividFeaturesHUAWEI Source # 
Instance details

Defined in Vulkan.Extensions.VK_HUAWEI_hdr_vivid

FromCStruct PhysicalDeviceHdrVividFeaturesHUAWEI Source # 
Instance details

Defined in Vulkan.Extensions.VK_HUAWEI_hdr_vivid

ToCStruct PhysicalDeviceHdrVividFeaturesHUAWEI Source # 
Instance details

Defined in Vulkan.Extensions.VK_HUAWEI_hdr_vivid

Zero PhysicalDeviceHdrVividFeaturesHUAWEI Source # 
Instance details

Defined in Vulkan.Extensions.VK_HUAWEI_hdr_vivid

type HUAWEI_HDR_VIVID_EXTENSION_NAME = "VK_HUAWEI_hdr_vivid" Source #