vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_IMG_relaxed_line_rasterization

Description

Name

VK_IMG_relaxed_line_rasterization - device extension

VK_IMG_relaxed_line_rasterization

Name String
VK_IMG_relaxed_line_rasterization
Extension Type
Device extension
Registered Extension Number
111
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
Special Use
Contact

Other Extension Metadata

Last Modified Date
2023-10-22
IP Status
No known IP claims.
Contributors
  • James Fitzpatrick, Imagination
  • Andrew Garrard, Imagination
  • Alex Walters, Imagination

Description

OpenGL specifies that implementations should rasterize lines using the diamond exit rule (a slightly modified version of Bresenham’s algorithm). To implement OpenGL some implementations have a device-level compatibility mode to rasterize lines according to the OpenGL specification.

This extension allows OpenGL emulation layers to enable the OpenGL compatible line rasterization mode of such implementations.

New Structures

New Enum Constants

Issues

None.

Version History

  • Revision 1, 2023-10-22 (James Fitzpatrick)

    • Initial version

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceRelaxedLineRasterizationFeaturesIMG Source #

VkPhysicalDeviceRelaxedLineRasterizationFeaturesIMG - Structure describing relaxed line rasterization features that can be supported by an implementation

Members

This structure describes the following feature:

Description

If the PhysicalDeviceRelaxedLineRasterizationFeaturesIMG structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceRelaxedLineRasterizationFeaturesIMG, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_IMG_relaxed_line_rasterization, Bool32, StructureType

Constructors

PhysicalDeviceRelaxedLineRasterizationFeaturesIMG 

Fields

Instances

Instances details
Eq PhysicalDeviceRelaxedLineRasterizationFeaturesIMG Source # 
Instance details

Defined in Vulkan.Extensions.VK_IMG_relaxed_line_rasterization

Storable PhysicalDeviceRelaxedLineRasterizationFeaturesIMG Source # 
Instance details

Defined in Vulkan.Extensions.VK_IMG_relaxed_line_rasterization

Show PhysicalDeviceRelaxedLineRasterizationFeaturesIMG Source # 
Instance details

Defined in Vulkan.Extensions.VK_IMG_relaxed_line_rasterization

FromCStruct PhysicalDeviceRelaxedLineRasterizationFeaturesIMG Source # 
Instance details

Defined in Vulkan.Extensions.VK_IMG_relaxed_line_rasterization

ToCStruct PhysicalDeviceRelaxedLineRasterizationFeaturesIMG Source # 
Instance details

Defined in Vulkan.Extensions.VK_IMG_relaxed_line_rasterization

Zero PhysicalDeviceRelaxedLineRasterizationFeaturesIMG Source # 
Instance details

Defined in Vulkan.Extensions.VK_IMG_relaxed_line_rasterization

type IMG_RELAXED_LINE_RASTERIZATION_EXTENSION_NAME = "VK_IMG_relaxed_line_rasterization" Source #