vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_INTEL_shader_integer_functions2

Description

Name

VK_INTEL_shader_integer_functions2 - device extension

VK_INTEL_shader_integer_functions2

Name String
VK_INTEL_shader_integer_functions2
Extension Type
Device extension
Registered Extension Number
210
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
SPIR-V Dependencies
Contact

Other Extension Metadata

Last Modified Date
2019-04-30
IP Status
No known IP claims.
Interactions and External Dependencies
Contributors
  • Ian Romanick, Intel
  • Ben Ashbaugh, Intel

Description

This extension adds support for several new integer instructions in SPIR-V for use in graphics shaders. Many of these instructions have pre-existing counterparts in the Kernel environment.

The added integer functions are defined by the SPV_INTEL_shader_integer_functions2 SPIR-V extension and can be used with the GL_INTEL_shader_integer_functions2 GLSL extension.

New Structures

New Enum Constants

New SPIR-V Capabilities

Version History

  • Revision 1, 2019-04-30 (Ian Romanick)

    • Initial draft

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL Source #

VkPhysicalDeviceShaderIntegerFunctions2FeaturesINTEL - Structure describing shader integer functions that can be supported by an implementation

Members

This structure describes the following feature:

Description

If the VkPhysicalDeviceShaderIntegerFunctions2FeaturesINTELfeatures. structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by VkPhysicalDeviceShaderIntegerFunctions2FeaturesINTELfeatures., it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_INTEL_shader_integer_functions2, Bool32, StructureType

Constructors

PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL 

Fields

  • shaderIntegerFunctions2 :: Bool

    shaderIntegerFunctions2 indicates that the implementation supports the IntegerFunctions2INTEL SPIR-V capability.

Instances

Instances details
Eq PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL Source # 
Instance details

Defined in Vulkan.Extensions.VK_INTEL_shader_integer_functions2

Storable PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL Source # 
Instance details

Defined in Vulkan.Extensions.VK_INTEL_shader_integer_functions2

Show PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL Source # 
Instance details

Defined in Vulkan.Extensions.VK_INTEL_shader_integer_functions2

FromCStruct PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL Source # 
Instance details

Defined in Vulkan.Extensions.VK_INTEL_shader_integer_functions2

ToCStruct PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL Source # 
Instance details

Defined in Vulkan.Extensions.VK_INTEL_shader_integer_functions2

Zero PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL Source # 
Instance details

Defined in Vulkan.Extensions.VK_INTEL_shader_integer_functions2

type INTEL_SHADER_INTEGER_FUNCTIONS_2_EXTENSION_NAME = "VK_INTEL_shader_integer_functions2" Source #