| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_8bit_storage
Description
Name
VK_KHR_8bit_storage - device extension
VK_KHR_8bit_storage
- Name String
VK_KHR_8bit_storage
- Extension Type
- Device extension
- Registered Extension Number
- 178
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 and
VK_KHR_storage_buffer_storage_class or Vulkan Version 1.1
- SPIR-V Dependencies
- Deprecation State
- Promoted to Vulkan 1.2
- Contact
Other Extension Metadata
- Last Modified Date
- 2018-02-05
- Interactions and External Dependencies
- This extension provides API support for GL_EXT_shader_16bit_storage
- IP Status
- No known IP claims.
- Contributors
- Alexander Galazin, Arm
Description
The VK_KHR_8bit_storage extension allows use of 8-bit types in uniform
and storage buffers, and push constant blocks. This extension introduces
several new optional features which map to SPIR-V capabilities and allow
access to 8-bit data in Block-decorated objects in the Uniform and
the StorageBuffer storage classes, and objects in the PushConstant
storage class.
The StorageBuffer8BitAccess capability must be supported by all
implementations of this extension. The other capabilities are optional.
Promotion to Vulkan 1.2
Vulkan APIs in this extension are included in core Vulkan 1.2, with the
KHR suffix omitted. However, if Vulkan 1.2 is supported and this
extension is not, the StorageBuffer8BitAccess capability is optional.
External interactions defined by this extension, such as SPIR-V token
names, retain their original names. The original Vulkan API names are
still available as aliases of the core functionality.
Promotion to Vulkan 1.4
If Vulkan 1.4 is supported, support for the storageBuffer8BitAccess
capability is required.
New Structures
New Enum Constants
KHR_8BIT_STORAGE_SPEC_VERSIONExtending
StructureType:
New SPIR-V Capabilities
Version History
Revision 1, 2018-02-05 (Alexander Galazin)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
type KHR_8BIT_STORAGE_SPEC_VERSION = 1 Source #
pattern KHR_8BIT_STORAGE_SPEC_VERSION :: Integral a => a Source #
type KHR_8BIT_STORAGE_EXTENSION_NAME = "VK_KHR_8bit_storage" Source #
pattern KHR_8BIT_STORAGE_EXTENSION_NAME :: (Eq a, IsString a) => a Source #