| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_calibrated_timestamps
Description
Name
VK_KHR_calibrated_timestamps - device extension
VK_KHR_calibrated_timestamps
- Name String
VK_KHR_calibrated_timestamps
- Extension Type
- Device extension
- Registered Extension Number
- 544
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Version 1.1
- Contact
- Extension Proposal
- VK_EXT_calibrated_timestamps
Other Extension Metadata
- Last Modified Date
- 2023-07-12
- IP Status
- No known IP claims.
- Contributors
- Matthaeus G. Chajdas, AMD
- Alan Harrison, AMD
- Derrick Owens, AMD
- Daniel Rakos, RasterGrid
- Faith Ekstrand, Intel
- Keith Packard, Valve
Description
This extension provides an interface to query calibrated timestamps obtained quasi simultaneously from two time domains.
New Commands
New Structures
New Enums
New Enum Constants
Version History
Revision 1, 2023-07-12 (Daniel Rakos)
- Initial draft.
See Also
CalibratedTimestampInfoKHR, TimeDomainKHR,
getCalibratedTimestampsKHR,
getPhysicalDeviceCalibrateableTimeDomainsKHR
Document Notes
For more information, see the Vulkan Specification
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- getPhysicalDeviceCalibrateableTimeDomainsKHR :: forall io. MonadIO io => PhysicalDevice -> io (Result, "timeDomains" ::: Vector TimeDomainKHR)
- getCalibratedTimestampsKHR :: forall io. MonadIO io => Device -> ("timestampInfos" ::: Vector CalibratedTimestampInfoKHR) -> io ("timestamps" ::: Vector Word64, "maxDeviation" ::: Word64)
- data CalibratedTimestampInfoKHR = CalibratedTimestampInfoKHR {}
- newtype TimeDomainKHR where
- type KHR_CALIBRATED_TIMESTAMPS_SPEC_VERSION = 1
- pattern KHR_CALIBRATED_TIMESTAMPS_SPEC_VERSION :: forall a. Integral a => a
- type KHR_CALIBRATED_TIMESTAMPS_EXTENSION_NAME = "VK_KHR_calibrated_timestamps"
- pattern KHR_CALIBRATED_TIMESTAMPS_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a
Documentation
getPhysicalDeviceCalibrateableTimeDomainsKHR Source #
Arguments
| :: forall io. MonadIO io | |
| => PhysicalDevice |
|
| -> io (Result, "timeDomains" ::: Vector TimeDomainKHR) |
vkGetPhysicalDeviceCalibrateableTimeDomainsKHR - Query calibrateable time domains
Description
If pTimeDomains is NULL, then the number of calibrateable time
domains supported for the given physicalDevice is returned in
pTimeDomainCount. Otherwise, pTimeDomainCount must point to a
variable set by the user to the number of elements in the pTimeDomains
array, and on return the variable is overwritten with the number of
values actually written to pTimeDomains. If the value of
pTimeDomainCount is less than the number of calibrateable time domains
supported, at most pTimeDomainCount values will be written to
pTimeDomains, and INCOMPLETE will be
returned instead of SUCCESS, to indicate
that not all the available time domains were returned.
Valid Usage (Implicit)
-
physicalDevicemust be a validPhysicalDevicehandle
-
pTimeDomainCountmust be a valid pointer to auint32_tvalue -
If the value referenced by
pTimeDomainCountis not0, andpTimeDomainsis notNULL,pTimeDomainsmust be a valid pointer to an array ofpTimeDomainCountTimeDomainKHRvalues
Return Codes
See Also
VK_EXT_calibrated_timestamps,
VK_KHR_calibrated_timestamps,
PhysicalDevice, TimeDomainKHR
getCalibratedTimestampsKHR Source #
Arguments
| :: forall io. MonadIO io | |
| => Device |
|
| -> ("timestampInfos" ::: Vector CalibratedTimestampInfoKHR) |
|
| -> io ("timestamps" ::: Vector Word64, "maxDeviation" ::: Word64) |
vkGetCalibratedTimestampsKHR - Query calibrated timestamps
Description
Note
The maximum deviation may vary between calls to
getCalibratedTimestampsKHR even for the same set of time domains due
to implementation and platform specific reasons. It is the application’s
responsibility to assess whether the returned maximum deviation makes
the timestamp values suitable for any particular purpose and can
choose to re-issue the timestamp calibration call pursuing a lower
deviation value.
Calibrated timestamp values can be extrapolated to estimate future coinciding timestamp values, however, depending on the nature of the time domains and other properties of the platform extrapolating values over a sufficiently long period of time may no longer be accurate enough to fit any particular purpose, so applications are expected to re-calibrate the timestamps on a regular basis.
Valid Usage
- The
timeDomainvalue of eachCalibratedTimestampInfoEXTinpTimestampInfosmust be unique
Valid Usage (Implicit)
-
devicemust be a validDevicehandle
-
pTimestampInfosmust be a valid pointer to an array oftimestampCountvalidCalibratedTimestampInfoKHRstructures -
pTimestampsmust be a valid pointer to an array oftimestampCountuint64_tvalues -
pMaxDeviationmust be a valid pointer to auint64_tvalue -
timestampCountmust be greater than0
Return Codes
See Also
VK_EXT_calibrated_timestamps,
VK_KHR_calibrated_timestamps,
CalibratedTimestampInfoKHR, Device
data CalibratedTimestampInfoKHR Source #
VkCalibratedTimestampInfoKHR - Structure specifying the input parameters of a calibrated timestamp query
Valid Usage (Implicit)
See Also
VK_EXT_calibrated_timestamps,
VK_KHR_calibrated_timestamps,
StructureType, TimeDomainKHR,
getCalibratedTimestampsEXT,
getCalibratedTimestampsKHR
Constructors
| CalibratedTimestampInfoKHR | |
Fields
| |
Instances
newtype TimeDomainKHR Source #
VkTimeDomainKHR - Supported time domains
Description
Note
An implementation supporting VK_KHR_calibrated_timestamps or
VK_EXT_calibrated_timestamps will use the same time domain for all its
Queue so that timestamp values reported for
TIME_DOMAIN_DEVICE_KHR can be matched to any timestamp captured
through cmdWriteTimestamp or
cmdWriteTimestamp2
.
struct timespec tv; clock_gettime(CLOCK_MONOTONIC, &tv); return tv.tv_nsec + tv.tv_sec*1000000000ull;
struct timespec tv; clock_gettime(CLOCK_MONOTONIC_RAW, &tv); return tv.tv_nsec + tv.tv_sec*1000000000ull;
LARGE_INTEGER counter; QueryPerformanceCounter(&counter); return counter.QuadPart;
See Also
VK_EXT_calibrated_timestamps,
VK_KHR_calibrated_timestamps,
CalibratedTimestampInfoKHR,
getPhysicalDeviceCalibrateableTimeDomainsEXT,
getPhysicalDeviceCalibrateableTimeDomainsKHR
Constructors
| TimeDomainKHR Int32 |
Bundled Patterns
| pattern TIME_DOMAIN_DEVICE_KHR :: TimeDomainKHR |
|
| pattern TIME_DOMAIN_CLOCK_MONOTONIC_KHR :: TimeDomainKHR |
|
| pattern TIME_DOMAIN_CLOCK_MONOTONIC_RAW_KHR :: TimeDomainKHR |
|
| pattern TIME_DOMAIN_QUERY_PERFORMANCE_COUNTER_KHR :: TimeDomainKHR |
|
Instances
pattern KHR_CALIBRATED_TIMESTAMPS_SPEC_VERSION :: forall a. Integral a => a Source #
type KHR_CALIBRATED_TIMESTAMPS_EXTENSION_NAME = "VK_KHR_calibrated_timestamps" Source #
pattern KHR_CALIBRATED_TIMESTAMPS_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a Source #