vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_dynamic_rendering

Description

Name

VK_KHR_dynamic_rendering - device extension

VK_KHR_dynamic_rendering

Name String
VK_KHR_dynamic_rendering
Extension Type
Device extension
Registered Extension Number
45
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies

VK_KHR_get_physical_device_properties2          or

Vulkan Version 1.1      and

VK_KHR_depth_stencil_resolve or Vulkan Version 1.2

Deprecation State
Contact
Extension Proposal
VK_KHR_dynamic_rendering

Other Extension Metadata

Last Modified Date
2021-10-06
Contributors
  • Tobias Hector, AMD
  • Arseny Kapoulkine, Roblox
  • François Duranleau, Gameloft
  • Stuart Smith, AMD
  • Hai Nguyen, Google
  • Jean-François Roy, Google
  • Jeff Leger, Qualcomm
  • Jan-Harald Fredriksen, Arm
  • Piers Daniell, Nvidia
  • James Fitzpatrick, Imagination
  • Piotr Byszewski, Mobica
  • Jesse Hall, Google
  • Mike Blumenkrantz, Valve

Description

This extension allows applications to create single-pass render pass instances without needing to create render pass objects or framebuffers. Dynamic render passes can also span across multiple primary command buffers, rather than relying on secondary command buffers.

This extension also incorporates ATTACHMENT_STORE_OP_NONE_KHR from VK_QCOM_render_pass_store_ops, enabling applications to avoid unnecessary synchronization when an attachment is not written during a render pass.

New Commands

New Structures

New Enums

New Bitmasks

New Enum Constants

Promotion to Vulkan 1.3

Vulkan APIs in this extension are included in core Vulkan 1.3, with the KHR suffix omitted. External interactions defined by this extension, such as SPIR-V token names, retain their original names. The original Vulkan API names are still available as aliases of the core functionality.

Version History

  • Revision 1, 2021-10-06 (Tobias Hector)

    • Initial revision

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Documentation

type KHR_DYNAMIC_RENDERING_EXTENSION_NAME = "VK_KHR_dynamic_rendering" Source #