vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_maintenance5

Description

Name

VK_KHR_maintenance5 - device extension

VK_KHR_maintenance5

Name String
VK_KHR_maintenance5
Extension Type
Device extension
Registered Extension Number
471
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies

Vulkan Version 1.1      and

VK_KHR_dynamic_rendering or Vulkan Version 1.3

API Interactions
  • Interacts with VK_VERSION_1_2
  • Interacts with VK_VERSION_1_3
  • Interacts with VK_VERSION_1_4
  • Interacts with VK_ARM_pipeline_opacity_micromap
  • Interacts with VK_EXT_attachment_feedback_loop_layout
  • Interacts with VK_EXT_buffer_device_address
  • Interacts with VK_EXT_conditional_rendering
  • Interacts with VK_EXT_descriptor_buffer
  • Interacts with VK_EXT_fragment_density_map
  • Interacts with VK_EXT_graphics_pipeline_library
  • Interacts with VK_EXT_opacity_micromap
  • Interacts with VK_EXT_pipeline_creation_cache_control
  • Interacts with VK_EXT_pipeline_protected_access
  • Interacts with VK_EXT_transform_feedback
  • Interacts with VK_KHR_acceleration_structure
  • Interacts with VK_KHR_buffer_device_address
  • Interacts with VK_KHR_dynamic_rendering
  • Interacts with VK_KHR_fragment_shading_rate
  • Interacts with VK_KHR_pipeline_executable_properties
  • Interacts with VK_KHR_pipeline_library
  • Interacts with VK_KHR_ray_tracing_pipeline
  • Interacts with VK_KHR_video_decode_queue
  • Interacts with VK_KHR_video_encode_queue
  • Interacts with VK_NV_device_generated_commands
  • Interacts with VK_NV_displacement_micromap
  • Interacts with VK_NV_ray_tracing
  • Interacts with VK_NV_ray_tracing_motion_blur
Deprecation State
Contact
Extension Proposal
VK_KHR_maintenance5

Other Extension Metadata

Last Modified Date
2023-05-02
Interactions and External Dependencies; Contributors
  • Stu Smith, AMD
  • Tobias Hector, AMD
  • Shahbaz Youssefi, Google
  • Slawomir Cygan, Intel
  • Lionel Landwerlin, Intel
  • James Fitzpatrick, Imagination Technologies
  • Andrew Garrard, Imagination Technologies
  • Ralph Potter, Samsung
  • Pan Gao, Huawei
  • Jan-Harald Fredriksen, ARM
  • Jon Leech, Khronos
  • Mike Blumenkrantz, Valve

Description

VK_KHR_maintenance5 adds a collection of minor features, none of which would warrant an entire extension of their own.

The new features are as follows:

New Commands

New Structures

New Enums

New Bitmasks

New Enum Constants

If VK_KHR_dynamic_rendering or Vulkan Version 1.3 and VK_EXT_fragment_density_map is supported:

If VK_KHR_dynamic_rendering or Vulkan Version 1.3 and VK_KHR_fragment_shading_rate is supported:

If VK_ARM_pipeline_opacity_micromap is supported:

If VK_EXT_attachment_feedback_loop_layout is supported:

If VK_EXT_conditional_rendering is supported:

If VK_EXT_descriptor_buffer is supported:

If VK_EXT_graphics_pipeline_library is supported:

If VK_EXT_opacity_micromap is supported:

If VK_EXT_transform_feedback is supported:

If VK_KHR_acceleration_structure is supported:

If VK_KHR_pipeline_executable_properties is supported:

If VK_KHR_pipeline_library is supported:

If VK_KHR_ray_tracing_pipeline is supported:

If VK_KHR_video_decode_queue is supported:

If VK_KHR_video_encode_queue is supported:

If VK_NV_device_generated_commands is supported:

If VK_NV_displacement_micromap is supported:

If VK_NV_ray_tracing is supported:

If VK_NV_ray_tracing_motion_blur is supported:

If Vulkan Version 1.2 or VK_KHR_buffer_device_address or VK_EXT_buffer_device_address is supported:

If Vulkan Version 1.3 or VK_EXT_pipeline_creation_cache_control is supported:

If Vulkan Version 1.4 or VK_EXT_pipeline_protected_access is supported:

Promotion to Vulkan 1.4

Functionality in this extension is included in core Vulkan 1.4 with the KHR suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.

Version History

  • Revision 1, 2022-12-12 (Stu Smith)

    • Initial revision

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Documentation

type KHR_MAINTENANCE_5_EXTENSION_NAME = "VK_KHR_maintenance5" Source #