vulkan
Safe HaskellSafe-Inferred
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_maintenance6

Description

Name

VK_KHR_maintenance6 - device extension

VK_KHR_maintenance6

Name String
VK_KHR_maintenance6
Extension Type
Device extension
Registered Extension Number
546
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
Vulkan Version 1.1
API Interactions
  • Interacts with VK_EXT_descriptor_buffer
  • Interacts with VK_KHR_push_descriptor
Contact
Extension Proposal
VK_KHR_maintenance6

Other Extension Metadata

Last Modified Date
2023-08-03
Interactions and External Dependencies
  • Interacts with VK_EXT_robustness2
Contributors
  • Jon Leech, Khronos
  • Stu Smith, AMD
  • Mike Blumenkrantz, Valve
  • Ralph Potter, Samsung
  • James Fitzpatrick, Imagination Technologies
  • Piers Daniell, NVIDIA
  • Daniel Story, Nintendo

Description

VK_KHR_maintenance6 adds a collection of minor features, none of which would warrant an entire extension of their own.

The new features are as follows:

New Commands

If VK_EXT_descriptor_buffer is supported:

If VK_KHR_push_descriptor is supported:

New Structures

If VK_EXT_descriptor_buffer is supported:

If VK_KHR_push_descriptor is supported:

New Enum Constants

If VK_EXT_descriptor_buffer is supported:

If VK_KHR_push_descriptor is supported:

Issues

None.

Version History

  • Revision 1, 2023-08-01 (Jon Leech)

    • Initial revision

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

cmdBindDescriptorSets2KHR Source #

Arguments

:: forall a io. (Extendss BindDescriptorSetsInfoKHR a, PokeChain a, MonadIO io) 
=> CommandBuffer

commandBuffer is the command buffer that the descriptor sets will be bound to.

-> BindDescriptorSetsInfoKHR a

pBindDescriptorSetsInfo is a pointer to a BindDescriptorSetsInfoKHR structure.

-> io () 

vkCmdBindDescriptorSets2KHR - Binds descriptor sets to a command buffer

Valid Usage

  • Each bit in pBindDescriptorSetsInfo->stageFlags must be a stage supported by the commandBuffer’s parent CommandPool’s queue family

Valid Usage (Implicit)

  • pBindDescriptorSetsInfo must be a valid pointer to a valid BindDescriptorSetsInfoKHR structure
  • commandBuffer must be in the recording state
  • The CommandPool that commandBuffer was allocated from must support graphics, or compute operations
  • This command must only be called outside of a video coding scope

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside Graphics ComputeState

See Also

VK_KHR_maintenance6, BindDescriptorSetsInfoKHR, CommandBuffer

cmdPushConstants2KHR Source #

Arguments

:: forall a io. (Extendss PushConstantsInfoKHR a, PokeChain a, MonadIO io) 
=> CommandBuffer

commandBuffer is the command buffer in which the push constant update will be recorded.

-> PushConstantsInfoKHR a

pPushConstantsInfo is a pointer to a PushConstantsInfoKHR structure.

-> io () 

vkCmdPushConstants2KHR - Update the values of push constants

Valid Usage (Implicit)

  • pPushConstantsInfo must be a valid pointer to a valid PushConstantsInfoKHR structure
  • commandBuffer must be in the recording state
  • The CommandPool that commandBuffer was allocated from must support graphics, or compute operations
  • This command must only be called outside of a video coding scope

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside Graphics ComputeState

See Also

VK_KHR_maintenance6, CommandBuffer, PushConstantsInfoKHR

cmdPushDescriptorSet2KHR Source #

Arguments

:: forall a io. (Extendss PushDescriptorSetInfoKHR a, PokeChain a, MonadIO io) 
=> CommandBuffer

commandBuffer is the command buffer that the descriptors will be recorded in.

-> PushDescriptorSetInfoKHR a

pPushDescriptorSetInfo is a pointer to a PushDescriptorSetInfoKHR structure.

-> io () 

vkCmdPushDescriptorSet2KHR - Pushes descriptor updates into a command buffer

Valid Usage

  • Each bit in pPushDescriptorSetInfo->stageFlags must be a stage supported by the commandBuffer’s parent CommandPool’s queue family

Valid Usage (Implicit)

  • pPushDescriptorSetInfo must be a valid pointer to a valid PushDescriptorSetInfoKHR structure
  • commandBuffer must be in the recording state
  • The CommandPool that commandBuffer was allocated from must support graphics, or compute operations
  • This command must only be called outside of a video coding scope

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside Graphics ComputeState

See Also

VK_KHR_maintenance6, VK_KHR_push_descriptor, CommandBuffer, PushDescriptorSetInfoKHR

cmdPushDescriptorSetWithTemplate2KHR Source #

Arguments

:: forall a io. (Extendss PushDescriptorSetWithTemplateInfoKHR a, PokeChain a, MonadIO io) 
=> CommandBuffer

commandBuffer is the command buffer that the descriptors will be recorded in.

-> PushDescriptorSetWithTemplateInfoKHR a

pPushDescriptorSetWithTemplateInfo is a pointer to a PushDescriptorSetWithTemplateInfoKHR structure.

-> io () 

vkCmdPushDescriptorSetWithTemplate2KHR - Pushes descriptor updates into a command buffer using a descriptor update template

Valid Usage (Implicit)

  • pPushDescriptorSetWithTemplateInfo must be a valid pointer to a valid PushDescriptorSetWithTemplateInfoKHR structure
  • commandBuffer must be in the recording state
  • The CommandPool that commandBuffer was allocated from must support graphics, or compute operations
  • This command must only be called outside of a video coding scope

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside Graphics ComputeState

See Also

VK_KHR_maintenance6, VK_KHR_push_descriptor, CommandBuffer, PushDescriptorSetWithTemplateInfoKHR

cmdSetDescriptorBufferOffsets2EXT Source #

Arguments

:: forall a io. (Extendss SetDescriptorBufferOffsetsInfoEXT a, PokeChain a, MonadIO io) 
=> CommandBuffer

commandBuffer is the command buffer in which the descriptor buffer offsets will be set.

-> SetDescriptorBufferOffsetsInfoEXT a

pSetDescriptorBufferOffsetsInfo is a pointer to a SetDescriptorBufferOffsetsInfoEXT structure.

-> io () 

vkCmdSetDescriptorBufferOffsets2EXT - Setting descriptor buffer offsets in a command buffer

Valid Usage

  • Each bit in pSetDescriptorBufferOffsetsInfo->stageFlags must be a stage supported by the commandBuffer’s parent CommandPool’s queue family

Valid Usage (Implicit)

  • pSetDescriptorBufferOffsetsInfo must be a valid pointer to a valid SetDescriptorBufferOffsetsInfoEXT structure
  • commandBuffer must be in the recording state
  • The CommandPool that commandBuffer was allocated from must support graphics, or compute operations
  • This command must only be called outside of a video coding scope

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside Graphics ComputeState

See Also

VK_EXT_descriptor_buffer, VK_KHR_maintenance6, CommandBuffer, SetDescriptorBufferOffsetsInfoEXT

cmdBindDescriptorBufferEmbeddedSamplers2EXT Source #

Arguments

:: forall a io. (Extendss BindDescriptorBufferEmbeddedSamplersInfoEXT a, PokeChain a, MonadIO io) 
=> CommandBuffer

commandBuffer is the command buffer that the embedded immutable samplers will be bound to.

-> BindDescriptorBufferEmbeddedSamplersInfoEXT a

pBindDescriptorBufferEmbeddedSamplersInfo is a pointer to a BindDescriptorBufferEmbeddedSamplersInfoEXT structure.

-> io () 

vkCmdBindDescriptorBufferEmbeddedSamplers2EXT - Setting embedded immutable samplers offsets in a command buffer

Valid Usage

  • Each bit in pBindDescriptorBufferEmbeddedSamplersInfo->stageFlags must be a stage supported by the commandBuffer’s parent CommandPool’s queue family

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside Graphics ComputeState

See Also

VK_EXT_descriptor_buffer, VK_KHR_maintenance6, BindDescriptorBufferEmbeddedSamplersInfoEXT, CommandBuffer

data PhysicalDeviceMaintenance6FeaturesKHR Source #

VkPhysicalDeviceMaintenance6FeaturesKHR - Structure describing whether the implementation supports maintenance6 functionality

Members

This structure describes the following feature:

Description

If the PhysicalDeviceMaintenance6FeaturesKHR structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. PhysicalDeviceMaintenance6FeaturesKHR can also be used in the pNext chain of DeviceCreateInfo to selectively enable these features.

Valid Usage (Implicit)

See Also

VK_KHR_maintenance6, Bool32, StructureType

Constructors

PhysicalDeviceMaintenance6FeaturesKHR 

Fields

Instances

Instances details
Storable PhysicalDeviceMaintenance6FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Show PhysicalDeviceMaintenance6FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Eq PhysicalDeviceMaintenance6FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

FromCStruct PhysicalDeviceMaintenance6FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

ToCStruct PhysicalDeviceMaintenance6FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Zero PhysicalDeviceMaintenance6FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

data PhysicalDeviceMaintenance6PropertiesKHR Source #

VkPhysicalDeviceMaintenance6PropertiesKHR - Structure describing various implementation-defined properties introduced with VK_KHR_maintenance6

Description

If the PhysicalDeviceMaintenance6PropertiesKHR structure is included in the pNext chain of the PhysicalDeviceProperties2 structure passed to getPhysicalDeviceProperties2, it is filled in with each corresponding implementation-dependent property.

Valid Usage (Implicit)

See Also

VK_KHR_maintenance6, Bool32, StructureType

Constructors

PhysicalDeviceMaintenance6PropertiesKHR 

Fields

Instances

Instances details
Storable PhysicalDeviceMaintenance6PropertiesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Show PhysicalDeviceMaintenance6PropertiesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Eq PhysicalDeviceMaintenance6PropertiesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

FromCStruct PhysicalDeviceMaintenance6PropertiesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

ToCStruct PhysicalDeviceMaintenance6PropertiesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Zero PhysicalDeviceMaintenance6PropertiesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

data BindMemoryStatusKHR Source #

VkBindMemoryStatusKHR - Structure specifying where to return memory binding status

Description

If the pNext chain of BindBufferMemoryInfo or BindImageMemoryInfo includes a BindMemoryStatusKHR structure, then the BindMemoryStatusKHR::pResult will be populated with a value describing the result of the corresponding memory binding operation.

Valid Usage (Implicit)

See Also

VK_KHR_maintenance6, Result, StructureType

Constructors

BindMemoryStatusKHR 

Fields

Instances

Instances details
Storable BindMemoryStatusKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Show BindMemoryStatusKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Eq BindMemoryStatusKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

FromCStruct BindMemoryStatusKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

ToCStruct BindMemoryStatusKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Zero BindMemoryStatusKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

data BindDescriptorSetsInfoKHR (es :: [Type]) Source #

VkBindDescriptorSetsInfoKHR - Structure specifying a descriptor set binding operation

Description

If stageFlags specifies a subset of all stages corresponding to one or more pipeline bind points, the binding operation still affects all stages corresponding to the given pipeline bind point(s) as if the equivalent original version of this command had been called with the same parameters. For example, specifying a stageFlags value of SHADER_STAGE_VERTEX_BIT | SHADER_STAGE_FRAGMENT_BIT | SHADER_STAGE_COMPUTE_BIT is equivalent to calling the original version of this command once with PIPELINE_BIND_POINT_GRAPHICS and once with PIPELINE_BIND_POINT_COMPUTE.

Valid Usage

  • Each element of pDescriptorSets must have been allocated with a DescriptorSetLayout that matches (is the same as, or identically defined as) the DescriptorSetLayout at set n in layout, where n is the sum of firstSet and the index into pDescriptorSets

Valid Usage (Implicit)

  • pNext must be NULL or a pointer to a valid instance of PipelineLayoutCreateInfo
  • The sType value of each struct in the pNext chain must be unique
  • stageFlags must be a valid combination of ShaderStageFlagBits values
  • stageFlags must not be 0
  • If layout is not NULL_HANDLE, layout must be a valid PipelineLayout handle
  • pDescriptorSets must be a valid pointer to an array of descriptorSetCount valid DescriptorSet handles
  • If dynamicOffsetCount is not 0, and pDynamicOffsets is not NULL, pDynamicOffsets must be a valid pointer to an array of dynamicOffsetCount or NULL_HANDLE uint32_t values
  • descriptorSetCount must be greater than 0
  • Both of layout, and the elements of pDescriptorSets that are valid handles of non-ignored parameters must have been created, allocated, or retrieved from the same Device

See Also

VK_KHR_maintenance6, DescriptorSet, PipelineLayout, ShaderStageFlags, StructureType, cmdBindDescriptorSets2KHR

Constructors

BindDescriptorSetsInfoKHR 

Fields

Instances

Instances details
Extensible BindDescriptorSetsInfoKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Methods

extensibleTypeName :: String Source #

getNext :: forall (es :: [Type]). BindDescriptorSetsInfoKHR es -> Chain es Source #

setNext :: forall (ds :: [Type]) (es :: [Type]). BindDescriptorSetsInfoKHR ds -> Chain es -> BindDescriptorSetsInfoKHR es Source #

extends :: forall e b proxy. Typeable e => proxy e -> (Extends BindDescriptorSetsInfoKHR e => b) -> Maybe b Source #

Show (Chain es) => Show (BindDescriptorSetsInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss BindDescriptorSetsInfoKHR es, PeekChain es) => FromCStruct (BindDescriptorSetsInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss BindDescriptorSetsInfoKHR es, PokeChain es) => ToCStruct (BindDescriptorSetsInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

es ~ ('[] :: [Type]) => Zero (BindDescriptorSetsInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

data PushConstantsInfoKHR (es :: [Type]) Source #

VkPushConstantsInfoKHR - Structure specifying a push constant update operation

Valid Usage

  • For each byte in the range specified by offset and size and for each shader stage in stageFlags, there must be a push constant range in layout that includes that byte and that stage

Valid Usage (Implicit)

  • pNext must be NULL or a pointer to a valid instance of PipelineLayoutCreateInfo
  • The sType value of each struct in the pNext chain must be unique
  • If layout is not NULL_HANDLE, layout must be a valid PipelineLayout handle
  • stageFlags must be a valid combination of ShaderStageFlagBits values
  • stageFlags must not be 0
  • pValues must be a valid pointer to an array of size bytes
  • size must be greater than 0

See Also

VK_KHR_maintenance6, PipelineLayout, ShaderStageFlags, StructureType, cmdPushConstants2KHR

Constructors

PushConstantsInfoKHR 

Fields

Instances

Instances details
Extensible PushConstantsInfoKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Methods

extensibleTypeName :: String Source #

getNext :: forall (es :: [Type]). PushConstantsInfoKHR es -> Chain es Source #

setNext :: forall (ds :: [Type]) (es :: [Type]). PushConstantsInfoKHR ds -> Chain es -> PushConstantsInfoKHR es Source #

extends :: forall e b proxy. Typeable e => proxy e -> (Extends PushConstantsInfoKHR e => b) -> Maybe b Source #

Show (Chain es) => Show (PushConstantsInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss PushConstantsInfoKHR es, PeekChain es) => FromCStruct (PushConstantsInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss PushConstantsInfoKHR es, PokeChain es) => ToCStruct (PushConstantsInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

es ~ ('[] :: [Type]) => Zero (PushConstantsInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

data PushDescriptorSetInfoKHR (es :: [Type]) Source #

VkPushDescriptorSetInfoKHR - Structure specifying a descriptor set push operation

Description

If stageFlags specifies a subset of all stages corresponding to one or more pipeline bind points, the binding operation still affects all stages corresponding to the given pipeline bind point(s) as if the equivalent original version of this command had been called with the same parameters. For example, specifying a stageFlags value of SHADER_STAGE_VERTEX_BIT | SHADER_STAGE_FRAGMENT_BIT | SHADER_STAGE_COMPUTE_BIT is equivalent to calling the original version of this command once with PIPELINE_BIND_POINT_GRAPHICS and once with PIPELINE_BIND_POINT_COMPUTE.

Valid Usage

Valid Usage (Implicit)

  • pNext must be NULL or a pointer to a valid instance of PipelineLayoutCreateInfo
  • The sType value of each struct in the pNext chain must be unique
  • stageFlags must be a valid combination of ShaderStageFlagBits values
  • stageFlags must not be 0
  • If layout is not NULL_HANDLE, layout must be a valid PipelineLayout handle
  • pDescriptorWrites must be a valid pointer to an array of descriptorWriteCount valid WriteDescriptorSet structures
  • descriptorWriteCount must be greater than 0

See Also

VK_KHR_maintenance6, VK_KHR_push_descriptor, PipelineLayout, ShaderStageFlags, StructureType, WriteDescriptorSet, cmdPushDescriptorSet2KHR

Constructors

PushDescriptorSetInfoKHR 

Fields

Instances

Instances details
Extensible PushDescriptorSetInfoKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Methods

extensibleTypeName :: String Source #

getNext :: forall (es :: [Type]). PushDescriptorSetInfoKHR es -> Chain es Source #

setNext :: forall (ds :: [Type]) (es :: [Type]). PushDescriptorSetInfoKHR ds -> Chain es -> PushDescriptorSetInfoKHR es Source #

extends :: forall e b proxy. Typeable e => proxy e -> (Extends PushDescriptorSetInfoKHR e => b) -> Maybe b Source #

Show (Chain es) => Show (PushDescriptorSetInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss PushDescriptorSetInfoKHR es, PeekChain es) => FromCStruct (PushDescriptorSetInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss PushDescriptorSetInfoKHR es, PokeChain es) => ToCStruct (PushDescriptorSetInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

es ~ ('[] :: [Type]) => Zero (PushDescriptorSetInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

data PushDescriptorSetWithTemplateInfoKHR (es :: [Type]) Source #

VkPushDescriptorSetWithTemplateInfoKHR - Structure specifying a descriptor set push operation using a descriptor update template

Valid Usage

  • The pipelineBindPoint specified during the creation of the descriptor update template must be supported by the commandBuffer’s parent CommandPool’s queue family

Valid Usage (Implicit)

  • pNext must be NULL or a pointer to a valid instance of PipelineLayoutCreateInfo
  • The sType value of each struct in the pNext chain must be unique
  • descriptorUpdateTemplate must be a valid DescriptorUpdateTemplate handle
  • If layout is not NULL_HANDLE, layout must be a valid PipelineLayout handle
  • pData must be a pointer value
  • Both of descriptorUpdateTemplate, and layout that are valid handles of non-ignored parameters must have been created, allocated, or retrieved from the same Device

See Also

VK_KHR_maintenance6, VK_KHR_push_descriptor, DescriptorUpdateTemplate, PipelineLayout, StructureType, cmdPushDescriptorSetWithTemplate2KHR

Constructors

PushDescriptorSetWithTemplateInfoKHR 

Fields

  • next :: Chain es

    pNext is NULL or a pointer to a structure extending this structure.

  • descriptorUpdateTemplate :: DescriptorUpdateTemplate

    descriptorUpdateTemplate is a descriptor update template defining how to interpret the descriptor information in pData.

  • layout :: PipelineLayout

    layout is a PipelineLayout object used to program the bindings. It must be compatible with the layout used to create the descriptorUpdateTemplate handle. If the dynamicPipelineLayout feature is enabled, layout can be NULL_HANDLE and the layout must be specified by chaining PipelineLayoutCreateInfo structure off the pNext

  • set :: Word32

    set is the set number of the descriptor set in the pipeline layout that will be updated. This must be the same number used to create the descriptorUpdateTemplate handle.

  • data' :: Ptr ()

    pData is a pointer to memory containing descriptors for the templated update.

Instances

Instances details
Extensible PushDescriptorSetWithTemplateInfoKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Show (Chain es) => Show (PushDescriptorSetWithTemplateInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss PushDescriptorSetWithTemplateInfoKHR es, PeekChain es) => FromCStruct (PushDescriptorSetWithTemplateInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss PushDescriptorSetWithTemplateInfoKHR es, PokeChain es) => ToCStruct (PushDescriptorSetWithTemplateInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

es ~ ('[] :: [Type]) => Zero (PushDescriptorSetWithTemplateInfoKHR es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

data SetDescriptorBufferOffsetsInfoEXT (es :: [Type]) Source #

VkSetDescriptorBufferOffsetsInfoEXT - Structure specifying descriptor buffer offsets to set in a command buffer

Description

If stageFlags specifies a subset of all stages corresponding to one or more pipeline bind points, the binding operation still affects all stages corresponding to the given pipeline bind point(s) as if the equivalent original version of this command had been called with the same parameters. For example, specifying a stageFlags value of SHADER_STAGE_VERTEX_BIT | SHADER_STAGE_FRAGMENT_BIT | SHADER_STAGE_COMPUTE_BIT is equivalent to calling the original version of this command once with PIPELINE_BIND_POINT_GRAPHICS and once with PIPELINE_BIND_POINT_COMPUTE.

Valid Usage

Valid Usage (Implicit)

  • pNext must be NULL or a pointer to a valid instance of PipelineLayoutCreateInfo
  • The sType value of each struct in the pNext chain must be unique
  • stageFlags must be a valid combination of ShaderStageFlagBits values
  • stageFlags must not be 0
  • If layout is not NULL_HANDLE, layout must be a valid PipelineLayout handle
  • pBufferIndices must be a valid pointer to an array of setCount uint32_t values
  • pOffsets must be a valid pointer to an array of setCount DeviceSize values
  • setCount must be greater than 0

See Also

VK_EXT_descriptor_buffer, VK_KHR_maintenance6, DeviceSize, PipelineLayout, ShaderStageFlags, StructureType, cmdSetDescriptorBufferOffsets2EXT

Constructors

SetDescriptorBufferOffsetsInfoEXT 

Fields

Instances

Instances details
Extensible SetDescriptorBufferOffsetsInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Show (Chain es) => Show (SetDescriptorBufferOffsetsInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss SetDescriptorBufferOffsetsInfoEXT es, PeekChain es) => FromCStruct (SetDescriptorBufferOffsetsInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss SetDescriptorBufferOffsetsInfoEXT es, PokeChain es) => ToCStruct (SetDescriptorBufferOffsetsInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

es ~ ('[] :: [Type]) => Zero (SetDescriptorBufferOffsetsInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

data BindDescriptorBufferEmbeddedSamplersInfoEXT (es :: [Type]) Source #

VkBindDescriptorBufferEmbeddedSamplersInfoEXT - Structure specifying embedded immutable sampler offsets to set in a command buffer

Description

If stageFlags specifies a subset of all stages corresponding to one or more pipeline bind points, the binding operation still affects all stages corresponding to the given pipeline bind point(s) as if the equivalent original version of this command had been called with the same parameters. For example, specifying a stageFlags value of SHADER_STAGE_VERTEX_BIT | SHADER_STAGE_FRAGMENT_BIT | SHADER_STAGE_COMPUTE_BIT is equivalent to calling the original version of this command once with PIPELINE_BIND_POINT_GRAPHICS and once with PIPELINE_BIND_POINT_COMPUTE.

Valid Usage

Valid Usage (Implicit)

See Also

VK_EXT_descriptor_buffer, VK_KHR_maintenance6, PipelineLayout, ShaderStageFlags, StructureType, cmdBindDescriptorBufferEmbeddedSamplers2EXT

Constructors

BindDescriptorBufferEmbeddedSamplersInfoEXT 

Fields

Instances

Instances details
Extensible BindDescriptorBufferEmbeddedSamplersInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Show (Chain es) => Show (BindDescriptorBufferEmbeddedSamplersInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss BindDescriptorBufferEmbeddedSamplersInfoEXT es, PeekChain es) => FromCStruct (BindDescriptorBufferEmbeddedSamplersInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss BindDescriptorBufferEmbeddedSamplersInfoEXT es, PokeChain es) => ToCStruct (BindDescriptorBufferEmbeddedSamplersInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

es ~ ('[] :: [Type]) => Zero (BindDescriptorBufferEmbeddedSamplersInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

pattern KHR_MAINTENANCE_6_SPEC_VERSION :: forall a. Integral a => a Source #

type KHR_MAINTENANCE_6_EXTENSION_NAME = "VK_KHR_maintenance6" Source #

pattern KHR_MAINTENANCE_6_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a Source #