vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_maintenance8

Description

Name

VK_KHR_maintenance8 - device extension

VK_KHR_maintenance8

Name String
VK_KHR_maintenance8
Extension Type
Device extension
Registered Extension Number
575
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
Vulkan Version 1.1
Contact
Extension Proposal
VK_KHR_maintenance8

Other Extension Metadata

Last Modified Date
2025-01-07
Interactions and External Dependencies; Contributors
  • Jon Leech, Khronos
  • Mike Blumenkrantz, Valve
  • Spencer Fricke, LunarG
  • Jan-Harald Fredriksen, ARM
  • Piers Daniell, NVIDIA
  • Matthew Netsch, Qualcomm
  • Ricardo Garcia, Igalia
  • Lionel Landwerlin, Intel
  • Rick Hammerstone, Qualcomm
  • Daniel Story, Nintendo
  • Hans-Kristian Arntzen, Valve
  • Caterina Shablia, Collabora
  • Georg Lehmann, Valve
  • Shahbaz Youssefi, Google
  • Tobias Hector, AMD

Description

VK_KHR_maintenance8 adds a collection of minor features, none of which would warrant an entire extension of their own.

The new features are as follows:

  • Allow copies between depth/stencil and “matching” color attachments
  • Allow dstCache in mergePipelineCaches to be implicitly synchronized.
  • Require src/dst sync scopes to work when doing queue family ownership transfers
  • Support Offset (as an alternative to ConstOffset) image operand in texture sampling and fetch operations
  • Use the SPIR-V definition of OpSRem and OpSMod, making these operations produce well-defined results for negative operands
  • Loosen layer restrictions when blitting from 3D images to other image types
  • Add space for an additional 64 access flags for use with VkMemoryBarrier2, VkBufferMemoryBarrier2, and VkImageMemoryBarrier2

New Structures

New Enums

New Bitmasks

New Enum Constants

Issues

None.

Version History

  • Revision 1, 2024-06-20 (Jon Leech)

    • Initial revision

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceMaintenance8FeaturesKHR Source #

VkPhysicalDeviceMaintenance8FeaturesKHR - Structure describing whether the implementation supports maintenance8 functionality

Members

This structure describes the following feature:

Description

If the PhysicalDeviceMaintenance8FeaturesKHR structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceMaintenance8FeaturesKHR, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_KHR_maintenance8, Bool32, StructureType

Constructors

PhysicalDeviceMaintenance8FeaturesKHR 

Fields

  • maintenance8 :: Bool

    maintenance8 indicates that the implementation supports the following:

    • Allow copies between depth/stencil and “matching” color attachments
    • Allow dstCache in mergePipelineCaches to be implicitly synchronized.
    • Require src/dst sync scopes to work when doing queue family ownership transfers
    • Support Offset (as an alternative to ConstOffset) image operand in texture sampling and fetch operations
    • Use the SPIR-V definition of OpSRem and OpSMod, making these operations produce well-defined results for negative operands
    • Loosen layer restrictions when blitting from 3D images to other image types
    • Add space for an additional 64 access flags for use with VkMemoryBarrier2, VkBufferMemoryBarrier2, and VkImageMemoryBarrier2

Instances

Instances details
Eq PhysicalDeviceMaintenance8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Storable PhysicalDeviceMaintenance8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Show PhysicalDeviceMaintenance8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

FromCStruct PhysicalDeviceMaintenance8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

ToCStruct PhysicalDeviceMaintenance8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Zero PhysicalDeviceMaintenance8FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

data MemoryBarrierAccessFlags3KHR Source #

VkMemoryBarrierAccessFlags3KHR - Structure specifying additional access flags

Valid Usage (Implicit)

See Also

VK_KHR_maintenance8, AccessFlags3KHR, StructureType

Constructors

MemoryBarrierAccessFlags3KHR 

Fields

Instances

Instances details
Eq MemoryBarrierAccessFlags3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Storable MemoryBarrierAccessFlags3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Show MemoryBarrierAccessFlags3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

FromCStruct MemoryBarrierAccessFlags3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

ToCStruct MemoryBarrierAccessFlags3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Zero MemoryBarrierAccessFlags3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

newtype AccessFlagBits3KHR Source #

VkAccessFlagBits3KHR - Access flags for VkAccessFlags3KHR

Description

See Also

VK_KHR_maintenance8, AccessFlags3KHR

Bundled Patterns

pattern ACCESS_3_NONE_KHR :: AccessFlagBits3KHR 

Instances

Instances details
Bits AccessFlagBits3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

FiniteBits AccessFlagBits3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Eq AccessFlagBits3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Ord AccessFlagBits3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Storable AccessFlagBits3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Read AccessFlagBits3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Show AccessFlagBits3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

Zero AccessFlagBits3KHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance8

type KHR_MAINTENANCE_8_EXTENSION_NAME = "VK_KHR_maintenance8" Source #