| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_robustness2
Description
Name
VK_KHR_robustness2 - device extension
VK_KHR_robustness2
- Name String
VK_KHR_robustness2
- Extension Type
- Device extension
- Registered Extension Number
- 613
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Contact
Other Extension Metadata
- Last Modified Date
- 2025-01-10
- IP Status
- No known IP claims.
- Contributors
- Liam Middlebrook, NVIDIA
- Jeff Bolz, NVIDIA
Description
This extension is based on the VK_EXT_robustness2 extension. This
extension adds stricter requirements for how out of bounds reads and
writes are handled. Most accesses must be tightly bounds-checked, out
of bounds writes must be discarded, out of bound reads must return
zero. Rather than allowing multiple possible (0,0,0,x) vectors, the out
of bounds values are treated as zero, and then missing components are
inserted based on the format as described in
https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#images-component-substitution
and
vertex input attribute extraction.
These additional requirements may be expensive on some implementations, and should only be enabled when truly necessary.
This extension also adds support for “null descriptors”, where
NULL_HANDLE can be used instead of a
valid handle. Accesses to null descriptors have well-defined behavior,
and do not rely on robustness.
New Structures
New Enum Constants
KHR_ROBUSTNESS_2_SPEC_VERSIONExtending
StructureType:
Issues
- Why do
PhysicalDeviceRobustness2PropertiesKHR::robustUniformBufferAccessSizeAlignmentandPhysicalDeviceRobustness2PropertiesKHR::robustStorageBufferAccessSizeAlignmentexist?
RESOLVED: Some implementations cannot efficiently tightly bounds-check all buffer accesses. Rather, the size of the bound range is padded to some power of two multiple, up to 256 bytes for uniform buffers and up to 4 bytes for storage buffers, and that padded size is bounds-checked. This is sufficient to implement D3D-like behavior, because D3D only allows binding whole uniform buffers or ranges that are a multiple of 256 bytes, and D3D raw and structured buffers only support 32-bit accesses.
Version History
Revision 1, 2025-01-10 (Piers Daniell)
- Internal revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceRobustness2FeaturesKHR = PhysicalDeviceRobustness2FeaturesKHR {}
- data PhysicalDeviceRobustness2PropertiesKHR = PhysicalDeviceRobustness2PropertiesKHR {}
- type KHR_ROBUSTNESS_2_SPEC_VERSION = 1
- pattern KHR_ROBUSTNESS_2_SPEC_VERSION :: Integral a => a
- type KHR_ROBUSTNESS_2_EXTENSION_NAME = "VK_KHR_robustness2"
- pattern KHR_ROBUSTNESS_2_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceRobustness2FeaturesKHR Source #
VkPhysicalDeviceRobustness2FeaturesKHR - Structure describing the out-of-bounds behavior for an implementation
Members
This structure describes the following features:
Description
If the PhysicalDeviceRobustness2FeaturesKHR structure is included in
the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceRobustness2FeaturesKHR, it must add an instance of the
structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage
-
If
robustBufferAccess2is enabled then robustBufferAccess must also be enabled
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_PHYSICAL_DEVICE_ROBUSTNESS_2_FEATURES_KHR
See Also
VK_EXT_robustness2,
VK_KHR_robustness2,
Bool32,
StructureType
Constructors
| PhysicalDeviceRobustness2FeaturesKHR | |
Fields
| |
Instances
data PhysicalDeviceRobustness2PropertiesKHR Source #
VkPhysicalDeviceRobustness2PropertiesKHR - Structure describing robust buffer access properties supported by an implementation
Description
If the PhysicalDeviceRobustness2PropertiesKHR structure is included in
the pNext chain of the
PhysicalDeviceProperties2
structure passed to
getPhysicalDeviceProperties2,
it is filled in with each corresponding implementation-dependent
property.
Valid Usage (Implicit)
See Also
VK_EXT_robustness2,
VK_KHR_robustness2,
DeviceSize,
StructureType
Constructors
| PhysicalDeviceRobustness2PropertiesKHR | |
Fields
| |
Instances
type KHR_ROBUSTNESS_2_SPEC_VERSION = 1 Source #
pattern KHR_ROBUSTNESS_2_SPEC_VERSION :: Integral a => a Source #
type KHR_ROBUSTNESS_2_EXTENSION_NAME = "VK_KHR_robustness2" Source #
pattern KHR_ROBUSTNESS_2_EXTENSION_NAME :: (Eq a, IsString a) => a Source #