vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_shader_bfloat16

Description

Name

VK_KHR_shader_bfloat16 - device extension

VK_KHR_shader_bfloat16

Name String
VK_KHR_shader_bfloat16
Extension Type
Device extension
Registered Extension Number
142
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
API Interactions
  • Interacts with VK_KHR_cooperative_matrix
SPIR-V Dependencies
Contact
Extension Proposal
VK_KHR_shader_bfloat16

Other Extension Metadata

Last Modified Date
2024-04-09
IP Status
No known IP claims.
Contributors
  • Tobias Hector, AMD
  • Stu Smith, AMD
  • Jeff Bolz, Nvidia
  • Kévin Petit, Arm
  • David Neto, Google
  • Graeme Leese, Broadcom
  • Ruihao Zhang, Qualcomm
  • Mark Sheppard, Imagination
  • Ben Ashbaugh, Intel
  • Dmitry Sidorov, Intel
  • Victor Mustya, Intel

Description

This extension enables support for bfloat16 (“brain float”) operations in shaders as defined in SPV_KHR_bfloat16.

New Structures

New Enum Constants

If VK_KHR_cooperative_matrix is supported:

New SPIR-V Capabilities

Version History

  • Revision 1, 2024-04-09 (Stu Smith)

    • Initial draft

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceShaderBfloat16FeaturesKHR Source #

VkPhysicalDeviceShaderBfloat16FeaturesKHR - Structure describing bfloat16 features that can be supported by the implementation

Members

This structure describes the following features:

Description

If the PhysicalDeviceShaderBfloat16FeaturesKHR structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceShaderBfloat16FeaturesKHR, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_KHR_shader_bfloat16, Bool32, StructureType

Constructors

PhysicalDeviceShaderBfloat16FeaturesKHR 

Fields

  • shaderBFloat16Type :: Bool

    shaderBFloat16Type indicates whether the implementation supports shaders with the BFloat16TypeKHR capability.

  • shaderBFloat16DotProduct :: Bool

    shaderBFloat16DotProduct indicates whether the implementation supports shaders with the BFloat16DotProductKHR capability.

  • shaderBFloat16CooperativeMatrix :: Bool

    shaderBFloat16CooperativeMatrix indicates whether the implementation supports shaders with the BFloat16CooperativeMatrixKHR capability.

Instances

Instances details
Eq PhysicalDeviceShaderBfloat16FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_bfloat16

Storable PhysicalDeviceShaderBfloat16FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_bfloat16

Show PhysicalDeviceShaderBfloat16FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_bfloat16

FromCStruct PhysicalDeviceShaderBfloat16FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_bfloat16

ToCStruct PhysicalDeviceShaderBfloat16FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_bfloat16

Zero PhysicalDeviceShaderBfloat16FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_bfloat16

type KHR_SHADER_BFLOAT16_EXTENSION_NAME = "VK_KHR_shader_bfloat16" Source #

newtype ComponentTypeKHR Source #

VkComponentTypeKHR - Specify SPIR-V cooperative matrix component type

Description

See Also

VK_KHR_cooperative_matrix, VK_NV_cooperative_matrix, VK_NV_cooperative_vector, ConvertCooperativeVectorMatrixInfoNV, CooperativeMatrixFlexibleDimensionsPropertiesNV, CooperativeMatrixPropertiesKHR, CooperativeMatrixPropertiesNV, CooperativeVectorPropertiesNV

Constructors

ComponentTypeKHR Int32 

Instances

Instances details
Eq ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector

Ord ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector

Storable ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector

Read ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector

Show ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector

Zero ComponentTypeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_cooperative_vector