vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_shader_clock

Description

Name

VK_KHR_shader_clock - device extension

VK_KHR_shader_clock

Name String
VK_KHR_shader_clock
Extension Type
Device extension
Registered Extension Number
182
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
SPIR-V Dependencies
Contact

Other Extension Metadata

Last Modified Date
2019-4-25
IP Status
No known IP claims.
Interactions and External Dependencies
Contributors
  • Aaron Hagan, AMD
  • Daniel Koch, NVIDIA

Description

This extension advertises the SPIR-V ShaderClockKHR capability for Vulkan, which allows a shader to query a real-time or monotonically incrementing counter at the subgroup level or across the device level. The two valid SPIR-V scopes for OpReadClockKHR are Subgroup and Device.

When using GLSL source-based shading languages, the clockRealtime*EXT() timing functions map to the OpReadClockKHR instruction with a scope of Device, and the clock*ARB() timing functions map to the OpReadClockKHR instruction with a scope of Subgroup.

New Structures

New Enum Constants

New SPIR-V Capabilities

Version History

  • Revision 1, 2019-4-25 (Aaron Hagan)

    • Initial revision

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceShaderClockFeaturesKHR Source #

VkPhysicalDeviceShaderClockFeaturesKHR - Structure describing features supported by VK_KHR_shader_clock

Members

This structure describes the following features:

Description

If the PhysicalDeviceShaderClockFeaturesKHR structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceShaderClockFeaturesKHR, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_KHR_shader_clock, Bool32, StructureType

Constructors

PhysicalDeviceShaderClockFeaturesKHR 

Fields

Instances

Instances details
Eq PhysicalDeviceShaderClockFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_clock

Storable PhysicalDeviceShaderClockFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_clock

Show PhysicalDeviceShaderClockFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_clock

FromCStruct PhysicalDeviceShaderClockFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_clock

ToCStruct PhysicalDeviceShaderClockFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_clock

Zero PhysicalDeviceShaderClockFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_clock

type KHR_SHADER_CLOCK_EXTENSION_NAME = "VK_KHR_shader_clock" Source #