| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_shader_expect_assume
Description
Name
VK_KHR_shader_expect_assume - device extension
VK_KHR_shader_expect_assume
- Name String
VK_KHR_shader_expect_assume
- Extension Type
- Device extension
- Registered Extension Number
- 545
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- SPIR-V Dependencies
- Contact
- Extension Proposal
- VK_KHR_shader_expect_assume
Other Extension Metadata
- Last Modified Date
- 2023-12-06
- IP Status
- No known IP claims.
- Contributors
- Kevin Petit, Arm
- Tobias Hector, AMD
- James Fitzpatrick, Imagination Technologies
Description
This extension allows the use of the SPV_KHR_expect_assume extension
in SPIR-V shader modules which enables SPIR-V producers to provide
optimization hints to the Vulkan implementation.
New Structures
New Enum Constants
New SPIR-V Capabilities
Version History
Revision 1, 2023-12-06 (Kevin Petit)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderExpectAssumeFeaturesKHR = PhysicalDeviceShaderExpectAssumeFeaturesKHR {}
- type KHR_SHADER_EXPECT_ASSUME_SPEC_VERSION = 1
- pattern KHR_SHADER_EXPECT_ASSUME_SPEC_VERSION :: forall a. Integral a => a
- type KHR_SHADER_EXPECT_ASSUME_EXTENSION_NAME = "VK_KHR_shader_expect_assume"
- pattern KHR_SHADER_EXPECT_ASSUME_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderExpectAssumeFeaturesKHR Source #
VkPhysicalDeviceShaderExpectAssumeFeaturesKHR - Structure describing shader expect assume features that can be supported by an implementation
Description
If the PhysicalDeviceShaderExpectAssumeFeaturesKHR structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. PhysicalDeviceShaderExpectAssumeFeaturesKHR can also be
used in the pNext chain of DeviceCreateInfo to
selectively enable these features.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderExpectAssumeFeaturesKHR | |
Fields | |
Instances
type KHR_SHADER_EXPECT_ASSUME_SPEC_VERSION = 1 Source #
pattern KHR_SHADER_EXPECT_ASSUME_SPEC_VERSION :: forall a. Integral a => a Source #
type KHR_SHADER_EXPECT_ASSUME_EXTENSION_NAME = "VK_KHR_shader_expect_assume" Source #
pattern KHR_SHADER_EXPECT_ASSUME_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a Source #