vulkan
Safe HaskellSafe-Inferred
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_shader_float_controls2

Description

Name

VK_KHR_shader_float_controls2 - device extension

VK_KHR_shader_float_controls2

Name String
VK_KHR_shader_float_controls2
Extension Type
Device extension
Registered Extension Number
529
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
Vulkan Version 1.1 and VK_KHR_shader_float_controls
SPIR-V Dependencies
Contact
Extension Proposal
VK_KHR_shader_float_controls2

Other Extension Metadata

Last Modified Date
2023-05-16
Interactions and External Dependencies
Contributors
  • Graeme Leese, Broadcom

Description

This extension enables use of the more expressive fast floating-point math flags in the SPV_KHR_float_controls2 extension. These flags give finer- grained control over which optimizations compilers may apply, potentially speeding up execution while retaining correct results.

The extension also adds control over the fast-math modes to the GLSL extended instruction set, making these operations more consistent with SPIR-V and allowing their use in situations where floating-point conformance is important.

New Structures

New Enum Constants

New SPIR-V Capabilities

Version History

  • Revision 1, 2023-05-16 (Graeme Leese)

    • Initial draft

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceShaderFloatControls2FeaturesKHR Source #

VkPhysicalDeviceShaderFloatControls2FeaturesKHR - Structure describing shader float controls 2 features that can be supported by an implementation

Members

This structure describes the following feature:

Description

If the PhysicalDeviceShaderFloatControls2FeaturesKHR structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. PhysicalDeviceShaderFloatControls2FeaturesKHR can also be used in the pNext chain of DeviceCreateInfo to selectively enable these features.

Valid Usage (Implicit)

See Also

VK_KHR_shader_float_controls2, Bool32, StructureType

Constructors

PhysicalDeviceShaderFloatControls2FeaturesKHR 

Fields

  • shaderFloatControls2 :: Bool

    shaderFloatControls2 specifies whether shader modules can declare the FloatControls2 capability.

Instances

Instances details
Storable PhysicalDeviceShaderFloatControls2FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_float_controls2

Show PhysicalDeviceShaderFloatControls2FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_float_controls2

Eq PhysicalDeviceShaderFloatControls2FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_float_controls2

FromCStruct PhysicalDeviceShaderFloatControls2FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_float_controls2

ToCStruct PhysicalDeviceShaderFloatControls2FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_float_controls2

Zero PhysicalDeviceShaderFloatControls2FeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_float_controls2

type KHR_SHADER_FLOAT_CONTROLS_2_EXTENSION_NAME = "VK_KHR_shader_float_controls2" Source #