vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_shader_maximal_reconvergence

Description

Name

VK_KHR_shader_maximal_reconvergence - device extension

VK_KHR_shader_maximal_reconvergence

Name String
VK_KHR_shader_maximal_reconvergence
Extension Type
Device extension
Registered Extension Number
435
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
Vulkan Version 1.1
SPIR-V Dependencies
Contact
Extension Proposal
VK_KHR_shader_maximal_reconvergence

Other Extension Metadata

Last Modified Date
2021-11-12
IP Status
No known IP claims.
Interactions and External Dependencies
Contributors
  • Alan Baker, Google

Description

This extension allows the use of the SPV_KHR_maximal_reconvergence SPIR-V extension in shader modules. SPV_KHR_maximal_reconvergence provides stronger guarantees that diverged subgroups will reconverge. These guarantees should match shader author intuition about divergence and reconvergence of invocations based on the structure of the code in the HLL.

Developers should utilize this extension if they require stronger guarantees about reconvergence than either the core spec or SPV_KHR_subgroup_uniform_control_flow. This extension will define the rules that govern how invocations diverge and reconverge in a way that should match developer intuition. It allows robust programs to be written relying on subgroup operations and other tangled instructions.

New Structures

New Enum Constants

Version History

  • Revision 1, 2021-11-12 (Alan Baker)

    • Internal draft version

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR Source #

VkPhysicalDeviceShaderMaximalReconvergenceFeaturesKHR - Structure describing support for shader maximal reconvergence by an implementation

Members

This structure describes the following feature:

Description

If the PhysicalDevicePrivateDataFeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDevicePrivateDataFeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_KHR_shader_maximal_reconvergence, Bool32, StructureType

Constructors

PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR 

Fields

  • shaderMaximalReconvergence :: Bool

    shaderMaximalReconvergence specifies whether the implementation supports the shader execution mode MaximallyReconvergesKHR

Instances

Instances details
Eq PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_maximal_reconvergence

Storable PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_maximal_reconvergence

Show PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_maximal_reconvergence

FromCStruct PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_maximal_reconvergence

ToCStruct PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_maximal_reconvergence

Zero PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_shader_maximal_reconvergence

type KHR_SHADER_MAXIMAL_RECONVERGENCE_EXTENSION_NAME = "VK_KHR_shader_maximal_reconvergence" Source #