| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_shader_quad_control
Description
Name
VK_KHR_shader_quad_control - device extension
VK_KHR_shader_quad_control
- Name String
VK_KHR_shader_quad_control
- Extension Type
- Device extension
- Registered Extension Number
- 236
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
Vulkan Version 1.2 and VK_KHR_shader_maximal_reconvergence
- SPIR-V Dependencies
- Contact
- Extension Proposal
- VK_KHR_shader_quad_control
Other Extension Metadata
- Last Modified Date
- 2023-11-01
- IP Status
- No known IP claims.
- Contributors
- Tobias Hector, AMD
- Bill Licea-Kane, Qualcomm
- Graeme Leese, Broadcom
- Jan-Harald Fredriksen, Arm
- Nicolai Hähnle, AMD
- Jeff Bolz, NVidia
- Alan Baker, Google
- Hans-Kristian Arntzen, Valve
Description
This extension adds new quad any/all operations, requires that derivatives are well-defined in quad-uniform control flow, and adds the ability to require helper invocations participate in group operations.
New Structures
New Enum Constants
New SPIR-V Capabilities
Version History
Revision 1, 2023-11-01 (Tobias Hector)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderQuadControlFeaturesKHR = PhysicalDeviceShaderQuadControlFeaturesKHR {}
- type KHR_SHADER_QUAD_CONTROL_SPEC_VERSION = 1
- pattern KHR_SHADER_QUAD_CONTROL_SPEC_VERSION :: Integral a => a
- type KHR_SHADER_QUAD_CONTROL_EXTENSION_NAME = "VK_KHR_shader_quad_control"
- pattern KHR_SHADER_QUAD_CONTROL_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderQuadControlFeaturesKHR Source #
VkPhysicalDeviceShaderQuadControlFeaturesKHR - Structure describing whether quad scopes are supported by the implementation
Members
This structure describes the following features:
Description
If the PhysicalDeviceShaderQuadControlFeaturesKHR structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceShaderQuadControlFeaturesKHR, it must add an instance
of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderQuadControlFeaturesKHR | |
Fields | |
Instances
type KHR_SHADER_QUAD_CONTROL_SPEC_VERSION = 1 Source #
pattern KHR_SHADER_QUAD_CONTROL_SPEC_VERSION :: Integral a => a Source #
type KHR_SHADER_QUAD_CONTROL_EXTENSION_NAME = "VK_KHR_shader_quad_control" Source #
pattern KHR_SHADER_QUAD_CONTROL_EXTENSION_NAME :: (Eq a, IsString a) => a Source #