| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_shader_subgroup_rotate
Description
Name
VK_KHR_shader_subgroup_rotate - device extension
VK_KHR_shader_subgroup_rotate
- Name String
VK_KHR_shader_subgroup_rotate
- Extension Type
- Device extension
- Registered Extension Number
- 417
- Revision
- 2
- Ratification Status
- Ratified
- Extension and Version Dependencies
- None
- SPIR-V Dependencies
- Contact
- Extension Proposal
- VK_KHR_shader_subgroup_rotate
- Last Modified Date
- 2024-01-29
- IP Status
- No known IP claims.
- Contributors
- Kévin Petit, Arm Ltd.
- Tobias Hector, AMD
- John Leech, Khronos
- Matthew Netsch, Qualcomm
- Jan-Harald Fredriksen, Arm Ltd.
- Graeme Leese, Broadcom
- Tom Olson, Arm Ltd.
- Spencer Fricke, LunarG Inc.
This extension adds support for the subgroup rotate instruction defined in SPV_KHR_subgroup_rotate.
New Structures
New Enum Constants
KHR_SHADER_SUBGROUP_ROTATE_SPEC_VERSIONExtending
StructureType:Extending
SubgroupFeatureFlagBits:
New SPIR-V Capabilities
Version History
Revision 2, 2024-01-29 (Kévin Petit)
Revision 1, 2023-06-20 (Kévin Petit)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderSubgroupRotateFeaturesKHR = PhysicalDeviceShaderSubgroupRotateFeaturesKHR {}
- type KHR_SHADER_SUBGROUP_ROTATE_SPEC_VERSION = 2
- pattern KHR_SHADER_SUBGROUP_ROTATE_SPEC_VERSION :: forall a. Integral a => a
- type KHR_SHADER_SUBGROUP_ROTATE_EXTENSION_NAME = "VK_KHR_shader_subgroup_rotate"
- pattern KHR_SHADER_SUBGROUP_ROTATE_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderSubgroupRotateFeaturesKHR Source #
VkPhysicalDeviceShaderSubgroupRotateFeaturesKHR - Structure describing whether subgroup rotation is enabled
Description
If the PhysicalDeviceShaderSubgroupRotateFeaturesKHR structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. PhysicalDeviceShaderSubgroupRotateFeaturesKHR can also be
used in the pNext chain of DeviceCreateInfo to
selectively enable these features.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderSubgroupRotateFeaturesKHR | |
Fields | |
Instances
pattern KHR_SHADER_SUBGROUP_ROTATE_SPEC_VERSION :: forall a. Integral a => a Source #
type KHR_SHADER_SUBGROUP_ROTATE_EXTENSION_NAME = "VK_KHR_shader_subgroup_rotate" Source #
pattern KHR_SHADER_SUBGROUP_ROTATE_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a Source #