| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_shader_subgroup_uniform_control_flow
Description
Name
VK_KHR_shader_subgroup_uniform_control_flow - device extension
VK_KHR_shader_subgroup_uniform_control_flow
- Name String
VK_KHR_shader_subgroup_uniform_control_flow
- Extension Type
- Device extension
- Registered Extension Number
- 324
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- Vulkan Version 1.1
- SPIR-V Dependencies
- Contact
Other Extension Metadata
- Last Modified Date
- 2020-08-27
- IP Status
- No known IP claims.
- Interactions and External Dependencies
- Requires SPIR-V 1.3.
- This extension provides API support for GL_EXT_subgroupuniform_qualifier
- Contributors
- Alan Baker, Google
- Jeff Bolz, NVIDIA
Description
This extension allows the use of the
SPV_KHR_subgroup_uniform_control_flow SPIR-V extension in shader
modules. SPV_KHR_subgroup_uniform_control_flow provides stronger
guarantees that diverged subgroups will reconverge.
Developers should utilize this extension if they use subgroup operations to reduce the work performed by a uniform subgroup. This extension will guarantee that uniform subgroup will reconverge in the same manner as invocation groups (see “Uniform Control Flow” in the Khronos SPIR-V Specification).
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
Version History
Revision 1, 2020-08-27 (Alan Baker)
- Internal draft version
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderSubgroupUniformControlFlowFeaturesKHR = PhysicalDeviceShaderSubgroupUniformControlFlowFeaturesKHR {}
- type KHR_SHADER_SUBGROUP_UNIFORM_CONTROL_FLOW_SPEC_VERSION = 1
- pattern KHR_SHADER_SUBGROUP_UNIFORM_CONTROL_FLOW_SPEC_VERSION :: Integral a => a
- type KHR_SHADER_SUBGROUP_UNIFORM_CONTROL_FLOW_EXTENSION_NAME = "VK_KHR_shader_subgroup_uniform_control_flow"
- pattern KHR_SHADER_SUBGROUP_UNIFORM_CONTROL_FLOW_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderSubgroupUniformControlFlowFeaturesKHR Source #
VkPhysicalDeviceShaderSubgroupUniformControlFlowFeaturesKHR - Structure describing support for shader subgroup uniform control flow by an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceShaderSubgroupUniformControlFlowFeaturesKHR
structure is included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceShaderSubgroupUniformControlFlowFeaturesKHR, it must
add an instance of the structure, with the desired feature members set
to TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
VK_KHR_shader_subgroup_uniform_control_flow,
Bool32,
StructureType
Constructors
| PhysicalDeviceShaderSubgroupUniformControlFlowFeaturesKHR | |
Fields | |
Instances
pattern KHR_SHADER_SUBGROUP_UNIFORM_CONTROL_FLOW_SPEC_VERSION :: Integral a => a Source #
type KHR_SHADER_SUBGROUP_UNIFORM_CONTROL_FLOW_EXTENSION_NAME = "VK_KHR_shader_subgroup_uniform_control_flow" Source #
pattern KHR_SHADER_SUBGROUP_UNIFORM_CONTROL_FLOW_EXTENSION_NAME :: (Eq a, IsString a) => a Source #