vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_zero_initialize_workgroup_memory

Description

Name

VK_KHR_zero_initialize_workgroup_memory - device extension

VK_KHR_zero_initialize_workgroup_memory

Name String
VK_KHR_zero_initialize_workgroup_memory
Extension Type
Device extension
Registered Extension Number
326
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
Deprecation State
Contact

Other Extension Metadata

Last Modified Date
2020-11-18
IP Status
No known IP claims.
Contributors
  • Alan Baker, Google
  • Jeff Bolz, Nvidia
  • Faith Ekstrand, Intel

Description

This extension allows the use of a null constant initializer on shader Workgroup memory variables, allowing implementations to expose any special hardware or instructions they may have. Zero initialization is commonly used by applications running untrusted content (e.g. web browsers) as way of defeating memory-scraping attacks.

New Structures

New Enum Constants

Promotion to Vulkan 1.3

Vulkan APIs in this extension are included in core Vulkan 1.3, with the KHR suffix omitted. External interactions defined by this extension, such as SPIR-V token names, retain their original names. The original Vulkan API names are still available as aliases of the core functionality.

Version History

  • Revision 1, 2020-11-18 (Alan Baker)

    • Internal draft version

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Documentation

type KHR_ZERO_INITIALIZE_WORKGROUP_MEMORY_EXTENSION_NAME = "VK_KHR_zero_initialize_workgroup_memory" Source #