vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_NV_descriptor_pool_overallocation

Description

Name

VK_NV_descriptor_pool_overallocation - device extension

VK_NV_descriptor_pool_overallocation

Name String
VK_NV_descriptor_pool_overallocation
Extension Type
Device extension
Registered Extension Number
547
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
Vulkan Version 1.1
Contact

Other Extension Metadata

Last Modified Date
2023-08-30
Contributors
  • Jeff Bolz, NVIDIA

Description

There are scenarios where the application does not know ahead of time how many descriptor sets it may need to allocate from a descriptor pool, or how many descriptors of any of the descriptor types it may need to allocate from the descriptor pool.

This extension gives applications the ability to request the implementation allow more sets or descriptors to be allocated than initially specified at descriptor pool creation time, subject to available resources.

The DESCRIPTOR_POOL_CREATE_ALLOW_OVERALLOCATION_SETS_BIT_NV flag lets the application allocate more than DescriptorPoolCreateInfo::maxSets descriptor sets, and the DESCRIPTOR_POOL_CREATE_ALLOW_OVERALLOCATION_POOLS_BIT_NV lets the application allocate more descriptors than initially specified by DescriptorPoolSize::descriptorCount for any descriptor types.

New Structures

New Enum Constants

Version History

  • Revision 1, 2023-08-30 (Piers Daniell)

    • Internal revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceDescriptorPoolOverallocationFeaturesNV Source #

VkPhysicalDeviceDescriptorPoolOverallocationFeaturesNV - Structure describing feature to allow descriptor pool overallocation

Members

This structure describes the following feature:

Description

If the PhysicalDeviceDescriptorPoolOverallocationFeaturesNV structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceDescriptorPoolOverallocationFeaturesNV, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_NV_descriptor_pool_overallocation, Bool32, StructureType

Constructors

PhysicalDeviceDescriptorPoolOverallocationFeaturesNV 

Fields

Instances

Instances details
Eq PhysicalDeviceDescriptorPoolOverallocationFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_descriptor_pool_overallocation

Storable PhysicalDeviceDescriptorPoolOverallocationFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_descriptor_pool_overallocation

Show PhysicalDeviceDescriptorPoolOverallocationFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_descriptor_pool_overallocation

FromCStruct PhysicalDeviceDescriptorPoolOverallocationFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_descriptor_pool_overallocation

ToCStruct PhysicalDeviceDescriptorPoolOverallocationFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_descriptor_pool_overallocation

Zero PhysicalDeviceDescriptorPoolOverallocationFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_descriptor_pool_overallocation

type NV_DESCRIPTOR_POOL_OVERALLOCATION_EXTENSION_NAME = "VK_NV_descriptor_pool_overallocation" Source #