| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_NV_device_diagnostics_config
Description
Name
VK_NV_device_diagnostics_config - device extension
VK_NV_device_diagnostics_config
- Name String
VK_NV_device_diagnostics_config
- Extension Type
- Device extension
- Registered Extension Number
- 301
- Revision
- 2
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Contact
Other Extension Metadata
- Last Modified Date
- 2022-04-06
- Contributors
- Kedarnath Thangudu, NVIDIA
- Thomas Klein, NVIDIA
Description
Applications using Nvidia Nsight™ Aftermath SDK for Vulkan to integrate device crash dumps into their error reporting mechanisms, may use this extension to configure options related to device crash dump creation.
Version 2 of this extension adds
DEVICE_DIAGNOSTICS_CONFIG_ENABLE_SHADER_ERROR_REPORTING_BIT_NV which
when set enables enhanced reporting of shader execution errors.
New Structures
New Enums
New Bitmasks
New Enum Constants
Version History
Revision 1, 2019-11-21 (Kedarnath Thangudu)
- Internal revisions
Revision 2, 2022-04-06 (Kedarnath Thangudu)
- Added a config bit
DEVICE_DIAGNOSTICS_CONFIG_ENABLE_SHADER_ERROR_REPORTING_BIT_NV
- Added a config bit
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceDiagnosticsConfigFeaturesNV = PhysicalDeviceDiagnosticsConfigFeaturesNV {}
- data DeviceDiagnosticsConfigCreateInfoNV = DeviceDiagnosticsConfigCreateInfoNV {}
- type DeviceDiagnosticsConfigFlagsNV = DeviceDiagnosticsConfigFlagBitsNV
- newtype DeviceDiagnosticsConfigFlagBitsNV where
- DeviceDiagnosticsConfigFlagBitsNV Flags
- pattern DEVICE_DIAGNOSTICS_CONFIG_ENABLE_SHADER_DEBUG_INFO_BIT_NV :: DeviceDiagnosticsConfigFlagBitsNV
- pattern DEVICE_DIAGNOSTICS_CONFIG_ENABLE_RESOURCE_TRACKING_BIT_NV :: DeviceDiagnosticsConfigFlagBitsNV
- pattern DEVICE_DIAGNOSTICS_CONFIG_ENABLE_AUTOMATIC_CHECKPOINTS_BIT_NV :: DeviceDiagnosticsConfigFlagBitsNV
- pattern DEVICE_DIAGNOSTICS_CONFIG_ENABLE_SHADER_ERROR_REPORTING_BIT_NV :: DeviceDiagnosticsConfigFlagBitsNV
- type NV_DEVICE_DIAGNOSTICS_CONFIG_SPEC_VERSION = 2
- pattern NV_DEVICE_DIAGNOSTICS_CONFIG_SPEC_VERSION :: Integral a => a
- type NV_DEVICE_DIAGNOSTICS_CONFIG_EXTENSION_NAME = "VK_NV_device_diagnostics_config"
- pattern NV_DEVICE_DIAGNOSTICS_CONFIG_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceDiagnosticsConfigFeaturesNV Source #
VkPhysicalDeviceDiagnosticsConfigFeaturesNV - Structure describing the device-generated diagnostic configuration features that can be supported by an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceDiagnosticsConfigFeaturesNV structure is included
in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceDiagnosticsConfigFeaturesNV, it must add an instance
of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceDiagnosticsConfigFeaturesNV | |
Fields | |
Instances
data DeviceDiagnosticsConfigCreateInfoNV Source #
VkDeviceDiagnosticsConfigCreateInfoNV - Specify diagnostics config for a Vulkan device
Valid Usage (Implicit)
See Also
VK_NV_device_diagnostics_config,
DeviceDiagnosticsConfigFlagsNV,
StructureType
Constructors
| DeviceDiagnosticsConfigCreateInfoNV | |
Fields
| |
Instances
newtype DeviceDiagnosticsConfigFlagBitsNV Source #
VkDeviceDiagnosticsConfigFlagBitsNV - Bitmask specifying diagnostics flags
Description
DEVICE_DIAGNOSTICS_CONFIG_ENABLE_SHADER_DEBUG_INFO_BIT_NVenables the generation of debug information for shaders.
DEVICE_DIAGNOSTICS_CONFIG_ENABLE_RESOURCE_TRACKING_BIT_NVenables driver side tracking of resources (images, buffers, etc.) used to augment the device fault information.DEVICE_DIAGNOSTICS_CONFIG_ENABLE_AUTOMATIC_CHECKPOINTS_BIT_NVenables automatic insertion of diagnostic checkpoints for draw calls, dispatches, trace rays, and copies. The CPU call stack at the time of the command will be associated as the marker data for the automatically inserted checkpoints.DEVICE_DIAGNOSTICS_CONFIG_ENABLE_SHADER_ERROR_REPORTING_BIT_NVenables shader error reporting.
See Also
VK_NV_device_diagnostics_config,
DeviceDiagnosticsConfigFlagsNV
Constructors
| DeviceDiagnosticsConfigFlagBitsNV Flags |
Bundled Patterns
Instances
pattern NV_DEVICE_DIAGNOSTICS_CONFIG_SPEC_VERSION :: Integral a => a Source #
type NV_DEVICE_DIAGNOSTICS_CONFIG_EXTENSION_NAME = "VK_NV_device_diagnostics_config" Source #
pattern NV_DEVICE_DIAGNOSTICS_CONFIG_EXTENSION_NAME :: (Eq a, IsString a) => a Source #