| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_NV_display_stereo
Description
Name
VK_NV_display_stereo - instance extension
VK_NV_display_stereo
- Name String
VK_NV_display_stereo
- Extension Type
- Instance extension
- Registered Extension Number
- 552
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_KHR_display and VK_KHR_get_display_properties2
- Contact
- Extension Proposal
- VK_NV_display_stereo
Other Extension Metadata
- Last Modified Date
- 2024-11-20
- Contributors
- Russell Chou, NVIDIA
- Jeff Juliano, NVIDIA
- James Jones, NVIDIA
Description
This extension allows the application to choose which type of 3D stereo hardware it wants to use so the driver can configure it properly. This configuration is useful for swapchains created from display surfaces because some environments do not have an intermediate windowing system available for easy configuration. This extension will override any stereo type configuration in the windowing system.
For HDMI 3D, only some display modes support stereo rendering, and a new structure is needed to expose that information to the application.
New Structures
New Enums
New Enum Constants
NV_DISPLAY_STEREO_SPEC_VERSIONExtending
StructureType:
Version History
Revision 1, 2024-11-20 (Russell Chou)
- Initial release
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data DisplaySurfaceStereoCreateInfoNV = DisplaySurfaceStereoCreateInfoNV {}
- data DisplayModeStereoPropertiesNV = DisplayModeStereoPropertiesNV {}
- newtype DisplaySurfaceStereoTypeNV where
- DisplaySurfaceStereoTypeNV Int32
- pattern DISPLAY_SURFACE_STEREO_TYPE_NONE_NV :: DisplaySurfaceStereoTypeNV
- pattern DISPLAY_SURFACE_STEREO_TYPE_ONBOARD_DIN_NV :: DisplaySurfaceStereoTypeNV
- pattern DISPLAY_SURFACE_STEREO_TYPE_HDMI_3D_NV :: DisplaySurfaceStereoTypeNV
- pattern DISPLAY_SURFACE_STEREO_TYPE_INBAND_DISPLAYPORT_NV :: DisplaySurfaceStereoTypeNV
- type NV_DISPLAY_STEREO_SPEC_VERSION = 1
- pattern NV_DISPLAY_STEREO_SPEC_VERSION :: forall a. Integral a => a
- type NV_DISPLAY_STEREO_EXTENSION_NAME = "VK_NV_display_stereo"
- pattern NV_DISPLAY_STEREO_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a
Documentation
data DisplaySurfaceStereoCreateInfoNV Source #
VkDisplaySurfaceStereoCreateInfoNV - Structure specifying stereo parameters of a newly created display plane surface object
Valid Usage (Implicit)
See Also
VK_NV_display_stereo,
DisplaySurfaceStereoTypeNV,
StructureType
Constructors
| DisplaySurfaceStereoCreateInfoNV | |
Fields
| |
Instances
data DisplayModeStereoPropertiesNV Source #
VkDisplayModeStereoPropertiesNV - Structure describing the stereo properties of a display mode
Valid Usage (Implicit)
See Also
Constructors
| DisplayModeStereoPropertiesNV | |
Fields
| |
Instances
newtype DisplaySurfaceStereoTypeNV Source #
VkDisplaySurfaceStereoTypeNV - 3D Stereo type
See Also
Constructors
| DisplaySurfaceStereoTypeNV Int32 |
Bundled Patterns
| pattern DISPLAY_SURFACE_STEREO_TYPE_NONE_NV :: DisplaySurfaceStereoTypeNV |
|
| pattern DISPLAY_SURFACE_STEREO_TYPE_ONBOARD_DIN_NV :: DisplaySurfaceStereoTypeNV |
|
| pattern DISPLAY_SURFACE_STEREO_TYPE_HDMI_3D_NV :: DisplaySurfaceStereoTypeNV |
|
| pattern DISPLAY_SURFACE_STEREO_TYPE_INBAND_DISPLAYPORT_NV :: DisplaySurfaceStereoTypeNV |
|
Instances
type NV_DISPLAY_STEREO_SPEC_VERSION = 1 Source #
pattern NV_DISPLAY_STEREO_SPEC_VERSION :: forall a. Integral a => a Source #
type NV_DISPLAY_STEREO_EXTENSION_NAME = "VK_NV_display_stereo" Source #
pattern NV_DISPLAY_STEREO_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a Source #