vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_NV_present_barrier

Description

Name

VK_NV_present_barrier - device extension

VK_NV_present_barrier

Name String
VK_NV_present_barrier
Extension Type
Device extension
Registered Extension Number
293
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies

VK_KHR_get_physical_device_properties2      or

Vulkan Version 1.1 and VK_KHR_surface and VK_KHR_get_surface_capabilities2 and VK_KHR_swapchain

Contact

Other Extension Metadata

Last Modified Date
2022-05-16
Contributors
  • Liya Li, Nvidia
  • Martin Schwarzer, Nvidia
  • Andy Wolf, Nvidia
  • Ian Williams, Nvidia
  • Ben Morris, Nvidia
  • James Jones, Nvidia
  • Jeff Juliano, Nvidia

Description

This extension adds support for synchronizing corresponding presentation requests across multiple swapchains using the present barrier.

New Structures

New Enum Constants

Issues

1) Is there a query interface to check if a swapchain is using the present barrier?

RESOLVED. There is no such query interface. When creating a swapchain, an application can specify to use the present barrier, and if the swapchain is created successfully, this swapchain will be using the present barrier.

2) Do we need an extra interface to set up the present barrier across distributed systems?

RESOLVED. If the required hardware is presented in the system, and all settings for the physical synchronization with other systems are set up, an implementation manages the configuration automatically when creating a swapchain, without any extra calls from the application.

Version History

  • Revision 1, 2022-07-20

    • Initial version

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDevicePresentBarrierFeaturesNV Source #

VkPhysicalDevicePresentBarrierFeaturesNV - Structure indicating support for VK_NV_present_barrier extension

Members

This structure describes the following feature:

Description

If the PhysicalDevicePresentBarrierFeaturesNV structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDevicePresentBarrierFeaturesNV, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_NV_present_barrier, Bool32, StructureType

Constructors

PhysicalDevicePresentBarrierFeaturesNV 

Fields

  • presentBarrier :: Bool

    presentBarrier indicates that the implementation supports the present barrier feature.

Instances

Instances details
Eq PhysicalDevicePresentBarrierFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

Storable PhysicalDevicePresentBarrierFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

Show PhysicalDevicePresentBarrierFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

FromCStruct PhysicalDevicePresentBarrierFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

ToCStruct PhysicalDevicePresentBarrierFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

Zero PhysicalDevicePresentBarrierFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

data SurfaceCapabilitiesPresentBarrierNV Source #

VkSurfaceCapabilitiesPresentBarrierNV - Structure describing present barrier capabilities of a surface

Description

This structure can be included in the pNext chain of SurfaceCapabilities2KHR to determine support for present barrier access. If presentBarrierSupported is FALSE, it indicates that the present barrier feature is not obtainable for this surface.

Valid Usage (Implicit)

See Also

VK_NV_present_barrier, Bool32, StructureType

Constructors

SurfaceCapabilitiesPresentBarrierNV 

Fields

  • presentBarrierSupported :: Bool

    presentBarrierSupported is a boolean describing whether the surface is able to make use of the present barrier feature.

Instances

Instances details
Eq SurfaceCapabilitiesPresentBarrierNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

Storable SurfaceCapabilitiesPresentBarrierNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

Show SurfaceCapabilitiesPresentBarrierNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

FromCStruct SurfaceCapabilitiesPresentBarrierNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

ToCStruct SurfaceCapabilitiesPresentBarrierNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

Zero SurfaceCapabilitiesPresentBarrierNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

data SwapchainPresentBarrierCreateInfoNV Source #

VkSwapchainPresentBarrierCreateInfoNV - specify the present barrier membership of this swapchain

Description

If the pNext chain of SwapchainCreateInfoKHR does not include this structure, the default value for presentBarrierEnable is FALSE, meaning the swapchain does not request to use the present barrier. Additionally, when recreating a swapchain that was using the present barrier, and the pNext chain of SwapchainCreateInfoKHR does not include this structure, it means the swapchain will stop using the present barrier.

Valid Usage (Implicit)

See Also

VK_NV_present_barrier, Bool32, StructureType

Constructors

SwapchainPresentBarrierCreateInfoNV 

Fields

Instances

Instances details
Eq SwapchainPresentBarrierCreateInfoNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

Storable SwapchainPresentBarrierCreateInfoNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

Show SwapchainPresentBarrierCreateInfoNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

FromCStruct SwapchainPresentBarrierCreateInfoNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

ToCStruct SwapchainPresentBarrierCreateInfoNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

Zero SwapchainPresentBarrierCreateInfoNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_present_barrier

type NV_PRESENT_BARRIER_EXTENSION_NAME = "VK_NV_present_barrier" Source #