| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_NV_ray_tracing_validation
Description
Name
VK_NV_ray_tracing_validation - device extension
VK_NV_ray_tracing_validation
- Name String
VK_NV_ray_tracing_validation
- Extension Type
- Device extension
- Registered Extension Number
- 569
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Contact
- Extension Proposal
- VK_NV_ray_tracing_validation
Other Extension Metadata
- Last Modified Date
- 2024-03-04
- Contributors
- Vikram Kushwaha, NVIDIA
- Eric Werness, NVIDIA
- Piers Daniell, NVIDIA
Description
This extension adds support for performing ray tracing validation at an implementation level.
New Structures
New Enum Constants
Version History
Revision 1, 2024-03-04 (Vikram Kushwaha)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceRayTracingValidationFeaturesNV = PhysicalDeviceRayTracingValidationFeaturesNV {}
- type NV_RAY_TRACING_VALIDATION_SPEC_VERSION = 1
- pattern NV_RAY_TRACING_VALIDATION_SPEC_VERSION :: Integral a => a
- type NV_RAY_TRACING_VALIDATION_EXTENSION_NAME = "VK_NV_ray_tracing_validation"
- pattern NV_RAY_TRACING_VALIDATION_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceRayTracingValidationFeaturesNV Source #
VkPhysicalDeviceRayTracingValidationFeaturesNV - Structure describing the ray tracing validation features that can be supported by an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceRayTracingValidationFeaturesNV structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceRayTracingValidationFeaturesNV, it must add an
instance of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceRayTracingValidationFeaturesNV | |
Fields | |
Instances
pattern NV_RAY_TRACING_VALIDATION_SPEC_VERSION :: Integral a => a Source #
type NV_RAY_TRACING_VALIDATION_EXTENSION_NAME = "VK_NV_ray_tracing_validation" Source #
pattern NV_RAY_TRACING_VALIDATION_EXTENSION_NAME :: (Eq a, IsString a) => a Source #