vulkan
Safe HaskellSafe-Inferred
LanguageHaskell2010

Vulkan.Extensions.VK_NV_shader_atomic_float16_vector

Description

Name

VK_NV_shader_atomic_float16_vector - device extension

VK_NV_shader_atomic_float16_vector

Name String
VK_NV_shader_atomic_float16_vector
Extension Type
Device extension
Registered Extension Number
564
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
None
SPIR-V Dependencies
Contact

Other Extension Metadata

Last Modified Date
2024-02-03
IP Status
No known IP claims.
Interactions and External Dependencies
Contributors
  • Jeff Bolz, NVIDIA

Description

This extension allows a shader to perform atomic add, min, max, and exchange operations on 2- and 4-component vectors of float16. Buffer, workgroup, and image storage classes are all supported.

New Structures

New Enum Constants

Issues

None.

New SPIR-V Capabilities

Version History

  • Revision 1, 2024-02-03 (Jeff Bolz)

    • Internal revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceShaderAtomicFloat16VectorFeaturesNV Source #

VkPhysicalDeviceShaderAtomicFloat16VectorFeaturesNV - Structure describing features supported by VK_NV_shader_atomic_float16_vector

Members

This structure describes the following features:

Description

If the PhysicalDeviceShaderAtomicFloat16VectorFeaturesNV structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. PhysicalDeviceShaderAtomicFloat16VectorFeaturesNV can also be used in the pNext chain of DeviceCreateInfo to selectively enable these features.

Valid Usage (Implicit)

See Also

VK_NV_shader_atomic_float16_vector, Bool32, StructureType

Constructors

PhysicalDeviceShaderAtomicFloat16VectorFeaturesNV 

Fields

  • shaderFloat16VectorAtomics :: Bool

    shaderFloat16VectorAtomics indicates whether shaders can perform 16-bit floating-point, 2- and 4-component vector atomic operations.

Instances

Instances details
Storable PhysicalDeviceShaderAtomicFloat16VectorFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_shader_atomic_float16_vector

Show PhysicalDeviceShaderAtomicFloat16VectorFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_shader_atomic_float16_vector

Eq PhysicalDeviceShaderAtomicFloat16VectorFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_shader_atomic_float16_vector

FromCStruct PhysicalDeviceShaderAtomicFloat16VectorFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_shader_atomic_float16_vector

ToCStruct PhysicalDeviceShaderAtomicFloat16VectorFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_shader_atomic_float16_vector

Zero PhysicalDeviceShaderAtomicFloat16VectorFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_shader_atomic_float16_vector

type NV_SHADER_ATOMIC_FLOAT16_VECTOR_EXTENSION_NAME = "VK_NV_shader_atomic_float16_vector" Source #