vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_QCOM_cooperative_matrix_conversion

Description

Name

VK_QCOM_cooperative_matrix_conversion - device extension

VK_QCOM_cooperative_matrix_conversion

Name String
VK_QCOM_cooperative_matrix_conversion
Extension Type
Device extension
Registered Extension Number
173
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
VK_KHR_cooperative_matrix
SPIR-V Dependencies
Contact
Extension Proposal
VK_QCOM_cooperative_matrix_conversion

Other Extension Metadata

Last Modified Date
2026-01-28
Interactions and External Dependencies
Contributors
  • Matthew Netsch, Qualcomm Technologies, Inc
  • Elina Kamenetskaya, Qualcomm Technologies, Inc
  • Alex Bourd, Qualcomm Technologies, Inc
  • Ruihao Zhang, Qualcomm Technologies, Inc
  • Wooyoung Kim, Qualcomm Technologies, Inc

Description

This extension adds support for new SPIR-V shader instructions that allow loading and storing a cooperative matrix without needing to stage through shared memory and to allow bit casting arrays.

These instructions are defined by the SPV_QCOM_cooperative_matrix_conversion SPIR-V extension and can be used with the GLSL_QCOM_cooperative_matrix_conversion GLSL extension.

New Structures

New Enum Constants

New SPIR-V Capabilities

Version History

  • Revision 1, 2026-01-28 (Matthew Netsch)

    • Initial draft

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceCooperativeMatrixConversionFeaturesQCOM Source #

VkPhysicalDeviceCooperativeMatrixConversionFeaturesQCOM - Structure describing cooperative matrix conversion features that can be supported by an implementation

Members

This structure describes the following features:

Description

If the PhysicalDeviceCooperativeMatrixConversionFeaturesQCOM structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceCooperativeMatrixConversionFeaturesQCOM, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_QCOM_cooperative_matrix_conversion, Bool32, StructureType

Constructors

PhysicalDeviceCooperativeMatrixConversionFeaturesQCOM 

Fields

  • cooperativeMatrixConversion :: Bool

    cooperativeMatrixConversion indicates that the implementation supports the CooperativeMatrixConversionQCOM SPIR-V capability.

Instances

Instances details
Eq PhysicalDeviceCooperativeMatrixConversionFeaturesQCOM Source # 
Instance details

Defined in Vulkan.Extensions.VK_QCOM_cooperative_matrix_conversion

Storable PhysicalDeviceCooperativeMatrixConversionFeaturesQCOM Source # 
Instance details

Defined in Vulkan.Extensions.VK_QCOM_cooperative_matrix_conversion

Show PhysicalDeviceCooperativeMatrixConversionFeaturesQCOM Source # 
Instance details

Defined in Vulkan.Extensions.VK_QCOM_cooperative_matrix_conversion

FromCStruct PhysicalDeviceCooperativeMatrixConversionFeaturesQCOM Source # 
Instance details

Defined in Vulkan.Extensions.VK_QCOM_cooperative_matrix_conversion

ToCStruct PhysicalDeviceCooperativeMatrixConversionFeaturesQCOM Source # 
Instance details

Defined in Vulkan.Extensions.VK_QCOM_cooperative_matrix_conversion

Zero PhysicalDeviceCooperativeMatrixConversionFeaturesQCOM Source # 
Instance details

Defined in Vulkan.Extensions.VK_QCOM_cooperative_matrix_conversion

type QCOM_COOPERATIVE_MATRIX_CONVERSION_EXTENSION_NAME = "VK_QCOM_cooperative_matrix_conversion" Source #