| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_QCOM_tile_properties
Description
Name
VK_QCOM_tile_properties - device extension
VK_QCOM_tile_properties
- Name String
VK_QCOM_tile_properties
- Extension Type
- Device extension
- Registered Extension Number
- 485
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- API Interactions
- Interacts with VK_VERSION_1_3
- Interacts with VK_KHR_dynamic_rendering
- Contact
- Extension Proposal
- VK_QCOM_tile_properties
Other Extension Metadata
- Last Modified Date
- 2022-07-11
- Interactions and External Dependencies
- This extension interacts with
VK_EXT_subpass_merge_feedback
- This extension interacts with
- Contributors
- Jonathan Wicks, Qualcomm Technologies, Inc.
- Jonathan Tinkham, Qualcomm Technologies, Inc.
- Arpit Agarwal, Qualcomm Technologies, Inc.
- Jeff Leger, Qualcomm Technologies, Inc.
Description
This extension allows an application to query the tile properties. This extension supports both renderpasses and dynamic rendering.
New Commands
New Structures
If VK_KHR_dynamic_rendering or Vulkan Version 1.3 is supported:
New Enum Constants
Version History
Revision 1, 2022-07-11 (Arpit Agarwal)
- Initial version
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- getFramebufferTilePropertiesQCOM :: MonadIO io => Device -> Framebuffer -> io (Result, "properties" ::: Vector TilePropertiesQCOM)
- getDynamicRenderingTilePropertiesQCOM :: forall (a :: [Type]) io. (Extendss RenderingInfo a, PokeChain a, MonadIO io) => Device -> RenderingInfo a -> io TilePropertiesQCOM
- data PhysicalDeviceTilePropertiesFeaturesQCOM = PhysicalDeviceTilePropertiesFeaturesQCOM {}
- data TilePropertiesQCOM = TilePropertiesQCOM {}
- type QCOM_TILE_PROPERTIES_SPEC_VERSION = 1
- pattern QCOM_TILE_PROPERTIES_SPEC_VERSION :: Integral a => a
- type QCOM_TILE_PROPERTIES_EXTENSION_NAME = "VK_QCOM_tile_properties"
- pattern QCOM_TILE_PROPERTIES_EXTENSION_NAME :: (Eq a, IsString a) => a
- type RenderingInfoKHR = RenderingInfo
Documentation
getFramebufferTilePropertiesQCOM Source #
Arguments
| :: MonadIO io | |
| => Device |
|
| -> Framebuffer |
|
| -> io (Result, "properties" ::: Vector TilePropertiesQCOM) |
vkGetFramebufferTilePropertiesQCOM - Get tile properties from the attachments in framebuffer
Description
If pProperties is NULL, then the number of tile properties available
is returned in pPropertiesCount. Otherwise, pPropertiesCount must
point to a variable set by the application to the number of elements in
the pProperties array, and on return the variable is overwritten with
the number of properties actually written to pProperties. If
pPropertiesCount is less than the number of tile properties available,
at most pPropertiesCount structures will be written, and
INCOMPLETE will be returned instead of
SUCCESS, to indicate that not all the
available properties were returned.
The number of tile properties available is determined by the number of
merged subpasses, and each tile property is associated with a merged
subpass. There will be at most as many properties as there are subpasses
within the render pass. To obtain the tile properties for a given merged
subpass, the pProperties array can be indexed using the
postMergeIndex value provided in
RenderPassSubpassFeedbackInfoEXT.
Valid Usage (Implicit)
-
devicemust be a validDevicehandle
-
framebuffermust be a validFramebufferhandle -
pPropertiesCountmust be a valid pointer to auint32_tvalue - If
the value referenced by
pPropertiesCountis not0, andpPropertiesis notNULL,pPropertiesmust be a valid pointer to an array ofpPropertiesCountTilePropertiesQCOMstructures -
framebuffermust have been created, allocated, or retrieved fromdevice
Return Codes
See Also
VK_QCOM_tile_properties,
Device, Framebuffer,
TilePropertiesQCOM
getDynamicRenderingTilePropertiesQCOM Source #
Arguments
| :: forall (a :: [Type]) io. (Extendss RenderingInfo a, PokeChain a, MonadIO io) | |
| => Device |
|
| -> RenderingInfo a |
|
| -> io TilePropertiesQCOM |
vkGetDynamicRenderingTilePropertiesQCOM - Get the properties when using dynamic rendering
Return Codes
See Also
VK_QCOM_tile_properties,
Device,
RenderingInfo,
TilePropertiesQCOM
data PhysicalDeviceTilePropertiesFeaturesQCOM Source #
VkPhysicalDeviceTilePropertiesFeaturesQCOM - Structure describing tile properties features that can be supported by an implementation
Members
This structure describes the following features:
Description
If the PhysicalDeviceTilePropertiesFeaturesQCOM structure is included
in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceTilePropertiesFeaturesQCOM, it must add an instance of
the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceTilePropertiesFeaturesQCOM | |
Fields | |
Instances
data TilePropertiesQCOM Source #
VkTilePropertiesQCOM - Structure holding available tile properties
Description
All tiles will be tightly packed around the first tile, with edges being multiples of tile width and/or height from the origin.
The tileSize is guaranteed to be a multiple of
tileGranularity.
Valid Usage (Implicit)
See Also
VK_QCOM_tile_properties,
Extent2D,
Extent3D,
Offset2D,
StructureType,
getDynamicRenderingTilePropertiesQCOM,
getFramebufferTilePropertiesQCOM
Constructors
| TilePropertiesQCOM | |
Fields
| |
Instances
type QCOM_TILE_PROPERTIES_SPEC_VERSION = 1 Source #
pattern QCOM_TILE_PROPERTIES_SPEC_VERSION :: Integral a => a Source #
type QCOM_TILE_PROPERTIES_EXTENSION_NAME = "VK_QCOM_tile_properties" Source #
pattern QCOM_TILE_PROPERTIES_EXTENSION_NAME :: (Eq a, IsString a) => a Source #
type RenderingInfoKHR = RenderingInfo Source #