vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_SEC_pipeline_cache_incremental_mode

Description

Name

VK_SEC_pipeline_cache_incremental_mode - device extension

VK_SEC_pipeline_cache_incremental_mode

Name String
VK_SEC_pipeline_cache_incremental_mode
Extension Type
Device extension
Registered Extension Number
638
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
Contact

Other Extension Metadata

Last Modified Date
2025-06-24
IP Status
No known IP claims.
Contributors
  • Chris Hambacher, Samsung
  • Mohan Maiya, Samsung
  • Brandon Schade, Samsung

Description

This extension allows layered implementations such as ANGLE to modify the default behavior of VkPipelineCache to return only the incremental data from the previous call to vkGetPipelineCacheData. Application developers should avoid using this extension.

There is currently no specification language written for this extension. The links to APIs defined by the extension are to stubs that only include generated content such as API declarations and implicit valid usage statements.

This extension is only intended for use in specific embedded environments with known implementation details, and is therefore undocumented.

New Structures

New Enum Constants

Stub API References

There is currently no specification language written for this type. This section acts only as placeholder and to avoid dead links in the specification and reference pages.

// Provided by VK_SEC_pipeline_cache_incremental_mode
typedef struct VkPhysicalDevicePipelineCacheIncrementalModeFeaturesSEC {
    VkStructureType    sType;
    void*              pNext;
    VkBool32           pipelineCacheIncrementalMode;
} VkPhysicalDevicePipelineCacheIncrementalModeFeaturesSEC;

Valid Usage (Implicit)

Version History

  • Revision 1, 2025-06-24 (Chris Hambacher)

    • Initial specification

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDevicePipelineCacheIncrementalModeFeaturesSEC Source #

VkPhysicalDevicePipelineCacheIncrementalModeFeaturesSEC - Stub description of VkPhysicalDevicePipelineCacheIncrementalModeFeaturesSEC

Valid Usage (Implicit)

See Also

VK_SEC_pipeline_cache_incremental_mode, Bool32, StructureType

Instances

Instances details
Eq PhysicalDevicePipelineCacheIncrementalModeFeaturesSEC Source # 
Instance details

Defined in Vulkan.Extensions.VK_SEC_pipeline_cache_incremental_mode

Storable PhysicalDevicePipelineCacheIncrementalModeFeaturesSEC Source # 
Instance details

Defined in Vulkan.Extensions.VK_SEC_pipeline_cache_incremental_mode

Show PhysicalDevicePipelineCacheIncrementalModeFeaturesSEC Source # 
Instance details

Defined in Vulkan.Extensions.VK_SEC_pipeline_cache_incremental_mode

FromCStruct PhysicalDevicePipelineCacheIncrementalModeFeaturesSEC Source # 
Instance details

Defined in Vulkan.Extensions.VK_SEC_pipeline_cache_incremental_mode

ToCStruct PhysicalDevicePipelineCacheIncrementalModeFeaturesSEC Source # 
Instance details

Defined in Vulkan.Extensions.VK_SEC_pipeline_cache_incremental_mode

Zero PhysicalDevicePipelineCacheIncrementalModeFeaturesSEC Source # 
Instance details

Defined in Vulkan.Extensions.VK_SEC_pipeline_cache_incremental_mode

type SEC_PIPELINE_CACHE_INCREMENTAL_MODE_EXTENSION_NAME = "VK_SEC_pipeline_cache_incremental_mode" Source #