| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.CommandBuffer
Synopsis
- allocateCommandBuffers :: MonadIO io => Device -> CommandBufferAllocateInfo -> io ("commandBuffers" ::: Vector CommandBuffer)
- withCommandBuffers :: MonadIO io => Device -> CommandBufferAllocateInfo -> (io (Vector CommandBuffer) -> (Vector CommandBuffer -> io ()) -> r) -> r
- freeCommandBuffers :: MonadIO io => Device -> CommandPool -> ("commandBuffers" ::: Vector CommandBuffer) -> io ()
- beginCommandBuffer :: forall (a :: [Type]) io. (Extendss CommandBufferBeginInfo a, PokeChain a, MonadIO io) => CommandBuffer -> CommandBufferBeginInfo a -> io ()
- useCommandBuffer :: forall (a :: [Type]) io r. (Extendss CommandBufferBeginInfo a, PokeChain a, MonadIO io) => CommandBuffer -> CommandBufferBeginInfo a -> io r -> io r
- endCommandBuffer :: MonadIO io => CommandBuffer -> io ()
- resetCommandBuffer :: MonadIO io => CommandBuffer -> CommandBufferResetFlags -> io ()
- data CommandBufferAllocateInfo = CommandBufferAllocateInfo {}
- data CommandBufferInheritanceInfo (es :: [Type]) = CommandBufferInheritanceInfo {}
- data CommandBufferBeginInfo (es :: [Type]) = CommandBufferBeginInfo {}
- data CommandBuffer = CommandBuffer {}
- newtype CommandBufferLevel where
- newtype QueryControlFlagBits where
- type QueryControlFlags = QueryControlFlagBits
- newtype CommandBufferUsageFlagBits where
- type CommandBufferUsageFlags = CommandBufferUsageFlagBits
- newtype CommandBufferResetFlagBits where
- type CommandBufferResetFlags = CommandBufferResetFlagBits
Documentation
allocateCommandBuffers Source #
Arguments
| :: MonadIO io | |
| => Device |
|
| -> CommandBufferAllocateInfo |
|
| -> io ("commandBuffers" ::: Vector CommandBuffer) |
vkAllocateCommandBuffers - Allocate command buffers from an existing command pool
Description
allocateCommandBuffers can be used to allocate multiple command
buffers. If the allocation of any of those command buffers fails, the
implementation must free all successfully allocated command buffer
objects from this command, set all entries of the pCommandBuffers
array to NULL and return the error.
Filling pCommandBuffers with NULL values on failure is an exception
to the default error behavior that output parameters will have undefined
contents.
When command buffers are first allocated, they are in the initial state.
Valid Usage (Implicit)
-
devicemust be a validDevicehandle
-
pAllocateInfomust be a valid pointer to a validCommandBufferAllocateInfostructure -
pCommandBuffersmust be a valid pointer to an array ofpAllocateInfo->commandBufferCountCommandBufferhandles - The device must
have been created with at least
1queue -
pAllocateInfo->commandBufferCountmust be greater than0
Return Codes
See Also
VK_VERSION_1_0,
CommandBuffer, CommandBufferAllocateInfo,
Device
withCommandBuffers :: MonadIO io => Device -> CommandBufferAllocateInfo -> (io (Vector CommandBuffer) -> (Vector CommandBuffer -> io ()) -> r) -> r Source #
A convenience wrapper to make a compatible pair of calls to
allocateCommandBuffers and freeCommandBuffers
To ensure that freeCommandBuffers is always called: pass
bracket (or the allocate function from your
favourite resource management library) as the last argument.
To just extract the pair pass (,) as the last argument.
Arguments
| :: MonadIO io | |
| => Device |
|
| -> CommandPool |
|
| -> ("commandBuffers" ::: Vector CommandBuffer) |
|
| -> io () |
vkFreeCommandBuffers - Free command buffers
Description
Any primary command buffer that is in the
recording or executable state
and has any element of pCommandBuffers recorded into it, becomes
invalid.
Valid Usage
- All elements of
pCommandBuffersmust not be in the pending state
-
pCommandBuffersmust be a valid pointer to an array ofcommandBufferCountCommandBufferhandles, each element of which must either be a valid handle orNULL
Valid Usage (Implicit)
-
devicemust be a validDevicehandle
-
commandPoolmust be a validCommandPoolhandle -
commandBufferCountmust be greater than0 -
commandPoolmust have been created, allocated, or retrieved fromdevice - Each element of
pCommandBuffersthat is a valid handle must have been created, allocated, or retrieved fromcommandPool
Host Synchronization
- Host access to
commandPoolmust be externally synchronized
- Host access to each member of
pCommandBuffersmust be externally synchronized
See Also
Arguments
| :: forall (a :: [Type]) io. (Extendss CommandBufferBeginInfo a, PokeChain a, MonadIO io) | |
| => CommandBuffer |
|
| -> CommandBufferBeginInfo a |
|
| -> io () |
vkBeginCommandBuffer - Start recording a command buffer
Valid Usage
-
commandBuffermust not be in the recording or pending state
- If
commandBufferwas allocated from aCommandPoolwhich did not have theCOMMAND_POOL_CREATE_RESET_COMMAND_BUFFER_BITflag set,commandBuffermust be in the initial state - If
commandBufferis a secondary command buffer, thepInheritanceInfomember ofpBeginInfomust be a validCommandBufferInheritanceInfostructure - If
commandBufferis a secondary command buffer and either theocclusionQueryEnablemember of thepInheritanceInfomember ofpBeginInfoisFALSE, or the occlusionQueryPrecise feature is not enabled, thenpBeginInfo->pInheritanceInfo->queryFlagsmust not containQUERY_CONTROL_PRECISE_BIT - If
commandBufferis a primary command buffer, thenpBeginInfo->flagsmust not set both theCOMMAND_BUFFER_USAGE_ONE_TIME_SUBMIT_BITand theCOMMAND_BUFFER_USAGE_SIMULTANEOUS_USE_BITflags
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
pBeginInfomust be a valid pointer to a validCommandBufferBeginInfostructure
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Return Codes
See Also
useCommandBuffer :: forall (a :: [Type]) io r. (Extendss CommandBufferBeginInfo a, PokeChain a, MonadIO io) => CommandBuffer -> CommandBufferBeginInfo a -> io r -> io r Source #
This function will call the supplied action between calls to
beginCommandBuffer and endCommandBuffer
Note that endCommandBuffer is *not* called if an exception is thrown
by the inner action.
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> io () |
vkEndCommandBuffer - Finish recording a command buffer
Description
The command buffer must have been in the recording state, and, if successful, is moved to the executable state.
If there was an error during recording, the application will be notified
by an unsuccessful return code returned by endCommandBuffer, and the
command buffer will be moved to the
invalid state.
In case the application recorded one or more video encode operations into the command buffer, implementations may return the VK_ERROR_INVALID_VIDEO_STD_PARAMETERS_KHR error if any of the specified Video Std parameters do not adhere to the syntactic or semantic requirements of the used video compression standard, or if values derived from parameters according to the rules defined by the used video compression standard do not adhere to the capabilities of the video compression standard or the implementation.
Applications should not rely on the VK_ERROR_INVALID_VIDEO_STD_PARAMETERS_KHR error being returned by any command as a means to verify Video Std parameters, as implementations are not required to report the error in any specific set of cases.
Valid Usage
-
commandBuffermust be in the recording state
- If
commandBufferis a primary command buffer, there must not be an active render pass instance - All queries made
active
during the recording of
commandBuffermust have been made inactive - Conditional rendering must not be active
- There must be no video session object bound
- If
commandBufferis a secondary command buffer, there must not be an outstandingcmdBeginDebugUtilsLabelEXTcommand recorded tocommandBufferthat has not previously been ended by a call tocmdEndDebugUtilsLabelEXT - If
commandBufferis a secondary command buffer, there must not be an outstandingcmdDebugMarkerBeginEXTcommand recorded tocommandBufferthat has not previously been ended by a call tocmdDebugMarkerEndEXT
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Return Codes
See Also
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> CommandBufferResetFlags |
|
| -> io () |
vkResetCommandBuffer - Reset a command buffer to the initial state
Description
Any primary command buffer that is in the
recording or executable state
and has commandBuffer recorded into it, becomes
invalid.
After a command buffer is reset, any objects or memory specified by commands recorded into the command buffer must no longer be accessed when the command buffer is accessed by the implementation.
Valid Usage
-
commandBuffermust not be in the pending state
-
commandBuffermust have been allocated from a pool that was created with theCOMMAND_POOL_CREATE_RESET_COMMAND_BUFFER_BIT
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
flagsmust be a valid combination ofCommandBufferResetFlagBitsvalues
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Return Codes
See Also
data CommandBufferAllocateInfo Source #
VkCommandBufferAllocateInfo - Structure specifying the allocation parameters for command buffer object
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_COMMAND_BUFFER_ALLOCATE_INFO
-
pNextmust beNULL -
commandPoolmust be a validCommandPoolhandle -
levelmust be a validCommandBufferLevelvalue
Host Synchronization
- Host access to
commandPoolmust be externally synchronized
See Also
VK_VERSION_1_0,
CommandBufferLevel,
CommandPool,
StructureType,
allocateCommandBuffers
Constructors
| CommandBufferAllocateInfo | |
Fields
| |
Instances
data CommandBufferInheritanceInfo (es :: [Type]) Source #
VkCommandBufferInheritanceInfo - Structure specifying command buffer inheritance information
Description
If the CommandBuffer will not be executed within
a render pass instance, or if the render pass instance was begun with
cmdBeginRendering,
renderPass, subpass, and framebuffer are ignored.
Valid Usage
- If
the
inheritedQueries
feature is not enabled,
occlusionQueryEnablemust beFALSE
- If the
inheritedQueries
feature is enabled,
queryFlagsmust be a valid combination ofQueryControlFlagBitsvalues - If the
inheritedQueries
feature is not enabled,
queryFlagsmust be0 - If
the
pipelineStatisticsQuery
feature is enabled,
pipelineStatisticsmust be a valid combination ofQueryPipelineStatisticFlagBitsvalues - If
the
pipelineStatisticsQuery
feature is not enabled,
pipelineStatisticsmust be0
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_COMMAND_BUFFER_INHERITANCE_INFO
- Each
pNextmember of any structure (including this one) in thepNextchain must be eitherNULLor a pointer to a valid instance ofAttachmentSampleCountInfoAMD,CommandBufferInheritanceConditionalRenderingInfoEXT,CommandBufferInheritanceDescriptorHeapInfoEXT,CommandBufferInheritanceRenderPassTransformInfoQCOM,CommandBufferInheritanceRenderingInfo,CommandBufferInheritanceViewportScissorInfoNV,CustomResolveCreateInfoEXT,ExternalFormatANDROID, VkExternalFormatOHOS,MultiviewPerViewAttributesInfoNVX,RenderPassTileShadingCreateInfoQCOM,RenderingAttachmentLocationInfo,RenderingInputAttachmentIndexInfo, orTileMemoryBindInfoQCOM - The
sTypevalue of each structure in thepNextchain must be unique - Both of
framebuffer, andrenderPassthat are valid handles of non-ignored parameters must have been created, allocated, or retrieved from the sameDevice
See Also
VK_VERSION_1_0,
Bool32, CommandBufferBeginInfo,
Framebuffer,
QueryControlFlags,
QueryPipelineStatisticFlags,
RenderPass,
StructureType
Constructors
| CommandBufferInheritanceInfo | |
Fields
| |
Instances
data CommandBufferBeginInfo (es :: [Type]) Source #
VkCommandBufferBeginInfo - Structure specifying a command buffer begin operation
Valid Usage
- If
flagscontainsCOMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BIT, theCommandPoolthatcommandBufferwas allocated from must support graphics operations
- If
flagscontainsCOMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BIT, theframebuffermember ofpInheritanceInfomust be eitherNULL_HANDLE, or a validFramebufferthat is compatible with therenderPassmember ofpInheritanceInfo - If
flagscontainsCOMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BITand the dynamicRendering feature is not enabled, therenderPassmember ofpInheritanceInfomust not beNULL_HANDLE - If
flagscontainsCOMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BITand therenderPassmember ofpInheritanceInfoisNULL_HANDLE, thepNextchain ofpInheritanceInfomust include aCommandBufferInheritanceRenderingInfostructure - If
flagscontainsCOMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BIT, therenderPassmember ofpInheritanceInfoisNULL_HANDLE, and thepNextchain ofpInheritanceInfoincludes aAttachmentSampleCountInfoAMDorAttachmentSampleCountInfoNVstructure, thecolorAttachmentCountmember of that structure must be equal to the value ofCommandBufferInheritanceRenderingInfo::colorAttachmentCount - If
flagscontainsCOMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BITand therenderPassmember ofpInheritanceInfois notNULL_HANDLE, therenderPassmember ofpInheritanceInfomust be a validRenderPass - If
flagscontainsCOMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BITand therenderPassmember ofpInheritanceInfois notNULL_HANDLE, thesubpassmember ofpInheritanceInfomust be a valid subpass index within therenderPassmember ofpInheritanceInfo - If
flagscontainsCOMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BIT, therenderPassmember ofpInheritanceInfois notNULL_HANDLE, andrenderPasswas created with tile shading enabled,TILE_SHADING_RENDER_PASS_ENABLE_BIT_QCOMmust be included inRenderPassTileShadingCreateInfoQCOM::flags - If
flagsdoes not containCOMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BIT, therenderPassmember ofpInheritanceInfoisNULL_HANDLE, orrenderPasswas not created with tile shading enabled,TILE_SHADING_RENDER_PASS_ENABLE_BIT_QCOMmust not be included inRenderPassTileShadingCreateInfoQCOM::flags - If
TILE_SHADING_RENDER_PASS_ENABLE_BIT_QCOMis included inRenderPassTileShadingCreateInfoQCOM::flags,RenderPassTileShadingCreateInfoQCOM::tileApronSizemust be equal to thetileApronSizeused to createrenderPass
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_COMMAND_BUFFER_BEGIN_INFO
-
pNextmust beNULLor a pointer to a valid instance ofDeviceGroupCommandBufferBeginInfo - The
sTypevalue of each structure in thepNextchain must be unique -
flagsmust be a valid combination ofCommandBufferUsageFlagBitsvalues
See Also
VK_VERSION_1_0,
CommandBufferInheritanceInfo,
CommandBufferUsageFlags,
StructureType, beginCommandBuffer
Constructors
| CommandBufferBeginInfo | |
Fields
| |
Instances
data CommandBuffer Source #
VkCommandBuffer - Opaque handle to a command buffer object
See Also
VK_DEFINE_HANDLE,
VK_VERSION_1_0,
CommandBufferSubmitInfo,
SubmitInfo,
allocateCommandBuffers,
beginCommandBuffer,
cmdBeginConditionalRenderingEXT,
cmdBeginCustomResolveEXT,
cmdBeginDebugUtilsLabelEXT,
cmdBeginPerTileExecutionQCOM,
cmdBeginQuery,
cmdBeginQueryIndexedEXT,
cmdBeginRenderPass,
cmdBeginRenderPass2,
cmdBeginRenderPass2,
cmdBeginRendering,
cmdBeginRendering,
cmdBeginTransformFeedbackEXT,
vkCmdBeginVideoCodingKHR,
cmdBindDescriptorBufferEmbeddedSamplers2EXT,
cmdBindDescriptorBufferEmbeddedSamplersEXT,
cmdBindDescriptorBuffersEXT,
cmdBindDescriptorSets,
Promoted_From_VK_KHR_maintenance6AdditionalFunctionality.cmdBindDescriptorSets2',
Promoted_From_VK_KHR_maintenance6AdditionalFunctionality.cmdBindDescriptorSets2',
cmdBindIndexBuffer,
cmdBindIndexBuffer2,
cmdBindIndexBuffer2,
cmdBindInvocationMaskHUAWEI,
cmdBindPipeline,
cmdBindPipelineShaderGroupNV,
cmdBindResourceHeapEXT,
cmdBindSamplerHeapEXT,
cmdBindShadersEXT,
cmdBindShadingRateImageNV,
cmdBindTileMemoryQCOM,
cmdBindTransformFeedbackBuffersEXT,
cmdBindVertexBuffers,
cmdBindVertexBuffers2,
cmdBindVertexBuffers2,
cmdBlitImage,
cmdBlitImage2,
cmdBlitImage2,
cmdBuildAccelerationStructureNV,
cmdBuildAccelerationStructuresIndirectKHR,
cmdBuildAccelerationStructuresKHR,
vkCmdBuildClusterAccelerationStructureIndirectNV,
cmdBuildMicromapsEXT,
vkCmdBuildPartitionedAccelerationStructuresNV,
cmdClearAttachments,
cmdClearColorImage,
cmdClearDepthStencilImage,
vkCmdControlVideoCodingKHR,
cmdConvertCooperativeVectorMatrixNV,
cmdCopyAccelerationStructureKHR,
cmdCopyAccelerationStructureNV,
cmdCopyAccelerationStructureToMemoryKHR,
cmdCopyBuffer,
cmdCopyBuffer2,
cmdCopyBuffer2,
cmdCopyBufferToImage,
cmdCopyBufferToImage2,
cmdCopyBufferToImage2,
cmdCopyImage,
cmdCopyImage2,
cmdCopyImage2,
cmdCopyImageToBuffer,
cmdCopyImageToBuffer2,
cmdCopyImageToBuffer2,
cmdCopyMemoryIndirectKHR,
cmdCopyMemoryIndirectNV,
cmdCopyMemoryToAccelerationStructureKHR,
cmdCopyMemoryToImageIndirectKHR,
cmdCopyMemoryToImageIndirectNV,
cmdCopyMemoryToMicromapEXT,
cmdCopyMicromapEXT,
cmdCopyMicromapToMemoryEXT,
cmdCopyQueryPoolResults,
cmdCopyTensorARM,
cmdCuLaunchKernelNVX,
cmdCudaLaunchKernelNV,
cmdDebugMarkerBeginEXT,
cmdDebugMarkerEndEXT,
cmdDebugMarkerInsertEXT,
vkCmdDecodeVideoKHR,
cmdDecompressMemoryEXT,
cmdDecompressMemoryIndirectCountEXT,
cmdDecompressMemoryIndirectCountNV,
cmdDecompressMemoryNV,
cmdDispatch,
cmdDispatchBase,
cmdDispatchBase,
cmdDispatchDataGraphARM,
cmdDispatchGraphAMDX,
cmdDispatchGraphIndirectAMDX,
cmdDispatchGraphIndirectCountAMDX,
cmdDispatchIndirect,
cmdDispatchTileQCOM,
cmdDraw,
cmdDrawClusterHUAWEI,
cmdDrawClusterIndirectHUAWEI,
cmdDrawIndexed,
cmdDrawIndexedIndirect,
cmdDrawIndexedIndirectCount,
cmdDrawIndexedIndirectCount,
cmdDrawIndexedIndirectCount,
cmdDrawIndirect,
cmdDrawIndirectByteCountEXT,
cmdDrawIndirectCount,
cmdDrawIndirectCount,
cmdDrawIndirectCount,
cmdDrawMeshTasksEXT,
cmdDrawMeshTasksIndirectCountEXT,
cmdDrawMeshTasksIndirectCountNV,
cmdDrawMeshTasksIndirectEXT,
cmdDrawMeshTasksIndirectNV,
cmdDrawMeshTasksNV,
cmdDrawMultiEXT,
cmdDrawMultiIndexedEXT,
vkCmdEncodeVideoKHR,
cmdEndConditionalRenderingEXT,
cmdEndDebugUtilsLabelEXT,
cmdEndPerTileExecutionQCOM,
cmdEndQuery,
cmdEndQueryIndexedEXT,
cmdEndRenderPass,
cmdEndRenderPass2,
cmdEndRenderPass2,
cmdEndRendering,
cmdEndRendering2KHR,
cmdEndRendering2KHR,
cmdEndRendering,
cmdEndTransformFeedbackEXT,
vkCmdEndVideoCodingKHR,
cmdExecuteCommands,
cmdExecuteGeneratedCommandsEXT,
cmdExecuteGeneratedCommandsNV,
cmdFillBuffer,
cmdInitializeGraphScratchMemoryAMDX,
cmdInsertDebugUtilsLabelEXT,
cmdNextSubpass,
cmdNextSubpass2,
cmdNextSubpass2,
cmdOpticalFlowExecuteNV,
cmdPipelineBarrier,
cmdPipelineBarrier2,
cmdPipelineBarrier2,
cmdPreprocessGeneratedCommandsEXT,
cmdPreprocessGeneratedCommandsNV,
cmdPushConstants,
Promoted_From_VK_KHR_maintenance6AdditionalFunctionality.cmdPushConstants2',
Promoted_From_VK_KHR_maintenance6AdditionalFunctionality.cmdPushConstants2',
cmdPushDataEXT,
cmdPushDescriptorSet,
Promoted_From_VK_KHR_maintenance6AdditionalFunctionality.cmdPushDescriptorSet2',
Promoted_From_VK_KHR_maintenance6AdditionalFunctionality.cmdPushDescriptorSet2',
cmdPushDescriptorSet,
cmdPushDescriptorSetWithTemplate,
Promoted_From_VK_KHR_maintenance6AdditionalFunctionality.cmdPushDescriptorSetWithTemplate2',
Promoted_From_VK_KHR_maintenance6AdditionalFunctionality.cmdPushDescriptorSetWithTemplate2',
cmdPushDescriptorSetWithTemplate,
cmdResetEvent,
cmdResetEvent2,
cmdResetEvent2,
cmdResetQueryPool,
cmdResolveImage,
cmdResolveImage2,
cmdResolveImage2,
cmdSetAlphaToCoverageEnableEXT,
cmdSetAlphaToOneEnableEXT,
cmdSetAttachmentFeedbackLoopEnableEXT,
cmdSetBlendConstants,
cmdSetCheckpointNV,
cmdSetCoarseSampleOrderNV,
cmdSetColorBlendAdvancedEXT,
cmdSetColorBlendEnableEXT,
cmdSetColorBlendEquationEXT,
cmdSetColorWriteEnableEXT,
cmdSetColorWriteMaskEXT,
cmdSetComputeOccupancyPriorityNV,
cmdSetConservativeRasterizationModeEXT,
cmdSetCoverageModulationModeNV,
cmdSetCoverageModulationTableEnableNV,
cmdSetCoverageModulationTableNV,
cmdSetCoverageReductionModeNV,
cmdSetCoverageToColorEnableNV,
cmdSetCoverageToColorLocationNV,
cmdSetCullMode,
cmdSetCullMode,
cmdSetDepthBias,
cmdSetDepthBias2EXT,
cmdSetDepthBiasEnable,
cmdSetDepthBiasEnable,
cmdSetDepthBounds,
cmdSetDepthBoundsTestEnable,
cmdSetDepthBoundsTestEnable,
cmdSetDepthClampEnableEXT,
cmdSetDepthClampRangeEXT,
cmdSetDepthClipEnableEXT,
cmdSetDepthClipNegativeOneToOneEXT,
cmdSetDepthCompareOp,
cmdSetDepthCompareOp,
cmdSetDepthTestEnable,
cmdSetDepthTestEnable,
cmdSetDepthWriteEnable,
cmdSetDepthWriteEnable,
cmdSetDescriptorBufferOffsets2EXT,
cmdSetDescriptorBufferOffsetsEXT,
cmdSetDeviceMask,
cmdSetDeviceMask,
cmdSetDiscardRectangleEXT,
cmdSetDiscardRectangleEnableEXT,
cmdSetDiscardRectangleModeEXT,
cmdSetEvent,
cmdSetEvent2,
cmdSetEvent2,
cmdSetExclusiveScissorEnableNV,
cmdSetExclusiveScissorNV,
cmdSetExtraPrimitiveOverestimationSizeEXT,
cmdSetFragmentShadingRateEnumNV,
cmdSetFragmentShadingRateKHR,
cmdSetFrontFace,
cmdSetFrontFace,
cmdSetLineRasterizationModeEXT,
cmdSetLineStipple,
cmdSetLineStipple,
cmdSetLineStippleEnableEXT,
cmdSetLineStipple,
cmdSetLineWidth,
cmdSetLogicOpEXT,
cmdSetLogicOpEnableEXT,
cmdSetPatchControlPointsEXT,
cmdSetPerformanceMarkerINTEL,
cmdSetPerformanceOverrideINTEL,
cmdSetPerformanceStreamMarkerINTEL,
cmdSetPolygonModeEXT,
cmdSetPrimitiveRestartEnable,
cmdSetPrimitiveRestartEnable,
cmdSetPrimitiveTopology,
cmdSetPrimitiveTopology,
cmdSetProvokingVertexModeEXT,
cmdSetRasterizationSamplesEXT,
cmdSetRasterizationStreamEXT,
cmdSetRasterizerDiscardEnable,
cmdSetRasterizerDiscardEnable,
cmdSetRayTracingPipelineStackSizeKHR,
cmdSetRenderingAttachmentLocations,
cmdSetRenderingAttachmentLocations,
cmdSetRenderingInputAttachmentIndices,
cmdSetRenderingInputAttachmentIndices,
cmdSetRepresentativeFragmentTestEnableNV,
cmdSetSampleLocationsEXT,
cmdSetSampleLocationsEnableEXT,
cmdSetSampleMaskEXT,
cmdSetScissor,
cmdSetScissorWithCount,
cmdSetScissorWithCount,
cmdSetShadingRateImageEnableNV,
cmdSetStencilCompareMask,
cmdSetStencilOp,
cmdSetStencilOp,
cmdSetStencilReference,
cmdSetStencilTestEnable,
cmdSetStencilTestEnable,
cmdSetStencilWriteMask,
cmdSetTessellationDomainOriginEXT,
cmdSetVertexInputEXT,
cmdSetViewport,
cmdSetViewportShadingRatePaletteNV,
cmdSetViewportSwizzleNV,
cmdSetViewportWScalingEnableNV,
cmdSetViewportWScalingNV,
cmdSetViewportWithCount,
cmdSetViewportWithCount,
cmdSubpassShadingHUAWEI,
cmdTraceRaysIndirect2KHR,
cmdTraceRaysIndirectKHR,
cmdTraceRaysKHR,
cmdTraceRaysNV,
cmdUpdateBuffer,
cmdUpdatePipelineIndirectBufferNV,
cmdWaitEvents,
cmdWaitEvents2,
cmdWaitEvents2,
cmdWriteAccelerationStructuresPropertiesKHR,
cmdWriteAccelerationStructuresPropertiesNV,
cmdWriteBufferMarker2AMD,
cmdWriteBufferMarkerAMD,
cmdWriteMicromapsPropertiesEXT,
cmdWriteTimestamp,
cmdWriteTimestamp2,
cmdWriteTimestamp2,
endCommandBuffer,
freeCommandBuffers,
resetCommandBuffer
Constructors
| CommandBuffer | |
Fields | |
Instances
| Eq CommandBuffer Source # | |
Defined in Vulkan.Core10.Handles Methods (==) :: CommandBuffer -> CommandBuffer -> Bool # (/=) :: CommandBuffer -> CommandBuffer -> Bool # | |
| Show CommandBuffer Source # | |
Defined in Vulkan.Core10.Handles Methods showsPrec :: Int -> CommandBuffer -> ShowS # show :: CommandBuffer -> String # showList :: [CommandBuffer] -> ShowS # | |
| HasObjectType CommandBuffer Source # | |
Defined in Vulkan.Core10.Handles Methods objectTypeAndHandle :: CommandBuffer -> (ObjectType, Word64) Source # | |
| IsHandle CommandBuffer Source # | |
Defined in Vulkan.Core10.Handles | |
| Zero CommandBuffer Source # | |
Defined in Vulkan.Core10.Handles Methods zero :: CommandBuffer Source # | |
newtype CommandBufferLevel Source #
VkCommandBufferLevel - Enumerant specifying a command buffer level
Description
COMMAND_BUFFER_LEVEL_PRIMARYspecifies a primary command buffer.
COMMAND_BUFFER_LEVEL_SECONDARYspecifies a secondary command buffer.
See Also
Constructors
| CommandBufferLevel Int32 |
Bundled Patterns
| pattern COMMAND_BUFFER_LEVEL_PRIMARY :: CommandBufferLevel | |
| pattern COMMAND_BUFFER_LEVEL_SECONDARY :: CommandBufferLevel |
Instances
newtype QueryControlFlagBits Source #
VkQueryControlFlagBits - Bitmask specifying constraints on a query
Description
QUERY_CONTROL_PRECISE_BITspecifies the precision of occlusion queries.
See Also
Constructors
| QueryControlFlagBits Flags |
Bundled Patterns
| pattern QUERY_CONTROL_PRECISE_BIT :: QueryControlFlagBits |
Instances
newtype CommandBufferUsageFlagBits Source #
VkCommandBufferUsageFlagBits - Bitmask specifying usage behavior for command buffer
Description
COMMAND_BUFFER_USAGE_ONE_TIME_SUBMIT_BITspecifies that each recording of the command buffer will only be submitted once, and the command buffer will be reset and recorded again between each submission.
COMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BITspecifies that a secondary command buffer is considered to be entirely inside a render pass. If this is a primary command buffer, then this bit is ignored.COMMAND_BUFFER_USAGE_SIMULTANEOUS_USE_BITspecifies that a command buffer can be resubmitted to any queue of the same queue family while it is in the pending state, and recorded into multiple primary command buffers.
See Also
Constructors
| CommandBufferUsageFlagBits Flags |
Bundled Patterns
Instances
newtype CommandBufferResetFlagBits Source #
VkCommandBufferResetFlagBits - Bitmask controlling behavior of a command buffer reset
Description
COMMAND_BUFFER_RESET_RELEASE_RESOURCES_BITspecifies that most or all memory resources currently owned by the command buffer should be returned to the parent command pool. If this flag is not set, then the command buffer may hold onto memory resources and reuse them when recording commands.commandBufferis moved to the initial state.
See Also
Constructors
| CommandBufferResetFlagBits Flags |
Bundled Patterns
| pattern COMMAND_BUFFER_RESET_RELEASE_RESOURCES_BIT :: CommandBufferResetFlagBits |