| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.AttachmentLoadOp
Synopsis
- newtype AttachmentLoadOp where
- AttachmentLoadOp Int32
- pattern ATTACHMENT_LOAD_OP_LOAD :: AttachmentLoadOp
- pattern ATTACHMENT_LOAD_OP_CLEAR :: AttachmentLoadOp
- pattern ATTACHMENT_LOAD_OP_DONT_CARE :: AttachmentLoadOp
- pattern ATTACHMENT_LOAD_OP_NONE :: AttachmentLoadOp
Documentation
newtype AttachmentLoadOp Source #
VkAttachmentLoadOp - Specify how contents of an attachment are treated at the beginning of the subpass where it is first used
Description
ATTACHMENT_LOAD_OP_LOADspecifies that the previous contents of the image within the render area will be preserved as the initial values. For attachments with a depth/stencil format, this uses the access typeACCESS_DEPTH_STENCIL_ATTACHMENT_READ_BIT. For attachments with a color format, this uses the access typeACCESS_COLOR_ATTACHMENT_READ_BIT.
ATTACHMENT_LOAD_OP_CLEARspecifies that the contents within the render area will be cleared to a uniform value, which is specified when a render pass instance is begun. For attachments with a depth/stencil format, this uses the access typeACCESS_DEPTH_STENCIL_ATTACHMENT_WRITE_BIT. For attachments with a color format, this uses the access typeACCESS_COLOR_ATTACHMENT_WRITE_BIT.ATTACHMENT_LOAD_OP_DONT_CAREspecifies that the previous contents within the area need not be preserved; the contents of the attachment will be undefined inside the render area. For attachments with a depth/stencil format, this uses the access typeACCESS_DEPTH_STENCIL_ATTACHMENT_WRITE_BIT. For attachments with a color format, this uses the access typeACCESS_COLOR_ATTACHMENT_WRITE_BIT.ATTACHMENT_LOAD_OP_NONEspecifies that the previous contents of the image will be undefined inside the render pass. No access type is used as the image is not accessed.
See Also
VK_VERSION_1_0,
AttachmentDescription,
AttachmentDescription2,
RenderingAttachmentInfo
Constructors
| AttachmentLoadOp Int32 |
Bundled Patterns
| pattern ATTACHMENT_LOAD_OP_LOAD :: AttachmentLoadOp | |
| pattern ATTACHMENT_LOAD_OP_CLEAR :: AttachmentLoadOp | |
| pattern ATTACHMENT_LOAD_OP_DONT_CARE :: AttachmentLoadOp | |
| pattern ATTACHMENT_LOAD_OP_NONE :: AttachmentLoadOp |