vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Core10.Enums.AttachmentStoreOp

Synopsis

Documentation

newtype AttachmentStoreOp Source #

VkAttachmentStoreOp - Specify how contents of an attachment are treated at the end of the subpass where it is last used

Description

ATTACHMENT_STORE_OP_DONT_CARE can cause contents generated during previous render passes to be discarded before reaching memory, even if no write to the attachment occurs during the current render pass.

See Also

VK_VERSION_1_0, AttachmentDescription, AttachmentDescription2, RenderingAttachmentInfo

Constructors

AttachmentStoreOp Int32 

Instances

Instances details
Eq AttachmentStoreOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentStoreOp

Ord AttachmentStoreOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentStoreOp

Storable AttachmentStoreOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentStoreOp

Read AttachmentStoreOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentStoreOp

Show AttachmentStoreOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentStoreOp

Zero AttachmentStoreOp Source # 
Instance details

Defined in Vulkan.Core10.Enums.AttachmentStoreOp