| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.AttachmentStoreOp
Synopsis
- newtype AttachmentStoreOp where
Documentation
newtype AttachmentStoreOp Source #
VkAttachmentStoreOp - Specify how contents of an attachment are treated at the end of the subpass where it is last used
Description
ATTACHMENT_STORE_OP_STOREspecifies the contents generated during the render pass and within the render area are written to memory. For attachments with a depth/stencil format, this uses the access typeACCESS_DEPTH_STENCIL_ATTACHMENT_WRITE_BIT. For attachments with a color format, this uses the access typeACCESS_COLOR_ATTACHMENT_WRITE_BIT.
ATTACHMENT_STORE_OP_DONT_CAREspecifies the contents within the render area are not needed after rendering, and may be discarded; the contents of the attachment will be undefined inside the render area. For attachments with a depth/stencil format, this uses the access typeACCESS_DEPTH_STENCIL_ATTACHMENT_WRITE_BIT. For attachments with a color format, this uses the access typeACCESS_COLOR_ATTACHMENT_WRITE_BIT.ATTACHMENT_STORE_OP_NONEspecifies the contents within the render area are not accessed by the store operation as long as no values are written to the attachment during the render pass. If values are written during the render pass, this behaves identically toATTACHMENT_STORE_OP_DONT_CAREand with matching access semantics.
ATTACHMENT_STORE_OP_DONT_CARE can cause contents generated during
previous render passes to be discarded before reaching memory, even if
no write to the attachment occurs during the current render pass.
See Also
VK_VERSION_1_0,
AttachmentDescription,
AttachmentDescription2,
RenderingAttachmentInfo
Constructors
| AttachmentStoreOp Int32 |
Bundled Patterns
| pattern ATTACHMENT_STORE_OP_STORE :: AttachmentStoreOp | |
| pattern ATTACHMENT_STORE_OP_DONT_CARE :: AttachmentStoreOp | |
| pattern ATTACHMENT_STORE_OP_NONE :: AttachmentStoreOp |