vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Core10.Enums.ColorComponentFlagBits

Synopsis

Documentation

newtype ColorComponentFlagBits Source #

VkColorComponentFlagBits - Bitmask controlling which components are written to the framebuffer

Description

  • COLOR_COMPONENT_R_BIT specifies that the R value is written to the color attachment for the appropriate sample. Otherwise, the value in memory is unmodified.
  • COLOR_COMPONENT_G_BIT specifies that the G value is written to the color attachment for the appropriate sample. Otherwise, the value in memory is unmodified.
  • COLOR_COMPONENT_B_BIT specifies that the B value is written to the color attachment for the appropriate sample. Otherwise, the value in memory is unmodified.
  • COLOR_COMPONENT_A_BIT specifies that the A value is written to the color attachment for the appropriate sample. Otherwise, the value in memory is unmodified.

The color write mask operation is applied regardless of whether blending is enabled.

The color write mask operation is applied only if Color Write Enable is enabled for the respective attachment. Otherwise the color write mask is ignored and writes to all components of the attachment are disabled.

See Also

VK_VERSION_1_0, ColorComponentFlags

Instances

Instances details
Bits ColorComponentFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.ColorComponentFlagBits

FiniteBits ColorComponentFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.ColorComponentFlagBits

Eq ColorComponentFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.ColorComponentFlagBits

Ord ColorComponentFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.ColorComponentFlagBits

Storable ColorComponentFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.ColorComponentFlagBits

Read ColorComponentFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.ColorComponentFlagBits

Show ColorComponentFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.ColorComponentFlagBits

Zero ColorComponentFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.ColorComponentFlagBits