| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.ColorComponentFlagBits
Synopsis
- type ColorComponentFlags = ColorComponentFlagBits
- newtype ColorComponentFlagBits where
Documentation
newtype ColorComponentFlagBits Source #
VkColorComponentFlagBits - Bitmask controlling which components are written to the framebuffer
Description
COLOR_COMPONENT_R_BITspecifies that the R value is written to the color attachment for the appropriate sample. Otherwise, the value in memory is unmodified.
COLOR_COMPONENT_G_BITspecifies that the G value is written to the color attachment for the appropriate sample. Otherwise, the value in memory is unmodified.COLOR_COMPONENT_B_BITspecifies that the B value is written to the color attachment for the appropriate sample. Otherwise, the value in memory is unmodified.COLOR_COMPONENT_A_BITspecifies that the A value is written to the color attachment for the appropriate sample. Otherwise, the value in memory is unmodified.
The color write mask operation is applied regardless of whether blending is enabled.
The color write mask operation is applied only if Color Write Enable is enabled for the respective attachment. Otherwise the color write mask is ignored and writes to all components of the attachment are disabled.
See Also
Constructors
| ColorComponentFlagBits Flags |
Bundled Patterns
| pattern COLOR_COMPONENT_R_BIT :: ColorComponentFlagBits | |
| pattern COLOR_COMPONENT_G_BIT :: ColorComponentFlagBits | |
| pattern COLOR_COMPONENT_B_BIT :: ColorComponentFlagBits | |
| pattern COLOR_COMPONENT_A_BIT :: ColorComponentFlagBits |