| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.CommandPoolCreateFlagBits
Synopsis
- type CommandPoolCreateFlags = CommandPoolCreateFlagBits
- newtype CommandPoolCreateFlagBits where
Documentation
newtype CommandPoolCreateFlagBits Source #
VkCommandPoolCreateFlagBits - Bitmask specifying usage behavior for a command pool
Description
COMMAND_POOL_CREATE_TRANSIENT_BITspecifies that command buffers allocated from the pool will be short-lived, meaning that they will be reset or freed in a relatively short timeframe. This flag may be used by the implementation to control memory allocation behavior within the pool.
COMMAND_POOL_CREATE_RESET_COMMAND_BUFFER_BITallows any command buffer allocated from a pool to be individually reset to the initial state; either by callingresetCommandBuffer, or via the implicit reset when callingbeginCommandBuffer. If this flag is not set on a pool, thenresetCommandBuffermust not be called for any command buffer allocated from that pool.COMMAND_POOL_CREATE_PROTECTED_BITspecifies that command buffers allocated from the pool are protected command buffers.
See Also
Constructors
| CommandPoolCreateFlagBits Flags |
Bundled Patterns