| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.DescriptorSetLayoutCreateFlagBits
Synopsis
- type DescriptorSetLayoutCreateFlags = DescriptorSetLayoutCreateFlagBits
- newtype DescriptorSetLayoutCreateFlagBits where
- DescriptorSetLayoutCreateFlagBits Flags
- pattern DESCRIPTOR_SET_LAYOUT_CREATE_PER_STAGE_BIT_NV :: DescriptorSetLayoutCreateFlagBits
- pattern DESCRIPTOR_SET_LAYOUT_CREATE_HOST_ONLY_POOL_BIT_EXT :: DescriptorSetLayoutCreateFlagBits
- pattern DESCRIPTOR_SET_LAYOUT_CREATE_INDIRECT_BINDABLE_BIT_NV :: DescriptorSetLayoutCreateFlagBits
- pattern DESCRIPTOR_SET_LAYOUT_CREATE_EMBEDDED_IMMUTABLE_SAMPLERS_BIT_EXT :: DescriptorSetLayoutCreateFlagBits
- pattern DESCRIPTOR_SET_LAYOUT_CREATE_DESCRIPTOR_BUFFER_BIT_EXT :: DescriptorSetLayoutCreateFlagBits
- pattern DESCRIPTOR_SET_LAYOUT_CREATE_PUSH_DESCRIPTOR_BIT :: DescriptorSetLayoutCreateFlagBits
- pattern DESCRIPTOR_SET_LAYOUT_CREATE_UPDATE_AFTER_BIND_POOL_BIT :: DescriptorSetLayoutCreateFlagBits
Documentation
newtype DescriptorSetLayoutCreateFlagBits Source #
VkDescriptorSetLayoutCreateFlagBits - Bitmask specifying descriptor set layout properties
Description
DESCRIPTOR_SET_LAYOUT_CREATE_PUSH_DESCRIPTOR_BITspecifies that descriptor sets must not be allocated using this layout, and descriptors are instead pushed bycmdPushDescriptorSet.
DESCRIPTOR_SET_LAYOUT_CREATE_UPDATE_AFTER_BIND_POOL_BITspecifies that descriptor sets using this layout must be allocated from a descriptor pool created with theDESCRIPTOR_POOL_CREATE_UPDATE_AFTER_BIND_BITbit set. Descriptor set layouts created with this bit set have alternate limits for the maximum number of descriptors per-stage and per-pipeline layout. The non-UpdateAfterBind limits only count descriptors in sets created without this flag. The UpdateAfterBind limits count all descriptors, but the limits may be higher than the non-UpdateAfterBind limits.DESCRIPTOR_SET_LAYOUT_CREATE_INDIRECT_BINDABLE_BIT_NVspecifies that descriptor sets using this layout allows them to be bound with compute pipelines that are created withPIPELINE_CREATE_INDIRECT_BINDABLE_BIT_NVflag set to be used in Device-Generated Commands.DESCRIPTOR_SET_LAYOUT_CREATE_DESCRIPTOR_BUFFER_BIT_EXTspecifies that this layout must only be used with descriptor buffers.DESCRIPTOR_SET_LAYOUT_CREATE_EMBEDDED_IMMUTABLE_SAMPLERS_BIT_EXTspecifies that this is a layout only containing immutable samplers that can be bound bycmdBindDescriptorBufferEmbeddedSamplersEXT. Unlike normal immutable samplers, embedded immutable samplers do not require the application to provide them in a descriptor buffer.DESCRIPTOR_SET_LAYOUT_CREATE_HOST_ONLY_POOL_BIT_EXTspecifies that descriptor sets using this layout must be allocated from a descriptor pool created with theDESCRIPTOR_POOL_CREATE_HOST_ONLY_BIT_EXTbit set. Descriptor set layouts created with this bit have no expressible limit for maximum number of descriptors per-stage. Host descriptor sets are limited only by available host memory, but may be limited for implementation specific reasons. Implementations may limit the number of supported descriptors to UpdateAfterBind limits or non-UpdateAfterBind limits, whichever is larger.DESCRIPTOR_SET_LAYOUT_CREATE_PER_STAGE_BIT_NVspecifies that binding numbers in descriptor sets using this layout may represent different resources and/or types of resources in each stage.
See Also
Constructors
| DescriptorSetLayoutCreateFlagBits Flags |
Bundled Patterns