vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Core10.Enums.MemoryPropertyFlagBits

Synopsis

Documentation

newtype MemoryPropertyFlagBits Source #

VkMemoryPropertyFlagBits - Bitmask specifying properties for a memory type

Description

For any memory allocated with both the MEMORY_PROPERTY_HOST_COHERENT_BIT and the MEMORY_PROPERTY_DEVICE_COHERENT_BIT_AMD, host or device accesses also perform automatic memory domain transfer operations, such that writes are always automatically available and visible to both host and device memory domains.

Device coherence is a useful property for certain debugging use cases (e.g. crash analysis, where performing separate coherence actions could mean values are not reported correctly). However, device coherent accesses may be slower than equivalent accesses without device coherence, particularly if they are also device uncached. For device uncached memory in particular, repeated accesses to the same or neighboring memory locations over a short time period (e.g. within a frame) may be slower than it would be for the equivalent cached memory type. As such, it is generally inadvisable to use device coherent or device uncached memory except when really needed.

See Also

VK_VERSION_1_0, MemoryPropertyFlags

Instances

Instances details
Bits MemoryPropertyFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.MemoryPropertyFlagBits

FiniteBits MemoryPropertyFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.MemoryPropertyFlagBits

Eq MemoryPropertyFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.MemoryPropertyFlagBits

Ord MemoryPropertyFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.MemoryPropertyFlagBits

Storable MemoryPropertyFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.MemoryPropertyFlagBits

Read MemoryPropertyFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.MemoryPropertyFlagBits

Show MemoryPropertyFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.MemoryPropertyFlagBits

Zero MemoryPropertyFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.MemoryPropertyFlagBits