| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.PipelineShaderStageCreateFlagBits
Synopsis
Documentation
newtype PipelineShaderStageCreateFlagBits Source #
VkPipelineShaderStageCreateFlagBits - Bitmask controlling how a pipeline shader stage is created
Description
PIPELINE_SHADER_STAGE_CREATE_ALLOW_VARYING_SUBGROUP_SIZE_BITspecifies that the SubgroupSize may vary in the shader stage.
PIPELINE_SHADER_STAGE_CREATE_REQUIRE_FULL_SUBGROUPS_BITspecifies that the subgroup sizes must be launched with all invocations active in the task, mesh, or compute stage.
If
PIPELINE_SHADER_STAGE_CREATE_ALLOW_VARYING_SUBGROUP_SIZE_BIT_EXT
and
PIPELINE_SHADER_STAGE_CREATE_REQUIRE_FULL_SUBGROUPS_BIT_EXT
are specified and
minSubgroupSize
does not equal
maxSubgroupSize
and no
required subgroup size
is specified, then the only way to guarantee that the 'X' dimension of
the local workgroup size is a multiple of
SubgroupSize
is to make it a multiple of maxSubgroupSize. Under these conditions,
you are guaranteed full subgroups but not any particular subgroup size.
See Also
Constructors
| PipelineShaderStageCreateFlagBits Flags |
Bundled Patterns