| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.PipelineStageFlagBits
Synopsis
- type PipelineStageFlags = PipelineStageFlagBits
- newtype PipelineStageFlagBits where
- PipelineStageFlagBits Flags
- pattern PIPELINE_STAGE_TOP_OF_PIPE_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_DRAW_INDIRECT_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_VERTEX_INPUT_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_VERTEX_SHADER_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_TESSELLATION_CONTROL_SHADER_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_TESSELLATION_EVALUATION_SHADER_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_GEOMETRY_SHADER_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_FRAGMENT_SHADER_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_EARLY_FRAGMENT_TESTS_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_LATE_FRAGMENT_TESTS_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_COLOR_ATTACHMENT_OUTPUT_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_COMPUTE_SHADER_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_TRANSFER_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_BOTTOM_OF_PIPE_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_HOST_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_ALL_GRAPHICS_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_ALL_COMMANDS_BIT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_COMMAND_PREPROCESS_BIT_EXT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_MESH_SHADER_BIT_EXT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_TASK_SHADER_BIT_EXT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHR :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_FRAGMENT_DENSITY_PROCESS_BIT_EXT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_RAY_TRACING_SHADER_BIT_KHR :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_ACCELERATION_STRUCTURE_BUILD_BIT_KHR :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_CONDITIONAL_RENDERING_BIT_EXT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_TRANSFORM_FEEDBACK_BIT_EXT :: PipelineStageFlagBits
- pattern PIPELINE_STAGE_NONE :: PipelineStageFlagBits
Documentation
newtype PipelineStageFlagBits Source #
VkPipelineStageFlagBits - Bitmask specifying pipeline stages
Description
These values all have the same meaning as the equivalently named values
for PipelineStageFlags2.
PIPELINE_STAGE_NONEspecifies no stages of execution.PIPELINE_STAGE_DRAW_INDIRECT_BITspecifies the stage of the pipeline whereVkDrawIndirect*/VkDispatchIndirect*/VkTraceRaysIndirect*data structures are consumed. This stage also includes reading commands written bycmdExecuteGeneratedCommandsNV. This stage also includes reading commands written bycmdExecuteGeneratedCommandsEXT.PIPELINE_STAGE_TASK_SHADER_BIT_EXTspecifies the task shader stage.PIPELINE_STAGE_MESH_SHADER_BIT_EXTspecifies the mesh shader stage.PIPELINE_STAGE_VERTEX_INPUT_BITspecifies the stage of the pipeline where vertex and index buffers are consumed.PIPELINE_STAGE_VERTEX_SHADER_BITspecifies the vertex shader stage.PIPELINE_STAGE_TESSELLATION_CONTROL_SHADER_BITspecifies the tessellation control shader stage.PIPELINE_STAGE_TESSELLATION_EVALUATION_SHADER_BITspecifies the tessellation evaluation shader stage.PIPELINE_STAGE_GEOMETRY_SHADER_BITspecifies the geometry shader stage.PIPELINE_STAGE_FRAGMENT_SHADER_BITspecifies the fragment shader stage.PIPELINE_STAGE_EARLY_FRAGMENT_TESTS_BITspecifies the stage of the pipeline where early fragment tests (depth and stencil tests before fragment shading) are performed. This stage also includes render pass load operations for framebuffer attachments with a depth/stencil format.PIPELINE_STAGE_LATE_FRAGMENT_TESTS_BITspecifies the stage of the pipeline where late fragment tests (depth and stencil tests after fragment shading) are performed. This stage also includes render pass store operations for framebuffer attachments with a depth/stencil format.PIPELINE_STAGE_COLOR_ATTACHMENT_OUTPUT_BITspecifies the stage of the pipeline after blending where the final color values are output from the pipeline. This stage includes blending, logic operations, render pass load and store operations for color attachments, render pass multisample resolve operations, andcmdClearAttachments.PIPELINE_STAGE_COMPUTE_SHADER_BITspecifies the execution of a compute shader.PIPELINE_STAGE_TRANSFER_BITspecifies the following commands:- All
copy commands,
including
cmdCopyQueryPoolResults cmdBlitImage2andcmdBlitImagecmdResolveImage2andcmdResolveImage- All
clear commands,
with the exception of
cmdClearAttachments
- All
copy commands,
including
PIPELINE_STAGE_HOST_BITspecifies a pseudo-stage indicating execution on the host of reads/writes of device memory. This stage is not invoked by any commands recorded in a command buffer.PIPELINE_STAGE_ACCELERATION_STRUCTURE_BUILD_BIT_KHRspecifies the execution ofcmdBuildAccelerationStructureNV,cmdCopyAccelerationStructureNV,cmdWriteAccelerationStructuresPropertiesNV,cmdBuildAccelerationStructuresKHR,cmdBuildAccelerationStructuresIndirectKHR,cmdCopyAccelerationStructureKHR,cmdCopyAccelerationStructureToMemoryKHR,cmdCopyMemoryToAccelerationStructureKHR, andcmdWriteAccelerationStructuresPropertiesKHR.PIPELINE_STAGE_RAY_TRACING_SHADER_BIT_KHRspecifies the execution of the ray tracing shader stages, viacmdTraceRaysNV,cmdTraceRaysKHR, orcmdTraceRaysIndirectKHRPIPELINE_STAGE_2_MEMORY_DECOMPRESSION_BIT_EXTspecifies the execution of decompression commands withcmdDecompressMemoryEXTandcmdDecompressMemoryIndirectCountEXT.PIPELINE_STAGE_ALL_GRAPHICS_BITspecifies the execution of all graphics pipeline stages, and is equivalent to the logical OR of:PIPELINE_STAGE_DRAW_INDIRECT_BITPIPELINE_STAGE_TASK_SHADER_BIT_EXTPIPELINE_STAGE_MESH_SHADER_BIT_EXTPIPELINE_STAGE_VERTEX_INPUT_BITPIPELINE_STAGE_VERTEX_SHADER_BITPIPELINE_STAGE_TESSELLATION_CONTROL_SHADER_BITPIPELINE_STAGE_TESSELLATION_EVALUATION_SHADER_BITPIPELINE_STAGE_GEOMETRY_SHADER_BITPIPELINE_STAGE_FRAGMENT_SHADER_BITPIPELINE_STAGE_EARLY_FRAGMENT_TESTS_BITPIPELINE_STAGE_LATE_FRAGMENT_TESTS_BITPIPELINE_STAGE_COLOR_ATTACHMENT_OUTPUT_BITPIPELINE_STAGE_CONDITIONAL_RENDERING_BIT_EXTPIPELINE_STAGE_TRANSFORM_FEEDBACK_BIT_EXTPIPELINE_STAGE_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHRPIPELINE_STAGE_FRAGMENT_DENSITY_PROCESS_BIT_EXT
PIPELINE_STAGE_ALL_COMMANDS_BITspecifies all operations performed by all commands supported on the queue it is used with.PIPELINE_STAGE_CONDITIONAL_RENDERING_BIT_EXTspecifies the stage of the pipeline where the predicate of conditional rendering is consumed.PIPELINE_STAGE_TRANSFORM_FEEDBACK_BIT_EXTspecifies the stage of the pipeline where vertex attribute output values are written to the transform feedback buffers.PIPELINE_STAGE_COMMAND_PREPROCESS_BIT_NVspecifies the stage of the pipeline where device-side preprocessing for generated commands viacmdPreprocessGeneratedCommandsNVis handled.PIPELINE_STAGE_COMMAND_PREPROCESS_BIT_EXTspecifies the stage of the pipeline where device-side preprocessing for generated commands viacmdPreprocessGeneratedCommandsEXTis handled.PIPELINE_STAGE_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHRspecifies the stage of the pipeline where the fragment shading rate attachment or shading rate image is read to determine the fragment shading rate for portions of a rasterized primitive.PIPELINE_STAGE_FRAGMENT_DENSITY_PROCESS_BIT_EXTspecifies the stage of the pipeline where the fragment density map is read to generate the fragment areas.PIPELINE_STAGE_TOP_OF_PIPE_BITis equivalent toPIPELINE_STAGE_ALL_COMMANDS_BITwithAccessFlagsset to0when specified in the second synchronization scope, but specifies no stage of execution when specified in the first scope.PIPELINE_STAGE_BOTTOM_OF_PIPE_BITis equivalent toPIPELINE_STAGE_ALL_COMMANDS_BITwithAccessFlagsset to0when specified in the first synchronization scope, but specifies no stage of execution when specified in the second scope.
See Also
VK_VERSION_1_0,
CheckpointDataNV,
PipelineStageFlags,
cmdWriteBufferMarkerAMD,
cmdWriteTimestamp
Constructors
| PipelineStageFlagBits Flags |
Bundled Patterns