vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Core10.Enums.QueueFlagBits

Synopsis

Documentation

newtype QueueFlagBits Source #

VkQueueFlagBits - Bitmask specifying capabilities of queues in a queue family

Description

  • QUEUE_GRAPHICS_BIT specifies that queues in this queue family support graphics operations.

At least one queue family of at least one physical device exposed by the implementation must support at least one of the following sets of operations:

  • graphics operations
  • compute operations
  • video encode operations
  • video decode operations

If an implementation exposes any queue family that supports graphics operations, at least one queue family of at least one physical device exposed by the implementation must support both graphics and compute operations.

Furthermore, if the protectedMemory physical device feature is supported, then at least one queue family of at least one physical device exposed by the implementation must support graphics operations, compute operations, and protected memory operations.

All commands that are allowed on a queue that supports transfer operations are also allowed on a queue that supports either graphics or compute operations. Thus, if the capabilities of a queue family include QUEUE_GRAPHICS_BIT or QUEUE_COMPUTE_BIT, then reporting the QUEUE_TRANSFER_BIT capability separately for that queue family is optional.

For further details see Queues.

See Also

VK_VERSION_1_0, QueueFlags

Constructors

QueueFlagBits Flags 

Instances

Instances details
Bits QueueFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.QueueFlagBits

FiniteBits QueueFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.QueueFlagBits

Eq QueueFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.QueueFlagBits

Ord QueueFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.QueueFlagBits

Storable QueueFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.QueueFlagBits

Read QueueFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.QueueFlagBits

Show QueueFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.QueueFlagBits

Zero QueueFlagBits Source # 
Instance details

Defined in Vulkan.Core10.Enums.QueueFlagBits