| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.QueueFlagBits
Synopsis
- type QueueFlags = QueueFlagBits
- newtype QueueFlagBits where
- QueueFlagBits Flags
- pattern QUEUE_GRAPHICS_BIT :: QueueFlagBits
- pattern QUEUE_COMPUTE_BIT :: QueueFlagBits
- pattern QUEUE_TRANSFER_BIT :: QueueFlagBits
- pattern QUEUE_SPARSE_BINDING_BIT :: QueueFlagBits
- pattern QUEUE_DATA_GRAPH_BIT_ARM :: QueueFlagBits
- pattern QUEUE_OPTICAL_FLOW_BIT_NV :: QueueFlagBits
- pattern QUEUE_PROTECTED_BIT :: QueueFlagBits
Documentation
type QueueFlags = QueueFlagBits Source #
newtype QueueFlagBits Source #
VkQueueFlagBits - Bitmask specifying capabilities of queues in a queue family
Description
QUEUE_GRAPHICS_BITspecifies that queues in this queue family support graphics operations.
QUEUE_COMPUTE_BITspecifies that queues in this queue family support compute operations.QUEUE_TRANSFER_BITspecifies that queues in this queue family support transfer operations.QUEUE_SPARSE_BINDING_BITspecifies that queues in this queue family support sparse memory management operations (see Sparse Resources). If any of the sparse resource features are supported, then at least one queue family must support this bit.- VK_QUEUE_VIDEO_DECODE_BIT_KHR specifies that queues in this queue family support video decode operations.
- VK_QUEUE_VIDEO_ENCODE_BIT_KHR specifies that queues in this queue family support video encode operations.
QUEUE_OPTICAL_FLOW_BIT_NVspecifies that queues in this queue family support optical flow operations.QUEUE_DATA_GRAPH_BIT_ARMspecifies that queues in this queue family support data graph operations.QUEUE_PROTECTED_BITspecifies that queues in this queue family support theDEVICE_QUEUE_CREATE_PROTECTED_BITbit. (see Protected Memory). If the physical device supports the protectedMemory feature, at least one of its queue families must support this bit.
At least one queue family of at least one physical device exposed by the implementation must support at least one of the following sets of operations:
- graphics operations
- compute operations
- video encode operations
- video decode operations
If an implementation exposes any queue family that supports graphics operations, at least one queue family of at least one physical device exposed by the implementation must support both graphics and compute operations.
Furthermore, if the protectedMemory physical device feature is supported, then at least one queue family of at least one physical device exposed by the implementation must support graphics operations, compute operations, and protected memory operations.
All commands that are allowed on a queue that supports transfer
operations are also allowed on a queue that supports either graphics or
compute operations. Thus, if the capabilities of a queue family include
QUEUE_GRAPHICS_BIT or QUEUE_COMPUTE_BIT, then reporting the
QUEUE_TRANSFER_BIT capability separately for that queue family is
optional.
For further details see Queues.
See Also
Constructors
| QueueFlagBits Flags |
Bundled Patterns
| pattern QUEUE_GRAPHICS_BIT :: QueueFlagBits | |
| pattern QUEUE_COMPUTE_BIT :: QueueFlagBits | |
| pattern QUEUE_TRANSFER_BIT :: QueueFlagBits | |
| pattern QUEUE_SPARSE_BINDING_BIT :: QueueFlagBits | |
| pattern QUEUE_DATA_GRAPH_BIT_ARM :: QueueFlagBits | |
| pattern QUEUE_OPTICAL_FLOW_BIT_NV :: QueueFlagBits | |
| pattern QUEUE_PROTECTED_BIT :: QueueFlagBits |