vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Core10.Enums.Result

Synopsis

Documentation

newtype Result Source #

VkResult - Vulkan command return codes

Description

  • SUCCESS Command successfully completed

If a command returns a runtime error, unless otherwise specified any output parameters will have undefined contents, except that if the output parameter is a structure with sType and pNext fields, those fields will be unmodified. Any structures chained from pNext will also have undefined contents, except that sType and pNext will be unmodified.

VK_ERROR_OUT_OF_*_MEMORY errors do not modify any currently existing Vulkan objects. Objects that have already been successfully created can still be used by the application.

As a general rule, Free, Release, and Reset commands do not return ERROR_OUT_OF_HOST_MEMORY, while any other command with a return code may return it. Any exceptions from this rule are described for those commands.

ERROR_UNKNOWN will be returned by an implementation when an unexpected error occurs that cannot be attributed to valid behavior of the application and implementation. Under these conditions, it may be returned from any command returning a Result.

ERROR_UNKNOWN is not expected to ever be returned if the application behavior is valid, and if the implementation is bug-free. If ERROR_UNKNOWN is returned, the application should be checked against the latest validation layers to verify correct behavior as much as possible. If no issues are identified it could be an implementation issue, and the implementor should be contacted for support.

Any command returning a Result may return ERROR_VALIDATION_FAILED if a violation of valid usage is detected.

Performance-critical commands generally do not have return codes. If a runtime error occurs in such commands, the implementation will defer reporting the error until a specified point. For commands that record into command buffers (vkCmd*) runtime errors are reported by endCommandBuffer.

See Also

VK_VERSION_1_0, Promoted_From_VK_KHR_maintenance6AdditionalFunctionality.BindMemoryStatus', PresentInfoKHR

Constructors

Result Int32 

Bundled Patterns

pattern SUCCESS :: Result 
pattern NOT_READY :: Result 
pattern TIMEOUT :: Result 
pattern EVENT_SET :: Result 
pattern EVENT_RESET :: Result 
pattern INCOMPLETE :: Result 
pattern ERROR_OUT_OF_HOST_MEMORY :: Result 
pattern ERROR_OUT_OF_DEVICE_MEMORY :: Result 
pattern ERROR_INITIALIZATION_FAILED :: Result 
pattern ERROR_DEVICE_LOST :: Result 
pattern ERROR_MEMORY_MAP_FAILED :: Result 
pattern ERROR_LAYER_NOT_PRESENT :: Result 
pattern ERROR_EXTENSION_NOT_PRESENT :: Result 
pattern ERROR_FEATURE_NOT_PRESENT :: Result 
pattern ERROR_INCOMPATIBLE_DRIVER :: Result 
pattern ERROR_TOO_MANY_OBJECTS :: Result 
pattern ERROR_FORMAT_NOT_SUPPORTED :: Result 
pattern ERROR_FRAGMENTED_POOL :: Result 
pattern ERROR_UNKNOWN :: Result 
pattern ERROR_NOT_ENOUGH_SPACE_KHR :: Result 
pattern PIPELINE_BINARY_MISSING_KHR :: Result 
pattern INCOMPATIBLE_SHADER_BINARY_EXT :: Result 
pattern ERROR_COMPRESSION_EXHAUSTED_EXT :: Result 
pattern OPERATION_NOT_DEFERRED_KHR :: Result 
pattern OPERATION_DEFERRED_KHR :: Result 
pattern THREAD_DONE_KHR :: Result 
pattern THREAD_IDLE_KHR :: Result 
pattern ERROR_FULL_SCREEN_EXCLUSIVE_MODE_LOST_EXT :: Result 
pattern ERROR_PRESENT_TIMING_QUEUE_FULL_EXT :: Result 
pattern ERROR_INVALID_DRM_FORMAT_MODIFIER_PLANE_LAYOUT_EXT :: Result 
pattern ERROR_INVALID_SHADER_NV :: Result 
pattern ERROR_INCOMPATIBLE_DISPLAY_KHR :: Result 
pattern ERROR_OUT_OF_DATE_KHR :: Result 
pattern SUBOPTIMAL_KHR :: Result 
pattern ERROR_NATIVE_WINDOW_IN_USE_KHR :: Result 
pattern ERROR_SURFACE_LOST_KHR :: Result 
pattern ERROR_NO_PIPELINE_MATCH :: Result 
pattern ERROR_INVALID_PIPELINE_CACHE_DATA :: Result 
pattern ERROR_NOT_PERMITTED :: Result 
pattern PIPELINE_COMPILE_REQUIRED :: Result 
pattern ERROR_FRAGMENTATION :: Result 
pattern ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS :: Result 
pattern ERROR_INVALID_EXTERNAL_HANDLE :: Result 
pattern ERROR_OUT_OF_POOL_MEMORY :: Result 
pattern ERROR_VALIDATION_FAILED :: Result 

Instances

Instances details
Eq Result Source # 
Instance details

Defined in Vulkan.Core10.Enums.Result

Methods

(==) :: Result -> Result -> Bool #

(/=) :: Result -> Result -> Bool #

Ord Result Source # 
Instance details

Defined in Vulkan.Core10.Enums.Result

Storable Result Source # 
Instance details

Defined in Vulkan.Core10.Enums.Result

Read Result Source # 
Instance details

Defined in Vulkan.Core10.Enums.Result

Show Result Source # 
Instance details

Defined in Vulkan.Core10.Enums.Result

Zero Result Source # 
Instance details

Defined in Vulkan.Core10.Enums.Result

Methods

zero :: Result Source #