| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.Result
Synopsis
- newtype Result where
- Result Int32
- pattern SUCCESS :: Result
- pattern NOT_READY :: Result
- pattern TIMEOUT :: Result
- pattern EVENT_SET :: Result
- pattern EVENT_RESET :: Result
- pattern INCOMPLETE :: Result
- pattern ERROR_OUT_OF_HOST_MEMORY :: Result
- pattern ERROR_OUT_OF_DEVICE_MEMORY :: Result
- pattern ERROR_INITIALIZATION_FAILED :: Result
- pattern ERROR_DEVICE_LOST :: Result
- pattern ERROR_MEMORY_MAP_FAILED :: Result
- pattern ERROR_LAYER_NOT_PRESENT :: Result
- pattern ERROR_EXTENSION_NOT_PRESENT :: Result
- pattern ERROR_FEATURE_NOT_PRESENT :: Result
- pattern ERROR_INCOMPATIBLE_DRIVER :: Result
- pattern ERROR_TOO_MANY_OBJECTS :: Result
- pattern ERROR_FORMAT_NOT_SUPPORTED :: Result
- pattern ERROR_FRAGMENTED_POOL :: Result
- pattern ERROR_UNKNOWN :: Result
- pattern ERROR_NOT_ENOUGH_SPACE_KHR :: Result
- pattern PIPELINE_BINARY_MISSING_KHR :: Result
- pattern INCOMPATIBLE_SHADER_BINARY_EXT :: Result
- pattern ERROR_COMPRESSION_EXHAUSTED_EXT :: Result
- pattern OPERATION_NOT_DEFERRED_KHR :: Result
- pattern OPERATION_DEFERRED_KHR :: Result
- pattern THREAD_DONE_KHR :: Result
- pattern THREAD_IDLE_KHR :: Result
- pattern ERROR_FULL_SCREEN_EXCLUSIVE_MODE_LOST_EXT :: Result
- pattern ERROR_PRESENT_TIMING_QUEUE_FULL_EXT :: Result
- pattern ERROR_INVALID_DRM_FORMAT_MODIFIER_PLANE_LAYOUT_EXT :: Result
- pattern ERROR_INVALID_SHADER_NV :: Result
- pattern ERROR_INCOMPATIBLE_DISPLAY_KHR :: Result
- pattern ERROR_OUT_OF_DATE_KHR :: Result
- pattern SUBOPTIMAL_KHR :: Result
- pattern ERROR_NATIVE_WINDOW_IN_USE_KHR :: Result
- pattern ERROR_SURFACE_LOST_KHR :: Result
- pattern ERROR_NO_PIPELINE_MATCH :: Result
- pattern ERROR_INVALID_PIPELINE_CACHE_DATA :: Result
- pattern ERROR_NOT_PERMITTED :: Result
- pattern PIPELINE_COMPILE_REQUIRED :: Result
- pattern ERROR_FRAGMENTATION :: Result
- pattern ERROR_INVALID_OPAQUE_CAPTURE_ADDRESS :: Result
- pattern ERROR_INVALID_EXTERNAL_HANDLE :: Result
- pattern ERROR_OUT_OF_POOL_MEMORY :: Result
- pattern ERROR_VALIDATION_FAILED :: Result
Documentation
VkResult - Vulkan command return codes
Description
SUCCESSCommand successfully completed
NOT_READYA fence or query has not yet completedTIMEOUTA wait operation has not completed in the specified timeEVENT_SETAn event is signaledEVENT_RESETAn event is unsignaledINCOMPLETEA return array was too small for the resultSUBOPTIMAL_KHRA swapchain no longer matches the surface properties exactly, but can still be used to present to the surface successfully.THREAD_IDLE_KHRA deferred operation is not complete but there is currently no work for this thread to do at the time of this call.THREAD_DONE_KHRA deferred operation is not complete but there is no work remaining to assign to additional threads.OPERATION_DEFERRED_KHRA deferred operation was requested and at least some of the work was deferred.OPERATION_NOT_DEFERRED_KHRA deferred operation was requested and no operations were deferred.PIPELINE_COMPILE_REQUIREDA requested pipeline creation would have required compilation, but the application requested compilation to not be performed.PIPELINE_BINARY_MISSING_KHRThe application attempted to create a pipeline binary by querying an internal cache, but the internal cache entry did not exist.INCOMPATIBLE_SHADER_BINARY_EXTThe provided binary shader code is not compatible with this device.In the initial version of the
VK_EXT_shader_objectextension, this return code was namedERROR_INCOMPATIBLE_SHADER_BINARY_EXTand improperly described as an error code. The name has been changed, but the old name is retained as an alias for compatibility with old code.ERROR_OUT_OF_HOST_MEMORYA host memory allocation has failed.ERROR_OUT_OF_DEVICE_MEMORYA device memory allocation has failed.ERROR_INITIALIZATION_FAILEDInitialization of an object could not be completed for implementation-specific reasons.ERROR_DEVICE_LOSTThe logical or physical device has been lost. See Lost DeviceERROR_MEMORY_MAP_FAILEDMapping of a memory object has failed.ERROR_LAYER_NOT_PRESENTA requested layer is not present or could not be loaded.ERROR_EXTENSION_NOT_PRESENTA requested extension is not supported.ERROR_FEATURE_NOT_PRESENTA requested feature is not supported.ERROR_INCOMPATIBLE_DRIVERThe requested version of Vulkan is not supported by the driver or is otherwise incompatible for implementation-specific reasons.ERROR_TOO_MANY_OBJECTSToo many objects of the type have already been created.ERROR_FORMAT_NOT_SUPPORTEDA requested format is not supported on this device.ERROR_FRAGMENTED_POOLA pool allocation has failed due to fragmentation of the pool’s memory. This must only be returned if no attempt to allocate host or device memory was made to accommodate the new allocation. This should be returned in preference toERROR_OUT_OF_POOL_MEMORY, but only if the implementation is certain that the pool allocation failure was due to fragmentation.ERROR_SURFACE_LOST_KHRA surface is no longer available.ERROR_NATIVE_WINDOW_IN_USE_KHRThe requested window is already in use by Vulkan or another API in a manner which prevents it from being used again.ERROR_OUT_OF_DATE_KHRA surface has changed in such a way that it is no longer compatible with the swapchain, and further presentation requests using the swapchain will fail. Applications must query the new surface properties and recreate their swapchain if they wish to continue presenting to the surface.ERROR_INCOMPATIBLE_DISPLAY_KHRThe display used by a swapchain does not use the same presentable image layout, or is incompatible in a way that prevents sharing an image.ERROR_INVALID_SHADER_NVOne or more shaders failed to compile or link. More details are reported back to the application viaVK_EXT_debug_reportif enabled.ERROR_OUT_OF_POOL_MEMORYA pool memory allocation has failed. This must only be returned if no attempt to allocate host or device memory was made to accommodate the new allocation. If the failure was definitely due to fragmentation of the pool,ERROR_FRAGMENTED_POOLshould be returned instead.ERROR_INVALID_EXTERNAL_HANDLEAn external handle is not a valid handle of the specified type.ERROR_FRAGMENTATIONA descriptor pool creation has failed due to fragmentation.ERROR_INVALID_DEVICE_ADDRESS_EXTA buffer creation failed because the requested address is not available.ERROR_INVALID_OPAQUE_CAPTURE_ADDRESSA buffer creation or memory allocation failed because the requested address is not available. A shader group handle assignment failed because the requested shader group handle information is no longer valid.ERROR_FULL_SCREEN_EXCLUSIVE_MODE_LOST_EXTAn operation on a swapchain created withFULL_SCREEN_EXCLUSIVE_APPLICATION_CONTROLLED_EXTfailed as it did not have exclusive full-screen access. This may occur due to implementation-dependent reasons, outside of the application’s control.ERROR_VALIDATION_FAILEDA command failed because invalid usage was detected by the implementation or a validation layer. This may result in the command not being dispatched to the ICD.ERROR_COMPRESSION_EXHAUSTED_EXTAn image creation failed because internal resources required for compression are exhausted. This must only be returned when fixed-rate compression is requested.- VK_ERROR_IMAGE_USAGE_NOT_SUPPORTED_KHR
The requested
ImageUsageFlagsare not supported. - VK_ERROR_VIDEO_PICTURE_LAYOUT_NOT_SUPPORTED_KHR The requested video picture layout is not supported.
- VK_ERROR_VIDEO_PROFILE_OPERATION_NOT_SUPPORTED_KHR
A video profile operation specified via
VkVideoProfileInfoKHR::
videoCodecOperationis not supported. - VK_ERROR_VIDEO_PROFILE_FORMAT_NOT_SUPPORTED_KHR Format parameters in a requested VkVideoProfileInfoKHR chain are not supported.
- VK_ERROR_VIDEO_PROFILE_CODEC_NOT_SUPPORTED_KHR Codec-specific parameters in a requested VkVideoProfileInfoKHR chain are not supported.
- VK_ERROR_VIDEO_STD_VERSION_NOT_SUPPORTED_KHR The specified video Std header version is not supported.
- VK_ERROR_INVALID_VIDEO_STD_PARAMETERS_KHR The specified Video Std parameters do not adhere to the syntactic or semantic requirements of the used video compression standard, or values derived from parameters according to the rules defined by the used video compression standard do not adhere to the capabilities of the video compression standard or the implementation.
ERROR_NOT_PERMITTEDThe driver implementation has denied a request to acquire a priority above the default priority (QUEUE_GLOBAL_PRIORITY_MEDIUM_EXT) because the application does not have sufficient privileges.ERROR_NOT_ENOUGH_SPACE_KHRThe application did not provide enough space to return all the required data.ERROR_UNKNOWNAn unknown error has occurred; either the application has provided invalid input, or an implementation failure has occurred.
If a command returns a runtime error, unless otherwise specified any
output parameters will have undefined contents, except that if the
output parameter is a structure with sType and pNext fields, those
fields will be unmodified. Any structures chained from pNext will also
have undefined contents, except that sType and pNext will be
unmodified.
VK_ERROR_OUT_OF_*_MEMORY errors do not modify any currently existing
Vulkan objects. Objects that have already been successfully created
can still be used by the application.
As a general rule, Free, Release, and Reset commands do not return
ERROR_OUT_OF_HOST_MEMORY, while any other command with a return code
may return it. Any exceptions from this rule are described for those
commands.
ERROR_UNKNOWN will be returned by an implementation when an unexpected
error occurs that cannot be attributed to valid behavior of the
application and implementation. Under these conditions, it may be
returned from any command returning a Result.
ERROR_UNKNOWN is not expected to ever be returned if the application
behavior is valid, and if the implementation is bug-free. If
ERROR_UNKNOWN is returned, the application should be checked against
the latest validation layers to verify correct behavior as much as
possible. If no issues are identified it could be an implementation
issue, and the implementor should be contacted for support.
Any command returning a Result may return ERROR_VALIDATION_FAILED
if a violation of valid usage is detected.
Performance-critical commands generally do not have return codes. If a
runtime error occurs in such commands, the implementation will defer
reporting the error until a specified point. For commands that record
into command buffers (vkCmd*) runtime errors are reported by
endCommandBuffer.
See Also
VK_VERSION_1_0,
Promoted_From_VK_KHR_maintenance6AdditionalFunctionality.BindMemoryStatus',
PresentInfoKHR
Bundled Patterns
Instances
| Eq Result Source # | |
| Ord Result Source # | |
| Storable Result Source # | |
| Read Result Source # | |
| Show Result Source # | |
| Zero Result Source # | |
Defined in Vulkan.Core10.Enums.Result | |