| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.ShaderStageFlagBits
Synopsis
- type ShaderStageFlags = ShaderStageFlagBits
- newtype ShaderStageFlagBits where
- ShaderStageFlagBits Flags
- pattern SHADER_STAGE_VERTEX_BIT :: ShaderStageFlagBits
- pattern SHADER_STAGE_TESSELLATION_CONTROL_BIT :: ShaderStageFlagBits
- pattern SHADER_STAGE_TESSELLATION_EVALUATION_BIT :: ShaderStageFlagBits
- pattern SHADER_STAGE_GEOMETRY_BIT :: ShaderStageFlagBits
- pattern SHADER_STAGE_FRAGMENT_BIT :: ShaderStageFlagBits
- pattern SHADER_STAGE_COMPUTE_BIT :: ShaderStageFlagBits
- pattern SHADER_STAGE_ALL_GRAPHICS :: ShaderStageFlagBits
- pattern SHADER_STAGE_ALL :: ShaderStageFlagBits
- pattern SHADER_STAGE_CLUSTER_CULLING_BIT_HUAWEI :: ShaderStageFlagBits
- pattern SHADER_STAGE_SUBPASS_SHADING_BIT_HUAWEI :: ShaderStageFlagBits
- pattern SHADER_STAGE_MESH_BIT_EXT :: ShaderStageFlagBits
- pattern SHADER_STAGE_TASK_BIT_EXT :: ShaderStageFlagBits
- pattern SHADER_STAGE_CALLABLE_BIT_KHR :: ShaderStageFlagBits
- pattern SHADER_STAGE_INTERSECTION_BIT_KHR :: ShaderStageFlagBits
- pattern SHADER_STAGE_MISS_BIT_KHR :: ShaderStageFlagBits
- pattern SHADER_STAGE_CLOSEST_HIT_BIT_KHR :: ShaderStageFlagBits
- pattern SHADER_STAGE_ANY_HIT_BIT_KHR :: ShaderStageFlagBits
- pattern SHADER_STAGE_RAYGEN_BIT_KHR :: ShaderStageFlagBits
Documentation
newtype ShaderStageFlagBits Source #
VkShaderStageFlagBits - Bitmask specifying a pipeline stage
Description
SHADER_STAGE_VERTEX_BITspecifies the vertex stage.
SHADER_STAGE_TESSELLATION_CONTROL_BITspecifies the tessellation control stage.SHADER_STAGE_TESSELLATION_EVALUATION_BITspecifies the tessellation evaluation stage.SHADER_STAGE_GEOMETRY_BITspecifies the geometry stage.SHADER_STAGE_FRAGMENT_BITspecifies the fragment stage.SHADER_STAGE_COMPUTE_BITspecifies the compute stage.SHADER_STAGE_ALL_GRAPHICSis a combination of bits used as shorthand to specify all graphics stages defined above (excluding the compute stage).SHADER_STAGE_ALLis a combination of bits used as shorthand to specify all shader stages supported by the device, including all additional stages which are introduced by extensions.SHADER_STAGE_TASK_BIT_EXTspecifies the task stage.SHADER_STAGE_MESH_BIT_EXTspecifies the mesh stage.SHADER_STAGE_CLUSTER_CULLING_BIT_HUAWEIspecifies the cluster culling stage.SHADER_STAGE_RAYGEN_BIT_KHRspecifies the ray generation stage.SHADER_STAGE_ANY_HIT_BIT_KHRspecifies the any-hit stage.SHADER_STAGE_CLOSEST_HIT_BIT_KHRspecifies the closest hit stage.SHADER_STAGE_MISS_BIT_KHRspecifies the miss stage.SHADER_STAGE_INTERSECTION_BIT_KHRspecifies the intersection stage.SHADER_STAGE_CALLABLE_BIT_KHRspecifies the callable stage.
SHADER_STAGE_ALL_GRAPHICS only includes the original five graphics
stages included in Vulkan 1.0, and not any stages added by extensions.
Thus, it may not have the desired effect in all cases.
See Also
VK_VERSION_1_0,
PipelineShaderStageCreateInfo,
ShaderCreateInfoEXT,
ShaderStageFlags,
cmdBindShadersEXT,
getShaderInfoAMD
Constructors
| ShaderStageFlagBits Flags |
Bundled Patterns