| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.StencilOp
Synopsis
- newtype StencilOp where
- StencilOp Int32
- pattern STENCIL_OP_KEEP :: StencilOp
- pattern STENCIL_OP_ZERO :: StencilOp
- pattern STENCIL_OP_REPLACE :: StencilOp
- pattern STENCIL_OP_INCREMENT_AND_CLAMP :: StencilOp
- pattern STENCIL_OP_DECREMENT_AND_CLAMP :: StencilOp
- pattern STENCIL_OP_INVERT :: StencilOp
- pattern STENCIL_OP_INCREMENT_AND_WRAP :: StencilOp
- pattern STENCIL_OP_DECREMENT_AND_WRAP :: StencilOp
Documentation
VkStencilOp - Stencil comparison function
Description
STENCIL_OP_KEEPkeeps the current value.
STENCIL_OP_ZEROsets the value to 0.STENCIL_OP_REPLACEsets the value toreference.STENCIL_OP_INCREMENT_AND_CLAMPincrements the current value and clamps to the maximum representable unsigned value.STENCIL_OP_DECREMENT_AND_CLAMPdecrements the current value and clamps to 0.STENCIL_OP_INVERTbitwise-inverts the current value.STENCIL_OP_INCREMENT_AND_WRAPincrements the current value and wraps to 0 when the maximum value would have been exceeded.STENCIL_OP_DECREMENT_AND_WRAPdecrements the current value and wraps to the maximum possible value when the value would go below 0.
For purposes of increment and decrement, the stencil bits are considered as an unsigned integer.
See Also
VK_VERSION_1_0,
StencilOpState,
cmdSetStencilOp,
cmdSetStencilOp
Bundled Patterns
| pattern STENCIL_OP_KEEP :: StencilOp | |
| pattern STENCIL_OP_ZERO :: StencilOp | |
| pattern STENCIL_OP_REPLACE :: StencilOp | |
| pattern STENCIL_OP_INCREMENT_AND_CLAMP :: StencilOp | |
| pattern STENCIL_OP_DECREMENT_AND_CLAMP :: StencilOp | |
| pattern STENCIL_OP_INVERT :: StencilOp | |
| pattern STENCIL_OP_INCREMENT_AND_WRAP :: StencilOp | |
| pattern STENCIL_OP_DECREMENT_AND_WRAP :: StencilOp |
Instances
| Eq StencilOp Source # | |
| Ord StencilOp Source # | |
| Storable StencilOp Source # | |
Defined in Vulkan.Core10.Enums.StencilOp | |
| Read StencilOp Source # | |
| Show StencilOp Source # | |
| Zero StencilOp Source # | |
Defined in Vulkan.Core10.Enums.StencilOp | |