vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Core10.Enums.SubpassContents

Synopsis

Documentation

newtype SubpassContents Source #

VkSubpassContents - Specify how commands in the first subpass of a render pass are provided

Description

  • SUBPASS_CONTENTS_INLINE specifies that the contents of the subpass will be recorded inline in the primary command buffer, and secondary command buffers must not be executed within the subpass.

See Also

VK_VERSION_1_0, SubpassBeginInfo, cmdBeginRenderPass, cmdNextSubpass

Constructors

SubpassContents Int32 

Instances

Instances details
Eq SubpassContents Source # 
Instance details

Defined in Vulkan.Core10.Enums.SubpassContents

Ord SubpassContents Source # 
Instance details

Defined in Vulkan.Core10.Enums.SubpassContents

Storable SubpassContents Source # 
Instance details

Defined in Vulkan.Core10.Enums.SubpassContents

Read SubpassContents Source # 
Instance details

Defined in Vulkan.Core10.Enums.SubpassContents

Show SubpassContents Source # 
Instance details

Defined in Vulkan.Core10.Enums.SubpassContents

Zero SubpassContents Source # 
Instance details

Defined in Vulkan.Core10.Enums.SubpassContents