| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Enums.SubpassContents
Synopsis
- newtype SubpassContents where
Documentation
newtype SubpassContents Source #
VkSubpassContents - Specify how commands in the first subpass of a render pass are provided
Description
SUBPASS_CONTENTS_INLINEspecifies that the contents of the subpass will be recorded inline in the primary command buffer, and secondary command buffers must not be executed within the subpass.
SUBPASS_CONTENTS_SECONDARY_COMMAND_BUFFERSspecifies that the contents are recorded in secondary command buffers that will be called from the primary command buffer, andcmdExecuteCommandsis the only valid command in the command buffer untilcmdNextSubpassorcmdEndRenderPass.SUBPASS_CONTENTS_INLINE_AND_SECONDARY_COMMAND_BUFFERS_KHRspecifies that the contents of the subpass can be recorded both inline and in secondary command buffers executed from this command buffer withcmdExecuteCommands.
See Also
VK_VERSION_1_0,
SubpassBeginInfo,
cmdBeginRenderPass,
cmdNextSubpass
Constructors
| SubpassContents Int32 |
Bundled Patterns