| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core10.Sampler
Synopsis
- createSampler :: forall (a :: [Type]) io. (Extendss SamplerCreateInfo a, PokeChain a, MonadIO io) => Device -> SamplerCreateInfo a -> ("allocator" ::: Maybe AllocationCallbacks) -> io Sampler
- withSampler :: forall (a :: [Type]) io r. (Extendss SamplerCreateInfo a, PokeChain a, MonadIO io) => Device -> SamplerCreateInfo a -> Maybe AllocationCallbacks -> (io Sampler -> (Sampler -> io ()) -> r) -> r
- destroySampler :: MonadIO io => Device -> Sampler -> ("allocator" ::: Maybe AllocationCallbacks) -> io ()
- data SamplerCreateInfo (es :: [Type]) = SamplerCreateInfo {
- next :: Chain es
- flags :: SamplerCreateFlags
- magFilter :: Filter
- minFilter :: Filter
- mipmapMode :: SamplerMipmapMode
- addressModeU :: SamplerAddressMode
- addressModeV :: SamplerAddressMode
- addressModeW :: SamplerAddressMode
- mipLodBias :: Float
- anisotropyEnable :: Bool
- maxAnisotropy :: Float
- compareEnable :: Bool
- compareOp :: CompareOp
- minLod :: Float
- maxLod :: Float
- borderColor :: BorderColor
- unnormalizedCoordinates :: Bool
- newtype Sampler = Sampler Word64
- newtype BorderColor where
- BorderColor Int32
- pattern BORDER_COLOR_FLOAT_CUSTOM_EXT :: BorderColor
- pattern BORDER_COLOR_FLOAT_OPAQUE_BLACK :: BorderColor
- pattern BORDER_COLOR_FLOAT_OPAQUE_WHITE :: BorderColor
- pattern BORDER_COLOR_FLOAT_TRANSPARENT_BLACK :: BorderColor
- pattern BORDER_COLOR_INT_CUSTOM_EXT :: BorderColor
- pattern BORDER_COLOR_INT_OPAQUE_BLACK :: BorderColor
- pattern BORDER_COLOR_INT_OPAQUE_WHITE :: BorderColor
- pattern BORDER_COLOR_INT_TRANSPARENT_BLACK :: BorderColor
- newtype Filter where
- Filter Int32
- pattern FILTER_CUBIC_EXT :: Filter
- pattern FILTER_LINEAR :: Filter
- pattern FILTER_NEAREST :: Filter
- newtype SamplerMipmapMode where
- newtype SamplerAddressMode where
- SamplerAddressMode Int32
- pattern SAMPLER_ADDRESS_MODE_CLAMP_TO_BORDER :: SamplerAddressMode
- pattern SAMPLER_ADDRESS_MODE_CLAMP_TO_EDGE :: SamplerAddressMode
- pattern SAMPLER_ADDRESS_MODE_MIRRORED_REPEAT :: SamplerAddressMode
- pattern SAMPLER_ADDRESS_MODE_MIRROR_CLAMP_TO_EDGE :: SamplerAddressMode
- pattern SAMPLER_ADDRESS_MODE_REPEAT :: SamplerAddressMode
- newtype SamplerCreateFlagBits where
- SamplerCreateFlagBits Flags
- pattern SAMPLER_CREATE_DESCRIPTOR_BUFFER_CAPTURE_REPLAY_BIT_EXT :: SamplerCreateFlagBits
- pattern SAMPLER_CREATE_IMAGE_PROCESSING_BIT_QCOM :: SamplerCreateFlagBits
- pattern SAMPLER_CREATE_NON_SEAMLESS_CUBE_MAP_BIT_EXT :: SamplerCreateFlagBits
- pattern SAMPLER_CREATE_SUBSAMPLED_BIT_EXT :: SamplerCreateFlagBits
- pattern SAMPLER_CREATE_SUBSAMPLED_COARSE_RECONSTRUCTION_BIT_EXT :: SamplerCreateFlagBits
- type SamplerCreateFlags = SamplerCreateFlagBits
Documentation
Arguments
| :: forall (a :: [Type]) io. (Extendss SamplerCreateInfo a, PokeChain a, MonadIO io) | |
| => Device |
|
| -> SamplerCreateInfo a |
|
| -> ("allocator" ::: Maybe AllocationCallbacks) |
|
| -> io Sampler |
vkCreateSampler - Create a new sampler object
Valid Usage
-
devicemust support at least one queue family with one of theQUEUE_COMPUTE_BITorQUEUE_GRAPHICS_BITcapabilities
- There must
be less than
PhysicalDeviceLimits::maxSamplerAllocationCountSamplerobjects currently created on the device - If there are any pipelines or shaders with embedded samplers currently created on the device, there must be less than (maxSamplerAllocationCount
- (minSamplerHeapReservedRangeWithEmbedded
/
samplerDescriptorSize))
Samplerobjects currently created on the device
Valid Usage (Implicit)
-
devicemust be a validDevicehandle
-
pCreateInfomust be a valid pointer to a validSamplerCreateInfostructure - If
pAllocatoris notNULL,pAllocatormust be a valid pointer to a validAllocationCallbacksstructure -
pSamplermust be a valid pointer to aSamplerhandle
Return Codes
See Also
VK_VERSION_1_0,
AllocationCallbacks,
Device, Sampler,
SamplerCreateInfo
withSampler :: forall (a :: [Type]) io r. (Extendss SamplerCreateInfo a, PokeChain a, MonadIO io) => Device -> SamplerCreateInfo a -> Maybe AllocationCallbacks -> (io Sampler -> (Sampler -> io ()) -> r) -> r Source #
A convenience wrapper to make a compatible pair of calls to
createSampler and destroySampler
To ensure that destroySampler is always called: pass
bracket (or the allocate function from your
favourite resource management library) as the last argument.
To just extract the pair pass (,) as the last argument.
Arguments
| :: MonadIO io | |
| => Device |
|
| -> Sampler |
|
| -> ("allocator" ::: Maybe AllocationCallbacks) |
|
| -> io () |
vkDestroySampler - Destroy a sampler object
Valid Usage
- If
AllocationCallbackswere provided whensamplerwas created, a compatible set of callbacks must be provided here - If no
AllocationCallbackswere provided whensamplerwas created,pAllocatormust beNULL
Valid Usage (Implicit)
-
devicemust be a validDevicehandle
- If
sampleris notNULL_HANDLE,samplermust be a validSamplerhandle - If
pAllocatoris notNULL,pAllocatormust be a valid pointer to a validAllocationCallbacksstructure - If
sampleris a valid handle, it must have been created, allocated, or retrieved fromdevice
Host Synchronization
- Host access to
samplermust be externally synchronized
See Also
data SamplerCreateInfo (es :: [Type]) Source #
VkSamplerCreateInfo - Structure specifying parameters of a newly created sampler
Description
Mapping of OpenGL to Vulkan Filter Modes
magFilter values of FILTER_NEAREST and
FILTER_LINEAR directly correspond to
GL_NEAREST and GL_LINEAR magnification filters. minFilter and
mipmapMode combine to correspond to the similarly named OpenGL
minification filter of GL_minFilter_MIPMAP_mipmapMode (e.g.
minFilter of FILTER_LINEAR and
mipmapMode of
SAMPLER_MIPMAP_MODE_NEAREST
correspond to GL_LINEAR_MIPMAP_NEAREST).
There are no Vulkan filter modes that directly correspond to OpenGL
minification filters of GL_LINEAR or GL_NEAREST, but they can be
emulated using
SAMPLER_MIPMAP_MODE_NEAREST,
minLod = 0, and maxLod = 0.25, and using minFilter =
FILTER_LINEAR or minFilter =
FILTER_NEAREST, respectively.
Note that using a maxLod of zero would cause
magnification
to always be performed, and the magFilter to always be used. This is
valid, just not an exact match for OpenGL behavior. Clamping the maximum
LOD to 0.25 allows the λ value to be non-zero and minification to be
performed, while still always rounding down to the base level. If the
minFilter and magFilter are equal, then using a maxLod of zero
also works.
The maximum number of sampler objects which can be simultaneously
created on a device is implementation-dependent and specified by the
maxSamplerAllocationCount
member of the PhysicalDeviceLimits
structure.
For historical reasons, if maxSamplerAllocationCount is exceeded, some
implementations may return
ERROR_TOO_MANY_OBJECTS. Exceeding this
limit will result in undefined behavior, and an application should not
rely on the use of the returned error code in order to identify when the
limit is reached.
Since Sampler is a non-dispatchable handle type,
implementations may return the same handle for sampler state vectors
that are identical. In such cases, all such objects would only count
once against the maxSamplerAllocationCount limit.
When this structure is used to write a descriptor via
writeSamplerDescriptorsEXT,
applications can give the descriptor a debug name in a similar way to
naming an object, via the
DebugUtilsObjectNameInfoEXT
structure. However, as there is no actual object,
DebugUtilsObjectNameInfoEXT
must be passed via the pNext chain of this structure, with a
objectType of OBJECT_TYPE_UNKNOWN and
a objectHandle of NULL_HANDLE. The name
is attached to the unique set of descriptor bits written by the
implementation, and writing the same bits again with new debug info
may rename the original descriptor.
Implementations are not prevented from returning the same bits for different descriptors. This can result in multiple different samplers mapping to the same name.
DescriptorSetAndBindingMappingEXT
can also be chained in the same way when defining an embedded sampler
via
DescriptorSetAndBindingMappingEXT,
naming the embedded sampler.
Valid Usage
- The absolute value of
mipLodBiasmust be less than or equal toPhysicalDeviceLimits::maxSamplerLodBias
- If the
VK_KHR_portability_subsetextension is enabled, andPhysicalDevicePortabilitySubsetFeaturesKHR::samplerMipLodBiasisFALSE,mipLodBiasmust be zero -
maxLodmust be greater than or equal tominLod - If the
samplerAnisotropy
feature is not enabled,
anisotropyEnablemust beFALSE - If
anisotropyEnableisTRUE,maxAnisotropymust be between1.0andPhysicalDeviceLimits::maxSamplerAnisotropy, inclusive - If
sampler Y′CBCR conversion
is enabled and the
potential format features
of the sampler Y′CBCR conversion do not support
FORMAT_FEATURE_SAMPLED_IMAGE_YCBCR_CONVERSION_SEPARATE_RECONSTRUCTION_FILTER_BIT,minFilterandmagFiltermust be equal to the sampler Y′CBCR conversion’schromaFilter - If
unnormalizedCoordinatesisTRUE,minFilterandmagFiltermust be equal - If
unnormalizedCoordinatesisTRUE,mipmapModemust beSAMPLER_MIPMAP_MODE_NEAREST - If
unnormalizedCoordinatesisTRUE,minLodandmaxLodmust be zero - If
unnormalizedCoordinatesisTRUE,addressModeUandaddressModeVmust each be eitherSAMPLER_ADDRESS_MODE_CLAMP_TO_EDGEorSAMPLER_ADDRESS_MODE_CLAMP_TO_BORDER - If
unnormalizedCoordinatesisTRUE,anisotropyEnablemust beFALSE - If
unnormalizedCoordinatesisTRUE,compareEnablemust beFALSE - If any of
addressModeU,addressModeVoraddressModeWareSAMPLER_ADDRESS_MODE_CLAMP_TO_BORDER,borderColormust be a validBorderColorvalue - If
sampler Y′CBCR conversion
is enabled,
addressModeU,addressModeV, andaddressModeWmust beSAMPLER_ADDRESS_MODE_CLAMP_TO_EDGE,anisotropyEnablemust beFALSE, andunnormalizedCoordinatesmust beFALSE - If
sampler Y′CBCR conversion
is enabled and the
pNextchain includes aSamplerReductionModeCreateInfostructure, then the sampler reduction mode must beSAMPLER_REDUCTION_MODE_WEIGHTED_AVERAGE - If the
samplerFilterMinmax
feature is not enabled and the
pNextchain includes aSamplerReductionModeCreateInfostructure, then the sampler reduction mode must beSAMPLER_REDUCTION_MODE_WEIGHTED_AVERAGE - If the
samplerMirrorClampToEdge
feature is not enabled, and if the
VK_KHR_sampler_mirror_clamp_to_edgeextension is not enabled,addressModeU,addressModeVandaddressModeWmust not beSAMPLER_ADDRESS_MODE_MIRROR_CLAMP_TO_EDGE - If
compareEnableisTRUE,compareOpmust be a validCompareOpvalue - If either
magFilterorminFilterisFILTER_CUBIC_EXT,anisotropyEnablemust beFALSE - If the
VK_EXT_filter_cubic
extension is not enabled and either
magFilterorminFilterisFILTER_CUBIC_IMG, thereductionModemember ofSamplerReductionModeCreateInfomust beSAMPLER_REDUCTION_MODE_WEIGHTED_AVERAGE - If
compareEnableisTRUE, thereductionModemember ofSamplerReductionModeCreateInfomust beSAMPLER_REDUCTION_MODE_WEIGHTED_AVERAGE - If
flagsincludesSAMPLER_CREATE_SUBSAMPLED_BIT_EXT, thenminFilterandmagFiltermust be equal - If
flagsincludesSAMPLER_CREATE_SUBSAMPLED_BIT_EXT, thenmipmapModemust beSAMPLER_MIPMAP_MODE_NEAREST - If
flagsincludesSAMPLER_CREATE_SUBSAMPLED_BIT_EXT, thenminLodandmaxLodmust be zero - If
flagsincludesSAMPLER_CREATE_SUBSAMPLED_BIT_EXT, thenaddressModeUandaddressModeVmust each be eitherSAMPLER_ADDRESS_MODE_CLAMP_TO_EDGEorSAMPLER_ADDRESS_MODE_CLAMP_TO_BORDER - If
flagsincludesSAMPLER_CREATE_SUBSAMPLED_BIT_EXT, thenanisotropyEnablemust beFALSE - If
flagsincludesSAMPLER_CREATE_SUBSAMPLED_BIT_EXT, thencompareEnablemust beFALSE - If
flagsincludesSAMPLER_CREATE_SUBSAMPLED_BIT_EXT, thenunnormalizedCoordinatesmust beFALSE - If the
nonSeamlessCubeMap
feature is not enabled,
flagsmust not includeSAMPLER_CREATE_NON_SEAMLESS_CUBE_MAP_BIT_EXT - If
borderColoris one ofBORDER_COLOR_FLOAT_CUSTOM_EXTorBORDER_COLOR_INT_CUSTOM_EXT, then aSamplerCustomBorderColorCreateInfoEXTmust be included in thepNextchain - If the
customBorderColors
feature is not enabled,
borderColormust not beBORDER_COLOR_FLOAT_CUSTOM_EXTorBORDER_COLOR_INT_CUSTOM_EXT - If
borderColoris one ofBORDER_COLOR_FLOAT_CUSTOM_EXTorBORDER_COLOR_INT_CUSTOM_EXT, andSamplerCustomBorderColorCreateInfoEXT::formatis notFORMAT_UNDEFINED,SamplerCustomBorderColorCreateInfoEXT::customBorderColormust be within the range of values representable informat - The maximum number of samplers
with custom border colors which can be simultaneously created on a
device is implementation-dependent and specified by the
maxCustomBorderColorSamplers
member of the
PhysicalDeviceCustomBorderColorPropertiesEXTstructure - If
flagsincludesSAMPLER_CREATE_DESCRIPTOR_BUFFER_CAPTURE_REPLAY_BIT_EXT, the descriptorBufferCaptureReplay feature must be enabled - If the
pNextchain includes aOpaqueCaptureDescriptorDataCreateInfoEXTstructure,flagsmust containSAMPLER_CREATE_DESCRIPTOR_BUFFER_CAPTURE_REPLAY_BIT_EXT - If
flagsincludesSAMPLER_CREATE_IMAGE_PROCESSING_BIT_QCOM, thenminFilterandmagFiltermust beFILTER_NEAREST - If
flagsincludesSAMPLER_CREATE_IMAGE_PROCESSING_BIT_QCOM, thenmipmapModemust beSAMPLER_MIPMAP_MODE_NEAREST - [If
flagsincludesSAMPLER_CREATE_IMAGE_PROCESSING_BIT_QCOM, thenminLodandmaxLodmust be zero - If
flagsincludesSAMPLER_CREATE_IMAGE_PROCESSING_BIT_QCOM, thenaddressModeUandaddressModeVmust each be eitherSAMPLER_ADDRESS_MODE_CLAMP_TO_EDGEorSAMPLER_ADDRESS_MODE_CLAMP_TO_BORDER - If
flagsincludesSAMPLER_CREATE_IMAGE_PROCESSING_BIT_QCOM, and ifaddressModeUoraddressModeVisSAMPLER_ADDRESS_MODE_CLAMP_TO_BORDER, thenborderColormust beBORDER_COLOR_FLOAT_TRANSPARENT_BLACK - If
flagsincludesSAMPLER_CREATE_IMAGE_PROCESSING_BIT_QCOM, thenanisotropyEnablemust beFALSE - If
flagsincludesSAMPLER_CREATE_IMAGE_PROCESSING_BIT_QCOM, thencompareEnablemust beFALSE
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_SAMPLER_CREATE_INFO
- Each
pNextmember of any structure (including this one) in thepNextchain must be eitherNULLor a pointer to a valid instance ofDebugUtilsObjectNameInfoEXT,OpaqueCaptureDescriptorDataCreateInfoEXT,SamplerBlockMatchWindowCreateInfoQCOM,SamplerBorderColorComponentMappingCreateInfoEXT,SamplerCubicWeightsCreateInfoQCOM,SamplerCustomBorderColorCreateInfoEXT,SamplerCustomBorderColorIndexCreateInfoEXT,SamplerReductionModeCreateInfo, orSamplerYcbcrConversionInfo - The
sTypevalue of each structure in thepNextchain must be unique -
flagsmust be a valid combination ofSamplerCreateFlagBitsvalues -
magFiltermust be a validFiltervalue -
minFiltermust be a validFiltervalue -
mipmapModemust be a validSamplerMipmapModevalue -
addressModeUmust be a validSamplerAddressModevalue -
addressModeVmust be a validSamplerAddressModevalue -
addressModeWmust be a validSamplerAddressModevalue
See Also
VK_VERSION_1_0,
Bool32,
BorderColor,
CompareOp,
DescriptorMappingSourceConstantOffsetEXT,
DescriptorMappingSourceIndirectIndexArrayEXT,
DescriptorMappingSourceIndirectIndexEXT,
DescriptorMappingSourcePushIndexEXT,
DescriptorMappingSourceShaderRecordIndexEXT,
Filter,
SamplerAddressMode,
SamplerCreateFlags,
SamplerMipmapMode,
StructureType, createSampler,
writeSamplerDescriptorsEXT
Constructors
| SamplerCreateInfo | |
Fields
| |
Instances
VkSampler - Opaque handle to a sampler object
See Also
VK_DEFINE_NON_DISPATCHABLE_HANDLE,
VK_VERSION_1_0,
DescriptorDataEXT,
DescriptorImageInfo,
DescriptorSetLayoutBinding,
ImageViewHandleInfoNVX,
SamplerCaptureDescriptorDataInfoEXT,
createSampler,
destroySampler
Instances
| Eq Sampler Source # | |
| Ord Sampler Source # | |
Defined in Vulkan.Core10.Handles | |
| Storable Sampler Source # | |
| Show Sampler Source # | |
| HasObjectType Sampler Source # | |
Defined in Vulkan.Core10.Handles Methods objectTypeAndHandle :: Sampler -> (ObjectType, Word64) Source # | |
| IsHandle Sampler Source # | |
Defined in Vulkan.Core10.Handles | |
| Zero Sampler Source # | |
Defined in Vulkan.Core10.Handles | |
newtype BorderColor Source #
VkBorderColor - Specify border color used for texture lookups
Description
BORDER_COLOR_FLOAT_TRANSPARENT_BLACKspecifies a transparent, floating-point format, black color.
BORDER_COLOR_INT_TRANSPARENT_BLACKspecifies a transparent, integer format, black color.BORDER_COLOR_FLOAT_OPAQUE_BLACKspecifies an opaque, floating-point format, black color.BORDER_COLOR_INT_OPAQUE_BLACKspecifies an opaque, integer format, black color.BORDER_COLOR_FLOAT_OPAQUE_WHITEspecifies an opaque, floating-point format, white color.BORDER_COLOR_INT_OPAQUE_WHITEspecifies an opaque, integer format, white color.BORDER_COLOR_FLOAT_CUSTOM_EXTspecifies that aSamplerCustomBorderColorCreateInfoEXTstructure is included in theSamplerCreateInfo::pNextchain containing the color data in floating-point format.BORDER_COLOR_INT_CUSTOM_EXTspecifies that aSamplerCustomBorderColorCreateInfoEXTstructure is included in theSamplerCreateInfo::pNextchain containing the color data in integer format.
These colors are described in detail in Border Replacement.
See Also
Constructors
| BorderColor Int32 |
Bundled Patterns
| pattern BORDER_COLOR_FLOAT_CUSTOM_EXT :: BorderColor | |
| pattern BORDER_COLOR_FLOAT_OPAQUE_BLACK :: BorderColor | |
| pattern BORDER_COLOR_FLOAT_OPAQUE_WHITE :: BorderColor | |
| pattern BORDER_COLOR_FLOAT_TRANSPARENT_BLACK :: BorderColor | |
| pattern BORDER_COLOR_INT_CUSTOM_EXT :: BorderColor | |
| pattern BORDER_COLOR_INT_OPAQUE_BLACK :: BorderColor | |
| pattern BORDER_COLOR_INT_OPAQUE_WHITE :: BorderColor | |
| pattern BORDER_COLOR_INT_TRANSPARENT_BLACK :: BorderColor |
Instances
VkFilter - Specify filters used for texture lookups
Description
FILTER_NEARESTspecifies nearest filtering.
FILTER_LINEARspecifies linear filtering.FILTER_CUBIC_EXTspecifies cubic filtering.
These filters are described in detail in Texel Filtering.
See Also
VK_VERSION_1_0,
BlitImageInfo2,
SamplerCreateInfo,
SamplerYcbcrConversionCreateInfo,
cmdBlitImage
Bundled Patterns
| pattern FILTER_CUBIC_EXT :: Filter | |
| pattern FILTER_LINEAR :: Filter | |
| pattern FILTER_NEAREST :: Filter |
Instances
| Eq Filter Source # | |
| Ord Filter Source # | |
| Storable Filter Source # | |
| Read Filter Source # | |
| Show Filter Source # | |
| Zero Filter Source # | |
Defined in Vulkan.Core10.Enums.Filter | |
newtype SamplerMipmapMode Source #
VkSamplerMipmapMode - Specify mipmap mode used for texture lookups
Description
SAMPLER_MIPMAP_MODE_NEARESTspecifies nearest filtering.
SAMPLER_MIPMAP_MODE_LINEARspecifies linear filtering.
These modes are described in detail in Texel Filtering.
See Also
Constructors
| SamplerMipmapMode Int32 |
Bundled Patterns
| pattern SAMPLER_MIPMAP_MODE_LINEAR :: SamplerMipmapMode | |
| pattern SAMPLER_MIPMAP_MODE_NEAREST :: SamplerMipmapMode |
Instances
newtype SamplerAddressMode Source #
VkSamplerAddressMode - Specify behavior of sampling with texture coordinates outside an image
Description
SAMPLER_ADDRESS_MODE_REPEATspecifies that the repeat wrap mode will be used.
SAMPLER_ADDRESS_MODE_MIRRORED_REPEATspecifies that the mirrored repeat wrap mode will be used.SAMPLER_ADDRESS_MODE_CLAMP_TO_EDGEspecifies that the clamp to edge wrap mode will be used.SAMPLER_ADDRESS_MODE_CLAMP_TO_BORDERspecifies that the clamp to border wrap mode will be used.SAMPLER_ADDRESS_MODE_MIRROR_CLAMP_TO_EDGEspecifies that the mirror clamp to edge wrap mode will be used. This is only valid if the samplerMirrorClampToEdge feature is enabled, or if theVK_KHR_sampler_mirror_clamp_to_edgeextension is enabled.
See Also
Constructors
| SamplerAddressMode Int32 |
Bundled Patterns
Instances
newtype SamplerCreateFlagBits Source #
VkSamplerCreateFlagBits - Bitmask specifying additional parameters of sampler
Description
-
SAMPLER_CREATE_SUBSAMPLED_BIT_EXTspecifies that the sampler will read from an image created withflagscontainingIMAGE_CREATE_SUBSAMPLED_BIT_EXT.
SAMPLER_CREATE_SUBSAMPLED_COARSE_RECONSTRUCTION_BIT_EXTspecifies that the implementation may use approximations when reconstructing a full color value for texture access from a subsampled image.SAMPLER_CREATE_NON_SEAMLESS_CUBE_MAP_BIT_EXTspecifies that cube map edge handling is not performed.-
SAMPLER_CREATE_IMAGE_PROCESSING_BIT_QCOMspecifies that the sampler will read from images using onlyOpImageSampleWeightedQCOM,OpImageBoxFilterQCOM,OpImageBlockMatchGatherSSDQCOM,OpImageBlockMatchGatherSADQCOM,OpImageBlockMatchWindowSSDQCOM,OpImageBlockMatchWindowSADQCOM,OpImageBlockMatchSSDQCOM, orOpImageBlockMatchSADQCOM.
The approximations used when
SAMPLER_CREATE_SUBSAMPLED_COARSE_RECONSTRUCTION_BIT_EXT is specified
are implementation defined. Some implementations may interpolate
between fragment density levels in a subsampled image. In that case,
this bit may be used to decide whether the interpolation factors are
calculated per fragment or at a coarser granularity.
SAMPLER_CREATE_DESCRIPTOR_BUFFER_CAPTURE_REPLAY_BIT_EXTspecifies that the sampler can be used with descriptor buffers when capturing and replaying (e.g. for trace capture and replay), seeOpaqueCaptureDescriptorDataCreateInfoEXTfor more detail.
See Also
Constructors
| SamplerCreateFlagBits Flags |
Bundled Patterns