| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core11.Enums.ChromaLocation
Synopsis
- newtype ChromaLocation where
- ChromaLocation Int32
- pattern CHROMA_LOCATION_COSITED_EVEN :: ChromaLocation
- pattern CHROMA_LOCATION_MIDPOINT :: ChromaLocation
Documentation
newtype ChromaLocation Source #
VkChromaLocation - Position of downsampled chroma samples
Description
CHROMA_LOCATION_COSITED_EVENspecifies that downsampled chroma samples are aligned with luma samples with even coordinates.
CHROMA_LOCATION_MIDPOINTspecifies that downsampled chroma samples are located half way between each even luma sample and the nearest higher odd luma sample.
See Also
VK_KHR_sampler_ycbcr_conversion,
VK_VERSION_1_1,
AndroidHardwareBufferFormatProperties2ANDROID,
AndroidHardwareBufferFormatPropertiesANDROID,
BufferCollectionPropertiesFUCHSIA,
VkNativeBufferFormatPropertiesOHOS,
PhysicalDeviceExternalFormatResolvePropertiesANDROID,
SamplerYcbcrConversionCreateInfo,
ScreenBufferFormatPropertiesQNX
Constructors
| ChromaLocation Int32 |
Bundled Patterns
| pattern CHROMA_LOCATION_COSITED_EVEN :: ChromaLocation | |
| pattern CHROMA_LOCATION_MIDPOINT :: ChromaLocation |