| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core11.Enums.ExternalFenceFeatureFlagBits
Documentation
newtype ExternalFenceFeatureFlagBits Source #
VkExternalFenceFeatureFlagBits - Bitfield describing features of an external fence handle type
Description
EXTERNAL_FENCE_FEATURE_EXPORTABLE_BITspecifies handles of this type can be exported from Vulkan fence objects.
EXTERNAL_FENCE_FEATURE_IMPORTABLE_BITspecifies handles of this type can be imported to Vulkan fence objects.
See Also
VK_KHR_external_fence_capabilities,
VK_VERSION_1_1,
ExternalFenceFeatureFlags
Constructors
| ExternalFenceFeatureFlagBits Flags |
Bundled Patterns
| pattern EXTERNAL_FENCE_FEATURE_EXPORTABLE_BIT :: ExternalFenceFeatureFlagBits | |
| pattern EXTERNAL_FENCE_FEATURE_IMPORTABLE_BIT :: ExternalFenceFeatureFlagBits |