| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core11.Enums.ExternalMemoryFeatureFlagBits
Synopsis
- type ExternalMemoryFeatureFlags = ExternalMemoryFeatureFlagBits
- newtype ExternalMemoryFeatureFlagBits where
Documentation
newtype ExternalMemoryFeatureFlagBits Source #
VkExternalMemoryFeatureFlagBits - Bitmask specifying features of an external memory handle type
Description
EXTERNAL_MEMORY_FEATURE_DEDICATED_ONLY_BITspecifies that tensors, images or buffers created with the specified parameters and handle type must use the mechanisms defined byMemoryDedicatedRequirementsandMemoryDedicatedAllocateInfoorMemoryDedicatedAllocateInfoTensorARMto create (or import) a dedicated allocation for the tensor, image or buffer.
EXTERNAL_MEMORY_FEATURE_EXPORTABLE_BITspecifies that handles of this type can be exported from Vulkan memory objects.EXTERNAL_MEMORY_FEATURE_IMPORTABLE_BITspecifies that handles of this type can be imported as Vulkan memory objects.
Because their semantics in external APIs roughly align with that of an
image or buffer with a dedicated allocation in Vulkan, implementations
are required to report EXTERNAL_MEMORY_FEATURE_DEDICATED_ONLY_BIT
for the following external handle types:
EXTERNAL_MEMORY_HANDLE_TYPE_D3D11_TEXTURE_BITEXTERNAL_MEMORY_HANDLE_TYPE_D3D11_TEXTURE_KMT_BITEXTERNAL_MEMORY_HANDLE_TYPE_D3D12_RESOURCE_BITEXTERNAL_MEMORY_HANDLE_TYPE_ANDROID_HARDWARE_BUFFER_BIT_ANDROIDfor images onlyEXTERNAL_MEMORY_HANDLE_TYPE_SCREEN_BUFFER_BIT_QNXfor images onlyEXTERNAL_MEMORY_HANDLE_TYPE_MTLTEXTURE_BIT_EXT
Implementations must not report
EXTERNAL_MEMORY_FEATURE_DEDICATED_ONLY_BIT for buffers with external
handle type
EXTERNAL_MEMORY_HANDLE_TYPE_ANDROID_HARDWARE_BUFFER_BIT_ANDROID.
Implementations must not report
EXTERNAL_MEMORY_FEATURE_DEDICATED_ONLY_BIT for buffers with external
handle type
EXTERNAL_MEMORY_HANDLE_TYPE_SCREEN_BUFFER_BIT_QNX.
Implementations must not report
EXTERNAL_MEMORY_FEATURE_DEDICATED_ONLY_BIT for tensors, images or
buffers with external handle type
EXTERNAL_MEMORY_HANDLE_TYPE_HOST_ALLOCATION_BIT_EXT,
or
EXTERNAL_MEMORY_HANDLE_TYPE_HOST_MAPPED_FOREIGN_MEMORY_BIT_EXT.
See Also
VK_KHR_external_memory_capabilities,
VK_VERSION_1_1,
ExternalMemoryFeatureFlags
Constructors
| ExternalMemoryFeatureFlagBits Flags |
Bundled Patterns