| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core11.Enums.SamplerYcbcrRange
Synopsis
- newtype SamplerYcbcrRange where
Documentation
newtype SamplerYcbcrRange Source #
VkSamplerYcbcrRange - Range of encoded values in a color space
Description
SAMPLER_YCBCR_RANGE_ITU_FULLspecifies that the full range of the encoded values are valid and interpreted according to the ITU “full range” quantization rules.
SAMPLER_YCBCR_RANGE_ITU_NARROWspecifies that headroom and foot room are reserved in the numerical range of encoded values, and the remaining values are expanded according to the ITU “narrow range” quantization rules.
The formulae for these conversions is described in the Sampler Y′CBCR Range Expansion section of the Image Operations chapter.
No range modification takes place if ycbcrModel is
SAMPLER_YCBCR_MODEL_CONVERSION_RGB_IDENTITY;
the ycbcrRange field of
SamplerYcbcrConversionCreateInfo
is ignored in this case.
See Also
VK_KHR_sampler_ycbcr_conversion,
VK_VERSION_1_1,
AndroidHardwareBufferFormatProperties2ANDROID,
AndroidHardwareBufferFormatPropertiesANDROID,
BufferCollectionPropertiesFUCHSIA,
VkNativeBufferFormatPropertiesOHOS,
SamplerYcbcrConversionCreateInfo,
ScreenBufferFormatPropertiesQNX
Constructors
| SamplerYcbcrRange Int32 |
Bundled Patterns
| pattern SAMPLER_YCBCR_RANGE_ITU_FULL :: SamplerYcbcrRange | |
| pattern SAMPLER_YCBCR_RANGE_ITU_NARROW :: SamplerYcbcrRange |