| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core11.Enums.TessellationDomainOrigin
Synopsis
Documentation
newtype TessellationDomainOrigin Source #
VkTessellationDomainOrigin - Enum describing tessellation domain origin
Description
TESSELLATION_DOMAIN_ORIGIN_UPPER_LEFTspecifies that the origin of the domain space is in the upper left corner, as shown in figure https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#img-tessellation-topology-ul.
TESSELLATION_DOMAIN_ORIGIN_LOWER_LEFTspecifies that the origin of the domain space is in the lower left corner, as shown in figure https://registry.khronos.org/vulkan/specs/latest/html/vkspec.html#img-tessellation-topology-ll.
This enum affects how the VertexOrderCw and VertexOrderCcw
tessellation execution modes are interpreted, since the winding is
defined relative to the orientation of the domain.
See Also
VK_KHR_maintenance2,
VK_VERSION_1_1,
PipelineTessellationDomainOriginStateCreateInfo,
cmdSetTessellationDomainOriginEXT
Constructors
| TessellationDomainOrigin Int32 |
Bundled Patterns
| pattern TESSELLATION_DOMAIN_ORIGIN_UPPER_LEFT :: TessellationDomainOrigin | |
| pattern TESSELLATION_DOMAIN_ORIGIN_LOWER_LEFT :: TessellationDomainOrigin |