| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core13.Promoted_From_VK_EXT_extended_dynamic_state
Synopsis
- cmdSetCullMode :: MonadIO io => CommandBuffer -> CullModeFlags -> io ()
- cmdSetFrontFace :: MonadIO io => CommandBuffer -> FrontFace -> io ()
- cmdSetPrimitiveTopology :: MonadIO io => CommandBuffer -> PrimitiveTopology -> io ()
- cmdSetViewportWithCount :: MonadIO io => CommandBuffer -> ("viewports" ::: Vector Viewport) -> io ()
- cmdSetScissorWithCount :: MonadIO io => CommandBuffer -> ("scissors" ::: Vector Rect2D) -> io ()
- cmdBindVertexBuffers2 :: MonadIO io => CommandBuffer -> ("firstBinding" ::: Word32) -> ("buffers" ::: Vector Buffer) -> ("offsets" ::: Vector DeviceSize) -> ("sizes" ::: Vector DeviceSize) -> ("strides" ::: Vector DeviceSize) -> io ()
- cmdSetDepthTestEnable :: MonadIO io => CommandBuffer -> ("depthTestEnable" ::: Bool) -> io ()
- cmdSetDepthWriteEnable :: MonadIO io => CommandBuffer -> ("depthWriteEnable" ::: Bool) -> io ()
- cmdSetDepthCompareOp :: MonadIO io => CommandBuffer -> ("depthCompareOp" ::: CompareOp) -> io ()
- cmdSetDepthBoundsTestEnable :: MonadIO io => CommandBuffer -> ("depthBoundsTestEnable" ::: Bool) -> io ()
- cmdSetStencilTestEnable :: MonadIO io => CommandBuffer -> ("stencilTestEnable" ::: Bool) -> io ()
- cmdSetStencilOp :: MonadIO io => CommandBuffer -> ("faceMask" ::: StencilFaceFlags) -> ("failOp" ::: StencilOp) -> ("passOp" ::: StencilOp) -> ("depthFailOp" ::: StencilOp) -> CompareOp -> io ()
- newtype DynamicState where
- DynamicState Int32
- pattern DYNAMIC_STATE_ALPHA_TO_COVERAGE_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_ALPHA_TO_ONE_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_ATTACHMENT_FEEDBACK_LOOP_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_BLEND_CONSTANTS :: DynamicState
- pattern DYNAMIC_STATE_COLOR_BLEND_ADVANCED_EXT :: DynamicState
- pattern DYNAMIC_STATE_COLOR_BLEND_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_COLOR_BLEND_EQUATION_EXT :: DynamicState
- pattern DYNAMIC_STATE_COLOR_WRITE_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_COLOR_WRITE_MASK_EXT :: DynamicState
- pattern DYNAMIC_STATE_CONSERVATIVE_RASTERIZATION_MODE_EXT :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_MODULATION_MODE_NV :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_REDUCTION_MODE_NV :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_TO_COLOR_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_TO_COLOR_LOCATION_NV :: DynamicState
- pattern DYNAMIC_STATE_CULL_MODE :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_BIAS :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_BIAS_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_BOUNDS :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_BOUNDS_TEST_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_CLAMP_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_CLAMP_RANGE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_CLIP_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_CLIP_NEGATIVE_ONE_TO_ONE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_COMPARE_OP :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_TEST_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_WRITE_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_DISCARD_RECTANGLE_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DISCARD_RECTANGLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DISCARD_RECTANGLE_MODE_EXT :: DynamicState
- pattern DYNAMIC_STATE_EXCLUSIVE_SCISSOR_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_EXCLUSIVE_SCISSOR_NV :: DynamicState
- pattern DYNAMIC_STATE_EXTRA_PRIMITIVE_OVERESTIMATION_SIZE_EXT :: DynamicState
- pattern DYNAMIC_STATE_FRAGMENT_SHADING_RATE_KHR :: DynamicState
- pattern DYNAMIC_STATE_FRONT_FACE :: DynamicState
- pattern DYNAMIC_STATE_LINE_RASTERIZATION_MODE_EXT :: DynamicState
- pattern DYNAMIC_STATE_LINE_STIPPLE :: DynamicState
- pattern DYNAMIC_STATE_LINE_STIPPLE_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_LINE_WIDTH :: DynamicState
- pattern DYNAMIC_STATE_LOGIC_OP_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_LOGIC_OP_EXT :: DynamicState
- pattern DYNAMIC_STATE_PATCH_CONTROL_POINTS_EXT :: DynamicState
- pattern DYNAMIC_STATE_POLYGON_MODE_EXT :: DynamicState
- pattern DYNAMIC_STATE_PRIMITIVE_RESTART_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_PRIMITIVE_TOPOLOGY :: DynamicState
- pattern DYNAMIC_STATE_PROVOKING_VERTEX_MODE_EXT :: DynamicState
- pattern DYNAMIC_STATE_RASTERIZATION_SAMPLES_EXT :: DynamicState
- pattern DYNAMIC_STATE_RASTERIZATION_STREAM_EXT :: DynamicState
- pattern DYNAMIC_STATE_RASTERIZER_DISCARD_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_RAY_TRACING_PIPELINE_STACK_SIZE_KHR :: DynamicState
- pattern DYNAMIC_STATE_REPRESENTATIVE_FRAGMENT_TEST_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_SAMPLE_LOCATIONS_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_SAMPLE_LOCATIONS_EXT :: DynamicState
- pattern DYNAMIC_STATE_SAMPLE_MASK_EXT :: DynamicState
- pattern DYNAMIC_STATE_SCISSOR :: DynamicState
- pattern DYNAMIC_STATE_SCISSOR_WITH_COUNT :: DynamicState
- pattern DYNAMIC_STATE_SHADING_RATE_IMAGE_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_STENCIL_COMPARE_MASK :: DynamicState
- pattern DYNAMIC_STATE_STENCIL_OP :: DynamicState
- pattern DYNAMIC_STATE_STENCIL_REFERENCE :: DynamicState
- pattern DYNAMIC_STATE_STENCIL_TEST_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_STENCIL_WRITE_MASK :: DynamicState
- pattern DYNAMIC_STATE_TESSELLATION_DOMAIN_ORIGIN_EXT :: DynamicState
- pattern DYNAMIC_STATE_VERTEX_INPUT_BINDING_STRIDE :: DynamicState
- pattern DYNAMIC_STATE_VERTEX_INPUT_EXT :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_COARSE_SAMPLE_ORDER_NV :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_SHADING_RATE_PALETTE_NV :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_SWIZZLE_NV :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_WITH_COUNT :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_W_SCALING_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_W_SCALING_NV :: DynamicState
Documentation
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> CullModeFlags |
|
| -> io () |
vkCmdSetCullMode - Set cull mode dynamically for a command buffer
Description
This command sets the cull mode for subsequent drawing commands when
drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_CULL_MODE set in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the
PipelineRasterizationStateCreateInfo::cullMode
value used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
cullModemust be a valid combination ofCullModeFlagBitsvalues -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetCullMode is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
CommandBuffer,
CullModeFlags
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> FrontFace |
|
| -> io () |
vkCmdSetFrontFace - Set front face orientation dynamically for a command buffer
Description
This command sets the front face orientation for subsequent drawing
commands when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_FRONT_FACE set in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the
PipelineRasterizationStateCreateInfo::frontFace
value used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
frontFacemust be a validFrontFacevalue -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetFrontFace is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
CommandBuffer,
FrontFace
cmdSetPrimitiveTopology Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> PrimitiveTopology |
|
| -> io () |
vkCmdSetPrimitiveTopology - Set primitive topology state dynamically for a command buffer
Description
This command sets the primitive topology for subsequent drawing commands
when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_PRIMITIVE_TOPOLOGY set
in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the
PipelineInputAssemblyStateCreateInfo::topology
value used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
primitiveTopologymust be a validPrimitiveTopologyvalue -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetPrimitiveTopology is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
CommandBuffer,
PrimitiveTopology
cmdSetViewportWithCount Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("viewports" ::: Vector Viewport) |
|
| -> io () |
vkCmdSetViewportWithCount - Set the viewport count and viewports dynamically for a command buffer
Description
This command sets the viewport count and viewports state for subsequent
drawing commands when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_VIEWPORT_WITH_COUNT set
in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the corresponding
PipelineViewportStateCreateInfo::viewportCount
and pViewports values used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
-
viewportCountmust be between1andPhysicalDeviceLimits::maxViewports, inclusive - If the
multiViewport
feature is not enabled,
viewportCountmust be1 -
commandBuffermust not haveCommandBufferInheritanceViewportScissorInfoNV::viewportScissor2Denabled
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
pViewportsmust be a valid pointer to an array ofviewportCountvalidViewportstructures -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
-
viewportCountmust be greater than0
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetViewportWithCount is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
CommandBuffer,
Viewport
cmdSetScissorWithCount Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("scissors" ::: Vector Rect2D) |
|
| -> io () |
vkCmdSetScissorWithCount - Set the scissor count and scissor rectangular bounds dynamically for a command buffer
Description
This command sets the scissor count and scissor rectangular bounds state
for subsequent drawing commands when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_SCISSOR_WITH_COUNT set
in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the corresponding
PipelineViewportStateCreateInfo::scissorCount
and pScissors values used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
-
scissorCountmust be between1andPhysicalDeviceLimits::maxViewports, inclusive - If the
multiViewport
feature is not enabled,
scissorCountmust be1 - The
xandymembers ofoffsetmember of any element ofpScissorsmust be greater than or equal to0 - Evaluation of
(
offset.x+extent.width) must not cause a signed integer addition overflow for any element ofpScissors - Evaluation of
(
offset.y+extent.height) must not cause a signed integer addition overflow for any element ofpScissors -
commandBuffermust not haveCommandBufferInheritanceViewportScissorInfoNV::viewportScissor2Denabled
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
pScissorsmust be a valid pointer to an array ofscissorCountRect2Dstructures -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
-
scissorCountmust be greater than0
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetScissorWithCount is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
CommandBuffer,
Rect2D
cmdBindVertexBuffers2 Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("firstBinding" ::: Word32) |
|
| -> ("buffers" ::: Vector Buffer) |
|
| -> ("offsets" ::: Vector DeviceSize) |
|
| -> ("sizes" ::: Vector DeviceSize) |
|
| -> ("strides" ::: Vector DeviceSize) |
|
| -> io () |
vkCmdBindVertexBuffers2 - Bind vertex buffers to a command buffer and dynamically set strides
Description
The values taken from elements i of pBuffers and pOffsets replace
the current state for the vertex input binding firstBinding + i, for i
in [0, bindingCount). The vertex input binding is updated to start at
the offset indicated by pOffsets[i] from the start of the buffer
pBuffers[i]. If pSizes is not NULL then pSizes[i] specifies the
bound size of the vertex buffer starting from the corresponding elements
of pBuffers[i] plus pOffsets[i]. If pSizes[i] is
WHOLE_SIZE then the bound size is from
pBuffers[i] plus pOffsets[i] to the end of the buffer pBuffers[i].
All vertex input attributes that use each of these bindings will use
these updated addresses in their address calculations for subsequent
drawing commands. If the
nullDescriptor
feature is enabled, elements of pBuffers can be
NULL_HANDLE, and can be used by the
vertex shader. If a vertex input attribute is bound to a vertex input
binding that is NULL_HANDLE, the values
taken from memory are considered to be zero, and missing G, B, or A
components are
filled with (0,0,1).
This command also
dynamically sets
the byte strides between consecutive elements within buffer
pBuffers[i] to the corresponding pStrides[i] value when drawing
using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_VERTEX_INPUT_BINDING_STRIDE
set in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, strides are specified by the
VertexInputBindingDescription::stride
values used to create the currently active pipeline.
If drawing using
shader objects
or if the bound pipeline state object was also created with the
DYNAMIC_STATE_VERTEX_INPUT_EXT
dynamic state enabled then
cmdSetVertexInputEXT
can be used instead of cmdBindVertexBuffers2 to set the stride.
Unlike the static state to set the same, pStrides must be between 0
and the maximum extent of the attributes in the binding.
cmdSetVertexInputEXT
does not have this restriction so can be used if other stride values are
desired.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
-
firstBindingmust be less thanPhysicalDeviceLimits::maxVertexInputBindings - The sum of
firstBindingandbindingCountmust be less than or equal toPhysicalDeviceLimits::maxVertexInputBindings - If
pSizesis notNULL, all elements ofpOffsetsmust be less than the size of the corresponding element inpBuffers - If
pSizesis notNULL, all elements ofpOffsetspluspSizes, wherepSizesis notWHOLE_SIZE, must be less than or equal to the size of the corresponding element inpBuffers - All elements of
pBuffersmust have been created with theBUFFER_USAGE_VERTEX_BUFFER_BITusage flag set - Each element of
pBuffersthat is non-sparse must be bound completely and contiguously to a singleDeviceMemoryobject - If the
nullDescriptor
feature is not enabled, all elements of
pBuffersmust not beNULL_HANDLE - If an element of
pBuffersisNULL_HANDLE, then the corresponding element ofpOffsetsmust be zero - If
pStridesis notNULLeach element ofpStridesmust be less than or equal toPhysicalDeviceLimits::maxVertexInputBindingStride - If
pStridesis notNULLeach element ofpStridesmust be either 0 or greater than or equal to the maximum extent of all vertex input attributes fetched from the corresponding binding, where the extent is calculated as theVertexInputAttributeDescription::offsetplusVertexInputAttributeDescription::formatsize
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
pBuffersmust be a valid pointer to an array ofbindingCountvalid orNULL_HANDLEBufferhandles -
pOffsetsmust be a valid pointer to an array ofbindingCountDeviceSizevalues - If
pSizesis notNULL,pSizesmust be a valid pointer to an array ofbindingCountDeviceSizevalues - If
pStridesis notNULL,pStridesmust be a valid pointer to an array ofbindingCountDeviceSizevalues -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
- If any of
pSizes, orpStridesare notNULL,bindingCountmust be greater than0 - Both of
commandBuffer, and the elements ofpBuffersthat are valid handles of non-ignored parameters must have been created, allocated, or retrieved from the sameDevice
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdBindVertexBuffers2 is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
Buffer, CommandBuffer,
DeviceSize
cmdSetDepthTestEnable Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("depthTestEnable" ::: Bool) |
|
| -> io () |
vkCmdSetDepthTestEnable - Set depth test enable dynamically for a command buffer
Description
This command sets the depth test enable for subsequent drawing commands
when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_DEPTH_TEST_ENABLE set
in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the
PipelineDepthStencilStateCreateInfo::depthTestEnable
value used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetDepthTestEnable is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
Bool32,
CommandBuffer
cmdSetDepthWriteEnable Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("depthWriteEnable" ::: Bool) |
|
| -> io () |
vkCmdSetDepthWriteEnable - Set depth write enable dynamically for a command buffer
Description
This command sets the depth write enable for subsequent drawing commands
when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_DEPTH_WRITE_ENABLE set
in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the
PipelineDepthStencilStateCreateInfo::depthWriteEnable
value used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetDepthWriteEnable is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
Bool32,
CommandBuffer
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("depthCompareOp" ::: CompareOp) |
|
| -> io () |
vkCmdSetDepthCompareOp - Set depth comparison operator dynamically for a command buffer
Description
This command sets the depth comparison operator for subsequent drawing
commands when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_DEPTH_COMPARE_OP set in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the
PipelineDepthStencilStateCreateInfo::depthCompareOp
value used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
depthCompareOpmust be a validCompareOpvalue -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetDepthCompareOp is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
CommandBuffer,
CompareOp
cmdSetDepthBoundsTestEnable Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("depthBoundsTestEnable" ::: Bool) |
|
| -> io () |
vkCmdSetDepthBoundsTestEnable - Set depth bounds test enable dynamically for a command buffer
Description
This command sets the depth bounds enable for subsequent drawing
commands when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_DEPTH_BOUNDS_TEST_ENABLE
set in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the
PipelineDepthStencilStateCreateInfo::depthBoundsTestEnable
value used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
- If the
depthBounds
feature is not enabled,
depthBoundsTestEnablemust beFALSE
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetDepthBoundsTestEnable is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
Bool32,
CommandBuffer
cmdSetStencilTestEnable Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("stencilTestEnable" ::: Bool) |
|
| -> io () |
vkCmdSetStencilTestEnable - Set stencil test enable dynamically for a command buffer
Description
This command sets the stencil test enable for subsequent drawing
commands when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_STENCIL_TEST_ENABLE set
in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the
PipelineDepthStencilStateCreateInfo::stencilTestEnable
value used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetStencilTestEnable is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
Bool32,
CommandBuffer
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("faceMask" ::: StencilFaceFlags) |
|
| -> ("failOp" ::: StencilOp) |
|
| -> ("passOp" ::: StencilOp) |
|
| -> ("depthFailOp" ::: StencilOp) |
|
| -> CompareOp |
|
| -> io () |
vkCmdSetStencilOp - Set stencil operation dynamically for a command buffer
Description
This command sets the stencil operation for subsequent drawing commands
when when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_STENCIL_OP set in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the corresponding
PipelineDepthStencilStateCreateInfo::failOp,
passOp, depthFailOp, and compareOp values used to create the
currently active pipeline, for both front and back faces.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
faceMaskmust be a valid combination ofStencilFaceFlagBitsvalues -
faceMaskmust not be0 -
failOpmust be a validStencilOpvalue -
passOpmust be a validStencilOpvalue -
depthFailOpmust be a validStencilOpvalue -
compareOpmust be a validCompareOpvalue -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetStencilOp is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state,
VK_EXT_shader_object,
VK_VERSION_1_3,
CommandBuffer,
CompareOp,
StencilFaceFlags,
StencilOp
newtype DynamicState Source #
VkDynamicState - Indicate which dynamic state is taken from dynamic state commands
Description
DYNAMIC_STATE_VIEWPORTspecifies that thepViewportsstate inPipelineViewportStateCreateInfowill be ignored and must be set dynamically withcmdSetViewportbefore any drawing commands. The number of viewports used by a pipeline is still specified by theviewportCountmember ofPipelineViewportStateCreateInfo.
DYNAMIC_STATE_SCISSORspecifies that thepScissorsstate inPipelineViewportStateCreateInfowill be ignored and must be set dynamically withcmdSetScissorbefore any drawing commands. The number of scissor rectangles used by a pipeline is still specified by thescissorCountmember ofPipelineViewportStateCreateInfo.DYNAMIC_STATE_LINE_WIDTHspecifies that thelineWidthstate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetLineWidthbefore any drawing commands that generate line primitives for the rasterizer.DYNAMIC_STATE_DEPTH_BIASspecifies that any instance ofDepthBiasRepresentationInfoEXTincluded in thepNextchain ofPipelineRasterizationStateCreateInfoas well as thedepthBiasConstantFactor,depthBiasClampanddepthBiasSlopeFactorstates inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthBiasorcmdSetDepthBias2EXTbefore any draws are performed with depth bias enabled.DYNAMIC_STATE_BLEND_CONSTANTSspecifies that theblendConstantsstate inPipelineColorBlendStateCreateInfowill be ignored and must be set dynamically withcmdSetBlendConstantsbefore any draws are performed with a pipeline state withPipelineColorBlendAttachmentStatememberblendEnableset toTRUEand any of the blend functions using a constant blend color.DYNAMIC_STATE_DEPTH_BOUNDSspecifies that theminDepthBoundsandmaxDepthBoundsstates ofPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthBoundsbefore any draws are performed with a pipeline state withPipelineDepthStencilStateCreateInfomemberdepthBoundsTestEnableset toTRUE.DYNAMIC_STATE_STENCIL_COMPARE_MASKspecifies that thecompareMaskstate inPipelineDepthStencilStateCreateInfofor bothfrontandbackwill be ignored and must be set dynamically withcmdSetStencilCompareMaskbefore any draws are performed with a pipeline state withPipelineDepthStencilStateCreateInfomemberstencilTestEnableset toTRUEDYNAMIC_STATE_STENCIL_WRITE_MASKspecifies that thewriteMaskstate inPipelineDepthStencilStateCreateInfofor bothfrontandbackwill be ignored and must be set dynamically withcmdSetStencilWriteMaskbefore any draws are performed with a pipeline state withPipelineDepthStencilStateCreateInfomemberstencilTestEnableset toTRUEDYNAMIC_STATE_STENCIL_REFERENCEspecifies that thereferencestate inPipelineDepthStencilStateCreateInfofor bothfrontandbackwill be ignored and must be set dynamically withcmdSetStencilReferencebefore any draws are performed with a pipeline state withPipelineDepthStencilStateCreateInfomemberstencilTestEnableset toTRUEDYNAMIC_STATE_VIEWPORT_W_SCALING_NVspecifies that thepViewportWScalingsstate inPipelineViewportWScalingStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetViewportWScalingNVbefore any draws are performed with a pipeline state withPipelineViewportWScalingStateCreateInfoNVmemberviewportScalingEnableset toTRUEDYNAMIC_STATE_DISCARD_RECTANGLE_EXTspecifies that thepDiscardRectanglesstate inPipelineDiscardRectangleStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetDiscardRectangleEXTbefore any draw or clear commands.DYNAMIC_STATE_DISCARD_RECTANGLE_ENABLE_EXTspecifies that the presence of thePipelineDiscardRectangleStateCreateInfoEXTstructure in theGraphicsPipelineCreateInfochain with adiscardRectangleCountgreater than zero does not implicitly enable discard rectangles and they must be enabled dynamically withcmdSetDiscardRectangleEnableEXTbefore any draw commands. This is available on implementations that support at leastspecVersion2of theVK_EXT_discard_rectanglesextension.DYNAMIC_STATE_DISCARD_RECTANGLE_MODE_EXTspecifies that thediscardRectangleModestate inPipelineDiscardRectangleStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetDiscardRectangleModeEXTbefore any draw commands. This is available on implementations that support at leastspecVersion2of theVK_EXT_discard_rectanglesextension.DYNAMIC_STATE_SAMPLE_LOCATIONS_EXTspecifies that thesampleLocationsInfostate inPipelineSampleLocationsStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetSampleLocationsEXTbefore any draw or clear commands. Enabling custom sample locations is still indicated by thesampleLocationsEnablemember ofPipelineSampleLocationsStateCreateInfoEXT.DYNAMIC_STATE_EXCLUSIVE_SCISSOR_NVspecifies that thepExclusiveScissorsstate inPipelineViewportExclusiveScissorStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetExclusiveScissorNVbefore any drawing commands.DYNAMIC_STATE_EXCLUSIVE_SCISSOR_ENABLE_NVspecifies that the exclusive scissors must be explicitly enabled withcmdSetExclusiveScissorEnableNVand theexclusiveScissorCountvalue inPipelineViewportExclusiveScissorStateCreateInfoNVwill not implicitly enable them. This is available on implementations that support at leastspecVersion2of theVK_NV_scissor_exclusiveextension.DYNAMIC_STATE_VIEWPORT_SHADING_RATE_PALETTE_NVspecifies that thepShadingRatePalettesstate inPipelineViewportShadingRateImageStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetViewportShadingRatePaletteNVbefore any drawing commands.DYNAMIC_STATE_VIEWPORT_COARSE_SAMPLE_ORDER_NVspecifies that the coarse sample order state inPipelineViewportCoarseSampleOrderStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoarseSampleOrderNVbefore any drawing commands.DYNAMIC_STATE_LINE_STIPPLEspecifies that thelineStippleFactorandlineStipplePatternstate inPipelineRasterizationLineStateCreateInfowill be ignored and must be set dynamically withcmdSetLineStipplebefore any draws are performed with a pipeline state withPipelineRasterizationLineStateCreateInfomemberstippledLineEnableset toTRUE.DYNAMIC_STATE_CULL_MODEspecifies that thecullModestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetCullModebefore any drawing commands.DYNAMIC_STATE_FRONT_FACEspecifies that thefrontFacestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetFrontFacebefore any drawing commands.DYNAMIC_STATE_PRIMITIVE_TOPOLOGYspecifies that thetopologystate inPipelineInputAssemblyStateCreateInfoonly specifies the topology class, and the specific topology order and adjacency must be set dynamically withcmdSetPrimitiveTopologybefore any drawing commands.DYNAMIC_STATE_VIEWPORT_WITH_COUNTspecifies that theviewportCountandpViewportsstate inPipelineViewportStateCreateInfowill be ignored and must be set dynamically withcmdSetViewportWithCountbefore any draw call.DYNAMIC_STATE_SCISSOR_WITH_COUNTspecifies that thescissorCountandpScissorsstate inPipelineViewportStateCreateInfowill be ignored and must be set dynamically withcmdSetScissorWithCountbefore any draw call.DYNAMIC_STATE_VERTEX_INPUT_BINDING_STRIDEspecifies that thestridestate inVertexInputBindingDescriptionwill be ignored and must be set dynamically withcmdBindVertexBuffers2before any draw call.DYNAMIC_STATE_DEPTH_TEST_ENABLEspecifies that thedepthTestEnablestate inPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthTestEnablebefore any draw call.DYNAMIC_STATE_DEPTH_WRITE_ENABLEspecifies that thedepthWriteEnablestate inPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthWriteEnablebefore any draw call.DYNAMIC_STATE_DEPTH_COMPARE_OPspecifies that thedepthCompareOpstate inPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthCompareOpbefore any draw call.DYNAMIC_STATE_DEPTH_BOUNDS_TEST_ENABLEspecifies that thedepthBoundsTestEnablestate inPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthBoundsTestEnablebefore any draw call.DYNAMIC_STATE_STENCIL_TEST_ENABLEspecifies that thestencilTestEnablestate inPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetStencilTestEnablebefore any draw call.DYNAMIC_STATE_STENCIL_OPspecifies that thefailOp,passOp,depthFailOp, andcompareOpstates inPipelineDepthStencilStateCreateInfofor bothfrontandbackwill be ignored and must be set dynamically withcmdSetStencilOpbefore any draws are performed with a pipeline state withPipelineDepthStencilStateCreateInfomemberstencilTestEnableset toTRUEDYNAMIC_STATE_PATCH_CONTROL_POINTS_EXTspecifies that thepatchControlPointsstate inPipelineTessellationStateCreateInfowill be ignored and must be set dynamically withcmdSetPatchControlPointsEXTbefore any drawing commands.DYNAMIC_STATE_RASTERIZER_DISCARD_ENABLEspecifies that therasterizerDiscardEnablestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetRasterizerDiscardEnablebefore any drawing commands.DYNAMIC_STATE_DEPTH_BIAS_ENABLEspecifies that thedepthBiasEnablestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthBiasEnablebefore any drawing commands.DYNAMIC_STATE_LOGIC_OP_EXTspecifies that thelogicOpstate inPipelineColorBlendStateCreateInfowill be ignored and must be set dynamically withcmdSetLogicOpEXTbefore any drawing commands.DYNAMIC_STATE_PRIMITIVE_RESTART_ENABLEspecifies that theprimitiveRestartEnablestate inPipelineInputAssemblyStateCreateInfowill be ignored and must be set dynamically withcmdSetPrimitiveRestartEnablebefore any drawing commands.DYNAMIC_STATE_FRAGMENT_SHADING_RATE_KHRspecifies that state inPipelineFragmentShadingRateStateCreateInfoKHRandPipelineFragmentShadingRateEnumStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetFragmentShadingRateKHRorcmdSetFragmentShadingRateEnumNVbefore any drawing commands.DYNAMIC_STATE_RAY_TRACING_PIPELINE_STACK_SIZE_KHRspecifies that the default stack size computation for the pipeline will be ignored and must be set dynamically withcmdSetRayTracingPipelineStackSizeKHRbefore any ray tracing calls are performed.DYNAMIC_STATE_VERTEX_INPUT_EXTspecifies that thepVertexInputStatestate will be ignored and must be set dynamically withcmdSetVertexInputEXTbefore any drawing commandsDYNAMIC_STATE_COLOR_WRITE_ENABLE_EXTspecifies that thepColorWriteEnablesstate inPipelineColorWriteCreateInfoEXTwill be ignored and must be set dynamically withcmdSetColorWriteEnableEXTbefore any draw call.DYNAMIC_STATE_TESSELLATION_DOMAIN_ORIGIN_EXTspecifies that thedomainOriginstate inPipelineTessellationDomainOriginStateCreateInfowill be ignored and must be set dynamically withcmdSetTessellationDomainOriginEXTbefore any draw call.DYNAMIC_STATE_DEPTH_CLAMP_ENABLE_EXTspecifies that thedepthClampEnablestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthClampEnableEXTbefore any draw call.DYNAMIC_STATE_POLYGON_MODE_EXTspecifies that thepolygonModestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetPolygonModeEXTbefore any draw call.DYNAMIC_STATE_RASTERIZATION_SAMPLES_EXTspecifies that therasterizationSamplesstate inPipelineMultisampleStateCreateInfowill be ignored and must be set dynamically withcmdSetRasterizationSamplesEXTbefore any draw call.DYNAMIC_STATE_SAMPLE_MASK_EXTspecifies that thepSampleMaskstate inPipelineMultisampleStateCreateInfowill be ignored and must be set dynamically withcmdSetSampleMaskEXTbefore any draw call.DYNAMIC_STATE_ALPHA_TO_COVERAGE_ENABLE_EXTspecifies that thealphaToCoverageEnablestate inPipelineMultisampleStateCreateInfowill be ignored and must be set dynamically withcmdSetAlphaToCoverageEnableEXTbefore any draw call.DYNAMIC_STATE_ALPHA_TO_ONE_ENABLE_EXTspecifies that thealphaToOneEnablestate inPipelineMultisampleStateCreateInfowill be ignored and must be set dynamically withcmdSetAlphaToOneEnableEXTbefore any draw call.DYNAMIC_STATE_LOGIC_OP_ENABLE_EXTspecifies that thelogicOpEnablestate inPipelineColorBlendStateCreateInfowill be ignored and must be set dynamically withcmdSetLogicOpEnableEXTbefore any draw call.DYNAMIC_STATE_COLOR_BLEND_ENABLE_EXTspecifies that theblendEnablestate inPipelineColorBlendAttachmentStatewill be ignored and must be set dynamically withcmdSetColorBlendEnableEXTbefore any draw call.DYNAMIC_STATE_COLOR_BLEND_EQUATION_EXTspecifies that thesrcColorBlendFactor,dstColorBlendFactor,colorBlendOp,srcAlphaBlendFactor,dstAlphaBlendFactor, andalphaBlendOpstates inPipelineColorBlendAttachmentStatewill be ignored and must be set dynamically withcmdSetColorBlendEquationEXTbefore any draw call.DYNAMIC_STATE_COLOR_WRITE_MASK_EXTspecifies that thecolorWriteMaskstate inPipelineColorBlendAttachmentStatewill be ignored and must be set dynamically withcmdSetColorWriteMaskEXTbefore any draw call.DYNAMIC_STATE_RASTERIZATION_STREAM_EXTspecifies that therasterizationStreamstate inPipelineRasterizationStateStreamCreateInfoEXTwill be ignored and must be set dynamically withcmdSetRasterizationStreamEXTbefore any draw call.DYNAMIC_STATE_CONSERVATIVE_RASTERIZATION_MODE_EXTspecifies that theconservativeRasterizationModestate inPipelineRasterizationConservativeStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetConservativeRasterizationModeEXTbefore any draw call.DYNAMIC_STATE_EXTRA_PRIMITIVE_OVERESTIMATION_SIZE_EXTspecifies that theextraPrimitiveOverestimationSizestate inPipelineRasterizationConservativeStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetExtraPrimitiveOverestimationSizeEXTbefore any draw call.DYNAMIC_STATE_DEPTH_CLIP_ENABLE_EXTspecifies that thedepthClipEnablestate inPipelineRasterizationDepthClipStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetDepthClipEnableEXTbefore any draw call.DYNAMIC_STATE_SAMPLE_LOCATIONS_ENABLE_EXTspecifies that thesampleLocationsEnablestate inPipelineSampleLocationsStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetSampleLocationsEnableEXTbefore any draw call.DYNAMIC_STATE_COLOR_BLEND_ADVANCED_EXTspecifies that thecolorBlendOpstate inPipelineColorBlendAttachmentState, andsrcPremultiplied,dstPremultiplied, andblendOverlapstates inPipelineColorBlendAdvancedStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetColorBlendAdvancedEXTbefore any draw call.DYNAMIC_STATE_PROVOKING_VERTEX_MODE_EXTspecifies that theprovokingVertexModestate inPipelineRasterizationProvokingVertexStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetProvokingVertexModeEXTbefore any draw call.DYNAMIC_STATE_LINE_RASTERIZATION_MODE_EXTspecifies that thelineRasterizationModestate inPipelineRasterizationLineStateCreateInfowill be ignored and must be set dynamically withcmdSetLineRasterizationModeEXTbefore any draw call.DYNAMIC_STATE_LINE_STIPPLE_ENABLE_EXTspecifies that thestippledLineEnablestate inPipelineRasterizationLineStateCreateInfowill be ignored and must be set dynamically withcmdSetLineStippleEnableEXTbefore any draw call.DYNAMIC_STATE_DEPTH_CLIP_NEGATIVE_ONE_TO_ONE_EXTspecifies that thenegativeOneToOnestate inPipelineViewportDepthClipControlCreateInfoEXTwill be ignored and must be set dynamically withcmdSetDepthClipNegativeOneToOneEXTbefore any draw call.DYNAMIC_STATE_DEPTH_CLAMP_RANGE_EXTspecifies that thedepthClampModeandpDepthClampRangestate inPipelineViewportDepthClampControlCreateInfoEXTwill be ignored and must be set dynamically withcmdSetDepthClampRangeEXTbefore any draw call.DYNAMIC_STATE_VIEWPORT_W_SCALING_ENABLE_NVspecifies that theviewportWScalingEnablestate inPipelineViewportWScalingStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetViewportWScalingEnableNVbefore any draw call.DYNAMIC_STATE_VIEWPORT_SWIZZLE_NVspecifies that theviewportCount, andpViewportSwizzlesstates inPipelineViewportSwizzleStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetViewportSwizzleNVbefore any draw call.DYNAMIC_STATE_COVERAGE_TO_COLOR_ENABLE_NVspecifies that thecoverageToColorEnablestate inPipelineCoverageToColorStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageToColorEnableNVbefore any draw call.DYNAMIC_STATE_COVERAGE_TO_COLOR_LOCATION_NVspecifies that thecoverageToColorLocationstate inPipelineCoverageToColorStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageToColorLocationNVbefore any draw call.DYNAMIC_STATE_COVERAGE_MODULATION_MODE_NVspecifies that thecoverageModulationModestate inPipelineCoverageModulationStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageModulationModeNVbefore any draw call.DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_ENABLE_NVspecifies that thecoverageModulationTableEnablestate inPipelineCoverageModulationStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageModulationTableEnableNVbefore any draw call.DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_NVspecifies that thecoverageModulationTableCount, andpCoverageModulationTablestates inPipelineCoverageModulationStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageModulationTableNVbefore any draw call.DYNAMIC_STATE_SHADING_RATE_IMAGE_ENABLE_NVspecifies that theshadingRateImageEnablestate inPipelineViewportShadingRateImageStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetShadingRateImageEnableNVbefore any draw call.DYNAMIC_STATE_REPRESENTATIVE_FRAGMENT_TEST_ENABLE_NVspecifies that therepresentativeFragmentTestEnablestate inPipelineRepresentativeFragmentTestStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetRepresentativeFragmentTestEnableNVbefore any draw call.DYNAMIC_STATE_COVERAGE_REDUCTION_MODE_NVspecifies that thecoverageReductionModestate inPipelineCoverageReductionStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageReductionModeNVbefore any draw call.DYNAMIC_STATE_ATTACHMENT_FEEDBACK_LOOP_ENABLE_EXTspecifies that thePIPELINE_CREATE_COLOR_ATTACHMENT_FEEDBACK_LOOP_BIT_EXTandPIPELINE_CREATE_DEPTH_STENCIL_ATTACHMENT_FEEDBACK_LOOP_BIT_EXTflags will be ignored and must be set dynamically withcmdSetAttachmentFeedbackLoopEnableEXTbefore any draw call.
See Also
Constructors
| DynamicState Int32 |
Bundled Patterns