| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Core13.Promoted_From_VK_EXT_extended_dynamic_state2
Synopsis
- cmdSetRasterizerDiscardEnable :: MonadIO io => CommandBuffer -> ("rasterizerDiscardEnable" ::: Bool) -> io ()
- cmdSetDepthBiasEnable :: MonadIO io => CommandBuffer -> ("depthBiasEnable" ::: Bool) -> io ()
- cmdSetPrimitiveRestartEnable :: MonadIO io => CommandBuffer -> ("primitiveRestartEnable" ::: Bool) -> io ()
- newtype DynamicState where
- DynamicState Int32
- pattern DYNAMIC_STATE_ALPHA_TO_COVERAGE_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_ALPHA_TO_ONE_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_ATTACHMENT_FEEDBACK_LOOP_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_BLEND_CONSTANTS :: DynamicState
- pattern DYNAMIC_STATE_COLOR_BLEND_ADVANCED_EXT :: DynamicState
- pattern DYNAMIC_STATE_COLOR_BLEND_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_COLOR_BLEND_EQUATION_EXT :: DynamicState
- pattern DYNAMIC_STATE_COLOR_WRITE_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_COLOR_WRITE_MASK_EXT :: DynamicState
- pattern DYNAMIC_STATE_CONSERVATIVE_RASTERIZATION_MODE_EXT :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_MODULATION_MODE_NV :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_REDUCTION_MODE_NV :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_TO_COLOR_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_COVERAGE_TO_COLOR_LOCATION_NV :: DynamicState
- pattern DYNAMIC_STATE_CULL_MODE :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_BIAS :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_BIAS_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_BOUNDS :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_BOUNDS_TEST_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_CLAMP_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_CLAMP_RANGE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_CLIP_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_CLIP_NEGATIVE_ONE_TO_ONE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_COMPARE_OP :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_TEST_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_DEPTH_WRITE_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_DISCARD_RECTANGLE_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DISCARD_RECTANGLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_DISCARD_RECTANGLE_MODE_EXT :: DynamicState
- pattern DYNAMIC_STATE_EXCLUSIVE_SCISSOR_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_EXCLUSIVE_SCISSOR_NV :: DynamicState
- pattern DYNAMIC_STATE_EXTRA_PRIMITIVE_OVERESTIMATION_SIZE_EXT :: DynamicState
- pattern DYNAMIC_STATE_FRAGMENT_SHADING_RATE_KHR :: DynamicState
- pattern DYNAMIC_STATE_FRONT_FACE :: DynamicState
- pattern DYNAMIC_STATE_LINE_RASTERIZATION_MODE_EXT :: DynamicState
- pattern DYNAMIC_STATE_LINE_STIPPLE :: DynamicState
- pattern DYNAMIC_STATE_LINE_STIPPLE_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_LINE_WIDTH :: DynamicState
- pattern DYNAMIC_STATE_LOGIC_OP_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_LOGIC_OP_EXT :: DynamicState
- pattern DYNAMIC_STATE_PATCH_CONTROL_POINTS_EXT :: DynamicState
- pattern DYNAMIC_STATE_POLYGON_MODE_EXT :: DynamicState
- pattern DYNAMIC_STATE_PRIMITIVE_RESTART_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_PRIMITIVE_TOPOLOGY :: DynamicState
- pattern DYNAMIC_STATE_PROVOKING_VERTEX_MODE_EXT :: DynamicState
- pattern DYNAMIC_STATE_RASTERIZATION_SAMPLES_EXT :: DynamicState
- pattern DYNAMIC_STATE_RASTERIZATION_STREAM_EXT :: DynamicState
- pattern DYNAMIC_STATE_RASTERIZER_DISCARD_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_RAY_TRACING_PIPELINE_STACK_SIZE_KHR :: DynamicState
- pattern DYNAMIC_STATE_REPRESENTATIVE_FRAGMENT_TEST_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_SAMPLE_LOCATIONS_ENABLE_EXT :: DynamicState
- pattern DYNAMIC_STATE_SAMPLE_LOCATIONS_EXT :: DynamicState
- pattern DYNAMIC_STATE_SAMPLE_MASK_EXT :: DynamicState
- pattern DYNAMIC_STATE_SCISSOR :: DynamicState
- pattern DYNAMIC_STATE_SCISSOR_WITH_COUNT :: DynamicState
- pattern DYNAMIC_STATE_SHADING_RATE_IMAGE_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_STENCIL_COMPARE_MASK :: DynamicState
- pattern DYNAMIC_STATE_STENCIL_OP :: DynamicState
- pattern DYNAMIC_STATE_STENCIL_REFERENCE :: DynamicState
- pattern DYNAMIC_STATE_STENCIL_TEST_ENABLE :: DynamicState
- pattern DYNAMIC_STATE_STENCIL_WRITE_MASK :: DynamicState
- pattern DYNAMIC_STATE_TESSELLATION_DOMAIN_ORIGIN_EXT :: DynamicState
- pattern DYNAMIC_STATE_VERTEX_INPUT_BINDING_STRIDE :: DynamicState
- pattern DYNAMIC_STATE_VERTEX_INPUT_EXT :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_COARSE_SAMPLE_ORDER_NV :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_SHADING_RATE_PALETTE_NV :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_SWIZZLE_NV :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_WITH_COUNT :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_W_SCALING_ENABLE_NV :: DynamicState
- pattern DYNAMIC_STATE_VIEWPORT_W_SCALING_NV :: DynamicState
Documentation
cmdSetRasterizerDiscardEnable Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("rasterizerDiscardEnable" ::: Bool) |
|
| -> io () |
vkCmdSetRasterizerDiscardEnable - Control whether primitives are discarded before the rasterization stage dynamically for a command buffer
Description
This command sets the discard enable for subsequent drawing commands
when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_RASTERIZER_DISCARD_ENABLE
set in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the
PipelineRasterizationStateCreateInfo::rasterizerDiscardEnable
value used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState2 feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetRasterizerDiscardEnable is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state2,
VK_EXT_shader_object,
VK_VERSION_1_3,
Bool32,
CommandBuffer
cmdSetDepthBiasEnable Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("depthBiasEnable" ::: Bool) |
|
| -> io () |
vkCmdSetDepthBiasEnable - Control whether to bias fragment depth values dynamically for a command buffer
Description
This command sets the depth bias enable for subsequent drawing commands
when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_DEPTH_BIAS_ENABLE set
in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the
PipelineRasterizationStateCreateInfo::depthBiasEnable
value used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState2 feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetDepthBiasEnable is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state2,
VK_EXT_shader_object,
VK_VERSION_1_3,
Bool32,
CommandBuffer
cmdSetPrimitiveRestartEnable Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("primitiveRestartEnable" ::: Bool) |
|
| -> io () |
vkCmdSetPrimitiveRestartEnable - Set primitive assembly restart state dynamically for a command buffer
Description
This command sets the primitive restart enable for subsequent drawing
commands when drawing using
shader objects,
or when the graphics pipeline is created with
DYNAMIC_STATE_PRIMITIVE_RESTART_ENABLE
set in
PipelineDynamicStateCreateInfo::pDynamicStates.
Otherwise, this state is specified by the
PipelineInputAssemblyStateCreateInfo::primitiveRestartEnable
value used to create the currently active pipeline.
Valid Usage
At least one of the following must be true:
- the extendedDynamicState2 feature is enabled
- the shaderObject feature is enabled
- the value of
ApplicationInfo::apiVersionused to create theInstanceparent ofcommandBufferis greater than or equal to Version 1.3
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetPrimitiveRestartEnable is not affected by conditional rendering
See Also
VK_EXT_extended_dynamic_state2,
VK_EXT_shader_object,
VK_VERSION_1_3,
Bool32,
CommandBuffer
newtype DynamicState Source #
VkDynamicState - Indicate which dynamic state is taken from dynamic state commands
Description
DYNAMIC_STATE_VIEWPORTspecifies that thepViewportsstate inPipelineViewportStateCreateInfowill be ignored and must be set dynamically withcmdSetViewportbefore any drawing commands. The number of viewports used by a pipeline is still specified by theviewportCountmember ofPipelineViewportStateCreateInfo.
DYNAMIC_STATE_SCISSORspecifies that thepScissorsstate inPipelineViewportStateCreateInfowill be ignored and must be set dynamically withcmdSetScissorbefore any drawing commands. The number of scissor rectangles used by a pipeline is still specified by thescissorCountmember ofPipelineViewportStateCreateInfo.DYNAMIC_STATE_LINE_WIDTHspecifies that thelineWidthstate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetLineWidthbefore any drawing commands that generate line primitives for the rasterizer.DYNAMIC_STATE_DEPTH_BIASspecifies that any instance ofDepthBiasRepresentationInfoEXTincluded in thepNextchain ofPipelineRasterizationStateCreateInfoas well as thedepthBiasConstantFactor,depthBiasClampanddepthBiasSlopeFactorstates inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthBiasorcmdSetDepthBias2EXTbefore any draws are performed with depth bias enabled.DYNAMIC_STATE_BLEND_CONSTANTSspecifies that theblendConstantsstate inPipelineColorBlendStateCreateInfowill be ignored and must be set dynamically withcmdSetBlendConstantsbefore any draws are performed with a pipeline state withPipelineColorBlendAttachmentStatememberblendEnableset toTRUEand any of the blend functions using a constant blend color.DYNAMIC_STATE_DEPTH_BOUNDSspecifies that theminDepthBoundsandmaxDepthBoundsstates ofPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthBoundsbefore any draws are performed with a pipeline state withPipelineDepthStencilStateCreateInfomemberdepthBoundsTestEnableset toTRUE.DYNAMIC_STATE_STENCIL_COMPARE_MASKspecifies that thecompareMaskstate inPipelineDepthStencilStateCreateInfofor bothfrontandbackwill be ignored and must be set dynamically withcmdSetStencilCompareMaskbefore any draws are performed with a pipeline state withPipelineDepthStencilStateCreateInfomemberstencilTestEnableset toTRUEDYNAMIC_STATE_STENCIL_WRITE_MASKspecifies that thewriteMaskstate inPipelineDepthStencilStateCreateInfofor bothfrontandbackwill be ignored and must be set dynamically withcmdSetStencilWriteMaskbefore any draws are performed with a pipeline state withPipelineDepthStencilStateCreateInfomemberstencilTestEnableset toTRUEDYNAMIC_STATE_STENCIL_REFERENCEspecifies that thereferencestate inPipelineDepthStencilStateCreateInfofor bothfrontandbackwill be ignored and must be set dynamically withcmdSetStencilReferencebefore any draws are performed with a pipeline state withPipelineDepthStencilStateCreateInfomemberstencilTestEnableset toTRUEDYNAMIC_STATE_VIEWPORT_W_SCALING_NVspecifies that thepViewportWScalingsstate inPipelineViewportWScalingStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetViewportWScalingNVbefore any draws are performed with a pipeline state withPipelineViewportWScalingStateCreateInfoNVmemberviewportScalingEnableset toTRUEDYNAMIC_STATE_DISCARD_RECTANGLE_EXTspecifies that thepDiscardRectanglesstate inPipelineDiscardRectangleStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetDiscardRectangleEXTbefore any draw or clear commands.DYNAMIC_STATE_DISCARD_RECTANGLE_ENABLE_EXTspecifies that the presence of thePipelineDiscardRectangleStateCreateInfoEXTstructure in theGraphicsPipelineCreateInfochain with adiscardRectangleCountgreater than zero does not implicitly enable discard rectangles and they must be enabled dynamically withcmdSetDiscardRectangleEnableEXTbefore any draw commands. This is available on implementations that support at leastspecVersion2of theVK_EXT_discard_rectanglesextension.DYNAMIC_STATE_DISCARD_RECTANGLE_MODE_EXTspecifies that thediscardRectangleModestate inPipelineDiscardRectangleStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetDiscardRectangleModeEXTbefore any draw commands. This is available on implementations that support at leastspecVersion2of theVK_EXT_discard_rectanglesextension.DYNAMIC_STATE_SAMPLE_LOCATIONS_EXTspecifies that thesampleLocationsInfostate inPipelineSampleLocationsStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetSampleLocationsEXTbefore any draw or clear commands. Enabling custom sample locations is still indicated by thesampleLocationsEnablemember ofPipelineSampleLocationsStateCreateInfoEXT.DYNAMIC_STATE_EXCLUSIVE_SCISSOR_NVspecifies that thepExclusiveScissorsstate inPipelineViewportExclusiveScissorStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetExclusiveScissorNVbefore any drawing commands.DYNAMIC_STATE_EXCLUSIVE_SCISSOR_ENABLE_NVspecifies that the exclusive scissors must be explicitly enabled withcmdSetExclusiveScissorEnableNVand theexclusiveScissorCountvalue inPipelineViewportExclusiveScissorStateCreateInfoNVwill not implicitly enable them. This is available on implementations that support at leastspecVersion2of theVK_NV_scissor_exclusiveextension.DYNAMIC_STATE_VIEWPORT_SHADING_RATE_PALETTE_NVspecifies that thepShadingRatePalettesstate inPipelineViewportShadingRateImageStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetViewportShadingRatePaletteNVbefore any drawing commands.DYNAMIC_STATE_VIEWPORT_COARSE_SAMPLE_ORDER_NVspecifies that the coarse sample order state inPipelineViewportCoarseSampleOrderStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoarseSampleOrderNVbefore any drawing commands.DYNAMIC_STATE_LINE_STIPPLEspecifies that thelineStippleFactorandlineStipplePatternstate inPipelineRasterizationLineStateCreateInfowill be ignored and must be set dynamically withcmdSetLineStipplebefore any draws are performed with a pipeline state withPipelineRasterizationLineStateCreateInfomemberstippledLineEnableset toTRUE.DYNAMIC_STATE_CULL_MODEspecifies that thecullModestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetCullModebefore any drawing commands.DYNAMIC_STATE_FRONT_FACEspecifies that thefrontFacestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetFrontFacebefore any drawing commands.DYNAMIC_STATE_PRIMITIVE_TOPOLOGYspecifies that thetopologystate inPipelineInputAssemblyStateCreateInfoonly specifies the topology class, and the specific topology order and adjacency must be set dynamically withcmdSetPrimitiveTopologybefore any drawing commands.DYNAMIC_STATE_VIEWPORT_WITH_COUNTspecifies that theviewportCountandpViewportsstate inPipelineViewportStateCreateInfowill be ignored and must be set dynamically withcmdSetViewportWithCountbefore any draw call.DYNAMIC_STATE_SCISSOR_WITH_COUNTspecifies that thescissorCountandpScissorsstate inPipelineViewportStateCreateInfowill be ignored and must be set dynamically withcmdSetScissorWithCountbefore any draw call.DYNAMIC_STATE_VERTEX_INPUT_BINDING_STRIDEspecifies that thestridestate inVertexInputBindingDescriptionwill be ignored and must be set dynamically withcmdBindVertexBuffers2before any draw call.DYNAMIC_STATE_DEPTH_TEST_ENABLEspecifies that thedepthTestEnablestate inPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthTestEnablebefore any draw call.DYNAMIC_STATE_DEPTH_WRITE_ENABLEspecifies that thedepthWriteEnablestate inPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthWriteEnablebefore any draw call.DYNAMIC_STATE_DEPTH_COMPARE_OPspecifies that thedepthCompareOpstate inPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthCompareOpbefore any draw call.DYNAMIC_STATE_DEPTH_BOUNDS_TEST_ENABLEspecifies that thedepthBoundsTestEnablestate inPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthBoundsTestEnablebefore any draw call.DYNAMIC_STATE_STENCIL_TEST_ENABLEspecifies that thestencilTestEnablestate inPipelineDepthStencilStateCreateInfowill be ignored and must be set dynamically withcmdSetStencilTestEnablebefore any draw call.DYNAMIC_STATE_STENCIL_OPspecifies that thefailOp,passOp,depthFailOp, andcompareOpstates inPipelineDepthStencilStateCreateInfofor bothfrontandbackwill be ignored and must be set dynamically withcmdSetStencilOpbefore any draws are performed with a pipeline state withPipelineDepthStencilStateCreateInfomemberstencilTestEnableset toTRUEDYNAMIC_STATE_PATCH_CONTROL_POINTS_EXTspecifies that thepatchControlPointsstate inPipelineTessellationStateCreateInfowill be ignored and must be set dynamically withcmdSetPatchControlPointsEXTbefore any drawing commands.DYNAMIC_STATE_RASTERIZER_DISCARD_ENABLEspecifies that therasterizerDiscardEnablestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetRasterizerDiscardEnablebefore any drawing commands.DYNAMIC_STATE_DEPTH_BIAS_ENABLEspecifies that thedepthBiasEnablestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthBiasEnablebefore any drawing commands.DYNAMIC_STATE_LOGIC_OP_EXTspecifies that thelogicOpstate inPipelineColorBlendStateCreateInfowill be ignored and must be set dynamically withcmdSetLogicOpEXTbefore any drawing commands.DYNAMIC_STATE_PRIMITIVE_RESTART_ENABLEspecifies that theprimitiveRestartEnablestate inPipelineInputAssemblyStateCreateInfowill be ignored and must be set dynamically withcmdSetPrimitiveRestartEnablebefore any drawing commands.DYNAMIC_STATE_FRAGMENT_SHADING_RATE_KHRspecifies that state inPipelineFragmentShadingRateStateCreateInfoKHRandPipelineFragmentShadingRateEnumStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetFragmentShadingRateKHRorcmdSetFragmentShadingRateEnumNVbefore any drawing commands.DYNAMIC_STATE_RAY_TRACING_PIPELINE_STACK_SIZE_KHRspecifies that the default stack size computation for the pipeline will be ignored and must be set dynamically withcmdSetRayTracingPipelineStackSizeKHRbefore any ray tracing calls are performed.DYNAMIC_STATE_VERTEX_INPUT_EXTspecifies that thepVertexInputStatestate will be ignored and must be set dynamically withcmdSetVertexInputEXTbefore any drawing commandsDYNAMIC_STATE_COLOR_WRITE_ENABLE_EXTspecifies that thepColorWriteEnablesstate inPipelineColorWriteCreateInfoEXTwill be ignored and must be set dynamically withcmdSetColorWriteEnableEXTbefore any draw call.DYNAMIC_STATE_TESSELLATION_DOMAIN_ORIGIN_EXTspecifies that thedomainOriginstate inPipelineTessellationDomainOriginStateCreateInfowill be ignored and must be set dynamically withcmdSetTessellationDomainOriginEXTbefore any draw call.DYNAMIC_STATE_DEPTH_CLAMP_ENABLE_EXTspecifies that thedepthClampEnablestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetDepthClampEnableEXTbefore any draw call.DYNAMIC_STATE_POLYGON_MODE_EXTspecifies that thepolygonModestate inPipelineRasterizationStateCreateInfowill be ignored and must be set dynamically withcmdSetPolygonModeEXTbefore any draw call.DYNAMIC_STATE_RASTERIZATION_SAMPLES_EXTspecifies that therasterizationSamplesstate inPipelineMultisampleStateCreateInfowill be ignored and must be set dynamically withcmdSetRasterizationSamplesEXTbefore any draw call.DYNAMIC_STATE_SAMPLE_MASK_EXTspecifies that thepSampleMaskstate inPipelineMultisampleStateCreateInfowill be ignored and must be set dynamically withcmdSetSampleMaskEXTbefore any draw call.DYNAMIC_STATE_ALPHA_TO_COVERAGE_ENABLE_EXTspecifies that thealphaToCoverageEnablestate inPipelineMultisampleStateCreateInfowill be ignored and must be set dynamically withcmdSetAlphaToCoverageEnableEXTbefore any draw call.DYNAMIC_STATE_ALPHA_TO_ONE_ENABLE_EXTspecifies that thealphaToOneEnablestate inPipelineMultisampleStateCreateInfowill be ignored and must be set dynamically withcmdSetAlphaToOneEnableEXTbefore any draw call.DYNAMIC_STATE_LOGIC_OP_ENABLE_EXTspecifies that thelogicOpEnablestate inPipelineColorBlendStateCreateInfowill be ignored and must be set dynamically withcmdSetLogicOpEnableEXTbefore any draw call.DYNAMIC_STATE_COLOR_BLEND_ENABLE_EXTspecifies that theblendEnablestate inPipelineColorBlendAttachmentStatewill be ignored and must be set dynamically withcmdSetColorBlendEnableEXTbefore any draw call.DYNAMIC_STATE_COLOR_BLEND_EQUATION_EXTspecifies that thesrcColorBlendFactor,dstColorBlendFactor,colorBlendOp,srcAlphaBlendFactor,dstAlphaBlendFactor, andalphaBlendOpstates inPipelineColorBlendAttachmentStatewill be ignored and must be set dynamically withcmdSetColorBlendEquationEXTbefore any draw call.DYNAMIC_STATE_COLOR_WRITE_MASK_EXTspecifies that thecolorWriteMaskstate inPipelineColorBlendAttachmentStatewill be ignored and must be set dynamically withcmdSetColorWriteMaskEXTbefore any draw call.DYNAMIC_STATE_RASTERIZATION_STREAM_EXTspecifies that therasterizationStreamstate inPipelineRasterizationStateStreamCreateInfoEXTwill be ignored and must be set dynamically withcmdSetRasterizationStreamEXTbefore any draw call.DYNAMIC_STATE_CONSERVATIVE_RASTERIZATION_MODE_EXTspecifies that theconservativeRasterizationModestate inPipelineRasterizationConservativeStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetConservativeRasterizationModeEXTbefore any draw call.DYNAMIC_STATE_EXTRA_PRIMITIVE_OVERESTIMATION_SIZE_EXTspecifies that theextraPrimitiveOverestimationSizestate inPipelineRasterizationConservativeStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetExtraPrimitiveOverestimationSizeEXTbefore any draw call.DYNAMIC_STATE_DEPTH_CLIP_ENABLE_EXTspecifies that thedepthClipEnablestate inPipelineRasterizationDepthClipStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetDepthClipEnableEXTbefore any draw call.DYNAMIC_STATE_SAMPLE_LOCATIONS_ENABLE_EXTspecifies that thesampleLocationsEnablestate inPipelineSampleLocationsStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetSampleLocationsEnableEXTbefore any draw call.DYNAMIC_STATE_COLOR_BLEND_ADVANCED_EXTspecifies that thecolorBlendOpstate inPipelineColorBlendAttachmentState, andsrcPremultiplied,dstPremultiplied, andblendOverlapstates inPipelineColorBlendAdvancedStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetColorBlendAdvancedEXTbefore any draw call.DYNAMIC_STATE_PROVOKING_VERTEX_MODE_EXTspecifies that theprovokingVertexModestate inPipelineRasterizationProvokingVertexStateCreateInfoEXTwill be ignored and must be set dynamically withcmdSetProvokingVertexModeEXTbefore any draw call.DYNAMIC_STATE_LINE_RASTERIZATION_MODE_EXTspecifies that thelineRasterizationModestate inPipelineRasterizationLineStateCreateInfowill be ignored and must be set dynamically withcmdSetLineRasterizationModeEXTbefore any draw call.DYNAMIC_STATE_LINE_STIPPLE_ENABLE_EXTspecifies that thestippledLineEnablestate inPipelineRasterizationLineStateCreateInfowill be ignored and must be set dynamically withcmdSetLineStippleEnableEXTbefore any draw call.DYNAMIC_STATE_DEPTH_CLIP_NEGATIVE_ONE_TO_ONE_EXTspecifies that thenegativeOneToOnestate inPipelineViewportDepthClipControlCreateInfoEXTwill be ignored and must be set dynamically withcmdSetDepthClipNegativeOneToOneEXTbefore any draw call.DYNAMIC_STATE_DEPTH_CLAMP_RANGE_EXTspecifies that thedepthClampModeandpDepthClampRangestate inPipelineViewportDepthClampControlCreateInfoEXTwill be ignored and must be set dynamically withcmdSetDepthClampRangeEXTbefore any draw call.DYNAMIC_STATE_VIEWPORT_W_SCALING_ENABLE_NVspecifies that theviewportWScalingEnablestate inPipelineViewportWScalingStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetViewportWScalingEnableNVbefore any draw call.DYNAMIC_STATE_VIEWPORT_SWIZZLE_NVspecifies that theviewportCount, andpViewportSwizzlesstates inPipelineViewportSwizzleStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetViewportSwizzleNVbefore any draw call.DYNAMIC_STATE_COVERAGE_TO_COLOR_ENABLE_NVspecifies that thecoverageToColorEnablestate inPipelineCoverageToColorStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageToColorEnableNVbefore any draw call.DYNAMIC_STATE_COVERAGE_TO_COLOR_LOCATION_NVspecifies that thecoverageToColorLocationstate inPipelineCoverageToColorStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageToColorLocationNVbefore any draw call.DYNAMIC_STATE_COVERAGE_MODULATION_MODE_NVspecifies that thecoverageModulationModestate inPipelineCoverageModulationStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageModulationModeNVbefore any draw call.DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_ENABLE_NVspecifies that thecoverageModulationTableEnablestate inPipelineCoverageModulationStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageModulationTableEnableNVbefore any draw call.DYNAMIC_STATE_COVERAGE_MODULATION_TABLE_NVspecifies that thecoverageModulationTableCount, andpCoverageModulationTablestates inPipelineCoverageModulationStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageModulationTableNVbefore any draw call.DYNAMIC_STATE_SHADING_RATE_IMAGE_ENABLE_NVspecifies that theshadingRateImageEnablestate inPipelineViewportShadingRateImageStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetShadingRateImageEnableNVbefore any draw call.DYNAMIC_STATE_REPRESENTATIVE_FRAGMENT_TEST_ENABLE_NVspecifies that therepresentativeFragmentTestEnablestate inPipelineRepresentativeFragmentTestStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetRepresentativeFragmentTestEnableNVbefore any draw call.DYNAMIC_STATE_COVERAGE_REDUCTION_MODE_NVspecifies that thecoverageReductionModestate inPipelineCoverageReductionStateCreateInfoNVwill be ignored and must be set dynamically withcmdSetCoverageReductionModeNVbefore any draw call.DYNAMIC_STATE_ATTACHMENT_FEEDBACK_LOOP_ENABLE_EXTspecifies that thePIPELINE_CREATE_COLOR_ATTACHMENT_FEEDBACK_LOOP_BIT_EXTandPIPELINE_CREATE_DEPTH_STENCIL_ATTACHMENT_FEEDBACK_LOOP_BIT_EXTflags will be ignored and must be set dynamically withcmdSetAttachmentFeedbackLoopEnableEXTbefore any draw call.
See Also
Constructors
| DynamicState Int32 |
Bundled Patterns