| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_AMD_anti_lag
Description
Name
VK_AMD_anti_lag - device extension
VK_AMD_anti_lag
- Name String
VK_AMD_anti_lag
- Extension Type
- Device extension
- Registered Extension Number
- 477
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Contact
- Stu Smith
- Extension Proposal
- VK_AMD_anti_lag
Other Extension Metadata
- Last Modified Date
- 2024-06-06
- IP Status
- No known IP claims.
- Contributors
- Tobias Hector, AMD
- Stuart Smith, AMD
- Arkadiusz Sarwa, AMD
Description
This extension automatically paces the CPU to make sure it does not get too far ahead of the GPU, reducing the latency between inputs received and updates on the screen. Additionally, Anti-Lag+ offers applications the ability to inform the driver when input processing begins, in order to align the timing of display updates, enabling even lower latency between receiving input and displaying on the screen.
New Commands
New Structures
New Enums
New Enum Constants
AMD_ANTI_LAG_SPEC_VERSIONExtending
StructureType:
Version History
Revision 1, 2024-06-06 (Arkadiusz Sarw)
- Initial version
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- antiLagUpdateAMD :: MonadIO io => Device -> AntiLagDataAMD -> io ()
- data PhysicalDeviceAntiLagFeaturesAMD = PhysicalDeviceAntiLagFeaturesAMD {}
- data AntiLagDataAMD = AntiLagDataAMD {}
- data AntiLagPresentationInfoAMD = AntiLagPresentationInfoAMD {}
- newtype AntiLagModeAMD where
- AntiLagModeAMD Int32
- pattern ANTI_LAG_MODE_DRIVER_CONTROL_AMD :: AntiLagModeAMD
- pattern ANTI_LAG_MODE_ON_AMD :: AntiLagModeAMD
- pattern ANTI_LAG_MODE_OFF_AMD :: AntiLagModeAMD
- newtype AntiLagStageAMD where
- AntiLagStageAMD Int32
- pattern ANTI_LAG_STAGE_INPUT_AMD :: AntiLagStageAMD
- pattern ANTI_LAG_STAGE_PRESENT_AMD :: AntiLagStageAMD
- type AMD_ANTI_LAG_SPEC_VERSION = 1
- pattern AMD_ANTI_LAG_SPEC_VERSION :: Integral a => a
- type AMD_ANTI_LAG_EXTENSION_NAME = "VK_AMD_anti_lag"
- pattern AMD_ANTI_LAG_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
Arguments
| :: MonadIO io | |
| => Device |
|
| -> AntiLagDataAMD |
|
| -> io () |
vkAntiLagUpdateAMD - Provide information to reduce latency
Description
This command should be executed immediately before the application
processes user input. If pData is not NULL and
AntiLagDataAMD::pPresentationInfo is not NULL, this command
should be executed again before
queuePresentKHR, with
pPresentationInfo set to matching values.
Valid Usage
- The antiLag feature must be enabled
Valid Usage (Implicit)
-
devicemust be a validDevicehandle
-
pDatamust be a valid pointer to a validAntiLagDataAMDstructure
See Also
data PhysicalDeviceAntiLagFeaturesAMD Source #
VkPhysicalDeviceAntiLagFeaturesAMD - Structure describing whether VK_AMD_anti_lag can be supported by an implementation.
Members
This structure describes the following feature:
Description
If the PhysicalDeviceAntiLagFeaturesAMD structure is included in the
pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceAntiLagFeaturesAMD, it must add an instance of the
structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceAntiLagFeaturesAMD | |
Fields
| |
Instances
data AntiLagDataAMD Source #
VkAntiLagDataAMD - Structure specifying the parameters for vkAntiLagUpdateAMD
Description
This structure specifies anti-lag parameters.
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_ANTI_LAG_DATA_AMD
-
modemust be a validAntiLagModeAMDvalue - If
pPresentationInfois notNULL,pPresentationInfomust be a valid pointer to a validAntiLagPresentationInfoAMDstructure
See Also
VK_AMD_anti_lag,
AntiLagModeAMD, AntiLagPresentationInfoAMD,
StructureType, antiLagUpdateAMD
Constructors
| AntiLagDataAMD | |
Fields
| |
Instances
| Show AntiLagDataAMD Source # | |
Defined in Vulkan.Extensions.VK_AMD_anti_lag Methods showsPrec :: Int -> AntiLagDataAMD -> ShowS # show :: AntiLagDataAMD -> String # showList :: [AntiLagDataAMD] -> ShowS # | |
| FromCStruct AntiLagDataAMD Source # | |
Defined in Vulkan.Extensions.VK_AMD_anti_lag Methods peekCStruct :: Ptr AntiLagDataAMD -> IO AntiLagDataAMD Source # | |
| ToCStruct AntiLagDataAMD Source # | |
Defined in Vulkan.Extensions.VK_AMD_anti_lag Methods withCStruct :: AntiLagDataAMD -> (Ptr AntiLagDataAMD -> IO b) -> IO b Source # pokeCStruct :: Ptr AntiLagDataAMD -> AntiLagDataAMD -> IO b -> IO b Source # withZeroCStruct :: (Ptr AntiLagDataAMD -> IO b) -> IO b Source # pokeZeroCStruct :: Ptr AntiLagDataAMD -> IO b -> IO b Source # cStructSize :: Int Source # | |
| Zero AntiLagDataAMD Source # | |
Defined in Vulkan.Extensions.VK_AMD_anti_lag Methods | |
data AntiLagPresentationInfoAMD Source #
VkAntiLagPresentationInfoAMD - Structure specifying information about stage
Description
This structure specifies information about the presentation stage for which anti-lag parameters are being set.
Valid Usage (Implicit)
See Also
VK_AMD_anti_lag,
AntiLagDataAMD, AntiLagStageAMD,
StructureType
Constructors
| AntiLagPresentationInfoAMD | |
Fields
| |
Instances
newtype AntiLagModeAMD Source #
VkAntiLagModeAMD - Set the status of the anti-lag feature
Description
ANTI_LAG_MODE_DRIVER_CONTROL_AMDspecifies that anti-lag will be enabled or disabled depending on driver settings.
ANTI_LAG_MODE_ON_AMDspecifies that anti-lag will be enabled.ANTI_LAG_MODE_OFF_AMDspecifies that anti-lag will be disabled.
See Also
Constructors
| AntiLagModeAMD Int32 |
Bundled Patterns
| pattern ANTI_LAG_MODE_DRIVER_CONTROL_AMD :: AntiLagModeAMD | |
| pattern ANTI_LAG_MODE_ON_AMD :: AntiLagModeAMD | |
| pattern ANTI_LAG_MODE_OFF_AMD :: AntiLagModeAMD |
Instances
newtype AntiLagStageAMD Source #
VkAntiLagStageAMD - Report the application stage
Description
ANTI_LAG_STAGE_INPUT_AMDspecifies the stage before processing input.
ANTI_LAG_STAGE_PRESENT_AMDspecifies the stage beforequeuePresentKHR.
See Also
Constructors
| AntiLagStageAMD Int32 |
Bundled Patterns
| pattern ANTI_LAG_STAGE_INPUT_AMD :: AntiLagStageAMD | |
| pattern ANTI_LAG_STAGE_PRESENT_AMD :: AntiLagStageAMD |
Instances
type AMD_ANTI_LAG_SPEC_VERSION = 1 Source #
pattern AMD_ANTI_LAG_SPEC_VERSION :: Integral a => a Source #
type AMD_ANTI_LAG_EXTENSION_NAME = "VK_AMD_anti_lag" Source #
pattern AMD_ANTI_LAG_EXTENSION_NAME :: (Eq a, IsString a) => a Source #