| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_AMD_buffer_marker
Description
Name
VK_AMD_buffer_marker - device extension
VK_AMD_buffer_marker
- Name String
VK_AMD_buffer_marker
- Extension Type
- Device extension
- Registered Extension Number
- 180
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- None
- API Interactions
- Interacts with VK_VERSION_1_3
- Interacts with VK_KHR_synchronization2
- Special Use
- Contact
Other Extension Metadata
- Last Modified Date
- 2018-01-26
- IP Status
- No known IP claims.
- Contributors
- Matthaeus G. Chajdas, AMD
- Jaakko Konttinen, AMD
- Daniel Rakos, AMD
Description
This extension adds a new operation to execute pipelined writes of small
marker values into a Buffer object.
The primary purpose of these markers is to facilitate the development of debugging tools for tracking which pipelined command contributed to device loss.
New Commands
If Vulkan Version 1.3 or VK_KHR_synchronization2 is supported:
New Enum Constants
Examples
None.
Version History
Revision 1, 2018-01-26 (Jaakko Konttinen)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- cmdWriteBufferMarkerAMD :: MonadIO io => CommandBuffer -> PipelineStageFlagBits -> ("dstBuffer" ::: Buffer) -> ("dstOffset" ::: DeviceSize) -> ("marker" ::: Word32) -> io ()
- cmdWriteBufferMarker2AMD :: MonadIO io => CommandBuffer -> PipelineStageFlags2 -> ("dstBuffer" ::: Buffer) -> ("dstOffset" ::: DeviceSize) -> ("marker" ::: Word32) -> io ()
- type AMD_BUFFER_MARKER_SPEC_VERSION = 1
- pattern AMD_BUFFER_MARKER_SPEC_VERSION :: Integral a => a
- type AMD_BUFFER_MARKER_EXTENSION_NAME = "VK_AMD_buffer_marker"
- pattern AMD_BUFFER_MARKER_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
cmdWriteBufferMarkerAMD Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> PipelineStageFlagBits |
|
| -> ("dstBuffer" ::: Buffer) |
|
| -> ("dstOffset" ::: DeviceSize) |
|
| -> ("marker" ::: Word32) |
|
| -> io () |
vkCmdWriteBufferMarkerAMD - Execute a pipelined write of a marker value into a buffer
Description
When cmdWriteBufferMarkerAMD is submitted to a queue, it defines an
execution dependency between prior operations and writing the marker
value, as well as a memory dependency from earlier
buffer marker write commands.
The first
synchronization scope
includes operations performed by operations that occur earlier in
submission order
in the pipeline stage identified by pipelineStage. It additionally
includes other
buffer marker write commands
that occur earlier in
submission order
that specified either the same pipelineStage or a stage that is
logically earlier.
The second synchronization scope includes only the buffer marker write.
The first access scope includes only accesses performed by other buffer marker write commands.
The second access scope is empty.
The access scope for buffer marker writes falls under the
ACCESS_TRANSFER_WRITE_BIT flag, and
is performed by either pipelineStage or
PIPELINE_STAGE_TRANSFER_BIT.
Synchronization commands
should specify this access flag and both pipeline stages when defining
dependencies with this command.
Similar to cmdWriteTimestamp, if
an implementation is unable to write a marker at any specific pipeline
stage, it may instead do so at any logically later stage.
Implementations may only support a limited number of pipelined marker write operations in flight at a given time, thus excessive number of marker write operations may degrade command execution performance.
Valid Usage
-
pipelineStagemust be a valid stage for the queue family that was used to create the command pool thatcommandBufferwas allocated from
- If the
geometryShader
feature is not enabled,
pipelineStagemust not bePIPELINE_STAGE_GEOMETRY_SHADER_BIT - If the
tessellationShader
feature is not enabled,
pipelineStagemust not bePIPELINE_STAGE_TESSELLATION_CONTROL_SHADER_BITorPIPELINE_STAGE_TESSELLATION_EVALUATION_SHADER_BIT - If the
conditionalRendering
feature is not enabled,
pipelineStagemust not bePIPELINE_STAGE_CONDITIONAL_RENDERING_BIT_EXT - If the
fragmentDensityMap
feature is not enabled,
pipelineStagemust not bePIPELINE_STAGE_FRAGMENT_DENSITY_PROCESS_BIT_EXT - If the
transformFeedback
feature is not enabled,
pipelineStagemust not bePIPELINE_STAGE_TRANSFORM_FEEDBACK_BIT_EXT - If the
meshShader
feature is not enabled,
pipelineStagemust not bePIPELINE_STAGE_MESH_SHADER_BIT_EXT - If the
taskShader
feature is not enabled,
pipelineStagemust not bePIPELINE_STAGE_TASK_SHADER_BIT_EXT - If neither
of the
shadingRateImage
or the
attachmentFragmentShadingRate
features are enabled,
pipelineStagemust not bePIPELINE_STAGE_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHR - If the
synchronization2
feature is not enabled,
pipelineStagemust not bePIPELINE_STAGE_NONE - If neither
of the
VK_NV_ray_tracing
extension or the
rayTracingPipeline
feature are enabled,
pipelineStagemust not bePIPELINE_STAGE_RAY_TRACING_SHADER_BIT_KHR -
dstOffsetmust be less than or equal to the size ofdstBufferminus4 -
dstBuffermust have been created with theBUFFER_USAGE_TRANSFER_DST_BITusage flag set - If
dstBufferis non-sparse then it must be bound completely and contiguously to a singleDeviceMemoryobject -
dstOffsetmust be a multiple of4
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
- If
pipelineStageis not0,pipelineStagemust be a validPipelineStageFlagBitsvalue -
dstBuffermust be a validBufferhandle -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_COMPUTE_BIT,QUEUE_GRAPHICS_BIT, orQUEUE_TRANSFER_BIToperations - This command must not be called between suspended render pass instances
- This command must only be called outside of a video coding scope
- Both of
commandBuffer, anddstBuffermust have been created, allocated, or retrieved from the sameDevice
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_COMPUTE_BIT VK_QUEUE_GRAPHICS_BIT VK_QUEUE_TRANSFER_BIT | Action |
Conditional Rendering
vkCmdWriteBufferMarkerAMD is not affected by conditional rendering
See Also
VK_AMD_buffer_marker,
Buffer, CommandBuffer,
DeviceSize,
PipelineStageFlagBits
cmdWriteBufferMarker2AMD Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> PipelineStageFlags2 |
|
| -> ("dstBuffer" ::: Buffer) |
|
| -> ("dstOffset" ::: DeviceSize) |
|
| -> ("marker" ::: Word32) |
|
| -> io () |
vkCmdWriteBufferMarker2AMD - Execute a pipelined write of a marker value into a buffer
Description
When cmdWriteBufferMarker2AMD is submitted to a queue, it defines an
execution dependency between prior operations and writing the marker
value, as well as a memory dependency from earlier
buffer marker write commands.
The first
synchronization scope
includes operations performed by operations that occur earlier in
submission order
in the pipeline stage identified by pipelineStage. It additionally
includes other
buffer marker write commands
that occur earlier in
submission order
that specified either the same pipelineStage or a stage that is
logically earlier.
The second synchronization scope includes only the buffer marker write.
The first access scope includes only accesses performed by other buffer marker write commands.
The second access scope is empty.
The access scope for buffer marker writes falls under the
ACCESS_TRANSFER_WRITE_BIT flag, and
is performed by either pipelineStage or
PIPELINE_STAGE_TRANSFER_BIT.
Synchronization commands
should specify this access flag and both pipeline stages when defining
dependencies with this command.
Similar to
cmdWriteTimestamp2,
if an implementation is unable to write a marker at any specific
pipeline stage, it may instead do so at any logically later stage.
Implementations may only support a limited number of pipelined marker write operations in flight at a given time. Thus an excessive number of marker write operations may degrade command execution performance.
Valid Usage
- If the
geometryShader
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_GEOMETRY_SHADER_BIT
- If the
tessellationShader
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_TESSELLATION_CONTROL_SHADER_BITorPIPELINE_STAGE_2_TESSELLATION_EVALUATION_SHADER_BIT - If the
conditionalRendering
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_CONDITIONAL_RENDERING_BIT_EXT - If the
fragmentDensityMap
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_FRAGMENT_DENSITY_PROCESS_BIT_EXT - If the
transformFeedback
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_TRANSFORM_FEEDBACK_BIT_EXT - If the
meshShader
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_MESH_SHADER_BIT_EXT - If the
taskShader
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_TASK_SHADER_BIT_EXT - If neither of the
shadingRateImage
or the
attachmentFragmentShadingRate
features are enabled,
stagemust not containPIPELINE_STAGE_2_FRAGMENT_SHADING_RATE_ATTACHMENT_BIT_KHR - If the
subpassShading
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_SUBPASS_SHADER_BIT_HUAWEI - If the
invocationMask
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_INVOCATION_MASK_BIT_HUAWEI - If neither the
VK_NV_ray_tracing
extension or the
rayTracingPipeline
feature are enabled,
stagemust not containPIPELINE_STAGE_2_RAY_TRACING_SHADER_BIT_KHR - If the
accelerationStructure
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_ACCELERATION_STRUCTURE_BUILD_BIT_KHR - If the
rayTracingMaintenance1
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_ACCELERATION_STRUCTURE_COPY_BIT_KHR - If the
micromap
feature is not enabled,
stagemust not containPIPELINE_STAGE_2_MICROMAP_BUILD_BIT_EXT - The synchronization2 feature must be enabled
-
stagemust include only a single pipeline stage -
stagemust include only stages that are valid for the queue family that was used to create the command pool thatcommandBufferwas allocated from -
dstOffsetmust be less than or equal to the size ofdstBufferminus4 -
dstBuffermust have been created with theBUFFER_USAGE_TRANSFER_DST_BITusage flag set - If
dstBufferis non-sparse then it must be bound completely and contiguously to a singleDeviceMemoryobject -
dstOffsetmust be a multiple of4
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
stagemust be a valid combination ofPipelineStageFlagBits2values -
dstBuffermust be a validBufferhandle -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_COMPUTE_BIT,QUEUE_GRAPHICS_BIT, orQUEUE_TRANSFER_BIToperations - This command must not be called between suspended render pass instances
- This command must only be called outside of a video coding scope
- Both of
commandBuffer, anddstBuffermust have been created, allocated, or retrieved from the sameDevice
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_COMPUTE_BIT VK_QUEUE_GRAPHICS_BIT VK_QUEUE_TRANSFER_BIT | Action |
Conditional Rendering
vkCmdWriteBufferMarker2AMD is not affected by conditional rendering
See Also
VK_AMD_buffer_marker,
VK_KHR_synchronization2,
VK_VERSION_1_3,
Buffer, CommandBuffer,
DeviceSize,
PipelineStageFlags2
type AMD_BUFFER_MARKER_SPEC_VERSION = 1 Source #
pattern AMD_BUFFER_MARKER_SPEC_VERSION :: Integral a => a Source #
type AMD_BUFFER_MARKER_EXTENSION_NAME = "VK_AMD_buffer_marker" Source #
pattern AMD_BUFFER_MARKER_EXTENSION_NAME :: (Eq a, IsString a) => a Source #