vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

Description

Name

VK_AMD_memory_overallocation_behavior - device extension

VK_AMD_memory_overallocation_behavior

Name String
VK_AMD_memory_overallocation_behavior
Extension Type
Device extension
Registered Extension Number
190
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies
None
Contact

Other Extension Metadata

Last Modified Date
2018-09-19
IP Status
No known IP claims.
Contributors
  • Martin Dinkov, AMD
  • Matthaeus Chajdas, AMD
  • Daniel Rakos, AMD
  • Jon Campbell, AMD

Description

This extension allows controlling whether explicit overallocation beyond the device memory heap sizes (reported by PhysicalDeviceMemoryProperties) is allowed or not. Overallocation may lead to performance loss and is not supported for all platforms.

New Structures

New Enums

New Enum Constants

Version History

  • Revision 1, 2018-09-19 (Martin Dinkov)

    • Initial draft.

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data DeviceMemoryOverallocationCreateInfoAMD Source #

VkDeviceMemoryOverallocationCreateInfoAMD - Specify memory overallocation behavior for a Vulkan device

Valid Usage (Implicit)

See Also

VK_AMD_memory_overallocation_behavior, MemoryOverallocationBehaviorAMD, StructureType

Constructors

DeviceMemoryOverallocationCreateInfoAMD 

Fields

Instances

Instances details
Eq DeviceMemoryOverallocationCreateInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

Storable DeviceMemoryOverallocationCreateInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

Show DeviceMemoryOverallocationCreateInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

FromCStruct DeviceMemoryOverallocationCreateInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

ToCStruct DeviceMemoryOverallocationCreateInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

Zero DeviceMemoryOverallocationCreateInfoAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

newtype MemoryOverallocationBehaviorAMD Source #

VkMemoryOverallocationBehaviorAMD - Specify memory overallocation behavior

Description

See Also

VK_AMD_memory_overallocation_behavior, DeviceMemoryOverallocationCreateInfoAMD

Instances

Instances details
Eq MemoryOverallocationBehaviorAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

Ord MemoryOverallocationBehaviorAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

Storable MemoryOverallocationBehaviorAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

Read MemoryOverallocationBehaviorAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

Show MemoryOverallocationBehaviorAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

Zero MemoryOverallocationBehaviorAMD Source # 
Instance details

Defined in Vulkan.Extensions.VK_AMD_memory_overallocation_behavior

type AMD_MEMORY_OVERALLOCATION_BEHAVIOR_EXTENSION_NAME = "VK_AMD_memory_overallocation_behavior" Source #