| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_AMD_memory_overallocation_behavior
Description
Name
VK_AMD_memory_overallocation_behavior - device extension
VK_AMD_memory_overallocation_behavior
- Name String
VK_AMD_memory_overallocation_behavior
- Extension Type
- Device extension
- Registered Extension Number
- 190
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- None
- Contact
Other Extension Metadata
- Last Modified Date
- 2018-09-19
- IP Status
- No known IP claims.
- Contributors
- Martin Dinkov, AMD
- Matthaeus Chajdas, AMD
- Daniel Rakos, AMD
- Jon Campbell, AMD
Description
This extension allows controlling whether explicit overallocation beyond
the device memory heap sizes (reported by
PhysicalDeviceMemoryProperties) is
allowed or not. Overallocation may lead to performance loss and is not
supported for all platforms.
New Structures
New Enums
New Enum Constants
Version History
Revision 1, 2018-09-19 (Martin Dinkov)
- Initial draft.
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data DeviceMemoryOverallocationCreateInfoAMD = DeviceMemoryOverallocationCreateInfoAMD {}
- newtype MemoryOverallocationBehaviorAMD where
- type AMD_MEMORY_OVERALLOCATION_BEHAVIOR_SPEC_VERSION = 1
- pattern AMD_MEMORY_OVERALLOCATION_BEHAVIOR_SPEC_VERSION :: Integral a => a
- type AMD_MEMORY_OVERALLOCATION_BEHAVIOR_EXTENSION_NAME = "VK_AMD_memory_overallocation_behavior"
- pattern AMD_MEMORY_OVERALLOCATION_BEHAVIOR_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data DeviceMemoryOverallocationCreateInfoAMD Source #
VkDeviceMemoryOverallocationCreateInfoAMD - Specify memory overallocation behavior for a Vulkan device
Valid Usage (Implicit)
See Also
VK_AMD_memory_overallocation_behavior,
MemoryOverallocationBehaviorAMD,
StructureType
Constructors
| DeviceMemoryOverallocationCreateInfoAMD | |
Fields
| |
Instances
newtype MemoryOverallocationBehaviorAMD Source #
VkMemoryOverallocationBehaviorAMD - Specify memory overallocation behavior
Description
MEMORY_OVERALLOCATION_BEHAVIOR_DEFAULT_AMDlets the implementation decide if overallocation is allowed.
MEMORY_OVERALLOCATION_BEHAVIOR_ALLOWED_AMDspecifies overallocation is allowed if platform permits.MEMORY_OVERALLOCATION_BEHAVIOR_DISALLOWED_AMDspecifies the application is not allowed to allocate device memory beyond the heap sizes reported byPhysicalDeviceMemoryProperties. Allocations that are not explicitly made by the application within the scope of the Vulkan instance are not accounted for.
See Also
VK_AMD_memory_overallocation_behavior,
DeviceMemoryOverallocationCreateInfoAMD
Constructors
| MemoryOverallocationBehaviorAMD Int32 |
Bundled Patterns
Instances
pattern AMD_MEMORY_OVERALLOCATION_BEHAVIOR_SPEC_VERSION :: Integral a => a Source #
type AMD_MEMORY_OVERALLOCATION_BEHAVIOR_EXTENSION_NAME = "VK_AMD_memory_overallocation_behavior" Source #
pattern AMD_MEMORY_OVERALLOCATION_BEHAVIOR_EXTENSION_NAME :: (Eq a, IsString a) => a Source #