| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_AMD_mixed_attachment_samples
Description
Name
VK_AMD_mixed_attachment_samples - device extension
VK_AMD_mixed_attachment_samples
- Name String
VK_AMD_mixed_attachment_samples
- Extension Type
- Device extension
- Registered Extension Number
- 137
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- None
- API Interactions
- Interacts with VK_VERSION_1_3
- Interacts with VK_KHR_dynamic_rendering
- Contact
Other Extension Metadata
- Last Modified Date
- 2017-07-24
- Contributors
- Mais Alnasser, AMD
- Matthaeus G. Chajdas, AMD
- Maciej Jesionowski, AMD
- Daniel Rakos, AMD
Description
This extension enables applications to use multisampled rendering with a depth/stencil sample count that is larger than the color sample count. Having a depth/stencil sample count larger than the color sample count allows maintaining geometry and coverage information at a higher sample rate than color information. All samples are depth/stencil tested, but only the first color sample count number of samples get a corresponding color output.
New Structures
If Vulkan Version 1.3 or VK_KHR_dynamic_rendering is supported:
New Enum Constants
If Vulkan Version 1.3 or VK_KHR_dynamic_rendering is supported:
Issues
None.
Version History
Revision 1, 2017-07-24 (Daniel Rakos)
- Internal revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data AttachmentSampleCountInfoAMD = AttachmentSampleCountInfoAMD {}
- type AMD_MIXED_ATTACHMENT_SAMPLES_SPEC_VERSION = 1
- pattern AMD_MIXED_ATTACHMENT_SAMPLES_SPEC_VERSION :: Integral a => a
- type AMD_MIXED_ATTACHMENT_SAMPLES_EXTENSION_NAME = "VK_AMD_mixed_attachment_samples"
- pattern AMD_MIXED_ATTACHMENT_SAMPLES_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data AttachmentSampleCountInfoAMD Source #
VkAttachmentSampleCountInfoAMD - Structure specifying command buffer inheritance info for dynamic render pass instances
Description
If
CommandBufferInheritanceInfo::renderPass
is NULL_HANDLE,
COMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BIT
is specified in
CommandBufferBeginInfo::flags, and the
pNext chain of
CommandBufferInheritanceInfo includes
AttachmentSampleCountInfoAMD, then this structure defines the sample
counts of each attachment within the render pass instance. If
AttachmentSampleCountInfoAMD is not included, the value of
CommandBufferInheritanceRenderingInfo::rasterizationSamples
is used as the sample count for each attachment. If
CommandBufferInheritanceInfo::renderPass
is not NULL_HANDLE, or
COMMAND_BUFFER_USAGE_RENDER_PASS_CONTINUE_BIT
is not specified in
CommandBufferBeginInfo::flags,
parameters of this structure are ignored.
AttachmentSampleCountInfoAMD can also be included in the pNext
chain of GraphicsPipelineCreateInfo.
When a graphics pipeline is created without a
RenderPass, if this structure is included in the
pNext chain of
GraphicsPipelineCreateInfo, it
specifies the sample count of attachments used for rendering. If this
structure is not specified, and the pipeline does not include a
RenderPass, the value of
PipelineMultisampleStateCreateInfo::rasterizationSamples
is used as the sample count for each attachment. If a graphics pipeline
is created with a valid RenderPass, parameters
of this structure are ignored.
Valid Usage (Implicit)
See Also
VK_AMD_mixed_attachment_samples,
VK_KHR_dynamic_rendering,
VK_NV_framebuffer_mixed_samples,
VK_VERSION_1_3,
SampleCountFlagBits,
StructureType
Constructors
| AttachmentSampleCountInfoAMD | |
Fields
| |
Instances
| Show AttachmentSampleCountInfoAMD Source # | |
Defined in Vulkan.Extensions.VK_AMD_mixed_attachment_samples Methods showsPrec :: Int -> AttachmentSampleCountInfoAMD -> ShowS # show :: AttachmentSampleCountInfoAMD -> String # showList :: [AttachmentSampleCountInfoAMD] -> ShowS # | |
| FromCStruct AttachmentSampleCountInfoAMD Source # | |
| ToCStruct AttachmentSampleCountInfoAMD Source # | |
Defined in Vulkan.Extensions.VK_AMD_mixed_attachment_samples Methods withCStruct :: AttachmentSampleCountInfoAMD -> (Ptr AttachmentSampleCountInfoAMD -> IO b) -> IO b Source # pokeCStruct :: Ptr AttachmentSampleCountInfoAMD -> AttachmentSampleCountInfoAMD -> IO b -> IO b Source # withZeroCStruct :: (Ptr AttachmentSampleCountInfoAMD -> IO b) -> IO b Source # pokeZeroCStruct :: Ptr AttachmentSampleCountInfoAMD -> IO b -> IO b Source # cStructSize :: Int Source # | |
| Zero AttachmentSampleCountInfoAMD Source # | |
Defined in Vulkan.Extensions.VK_AMD_mixed_attachment_samples Methods | |
pattern AMD_MIXED_ATTACHMENT_SAMPLES_SPEC_VERSION :: Integral a => a Source #
type AMD_MIXED_ATTACHMENT_SAMPLES_EXTENSION_NAME = "VK_AMD_mixed_attachment_samples" Source #
pattern AMD_MIXED_ATTACHMENT_SAMPLES_EXTENSION_NAME :: (Eq a, IsString a) => a Source #