| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_AMD_shader_early_and_late_fragment_tests
Description
Name
VK_AMD_shader_early_and_late_fragment_tests - device extension
VK_AMD_shader_early_and_late_fragment_tests
- Name String
VK_AMD_shader_early_and_late_fragment_tests
- Extension Type
- Device extension
- Registered Extension Number
- 322
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- SPIR-V Dependencies
- Contact
- Extension Proposal
- VK_AMD_shader_early_and_late_fragment_tests
Other Extension Metadata
- Last Modified Date
- 2021-09-14
- Interactions and External Dependencies
- This extension interacts with
VK_EXT_shader_stencil_export
- This extension interacts with
- Contributors
- Tobias Hector, AMD
Description
This extension adds support for the
SPV_AMD_shader_early_and_late_fragment_tests
extension, allowing shaders to explicitly opt in to allowing both early
and late fragment tests with the EarlyAndLateFragmentTestsAMD
execution mode.
If the VK_EXT_shader_stencil_export extension is supported, additional
execution modes allowing early depth tests similar to DepthUnchanged,
DepthLess, and DepthGreater are provided.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
Version History
Revision 1, 2021-09-14 (Tobias Hector)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderEarlyAndLateFragmentTestsFeaturesAMD = PhysicalDeviceShaderEarlyAndLateFragmentTestsFeaturesAMD {}
- type AMD_SHADER_EARLY_AND_LATE_FRAGMENT_TESTS_SPEC_VERSION = 1
- pattern AMD_SHADER_EARLY_AND_LATE_FRAGMENT_TESTS_SPEC_VERSION :: Integral a => a
- type AMD_SHADER_EARLY_AND_LATE_FRAGMENT_TESTS_EXTENSION_NAME = "VK_AMD_shader_early_and_late_fragment_tests"
- pattern AMD_SHADER_EARLY_AND_LATE_FRAGMENT_TESTS_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderEarlyAndLateFragmentTestsFeaturesAMD Source #
VkPhysicalDeviceShaderEarlyAndLateFragmentTestsFeaturesAMD - Structure describing whether early and late fragment tests can be supported by an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceShaderEarlyAndLateFragmentTestsFeaturesAMD
structure is included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceShaderEarlyAndLateFragmentTestsFeaturesAMD, it must
add an instance of the structure, with the desired feature members set
to TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
VK_AMD_shader_early_and_late_fragment_tests,
Bool32,
StructureType
Constructors
| PhysicalDeviceShaderEarlyAndLateFragmentTestsFeaturesAMD | |
Fields | |
Instances
pattern AMD_SHADER_EARLY_AND_LATE_FRAGMENT_TESTS_SPEC_VERSION :: Integral a => a Source #
type AMD_SHADER_EARLY_AND_LATE_FRAGMENT_TESTS_EXTENSION_NAME = "VK_AMD_shader_early_and_late_fragment_tests" Source #
pattern AMD_SHADER_EARLY_AND_LATE_FRAGMENT_TESTS_EXTENSION_NAME :: (Eq a, IsString a) => a Source #