vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_ARM_render_pass_striped

Description

Name

VK_ARM_render_pass_striped - device extension

VK_ARM_render_pass_striped

Name String
VK_ARM_render_pass_striped
Extension Type
Device extension
Registered Extension Number
425
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies

VK_KHR_get_physical_device_properties2          or

Vulkan Version 1.1      and

VK_KHR_synchronization2 or Vulkan Version 1.3

Contact
Extension Proposal
VK_ARM_render_pass_striped

Other Extension Metadata

Last Modified Date
2023-11-21
IP Status
No known IP claims.
Contributors
  • Jan-Harald Fredriksen, Arm
  • Lisa Wu, Arm
  • Torbjorn Nilsson, Arm
  • Ying-Chieh Chen, Mediatek
  • Jim Chiu, Mediatek

Description

This extension adds the ability to split a render pass instance into stripes, and to get a notification when rendering has completed for each stripe.

New Structures

New Enum Constants

Examples

None.

Version History

  • Revision 1, 2023-11-21

    • Initial revision

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceRenderPassStripedFeaturesARM Source #

VkPhysicalDeviceRenderPassStripedFeaturesARM - Structure describing whether striped rendering can be supported by an implementation

Members

The members of the PhysicalDeviceRenderPassStripedFeaturesARM structure describe the following features:

Description

If the PhysicalDeviceRenderPassStripedFeaturesARM structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceRenderPassStripedFeaturesARM, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_ARM_render_pass_striped, Bool32, StructureType

Constructors

PhysicalDeviceRenderPassStripedFeaturesARM 

Fields

  • renderPassStriped :: Bool

    renderPassStriped indicates that striped rendering is supported by the implementation.

Instances

Instances details
Eq PhysicalDeviceRenderPassStripedFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

Storable PhysicalDeviceRenderPassStripedFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

Show PhysicalDeviceRenderPassStripedFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

FromCStruct PhysicalDeviceRenderPassStripedFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

ToCStruct PhysicalDeviceRenderPassStripedFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

Zero PhysicalDeviceRenderPassStripedFeaturesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

data PhysicalDeviceRenderPassStripedPropertiesARM Source #

VkPhysicalDeviceRenderPassStripedPropertiesARM - Structure describing striped rendering limits of an implementation

Members

The members of the PhysicalDeviceRenderPassStripedPropertiesARM structure describe the following limits:

Description

If the PhysicalDeviceRenderPassStripedPropertiesARM structure is included in the pNext chain of the PhysicalDeviceProperties2 structure passed to getPhysicalDeviceProperties2, it is filled in with each corresponding implementation-dependent property.

Valid Usage (Implicit)

See Also

VK_ARM_render_pass_striped, Extent2D, StructureType

Constructors

PhysicalDeviceRenderPassStripedPropertiesARM 

Fields

Instances

Instances details
Storable PhysicalDeviceRenderPassStripedPropertiesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

Show PhysicalDeviceRenderPassStripedPropertiesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

FromCStruct PhysicalDeviceRenderPassStripedPropertiesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

ToCStruct PhysicalDeviceRenderPassStripedPropertiesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

Zero PhysicalDeviceRenderPassStripedPropertiesARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

data RenderPassStripeInfoARM Source #

VkRenderPassStripeInfoARM - Structure specifying per rendering stripe information

Description

stripeArea is the render area that is affected by this stripe of the render pass instance. It must be a subregion of the renderArea of the render pass instance.

Valid Usage (Implicit)

See Also

VK_ARM_render_pass_striped, Rect2D, RenderPassStripeBeginInfoARM, StructureType

Constructors

RenderPassStripeInfoARM 

Fields

  • stripeArea :: Rect2D

    stripeArea is the stripe area, and is described in more detail below.

Instances

Instances details
Storable RenderPassStripeInfoARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

Show RenderPassStripeInfoARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

FromCStruct RenderPassStripeInfoARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

ToCStruct RenderPassStripeInfoARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

Zero RenderPassStripeInfoARM Source # 
Instance details

Defined in Vulkan.Extensions.VK_ARM_render_pass_striped

data RenderPassStripeBeginInfoARM Source #

VkRenderPassStripeBeginInfoARM - Structure specifying striped rendering information

Description

This structure can be included in the pNext chain of RenderPassBeginInfo or RenderingInfo to define how the render pass instance is split into stripes.

Valid Usage

  • The stripeArea defined by each element of pStripeInfos must not overlap the stripeArea of any other element

Valid Usage (Implicit)

  • pStripeInfos must be a valid pointer to an array of stripeInfoCount valid RenderPassStripeInfoARM structures
  • stripeInfoCount must be greater than 0

See Also

VK_ARM_render_pass_striped, RenderPassStripeInfoARM, StructureType

Constructors

RenderPassStripeBeginInfoARM 

Fields

data RenderPassStripeSubmitInfoARM Source #

VkRenderPassStripeSubmitInfoARM - Structure specifying striped rendering submit information

Description

This structure can be included in the pNext chain of CommandBufferSubmitInfo to provide a set of semaphores to be signaled for each striped render pass instance.

The elements of pStripeSemaphoreInfos are mapped to render pass instances in CommandBufferSubmitInfo::commandBuffer in submission order and in stripe order within each render pass instance. Each semaphore in pStripeSemaphoreInfos is signaled when the implementation has completed execution of the associated stripe. In a render pass instance that has multiview enabled, the stripe includes all views in the view mask. In a render pass instance with layerCount greater than 1, the stripe includes all layers.

Render pass instances that specify the RENDERING_RESUMING_BIT will not have any elements of pStripeSemaphoreInfos mapped to them. Instead, for suspending and resuming render pass instances, this mapping is done for the first suspending render pass instance, and the per-stripe semaphores are only signaled for the last resuming render pass instance.

Valid Usage

Valid Usage (Implicit)

  • pStripeSemaphoreInfos must be a valid pointer to an array of stripeSemaphoreInfoCount valid SemaphoreSubmitInfo structures
  • stripeSemaphoreInfoCount must be greater than 0

See Also

VK_ARM_render_pass_striped, SemaphoreSubmitInfo, StructureType

Constructors

RenderPassStripeSubmitInfoARM 

Fields

type ARM_RENDER_PASS_STRIPED_EXTENSION_NAME = "VK_ARM_render_pass_striped" Source #