| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_ARM_render_pass_striped
Description
Name
VK_ARM_render_pass_striped - device extension
VK_ARM_render_pass_striped
- Name String
VK_ARM_render_pass_striped
- Extension Type
- Device extension
- Registered Extension Number
- 425
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or
VK_KHR_synchronization2 or Vulkan Version 1.3
- Contact
- Extension Proposal
- VK_ARM_render_pass_striped
Other Extension Metadata
- Last Modified Date
- 2023-11-21
- IP Status
- No known IP claims.
- Contributors
- Jan-Harald Fredriksen, Arm
- Lisa Wu, Arm
- Torbjorn Nilsson, Arm
- Ying-Chieh Chen, Mediatek
- Jim Chiu, Mediatek
Description
This extension adds the ability to split a render pass instance into stripes, and to get a notification when rendering has completed for each stripe.
New Structures
Extending
CommandBufferSubmitInfo:Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:Extending
PhysicalDeviceProperties2:Extending
RenderingInfo,RenderPassBeginInfo:
New Enum Constants
Examples
None.
Version History
Revision 1, 2023-11-21
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceRenderPassStripedFeaturesARM = PhysicalDeviceRenderPassStripedFeaturesARM {}
- data PhysicalDeviceRenderPassStripedPropertiesARM = PhysicalDeviceRenderPassStripedPropertiesARM {}
- data RenderPassStripeInfoARM = RenderPassStripeInfoARM {
- stripeArea :: Rect2D
- data RenderPassStripeBeginInfoARM = RenderPassStripeBeginInfoARM {}
- data RenderPassStripeSubmitInfoARM = RenderPassStripeSubmitInfoARM {}
- type ARM_RENDER_PASS_STRIPED_SPEC_VERSION = 1
- pattern ARM_RENDER_PASS_STRIPED_SPEC_VERSION :: Integral a => a
- type ARM_RENDER_PASS_STRIPED_EXTENSION_NAME = "VK_ARM_render_pass_striped"
- pattern ARM_RENDER_PASS_STRIPED_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceRenderPassStripedFeaturesARM Source #
VkPhysicalDeviceRenderPassStripedFeaturesARM - Structure describing whether striped rendering can be supported by an implementation
Members
The members of the PhysicalDeviceRenderPassStripedFeaturesARM
structure describe the following features:
Description
If the PhysicalDeviceRenderPassStripedFeaturesARM structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceRenderPassStripedFeaturesARM, it must add an instance
of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceRenderPassStripedFeaturesARM | |
Fields | |
Instances
data PhysicalDeviceRenderPassStripedPropertiesARM Source #
VkPhysicalDeviceRenderPassStripedPropertiesARM - Structure describing striped rendering limits of an implementation
Members
The members of the PhysicalDeviceRenderPassStripedPropertiesARM
structure describe the following limits:
Description
If the PhysicalDeviceRenderPassStripedPropertiesARM structure is
included in the pNext chain of the
PhysicalDeviceProperties2
structure passed to
getPhysicalDeviceProperties2,
it is filled in with each corresponding implementation-dependent
property.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceRenderPassStripedPropertiesARM | |
Fields | |
Instances
data RenderPassStripeInfoARM Source #
VkRenderPassStripeInfoARM - Structure specifying per rendering stripe information
Description
stripeArea is the render area that is affected by this stripe of the
render pass instance. It must be a subregion of the renderArea of
the render pass instance.
Valid Usage (Implicit)
See Also
VK_ARM_render_pass_striped,
Rect2D, RenderPassStripeBeginInfoARM,
StructureType
Constructors
| RenderPassStripeInfoARM | |
Fields
| |
Instances
data RenderPassStripeBeginInfoARM Source #
VkRenderPassStripeBeginInfoARM - Structure specifying striped rendering information
Description
This structure can be included in the pNext chain of
RenderPassBeginInfo or
RenderingInfo to
define how the render pass instance is split into stripes.
Valid Usage
-
stripeInfoCountmust be less than or equal toPhysicalDeviceRenderPassStripedPropertiesARM::maxRenderPassStripes
- The
stripeAreadefined by each element ofpStripeInfosmust not overlap thestripeAreaof any other element
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_RENDER_PASS_STRIPE_BEGIN_INFO_ARM
-
pStripeInfosmust be a valid pointer to an array ofstripeInfoCountvalidRenderPassStripeInfoARMstructures -
stripeInfoCountmust be greater than0
See Also
VK_ARM_render_pass_striped,
RenderPassStripeInfoARM,
StructureType
Constructors
| RenderPassStripeBeginInfoARM | |
Fields
| |
Instances
| Show RenderPassStripeBeginInfoARM Source # | |
Defined in Vulkan.Extensions.VK_ARM_render_pass_striped Methods showsPrec :: Int -> RenderPassStripeBeginInfoARM -> ShowS # show :: RenderPassStripeBeginInfoARM -> String # showList :: [RenderPassStripeBeginInfoARM] -> ShowS # | |
| FromCStruct RenderPassStripeBeginInfoARM Source # | |
Defined in Vulkan.Extensions.VK_ARM_render_pass_striped | |
| ToCStruct RenderPassStripeBeginInfoARM Source # | |
Defined in Vulkan.Extensions.VK_ARM_render_pass_striped Methods withCStruct :: RenderPassStripeBeginInfoARM -> (Ptr RenderPassStripeBeginInfoARM -> IO b) -> IO b Source # pokeCStruct :: Ptr RenderPassStripeBeginInfoARM -> RenderPassStripeBeginInfoARM -> IO b -> IO b Source # withZeroCStruct :: (Ptr RenderPassStripeBeginInfoARM -> IO b) -> IO b Source # pokeZeroCStruct :: Ptr RenderPassStripeBeginInfoARM -> IO b -> IO b Source # cStructSize :: Int Source # | |
| Zero RenderPassStripeBeginInfoARM Source # | |
Defined in Vulkan.Extensions.VK_ARM_render_pass_striped Methods | |
data RenderPassStripeSubmitInfoARM Source #
VkRenderPassStripeSubmitInfoARM - Structure specifying striped rendering submit information
Description
This structure can be included in the pNext chain of
CommandBufferSubmitInfo
to provide a set of semaphores to be signaled for each striped render
pass instance.
The elements of pStripeSemaphoreInfos are mapped to render pass
instances in
CommandBufferSubmitInfo::commandBuffer
in submission order and in stripe order within each render pass
instance. Each semaphore in pStripeSemaphoreInfos is signaled when the
implementation has completed execution of the associated stripe. In a
render pass instance that has multiview enabled, the stripe includes all
views in the view mask. In a render pass instance with layerCount
greater than 1, the stripe includes all layers.
Render pass instances that specify the
RENDERING_RESUMING_BIT will not
have any elements of pStripeSemaphoreInfos mapped to them. Instead,
for suspending and resuming render pass instances, this mapping is done
for the first suspending render pass instance, and the per-stripe
semaphores are only signaled for the last resuming render pass instance.
Valid Usage
- The
semaphoremember of each element ofpStripeSemaphoreInfosmust have been created with aSemaphoreTypeofSEMAPHORE_TYPE_BINARY
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_RENDER_PASS_STRIPE_SUBMIT_INFO_ARM
-
pStripeSemaphoreInfosmust be a valid pointer to an array ofstripeSemaphoreInfoCountvalidSemaphoreSubmitInfostructures -
stripeSemaphoreInfoCountmust be greater than0
See Also
VK_ARM_render_pass_striped,
SemaphoreSubmitInfo,
StructureType
Constructors
| RenderPassStripeSubmitInfoARM | |
Fields
| |
Instances
| Show RenderPassStripeSubmitInfoARM Source # | |
Defined in Vulkan.Extensions.VK_ARM_render_pass_striped Methods showsPrec :: Int -> RenderPassStripeSubmitInfoARM -> ShowS # show :: RenderPassStripeSubmitInfoARM -> String # showList :: [RenderPassStripeSubmitInfoARM] -> ShowS # | |
| FromCStruct RenderPassStripeSubmitInfoARM Source # | |
| ToCStruct RenderPassStripeSubmitInfoARM Source # | |
Defined in Vulkan.Extensions.VK_ARM_render_pass_striped Methods withCStruct :: RenderPassStripeSubmitInfoARM -> (Ptr RenderPassStripeSubmitInfoARM -> IO b) -> IO b Source # pokeCStruct :: Ptr RenderPassStripeSubmitInfoARM -> RenderPassStripeSubmitInfoARM -> IO b -> IO b Source # withZeroCStruct :: (Ptr RenderPassStripeSubmitInfoARM -> IO b) -> IO b Source # pokeZeroCStruct :: Ptr RenderPassStripeSubmitInfoARM -> IO b -> IO b Source # cStructSize :: Int Source # | |
| Zero RenderPassStripeSubmitInfoARM Source # | |
Defined in Vulkan.Extensions.VK_ARM_render_pass_striped Methods | |
type ARM_RENDER_PASS_STRIPED_SPEC_VERSION = 1 Source #
pattern ARM_RENDER_PASS_STRIPED_SPEC_VERSION :: Integral a => a Source #
type ARM_RENDER_PASS_STRIPED_EXTENSION_NAME = "VK_ARM_render_pass_striped" Source #
pattern ARM_RENDER_PASS_STRIPED_EXTENSION_NAME :: (Eq a, IsString a) => a Source #