| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_attachment_feedback_loop_dynamic_state
Description
Name
VK_EXT_attachment_feedback_loop_dynamic_state - device extension
VK_EXT_attachment_feedback_loop_dynamic_state
- Name String
VK_EXT_attachment_feedback_loop_dynamic_state
- Extension Type
- Device extension
- Registered Extension Number
- 525
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or
Vulkan Version 1.1 and VK_EXT_attachment_feedback_loop_layout
- Special Uses
- Contact
- Extension Proposal
- VK_EXT_attachment_feedback_loop_dynamic_state
Other Extension Metadata
- Last Modified Date
- 2023-04-28
- IP Status
- No known IP claims.
- Contributors
- Mike Blumenkrantz, Valve
- Daniel Story, Nintendo
- Stu Smith, AMD
- Samuel Pitoiset, Valve
- Ricardo Garcia, Igalia
Description
This extension adds support for setting attachment feedback loops dynamically on command buffers.
New Commands
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
EXT_ATTACHMENT_FEEDBACK_LOOP_DYNAMIC_STATE_SPEC_VERSIONExtending
DynamicState:Extending
StructureType:
Version History
Revision 1, 2023-04-28 (Mike Blumenkrantz)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- cmdSetAttachmentFeedbackLoopEnableEXT :: MonadIO io => CommandBuffer -> ("aspectMask" ::: ImageAspectFlags) -> io ()
- data PhysicalDeviceAttachmentFeedbackLoopDynamicStateFeaturesEXT = PhysicalDeviceAttachmentFeedbackLoopDynamicStateFeaturesEXT {}
- type EXT_ATTACHMENT_FEEDBACK_LOOP_DYNAMIC_STATE_SPEC_VERSION = 1
- pattern EXT_ATTACHMENT_FEEDBACK_LOOP_DYNAMIC_STATE_SPEC_VERSION :: Integral a => a
- type EXT_ATTACHMENT_FEEDBACK_LOOP_DYNAMIC_STATE_EXTENSION_NAME = "VK_EXT_attachment_feedback_loop_dynamic_state"
- pattern EXT_ATTACHMENT_FEEDBACK_LOOP_DYNAMIC_STATE_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
cmdSetAttachmentFeedbackLoopEnableEXT Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> ("aspectMask" ::: ImageAspectFlags) |
|
| -> io () |
vkCmdSetAttachmentFeedbackLoopEnableEXT - Specify whether attachment feedback loops are enabled dynamically on a command buffer
Description
For attachments that are written to in a render pass, only attachments
with the aspects specified in aspectMask can be accessed as
non-attachments by subsequent
drawing commands.
Valid Usage
- The attachmentFeedbackLoopDynamicState feature must be enabled
-
aspectMaskmust only includeIMAGE_ASPECT_NONE,IMAGE_ASPECT_COLOR_BIT,IMAGE_ASPECT_DEPTH_BIT, andIMAGE_ASPECT_STENCIL_BIT -
If the
attachmentFeedbackLoopLayout
feature is not enabled,
aspectMaskmust beIMAGE_ASPECT_NONE
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
aspectMaskmust be a valid combination ofImageAspectFlagBitsvalues -
commandBuffermust be in the recording state -
The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_GRAPHICS_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_GRAPHICS_BIT | State |
Conditional Rendering
vkCmdSetAttachmentFeedbackLoopEnableEXT is not affected by conditional rendering
See Also
VK_EXT_attachment_feedback_loop_dynamic_state,
CommandBuffer,
ImageAspectFlags
data PhysicalDeviceAttachmentFeedbackLoopDynamicStateFeaturesEXT Source #
VkPhysicalDeviceAttachmentFeedbackLoopDynamicStateFeaturesEXT - Structure describing if dynamic feedback loops can be used
Members
This structure describes the following features:
Description
If the PhysicalDeviceAttachmentFeedbackLoopDynamicStateFeaturesEXT
structure is included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceAttachmentFeedbackLoopDynamicStateFeaturesEXT, it must
add an instance of the structure, with the desired feature members set
to TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
VK_EXT_attachment_feedback_loop_dynamic_state,
Bool32,
StructureType
Constructors
| PhysicalDeviceAttachmentFeedbackLoopDynamicStateFeaturesEXT | |
Fields | |
Instances
pattern EXT_ATTACHMENT_FEEDBACK_LOOP_DYNAMIC_STATE_SPEC_VERSION :: Integral a => a Source #
type EXT_ATTACHMENT_FEEDBACK_LOOP_DYNAMIC_STATE_EXTENSION_NAME = "VK_EXT_attachment_feedback_loop_dynamic_state" Source #
pattern EXT_ATTACHMENT_FEEDBACK_LOOP_DYNAMIC_STATE_EXTENSION_NAME :: (Eq a, IsString a) => a Source #