vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_fragment_density_map

Description

Name

VK_EXT_fragment_density_map - device extension

VK_EXT_fragment_density_map

Name String
VK_EXT_fragment_density_map
Extension Type
Device extension
Registered Extension Number
219
Revision
3
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
API Interactions
  • Interacts with VK_VERSION_1_3
  • Interacts with VK_KHR_dynamic_rendering
  • Interacts with VK_KHR_format_feature_flags2
SPIR-V Dependencies
Contact

Other Extension Metadata

Last Modified Date
2025-05-20
Interactions and External Dependencies
Contributors
  • Matthew Netsch, Qualcomm Technologies, Inc.
  • Robert VanReenen, Qualcomm Technologies, Inc.
  • Jonathan Wicks, Qualcomm Technologies, Inc.
  • Tate Hornbeck, Qualcomm Technologies, Inc.
  • Sam Holmes, Qualcomm Technologies, Inc.
  • Jeff Leger, Qualcomm Technologies, Inc.
  • Jan-Harald Fredriksen, ARM
  • Jeff Bolz, NVIDIA
  • Pat Brown, NVIDIA
  • Daniel Rakos, AMD
  • Piers Daniell, NVIDIA

Description

This extension allows an application to specify areas of the render target where the fragment shader may be invoked fewer times. These fragments are broadcasted out to multiple pixels to cover the render target.

The primary use of this extension is to reduce workloads in areas where lower quality may not be perceived such as the distorted edges of a lens or the periphery of a user’s gaze.

New Structures

If Vulkan Version 1.3 or VK_KHR_dynamic_rendering is supported:

New Enum Constants

If VK_KHR_format_feature_flags2 or Vulkan Version 1.3 is supported:

If Vulkan Version 1.3 or VK_KHR_dynamic_rendering is supported:

New or Modified Built-In Variables

New SPIR-V Capabilities

Version History

  • Revision 1, 2018-09-25 (Matthew Netsch)

    • Initial version
  • Revision 2, 2021-09-30 (Jon Leech)

    • Add interaction with VK_KHR_format_feature_flags2 to vk.xml
  • Revision 3, 2025-05-20 (Matthew Netsch)

    • Fixes fragmentDensityTexelSize calculation equation

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceFragmentDensityMapFeaturesEXT Source #

VkPhysicalDeviceFragmentDensityMapFeaturesEXT - Structure describing fragment density map features that can be supported by an implementation

Members

This structure describes the following features:

Description

If the PhysicalDeviceFragmentDensityMapFeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceFragmentDensityMapFeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_fragment_density_map, Bool32, StructureType

Constructors

PhysicalDeviceFragmentDensityMapFeaturesEXT 

Fields

Instances

Instances details
Eq PhysicalDeviceFragmentDensityMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

Storable PhysicalDeviceFragmentDensityMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

Show PhysicalDeviceFragmentDensityMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

FromCStruct PhysicalDeviceFragmentDensityMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

ToCStruct PhysicalDeviceFragmentDensityMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

Zero PhysicalDeviceFragmentDensityMapFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

data PhysicalDeviceFragmentDensityMapPropertiesEXT Source #

VkPhysicalDeviceFragmentDensityMapPropertiesEXT - Structure describing fragment density map properties that can be supported by an implementation

Description

If the PhysicalDeviceFragmentDensityMapPropertiesEXT structure is included in the pNext chain of the PhysicalDeviceProperties2 structure passed to getPhysicalDeviceProperties2, it is filled in with each corresponding implementation-dependent property.

Valid Usage (Implicit)

See Also

VK_EXT_fragment_density_map, Bool32, Extent2D, StructureType

Constructors

PhysicalDeviceFragmentDensityMapPropertiesEXT 

Fields

Instances

Instances details
Storable PhysicalDeviceFragmentDensityMapPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

Show PhysicalDeviceFragmentDensityMapPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

FromCStruct PhysicalDeviceFragmentDensityMapPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

ToCStruct PhysicalDeviceFragmentDensityMapPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

Zero PhysicalDeviceFragmentDensityMapPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

data RenderPassFragmentDensityMapCreateInfoEXT Source #

VkRenderPassFragmentDensityMapCreateInfoEXT - Structure containing fragment density map attachment for render pass

Description

The fragment density map is read at an implementation-dependent time with the following constraints determined by the attachment’s image view flags:

The fragment density map may additionally be read by the device during PIPELINE_STAGE_FRAGMENT_DENSITY_PROCESS_BIT_EXT for any mode.

If this structure is not present, it is as if fragmentDensityMapAttachment was given as ATTACHMENT_UNUSED.

Valid Usage

Valid Usage (Implicit)

See Also

VK_EXT_fragment_density_map, AttachmentReference, StructureType

Constructors

RenderPassFragmentDensityMapCreateInfoEXT 

Fields

Instances

Instances details
Storable RenderPassFragmentDensityMapCreateInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

Show RenderPassFragmentDensityMapCreateInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

FromCStruct RenderPassFragmentDensityMapCreateInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

ToCStruct RenderPassFragmentDensityMapCreateInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

Zero RenderPassFragmentDensityMapCreateInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

data RenderingFragmentDensityMapAttachmentInfoEXT Source #

VkRenderingFragmentDensityMapAttachmentInfoEXT - Structure specifying fragment shading rate attachment information

Description

This structure can be included in the pNext chain of RenderingInfo to define a fragment density map. If this structure is not included in the pNext chain, imageView is treated as NULL_HANDLE.

Valid Usage

Valid Usage (Implicit)

See Also

VK_EXT_fragment_density_map, VK_KHR_dynamic_rendering, VK_VERSION_1_3, ImageLayout, ImageView, StructureType

Constructors

RenderingFragmentDensityMapAttachmentInfoEXT 

Fields

  • imageView :: ImageView

    imageView is the image view that will be used as a fragment density map attachment.

  • imageLayout :: ImageLayout

    imageLayout is the layout that imageView will be in during rendering.

Instances

Instances details
Eq RenderingFragmentDensityMapAttachmentInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

Storable RenderingFragmentDensityMapAttachmentInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

Show RenderingFragmentDensityMapAttachmentInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

FromCStruct RenderingFragmentDensityMapAttachmentInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

ToCStruct RenderingFragmentDensityMapAttachmentInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

Zero RenderingFragmentDensityMapAttachmentInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map

type EXT_FRAGMENT_DENSITY_MAP_EXTENSION_NAME = "VK_EXT_fragment_density_map" Source #