| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_fragment_density_map
Description
Name
VK_EXT_fragment_density_map - device extension
VK_EXT_fragment_density_map
- Name String
VK_EXT_fragment_density_map
- Extension Type
- Device extension
- Registered Extension Number
- 219
- Revision
- 3
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- API Interactions
- Interacts with VK_VERSION_1_3
- Interacts with VK_KHR_dynamic_rendering
- Interacts with VK_KHR_format_feature_flags2
- SPIR-V Dependencies
- Contact
Other Extension Metadata
- Last Modified Date
- 2025-05-20
- Interactions and External Dependencies
- This extension provides API support for GL_EXT_fragment_invocation_density
- Contributors
- Matthew Netsch, Qualcomm Technologies, Inc.
- Robert VanReenen, Qualcomm Technologies, Inc.
- Jonathan Wicks, Qualcomm Technologies, Inc.
- Tate Hornbeck, Qualcomm Technologies, Inc.
- Sam Holmes, Qualcomm Technologies, Inc.
- Jeff Leger, Qualcomm Technologies, Inc.
- Jan-Harald Fredriksen, ARM
- Jeff Bolz, NVIDIA
- Pat Brown, NVIDIA
- Daniel Rakos, AMD
- Piers Daniell, NVIDIA
Description
This extension allows an application to specify areas of the render target where the fragment shader may be invoked fewer times. These fragments are broadcasted out to multiple pixels to cover the render target.
The primary use of this extension is to reduce workloads in areas where lower quality may not be perceived such as the distorted edges of a lens or the periphery of a user’s gaze.
New Structures
Extending
PhysicalDeviceProperties2:Extending
RenderPassCreateInfo,RenderPassCreateInfo2:
If Vulkan Version 1.3 or VK_KHR_dynamic_rendering is supported:
New Enum Constants
EXT_FRAGMENT_DENSITY_MAP_SPEC_VERSIONExtending
AccessFlagBits:Extending
FormatFeatureFlagBits:Extending
ImageCreateFlagBits:Extending
ImageLayout:Extending
ImageUsageFlagBits:Extending
ImageViewCreateFlagBits:Extending
PipelineStageFlagBits:Extending
SamplerCreateFlagBits:Extending
StructureType:
If VK_KHR_format_feature_flags2 or Vulkan Version 1.3 is supported:
If Vulkan Version 1.3 or VK_KHR_dynamic_rendering is supported:
Extending
PipelineCreateFlagBits:Extending
StructureType:
New or Modified Built-In Variables
New SPIR-V Capabilities
Version History
Revision 1, 2018-09-25 (Matthew Netsch)
- Initial version
Revision 2, 2021-09-30 (Jon Leech)
- Add interaction with
VK_KHR_format_feature_flags2tovk.xml
- Add interaction with
Revision 3, 2025-05-20 (Matthew Netsch)
- Fixes fragmentDensityTexelSize calculation equation
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- pattern PIPELINE_RASTERIZATION_STATE_CREATE_FRAGMENT_DENSITY_MAP_ATTACHMENT_BIT_EXT :: PipelineCreateFlagBits
- data PhysicalDeviceFragmentDensityMapFeaturesEXT = PhysicalDeviceFragmentDensityMapFeaturesEXT {}
- data PhysicalDeviceFragmentDensityMapPropertiesEXT = PhysicalDeviceFragmentDensityMapPropertiesEXT {}
- data RenderPassFragmentDensityMapCreateInfoEXT = RenderPassFragmentDensityMapCreateInfoEXT {}
- data RenderingFragmentDensityMapAttachmentInfoEXT = RenderingFragmentDensityMapAttachmentInfoEXT {}
- type EXT_FRAGMENT_DENSITY_MAP_SPEC_VERSION = 3
- pattern EXT_FRAGMENT_DENSITY_MAP_SPEC_VERSION :: Integral a => a
- type EXT_FRAGMENT_DENSITY_MAP_EXTENSION_NAME = "VK_EXT_fragment_density_map"
- pattern EXT_FRAGMENT_DENSITY_MAP_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
pattern PIPELINE_RASTERIZATION_STATE_CREATE_FRAGMENT_DENSITY_MAP_ATTACHMENT_BIT_EXT :: PipelineCreateFlagBits Source #
data PhysicalDeviceFragmentDensityMapFeaturesEXT Source #
VkPhysicalDeviceFragmentDensityMapFeaturesEXT - Structure describing fragment density map features that can be supported by an implementation
Members
This structure describes the following features:
Description
If the PhysicalDeviceFragmentDensityMapFeaturesEXT structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceFragmentDensityMapFeaturesEXT, it must add an instance
of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceFragmentDensityMapFeaturesEXT | |
Fields
| |
Instances
data PhysicalDeviceFragmentDensityMapPropertiesEXT Source #
VkPhysicalDeviceFragmentDensityMapPropertiesEXT - Structure describing fragment density map properties that can be supported by an implementation
Description
If the PhysicalDeviceFragmentDensityMapPropertiesEXT structure is
included in the pNext chain of the
PhysicalDeviceProperties2
structure passed to
getPhysicalDeviceProperties2,
it is filled in with each corresponding implementation-dependent
property.
Valid Usage (Implicit)
See Also
VK_EXT_fragment_density_map,
Bool32,
Extent2D,
StructureType
Constructors
| PhysicalDeviceFragmentDensityMapPropertiesEXT | |
Fields
| |
Instances
data RenderPassFragmentDensityMapCreateInfoEXT Source #
VkRenderPassFragmentDensityMapCreateInfoEXT - Structure containing fragment density map attachment for render pass
Description
The fragment density map is read at an implementation-dependent time
with the following constraints determined by the attachment’s image view
flags:
IMAGE_VIEW_CREATE_FRAGMENT_DENSITY_MAP_DYNAMIC_BIT_EXTspecifies that the fragment density map will be read by the device duringPIPELINE_STAGE_FRAGMENT_DENSITY_PROCESS_BIT_EXTIMAGE_VIEW_CREATE_FRAGMENT_DENSITY_MAP_DEFERRED_BIT_EXTspecifies that the fragment density map will be read by the host duringendCommandBufferof the primary command buffer that the render pass is recorded into- Otherwise the fragment density map will be read by the host during
cmdBeginRenderPass
The fragment density map may additionally be read by the device during
PIPELINE_STAGE_FRAGMENT_DENSITY_PROCESS_BIT_EXT
for any mode.
If this structure is not present, it is as if
fragmentDensityMapAttachment was given as
ATTACHMENT_UNUSED.
Valid Usage
-
If
fragmentDensityMapAttachmentis notATTACHMENT_UNUSED,fragmentDensityMapAttachmentmust not be an element ofSubpassDescription::pInputAttachments,SubpassDescription::pColorAttachments,SubpassDescription::pResolveAttachments,SubpassDescription::pDepthStencilAttachment, orSubpassDescription::pPreserveAttachmentsfor any subpass
-
If
fragmentDensityMapAttachmentis notATTACHMENT_UNUSED,layoutmust be equal toIMAGE_LAYOUT_FRAGMENT_DENSITY_MAP_OPTIMAL_EXT, orIMAGE_LAYOUT_GENERAL -
If
fragmentDensityMapAttachmentis notATTACHMENT_UNUSED,fragmentDensityMapAttachmentmust reference an attachment with aloadOpequal toATTACHMENT_LOAD_OP_LOADorATTACHMENT_LOAD_OP_DONT_CARE -
If
fragmentDensityMapAttachmentis notATTACHMENT_UNUSED,fragmentDensityMapAttachmentmust reference an attachment with astoreOpequal toATTACHMENT_STORE_OP_DONT_CARE
Valid Usage (Implicit)
-
fragmentDensityMapAttachmentmust be a validAttachmentReferencestructure
See Also
VK_EXT_fragment_density_map,
AttachmentReference,
StructureType
Constructors
| RenderPassFragmentDensityMapCreateInfoEXT | |
Fields
| |
Instances
data RenderingFragmentDensityMapAttachmentInfoEXT Source #
VkRenderingFragmentDensityMapAttachmentInfoEXT - Structure specifying fragment shading rate attachment information
Description
This structure can be included in the pNext chain of
RenderingInfo to
define a fragment density map. If this structure is not included in the
pNext chain, imageView is treated as
NULL_HANDLE.
Valid Usage
-
If
imageViewis notNULL_HANDLE,imageLayoutmust beIMAGE_LAYOUT_GENERALorIMAGE_LAYOUT_FRAGMENT_DENSITY_MAP_OPTIMAL_EXT
-
If
imageViewis notNULL_HANDLE, it must have been created with theIMAGE_USAGE_FRAGMENT_DENSITY_MAP_BIT_EXTusage flag set_EXT -
If
imageViewis notNULL_HANDLE, it must not have been created withIMAGE_CREATE_SUBSAMPLED_BIT_EXT -
If the
multiview
feature is not enabled,
PhysicalDeviceProperties::apiVersionis less than Vulkan 1.1, andimageViewis notNULL_HANDLE, it must have alayerCountequal to1
Valid Usage (Implicit)
-
imageViewmust be a validImageViewhandle -
imageLayoutmust be a validImageLayoutvalue
See Also
VK_EXT_fragment_density_map,
VK_KHR_dynamic_rendering,
VK_VERSION_1_3,
ImageLayout,
ImageView,
StructureType
Constructors
| RenderingFragmentDensityMapAttachmentInfoEXT | |
Fields
| |
Instances
type EXT_FRAGMENT_DENSITY_MAP_SPEC_VERSION = 3 Source #
pattern EXT_FRAGMENT_DENSITY_MAP_SPEC_VERSION :: Integral a => a Source #
type EXT_FRAGMENT_DENSITY_MAP_EXTENSION_NAME = "VK_EXT_fragment_density_map" Source #
pattern EXT_FRAGMENT_DENSITY_MAP_EXTENSION_NAME :: (Eq a, IsString a) => a Source #