vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_fragment_density_map2

Description

Name

VK_EXT_fragment_density_map2 - device extension

VK_EXT_fragment_density_map2

Name String
VK_EXT_fragment_density_map2
Extension Type
Device extension
Registered Extension Number
333
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_EXT_fragment_density_map
Contact

Other Extension Metadata

Last Modified Date
2020-06-16
Interactions and External Dependencies
  • Interacts with Vulkan 1.1
Contributors
  • Matthew Netsch, Qualcomm Technologies, Inc.
  • Jonathan Tinkham, Qualcomm Technologies, Inc.
  • Jonathan Wicks, Qualcomm Technologies, Inc.
  • Jan-Harald Fredriksen, ARM

Description

This extension adds additional features and properties to VK_EXT_fragment_density_map in order to reduce fragment density map host latency as well as improved queries for subsampled sampler implementation-dependent behavior.

New Structures

New Enum Constants

Version History

  • Revision 1, 2020-06-16 (Matthew Netsch)

    • Initial version

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceFragmentDensityMap2FeaturesEXT Source #

VkPhysicalDeviceFragmentDensityMap2FeaturesEXT - Structure describing additional fragment density map features that can be supported by an implementation

Members

This structure describes the following feature:

Description

If the PhysicalDeviceFragmentDensityMap2FeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceFragmentDensityMap2FeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_fragment_density_map2, Bool32, StructureType

Constructors

PhysicalDeviceFragmentDensityMap2FeaturesEXT 

Fields

Instances

Instances details
Eq PhysicalDeviceFragmentDensityMap2FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

Storable PhysicalDeviceFragmentDensityMap2FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

Show PhysicalDeviceFragmentDensityMap2FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

FromCStruct PhysicalDeviceFragmentDensityMap2FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

ToCStruct PhysicalDeviceFragmentDensityMap2FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

Zero PhysicalDeviceFragmentDensityMap2FeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

data PhysicalDeviceFragmentDensityMap2PropertiesEXT Source #

VkPhysicalDeviceFragmentDensityMap2PropertiesEXT - Structure describing additional fragment density map properties that can be supported by an implementation

Description

If the PhysicalDeviceFragmentDensityMap2PropertiesEXT structure is included in the pNext chain of the PhysicalDeviceProperties2 structure passed to getPhysicalDeviceProperties2, it is filled in with each corresponding implementation-dependent property.

Valid Usage (Implicit)

See Also

VK_EXT_fragment_density_map2, Bool32, StructureType

Constructors

PhysicalDeviceFragmentDensityMap2PropertiesEXT 

Fields

Instances

Instances details
Eq PhysicalDeviceFragmentDensityMap2PropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

Storable PhysicalDeviceFragmentDensityMap2PropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

Show PhysicalDeviceFragmentDensityMap2PropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

FromCStruct PhysicalDeviceFragmentDensityMap2PropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

ToCStruct PhysicalDeviceFragmentDensityMap2PropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

Zero PhysicalDeviceFragmentDensityMap2PropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_fragment_density_map2

type EXT_FRAGMENT_DENSITY_MAP_2_EXTENSION_NAME = "VK_EXT_fragment_density_map2" Source #