| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_global_priority_query
Description
Name
VK_EXT_global_priority_query - device extension
VK_EXT_global_priority_query
- Name String
VK_EXT_global_priority_query
- Extension Type
- Device extension
- Registered Extension Number
- 389
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_EXT_global_priority and
VK_KHR_get_physical_device_properties2 or
- Deprecation State
Promoted to VK_KHR_global_priority extension
- Which in turn was promoted to Vulkan 1.4
- Contact
Other Extension Metadata
- Last Modified Date
- 2021-03-29
- IP Status
- No known IP claims.
- Contributors
- Yiwei Zhang, Google
Description
This device extension allows applications to query the global queue priorities supported by a queue family. It allows implementations to report which global priority levels are treated differently by the implementation, instead of silently mapping multiple requested global priority levels to the same internal priority, or using device creation failure to signal that a requested priority is not supported. It is intended primarily for use by system integration along with certain platform-specific priority enforcement rules.
New Structures
New Enum Constants
Issues
1) Can we additionally query whether a caller is permitted to acquire a specific global queue priority in this extension?
RESOLVED: No. Whether a caller has enough privilege goes with the OS, and the Vulkan driver cannot really guarantee that the privilege will not change in between this query and the actual queue creation call.
2) If more than 1 queue using global priority is requested, is there a good way to know which queue is failing the device creation?
RESOLVED: No. There is not a good way at this moment, and it is also not quite actionable for the applications to know that because the information may not be accurate. Queue creation can fail because of runtime constraints like insufficient privilege or lack of resource, and the failure is not necessarily tied to that particular queue configuration requested.
Version History
- Revision 1, 2021-03-29 (Yiwei Zhang)
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
pattern MAX_GLOBAL_PRIORITY_SIZE_EXT :: Integral a => a Source #
type PhysicalDeviceGlobalPriorityQueryFeaturesEXT = PhysicalDeviceGlobalPriorityQueryFeatures Source #
pattern EXT_GLOBAL_PRIORITY_QUERY_SPEC_VERSION :: Integral a => a Source #
type EXT_GLOBAL_PRIORITY_QUERY_EXTENSION_NAME = "VK_EXT_global_priority_query" Source #
pattern EXT_GLOBAL_PRIORITY_QUERY_EXTENSION_NAME :: (Eq a, IsString a) => a Source #