| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_host_query_reset
Description
Name
VK_EXT_host_query_reset - device extension
VK_EXT_host_query_reset
- Name String
VK_EXT_host_query_reset
- Extension Type
- Device extension
- Registered Extension Number
- 262
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Deprecation State
- Promoted to Vulkan 1.2
- Contact
Other Extension Metadata
- Last Modified Date
- 2019-03-06
- IP Status
- No known IP claims.
- Contributors
- Bas Nieuwenhuizen, Google
- Faith Ekstrand, Intel
- Jeff Bolz, NVIDIA
- Piers Daniell, NVIDIA
Description
This extension adds a new function to reset queries from the host.
Promotion to Vulkan 1.2
All functionality in this extension is included in core Vulkan 1.2, with the EXT suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.
New Commands
New Structures
New Enum Constants
Version History
Revision 1, 2019-03-12 (Bas Nieuwenhuizen)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
resetQueryPoolEXT :: MonadIO io => Device -> QueryPool -> ("firstQuery" ::: Word32) -> ("queryCount" ::: Word32) -> io () Source #
type EXT_HOST_QUERY_RESET_SPEC_VERSION = 1 Source #
pattern EXT_HOST_QUERY_RESET_SPEC_VERSION :: Integral a => a Source #
type EXT_HOST_QUERY_RESET_EXTENSION_NAME = "VK_EXT_host_query_reset" Source #
pattern EXT_HOST_QUERY_RESET_EXTENSION_NAME :: (Eq a, IsString a) => a Source #