| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_image_2d_view_of_3d
Description
Name
VK_EXT_image_2d_view_of_3d - device extension
VK_EXT_image_2d_view_of_3d
- Name String
VK_EXT_image_2d_view_of_3d
- Extension Type
- Device extension
- Registered Extension Number
- 394
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Special Use
- Contact
Other Extension Metadata
- Last Modified Date
- 2022-02-22
- IP Status
- No known IP claims.
- Contributors
- Mike Blumenkrantz, Valve
- Piers Daniell, NVIDIA
- Spencer Fricke, Samsung
- Ricardo Garcia, Igalia
- Graeme Leese, Broadcom
- Ralph Potter, Samsung
- Stu Smith, AMD
- Shahbaz Youssefi, Google
- Alex Walters, Imagination
Description
This extension allows a single slice of a 3D image to be used as a 2D
view in image descriptors, matching both the functionality of
glBindImageTexture in OpenGL with the layer parameter set to true and
2D view binding provided by the extension EGL_KHR_gl_texture_3D_image.
It is primarily intended to support GL emulation.
New Structures
New Enum Constants
EXT_IMAGE_2D_VIEW_OF_3D_SPEC_VERSIONExtending
ImageCreateFlagBits:Extending
StructureType:
Version History
Revision 1, 2022-03-25 (Mike Blumenkrantz)
- Internal revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceImage2DViewOf3DFeaturesEXT = PhysicalDeviceImage2DViewOf3DFeaturesEXT {}
- type EXT_IMAGE_2D_VIEW_OF_3D_SPEC_VERSION = 1
- pattern EXT_IMAGE_2D_VIEW_OF_3D_SPEC_VERSION :: Integral a => a
- type EXT_IMAGE_2D_VIEW_OF_3D_EXTENSION_NAME = "VK_EXT_image_2d_view_of_3d"
- pattern EXT_IMAGE_2D_VIEW_OF_3D_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceImage2DViewOf3DFeaturesEXT Source #
VkPhysicalDeviceImage2DViewOf3DFeaturesEXT - Structure describing whether single-slice 2D views of 3D images can be used in image descriptors
Members
This structure describes the following features:
Description
If the PhysicalDeviceImage2DViewOf3DFeaturesEXT structure is included
in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceImage2DViewOf3DFeaturesEXT, it must add an instance of
the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceImage2DViewOf3DFeaturesEXT | |
Fields
| |
Instances
type EXT_IMAGE_2D_VIEW_OF_3D_SPEC_VERSION = 1 Source #
pattern EXT_IMAGE_2D_VIEW_OF_3D_SPEC_VERSION :: Integral a => a Source #
type EXT_IMAGE_2D_VIEW_OF_3D_EXTENSION_NAME = "VK_EXT_image_2d_view_of_3d" Source #
pattern EXT_IMAGE_2D_VIEW_OF_3D_EXTENSION_NAME :: (Eq a, IsString a) => a Source #