| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_legacy_vertex_attributes
Description
Name
VK_EXT_legacy_vertex_attributes - device extension
VK_EXT_legacy_vertex_attributes
- Name String
VK_EXT_legacy_vertex_attributes
- Extension Type
- Device extension
- Registered Extension Number
- 496
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_EXT_vertex_input_dynamic_state
- Special Use
- Contact
- Extension Proposal
- VK_EXT_legacy_vertex_attributes
Other Extension Metadata
- Last Modified Date
- 2024-02-23
- IP Status
- No known IP claims.
- Contributors
- Mike Blumenkrantz, Valve
- Piers Daniell, NVIDIA
- Spencer Fricke, LunarG
- Alyssa Rosenzweig, Valve
Description
This extension adds support for legacy features of (non-64-bit) vertex attributes as found in OpenGL:
- Vertex attributes loaded from arbitrary buffer alignments
- Vertex attributes using arbitrary strides
- Vertex attributes where the component data type of the binding does not match the component numeric type of the shader input
These features are only usable with dynamic vertex input. Unaligned loads of vertex attributes may incur performance penalties, indicated with a property.
New Structures
New Enum Constants
Issues
- ) Should implementations convert float/integer values?
RESOLVED: No. When fetching an integer data type from float values or float data types from integer values, the resulting shader values are implementation-dependent.
Version History
Revision 1, 2024-02-16 (Mike Blumenkrantz)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceLegacyVertexAttributesFeaturesEXT = PhysicalDeviceLegacyVertexAttributesFeaturesEXT {}
- data PhysicalDeviceLegacyVertexAttributesPropertiesEXT = PhysicalDeviceLegacyVertexAttributesPropertiesEXT {}
- type EXT_LEGACY_VERTEX_ATTRIBUTES_SPEC_VERSION = 1
- pattern EXT_LEGACY_VERTEX_ATTRIBUTES_SPEC_VERSION :: Integral a => a
- type EXT_LEGACY_VERTEX_ATTRIBUTES_EXTENSION_NAME = "VK_EXT_legacy_vertex_attributes"
- pattern EXT_LEGACY_VERTEX_ATTRIBUTES_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceLegacyVertexAttributesFeaturesEXT Source #
VkPhysicalDeviceLegacyVertexAttributesFeaturesEXT - Structure describing compatibility features for vertex attributes
Members
This structure describes the following features:
Description
If the PhysicalDeviceLegacyVertexAttributesFeaturesEXT structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceLegacyVertexAttributesFeaturesEXT, it must add an
instance of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceLegacyVertexAttributesFeaturesEXT | |
Fields | |
Instances
data PhysicalDeviceLegacyVertexAttributesPropertiesEXT Source #
VkPhysicalDeviceLegacyVertexAttributesPropertiesEXT - Structure describing properties for legacy vertex attributes
Members
This structure describes the following features:
Description
If the PhysicalDeviceLegacyVertexAttributesPropertiesEXT structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceLegacyVertexAttributesPropertiesEXT, it must add an
instance of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceLegacyVertexAttributesPropertiesEXT | |
Fields | |
Instances
pattern EXT_LEGACY_VERTEX_ATTRIBUTES_SPEC_VERSION :: Integral a => a Source #
type EXT_LEGACY_VERTEX_ATTRIBUTES_EXTENSION_NAME = "VK_EXT_legacy_vertex_attributes" Source #
pattern EXT_LEGACY_VERTEX_ATTRIBUTES_EXTENSION_NAME :: (Eq a, IsString a) => a Source #