vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_map_memory_placed

Description

Name

VK_EXT_map_memory_placed - device extension

VK_EXT_map_memory_placed

Name String
VK_EXT_map_memory_placed
Extension Type
Device extension
Registered Extension Number
273
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_map_memory2 or Vulkan Version 1.4
Contact
Extension Proposal
VK_EXT_map_memory_placed

Other Extension Metadata

Last Modified Date
2023-03-21
IP Status
No known IP claims.
Interactions and External Dependencies
  • Depends on apitext:VK_KHR_map_memory2
  • Interacts with apitext:VK_EXT_external_memory_host
Contributors
  • Faith Ekstrand, Collabora
  • Tobias Hector, AMD
  • James Jones, NVIDIA
  • Georg Lehmann, Valve
  • Derek Lesho, Codeweavers

Description

This extension allows an application to request that mapMemory2KHR attempt to place the memory map at a particular virtual address.

New Structures

New Enum Constants

Version History

  • Revision 1, 2024-01-14 (Faith Ekstrand)

    • Internal revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceMapMemoryPlacedFeaturesEXT Source #

VkPhysicalDeviceMapMemoryPlacedFeaturesEXT - Structure describing placed memory map features that can be supported by an implementation

Members

This structure describes the following features:

Description

If the PhysicalDeviceMapMemoryPlacedFeaturesEXT structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceMapMemoryPlacedFeaturesEXT, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_map_memory_placed, Bool32, StructureType

Constructors

PhysicalDeviceMapMemoryPlacedFeaturesEXT 

Fields

  • memoryMapPlaced :: Bool

    memoryMapPlaced indicates that the implementation supports placing memory maps at application-specified virtual addresses.

  • memoryMapRangePlaced :: Bool

    memoryMapRangePlaced indicates that the implementation supports placing memory maps of a subrange of a memory object at application-specified virtual addresses.

  • memoryUnmapReserve :: Bool

    memoryUnmapReserve indicates that the implementation supports leaving the memory range reserved when unmapping a memory object.

Instances

Instances details
Eq PhysicalDeviceMapMemoryPlacedFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

Storable PhysicalDeviceMapMemoryPlacedFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

Show PhysicalDeviceMapMemoryPlacedFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

FromCStruct PhysicalDeviceMapMemoryPlacedFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

ToCStruct PhysicalDeviceMapMemoryPlacedFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

Zero PhysicalDeviceMapMemoryPlacedFeaturesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

data PhysicalDeviceMapMemoryPlacedPropertiesEXT Source #

VkPhysicalDeviceMapMemoryPlacedPropertiesEXT - Structure describing the alignment requirements of placed memory maps for a physical device

Members

The members of the PhysicalDeviceMapMemoryPlacedPropertiesEXT structure describe the following:

Description

If the PhysicalDeviceMapMemoryPlacedPropertiesEXT structure is included in the pNext chain of the PhysicalDeviceProperties2 structure passed to getPhysicalDeviceProperties2, it is filled in with each corresponding implementation-dependent property.

Valid Usage (Implicit)

See Also

VK_EXT_map_memory_placed, DeviceSize, StructureType

Constructors

PhysicalDeviceMapMemoryPlacedPropertiesEXT 

Fields

  • minPlacedMemoryMapAlignment :: DeviceSize

    minPlacedMemoryMapAlignment is the minimum alignment required for memory object offsets and virtual address ranges when using placed memory mapping.

Instances

Instances details
Eq PhysicalDeviceMapMemoryPlacedPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

Storable PhysicalDeviceMapMemoryPlacedPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

Show PhysicalDeviceMapMemoryPlacedPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

FromCStruct PhysicalDeviceMapMemoryPlacedPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

ToCStruct PhysicalDeviceMapMemoryPlacedPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

Zero PhysicalDeviceMapMemoryPlacedPropertiesEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

data MemoryMapPlacedInfoEXT Source #

VkMemoryMapPlacedInfoEXT - Structure containing memory map placement parameters

Valid Usage

  • The address range specified by pPlacedAddress and MemoryMapInfo::size must not overlap any existing Vulkan memory object mapping

Valid Usage (Implicit)

See Also

VK_EXT_map_memory_placed, StructureType

Constructors

MemoryMapPlacedInfoEXT 

Fields

Instances

Instances details
Storable MemoryMapPlacedInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

Show MemoryMapPlacedInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

FromCStruct MemoryMapPlacedInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

ToCStruct MemoryMapPlacedInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

Zero MemoryMapPlacedInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_EXT_map_memory_placed

type EXT_MAP_MEMORY_PLACED_EXTENSION_NAME = "VK_EXT_map_memory_placed" Source #