| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_map_memory_placed
Description
Name
VK_EXT_map_memory_placed - device extension
VK_EXT_map_memory_placed
- Name String
VK_EXT_map_memory_placed
- Extension Type
- Device extension
- Registered Extension Number
- 273
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_map_memory2 or Vulkan Version 1.4
- Contact
- Extension Proposal
- VK_EXT_map_memory_placed
Other Extension Metadata
- Last Modified Date
- 2023-03-21
- IP Status
- No known IP claims.
- Interactions and External Dependencies
- Depends on apitext:VK_KHR_map_memory2
- Interacts with apitext:VK_EXT_external_memory_host
- Contributors
- Faith Ekstrand, Collabora
- Tobias Hector, AMD
- James Jones, NVIDIA
- Georg Lehmann, Valve
- Derek Lesho, Codeweavers
Description
This extension allows an application to request that
mapMemory2KHR attempt to place
the memory map at a particular virtual address.
New Structures
Extending
MemoryMapInfo:
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:Extending
PhysicalDeviceProperties2:
New Enum Constants
EXT_MAP_MEMORY_PLACED_SPEC_VERSIONExtending
MemoryMapFlagBits:Extending
MemoryUnmapFlagBits:Extending
StructureType:
Version History
Revision 1, 2024-01-14 (Faith Ekstrand)
- Internal revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceMapMemoryPlacedFeaturesEXT = PhysicalDeviceMapMemoryPlacedFeaturesEXT {}
- data PhysicalDeviceMapMemoryPlacedPropertiesEXT = PhysicalDeviceMapMemoryPlacedPropertiesEXT {}
- data MemoryMapPlacedInfoEXT = MemoryMapPlacedInfoEXT {
- placedAddress :: Ptr ()
- type EXT_MAP_MEMORY_PLACED_SPEC_VERSION = 1
- pattern EXT_MAP_MEMORY_PLACED_SPEC_VERSION :: Integral a => a
- type EXT_MAP_MEMORY_PLACED_EXTENSION_NAME = "VK_EXT_map_memory_placed"
- pattern EXT_MAP_MEMORY_PLACED_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceMapMemoryPlacedFeaturesEXT Source #
VkPhysicalDeviceMapMemoryPlacedFeaturesEXT - Structure describing placed memory map features that can be supported by an implementation
Members
This structure describes the following features:
Description
If the PhysicalDeviceMapMemoryPlacedFeaturesEXT structure is included
in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceMapMemoryPlacedFeaturesEXT, it must add an instance of
the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceMapMemoryPlacedFeaturesEXT | |
Fields | |
Instances
data PhysicalDeviceMapMemoryPlacedPropertiesEXT Source #
VkPhysicalDeviceMapMemoryPlacedPropertiesEXT - Structure describing the alignment requirements of placed memory maps for a physical device
Members
The members of the PhysicalDeviceMapMemoryPlacedPropertiesEXT
structure describe the following:
Description
If the PhysicalDeviceMapMemoryPlacedPropertiesEXT structure is
included in the pNext chain of the
PhysicalDeviceProperties2
structure passed to
getPhysicalDeviceProperties2,
it is filled in with each corresponding implementation-dependent
property.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceMapMemoryPlacedPropertiesEXT | |
Fields | |
Instances
data MemoryMapPlacedInfoEXT Source #
VkMemoryMapPlacedInfoEXT - Structure containing memory map placement parameters
Valid Usage
-
pPlacedAddressmust be aligned to an integer multiple ofPhysicalDeviceMapMemoryPlacedPropertiesEXT::minPlacedMemoryMapAlignment
- The address
range specified by
pPlacedAddressandMemoryMapInfo::sizemust not overlap any existing Vulkan memory object mapping
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_MEMORY_MAP_PLACED_INFO_EXT
See Also
Constructors
| MemoryMapPlacedInfoEXT | |
Fields
| |
Instances
type EXT_MAP_MEMORY_PLACED_SPEC_VERSION = 1 Source #
pattern EXT_MAP_MEMORY_PLACED_SPEC_VERSION :: Integral a => a Source #
type EXT_MAP_MEMORY_PLACED_EXTENSION_NAME = "VK_EXT_map_memory_placed" Source #
pattern EXT_MAP_MEMORY_PLACED_EXTENSION_NAME :: (Eq a, IsString a) => a Source #