| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_memory_priority
Description
Name
VK_EXT_memory_priority - device extension
VK_EXT_memory_priority
- Name String
VK_EXT_memory_priority
- Extension Type
- Device extension
- Registered Extension Number
- 239
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Contact
Other Extension Metadata
- Last Modified Date
- 2018-10-08
- Contributors
- Jeff Bolz, NVIDIA
- Jeff Juliano, NVIDIA
Description
This extension adds a priority value specified at memory allocation
time. On some systems with both device-local and non-device-local memory
heaps, the implementation may transparently move memory from one heap to
another when a heap becomes full (for example, when the total memory
used across all processes exceeds the size of the heap). In such a case,
this priority value may be used to determine which allocations are more
likely to remain in device-local memory.
New Structures
New Enum Constants
Version History
Revision 1, 2018-10-08 (Jeff Bolz)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceMemoryPriorityFeaturesEXT = PhysicalDeviceMemoryPriorityFeaturesEXT {}
- data MemoryPriorityAllocateInfoEXT = MemoryPriorityAllocateInfoEXT {}
- type EXT_MEMORY_PRIORITY_SPEC_VERSION = 1
- pattern EXT_MEMORY_PRIORITY_SPEC_VERSION :: Integral a => a
- type EXT_MEMORY_PRIORITY_EXTENSION_NAME = "VK_EXT_memory_priority"
- pattern EXT_MEMORY_PRIORITY_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceMemoryPriorityFeaturesEXT Source #
VkPhysicalDeviceMemoryPriorityFeaturesEXT - Structure describing memory priority features that can be supported by an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceMemoryPriorityFeaturesEXT structure is included
in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceMemoryPriorityFeaturesEXT, it must add an instance of
the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceMemoryPriorityFeaturesEXT | |
Fields
| |
Instances
data MemoryPriorityAllocateInfoEXT Source #
VkMemoryPriorityAllocateInfoEXT - Specify a memory allocation priority
Description
Memory allocations with higher priority may be more likely to stay in device-local memory when the system is under memory pressure.
If this structure is not included, it is as if the priority value were
0.5.
Valid Usage (Implicit)
See Also
Constructors
| MemoryPriorityAllocateInfoEXT | |
Instances
type EXT_MEMORY_PRIORITY_SPEC_VERSION = 1 Source #
pattern EXT_MEMORY_PRIORITY_SPEC_VERSION :: Integral a => a Source #
type EXT_MEMORY_PRIORITY_EXTENSION_NAME = "VK_EXT_memory_priority" Source #
pattern EXT_MEMORY_PRIORITY_EXTENSION_NAME :: (Eq a, IsString a) => a Source #