| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_pipeline_protected_access
Description
Name
VK_EXT_pipeline_protected_access - device extension
VK_EXT_pipeline_protected_access
- Name String
VK_EXT_pipeline_protected_access
- Extension Type
- Device extension
- Registered Extension Number
- 467
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Deprecation State
- Promoted to Vulkan 1.4
- Contact
- Extension Proposal
- VK_EXT_pipeline_protected_access
Other Extension Metadata
- Last Modified Date
- 2022-07-28
- Contributors
- Shahbaz Youssefi, Google
- Jörg Wagner, Arm
- Ralph Potter, Samsung
- Daniel Koch, NVIDIA
Description
This extension allows protected memory access to be specified per pipeline as opposed to per device. Through the usage of this extension, any performance penalty paid due to access to protected memory will be limited to the specific pipelines that make such accesses.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
EXT_PIPELINE_PROTECTED_ACCESS_SPEC_VERSIONExtending
PipelineCreateFlagBits:Extending
StructureType:
Promotion to Vulkan 1.4
Functionality in this extension is included in core Vulkan 1.4 with the EXT suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.
Version History
Revision 1, 2022-07-28 (Shahbaz Youssefi)
- Internal revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
pattern STRUCTURE_TYPE_PHYSICAL_DEVICE_PIPELINE_PROTECTED_ACCESS_FEATURES_EXT :: StructureType Source #
type PhysicalDevicePipelineProtectedAccessFeaturesEXT = PhysicalDevicePipelineProtectedAccessFeatures Source #
pattern EXT_PIPELINE_PROTECTED_ACCESS_SPEC_VERSION :: Integral a => a Source #
type EXT_PIPELINE_PROTECTED_ACCESS_EXTENSION_NAME = "VK_EXT_pipeline_protected_access" Source #
pattern EXT_PIPELINE_PROTECTED_ACCESS_EXTENSION_NAME :: (Eq a, IsString a) => a Source #