| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_pipeline_robustness
Description
Name
VK_EXT_pipeline_robustness - device extension
VK_EXT_pipeline_robustness
- Name String
VK_EXT_pipeline_robustness
- Extension Type
- Device extension
- Registered Extension Number
- 69
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Deprecation State
- Promoted to Vulkan 1.4
- Contact
- Jarred Davies
Other Extension Metadata
- Last Modified Date
- 2022-07-12
- Interactions and External Dependencies
- Interacts with
VK_EXT_robustness2 - Interacts with
VK_EXT_image_robustness - Interacts with
VK_KHR_ray_tracing_pipeline
- Interacts with
- Contributors
- Jarred Davies, Imagination Technologies
- Alex Walters, Imagination Technologies
- Piers Daniell, NVIDIA
- Graeme Leese, Broadcom Corporation
- Jeff Leger, Qualcomm Technologies, Inc.
- Faith Ekstrand, Intel
- Lionel Landwerlin, Intel
- Shahbaz Youssefi, Google, Inc.
Description
This extension allows users to request robustness on a per-pipeline stage basis.
As robustBufferAccess and other robustness features may have an adverse effect on performance, this extension is designed to allow users to request robust behavior only where it may be needed.
New Structures
Extending
GraphicsPipelineCreateInfo,ComputePipelineCreateInfo,PipelineShaderStageCreateInfo,RayTracingPipelineCreateInfoKHR:
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:Extending
PhysicalDeviceProperties2:
New Enums
New Enum Constants
EXT_PIPELINE_ROBUSTNESS_SPEC_VERSIONExtending
PipelineRobustnessBufferBehavior:Extending
PipelineRobustnessImageBehavior:Extending
StructureType:
Promotion to Vulkan 1.4
Functionality in this extension is included in core Vulkan 1.4 with the EXT suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.
Version History
Revision 1, 2022-07-12 (Jarred Davies)
- Initial version
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
pattern PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_DEVICE_DEFAULT_EXT :: PipelineRobustnessBufferBehavior Source #
pattern PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_DISABLED_EXT :: PipelineRobustnessBufferBehavior Source #
pattern PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_EXT :: PipelineRobustnessBufferBehavior Source #
pattern PIPELINE_ROBUSTNESS_BUFFER_BEHAVIOR_ROBUST_BUFFER_ACCESS_2_EXT :: PipelineRobustnessBufferBehavior Source #
pattern PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_DEVICE_DEFAULT_EXT :: PipelineRobustnessImageBehavior Source #
pattern PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESS_EXT :: PipelineRobustnessImageBehavior Source #
pattern PIPELINE_ROBUSTNESS_IMAGE_BEHAVIOR_ROBUST_IMAGE_ACCESS_2_EXT :: PipelineRobustnessImageBehavior Source #
type PhysicalDevicePipelineRobustnessFeaturesEXT = PhysicalDevicePipelineRobustnessFeatures Source #
type PhysicalDevicePipelineRobustnessPropertiesEXT = PhysicalDevicePipelineRobustnessProperties Source #
type EXT_PIPELINE_ROBUSTNESS_SPEC_VERSION = 1 Source #
pattern EXT_PIPELINE_ROBUSTNESS_SPEC_VERSION :: Integral a => a Source #
type EXT_PIPELINE_ROBUSTNESS_EXTENSION_NAME = "VK_EXT_pipeline_robustness" Source #
pattern EXT_PIPELINE_ROBUSTNESS_EXTENSION_NAME :: (Eq a, IsString a) => a Source #