vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_EXT_present_mode_fifo_latest_ready

Description

Name

VK_EXT_present_mode_fifo_latest_ready - device extension

VK_EXT_present_mode_fifo_latest_ready

Name String
VK_EXT_present_mode_fifo_latest_ready
Extension Type
Device extension
Registered Extension Number
362
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_swapchain
Deprecation State
Contact
Extension Proposal
VK_EXT_present_mode_fifo_latest_ready

Other Extension Metadata

Last Modified Date
2024-05-28
IP Status
No known IP claims.
Contributors
  • James Jones, NVIDIA
  • Lionel Duc, NVIDIA

Description

This device extension adds a new present mode, PRESENT_MODE_FIFO_LATEST_READY_EXT.

This tear-free present mode behaves much like PRESENT_MODE_FIFO_KHR, except that each vertical blanking period dequeues consecutive present requests until the latest ready is found to update the current image.

While this seems similar in concept to PRESENT_MODE_MAILBOX_KHR, the fundamental difference is that the processing of the present requests is done during vblank. From the application perspective, this means for example, that in a flip-based model, a single vblank may cause multiple swapchain images to be released at once, while PRESENT_MODE_MAILBOX_KHR may continuously be releasing images as new requests become ready.

This additional present mode is useful when using a time-based present API.

Promotion to VK_KHR_present_mode_fifo_latest_ready

All functionality in this extension is included in VK_KHR_present_mode_fifo_latest_ready, with the suffix changed to KHR. The original type and enum names are still available as aliases of the KHR names.

New Structures

New Enum Constants

Version History

  • Revision 1, 2024-05-28 (Lionel Duc)

    • Internal revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

type EXT_PRESENT_MODE_FIFO_LATEST_READY_EXTENSION_NAME = "VK_EXT_present_mode_fifo_latest_ready" Source #

data PhysicalDevicePresentModeFifoLatestReadyFeaturesKHR Source #

VkPhysicalDevicePresentModeFifoLatestReadyFeaturesKHR - Structure describing support for VK_PRESENT_MODE_FIFO_LATEST_READY_KHR

Description

If the PhysicalDevicePresentModeFifoLatestReadyFeaturesKHR structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDevicePresentModeFifoLatestReadyFeaturesKHR, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_EXT_present_mode_fifo_latest_ready, VK_KHR_present_mode_fifo_latest_ready, Bool32, StructureType

Constructors

PhysicalDevicePresentModeFifoLatestReadyFeaturesKHR 

Fields

Instances

Instances details
Eq PhysicalDevicePresentModeFifoLatestReadyFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_present_mode_fifo_latest_ready

Storable PhysicalDevicePresentModeFifoLatestReadyFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_present_mode_fifo_latest_ready

Show PhysicalDevicePresentModeFifoLatestReadyFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_present_mode_fifo_latest_ready

FromCStruct PhysicalDevicePresentModeFifoLatestReadyFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_present_mode_fifo_latest_ready

ToCStruct PhysicalDevicePresentModeFifoLatestReadyFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_present_mode_fifo_latest_ready

Zero PhysicalDevicePresentModeFifoLatestReadyFeaturesKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_present_mode_fifo_latest_ready

newtype PresentModeKHR Source #

VkPresentModeKHR - Presentation mode supported for a surface

Description

  • PRESENT_MODE_IMMEDIATE_KHR specifies that the presentation engine does not wait for a vertical blanking period to update the current image, meaning this mode may result in visible tearing. No internal queuing of presentation requests is needed, as the requests are applied immediately.
  • PRESENT_MODE_MAILBOX_KHR specifies that the presentation engine waits for the next vertical blanking period to update the current image. Tearing cannot be observed. An internal single-entry queue is used to hold pending presentation requests. If the queue is full when a new presentation request is received, the new request replaces the existing entry, and any images associated with the prior entry become available for reuse by the application. One request is removed from the queue and processed during each vertical blanking period in which the queue is non-empty.
  • PRESENT_MODE_FIFO_KHR specifies that the presentation engine waits for the next vertical blanking period to update the current image. Tearing cannot be observed. An internal queue is used to hold pending presentation requests. New requests are appended to the end of the queue, and one request is removed from the beginning of the queue and processed during each vertical blanking period in which the queue is non-empty. This is the only value of presentMode that is required to be supported.
  • PRESENT_MODE_FIFO_RELAXED_KHR specifies that the presentation engine generally waits for the next vertical blanking period to update the current image. If a vertical blanking period has already passed since the last update of the current image then the presentation engine does not wait for another vertical blanking period for the update, meaning this mode may result in visible tearing in this case. This mode is useful for reducing visual stutter with an application that will mostly present a new image before the next vertical blanking period, but may occasionally be late, and present a new image just after the next vertical blanking period. An internal queue is used to hold pending presentation requests. New requests are appended to the end of the queue, and one request is removed from the beginning of the queue and processed during or after each vertical blanking period in which the queue is non-empty.
  • PRESENT_MODE_FIFO_LATEST_READY_KHR specifies that the presentation engine waits for the next vertical blanking period to update the current image. Tearing cannot be observed. An internal queue is used to hold pending presentation requests. New requests are appended to the end of the queue. At each vertical blanking period, the presentation engine dequeues all successive requests that are ready to be presented from the beginning of the queue. If using the VK_GOOGLE_display_timing extension or the presentAtAbsoluteTime feature to provide a target present time, the presentation engine checks the specified time for each image. If the target present time is less-than or equal-to the current time, the presentation engine dequeues the image and checks the next one. The image of the last dequeued request is presented. The other dequeued requests are dropped.
  • PRESENT_MODE_SHARED_DEMAND_REFRESH_KHR specifies that the presentation engine and application have concurrent access to a single image, which is referred to as a shared presentable image. The presentation engine is only required to update the current image after a new presentation request is received. Therefore the application must make a presentation request whenever an update is required. However, the presentation engine may update the current image at any point, meaning this mode may result in visible tearing.
  • PRESENT_MODE_SHARED_CONTINUOUS_REFRESH_KHR specifies that the presentation engine and application have concurrent access to a single image, which is referred to as a shared presentable image. The presentation engine periodically updates the current image on its regular refresh cycle. The application is only required to make one initial presentation request, after which the presentation engine must update the current image without any need for further presentation requests. The application can indicate the image contents have been updated by making a presentation request, but this does not guarantee the timing of when it will be updated. This mode may result in visible tearing if rendering to the image is not timed correctly.

The supported ImageUsageFlagBits of the presentable images of a swapchain created for a surface may differ depending on the presentation mode, and can be determined as per the table below:

Presentation modeImage usage flags
PRESENT_MODE_IMMEDIATE_KHRSurfaceCapabilitiesKHR::supportedUsageFlags
PRESENT_MODE_MAILBOX_KHRSurfaceCapabilitiesKHR::supportedUsageFlags
PRESENT_MODE_FIFO_KHRSurfaceCapabilitiesKHR::supportedUsageFlags
PRESENT_MODE_FIFO_RELAXED_KHRSurfaceCapabilitiesKHR::supportedUsageFlags
PRESENT_MODE_FIFO_LATEST_READY_KHRSurfaceCapabilitiesKHR::supportedUsageFlags
PRESENT_MODE_SHARED_DEMAND_REFRESH_KHRSharedPresentSurfaceCapabilitiesKHR::sharedPresentSupportedUsageFlags
PRESENT_MODE_SHARED_CONTINUOUS_REFRESH_KHRSharedPresentSurfaceCapabilitiesKHR::sharedPresentSupportedUsageFlags

Presentable Image Usage Queries

For reference, the mode indicated by PRESENT_MODE_FIFO_KHR is equivalent to the behavior of {wgl|glX|egl}SwapBuffers with a swap interval of 1, while the mode indicated by PRESENT_MODE_FIFO_RELAXED_KHR is equivalent to the behavior of {wgl|glX}SwapBuffers with a swap interval of -1 (from the {WGL|GLX}_EXT_swap_control_tear extensions).

See Also

VK_KHR_surface, LatencySurfaceCapabilitiesNV, SurfacePresentModeCompatibilityKHR, SurfacePresentModeKHR, SwapchainCreateInfoKHR, SwapchainPresentModeInfoKHR, SwapchainPresentModesCreateInfoKHR, getPhysicalDeviceSurfacePresentModes2EXT, getPhysicalDeviceSurfacePresentModesKHR

Constructors

PresentModeKHR Int32 

Instances

Instances details
Eq PresentModeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_surface

Ord PresentModeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_surface

Storable PresentModeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_surface

Read PresentModeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_surface

Show PresentModeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_surface

Zero PresentModeKHR Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_surface