| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_shader_float8
Description
Name
VK_EXT_shader_float8 - device extension
VK_EXT_shader_float8
- Name String
VK_EXT_shader_float8
- Extension Type
- Device extension
- Registered Extension Number
- 568
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- API Interactions
- Interacts with VK_KHR_cooperative_matrix
- SPIR-V Dependencies
- Contact
- Extension Proposal
- VK_EXT_shader_float8
Other Extension Metadata
- Last Modified Date
- 2025-04-16
- IP Status
- No known IP claims.
- Contributors
- Kévin Petit, Arm Ltd.
- Stu Smith, AMD
- Jeff Bolz, NVIDIA
- Craig Graham, Samsung
Description
This extension enables support for 8-bit floating-point data types as defined in SPV_EXT_float8.
New Structures
New Enum Constants
EXT_SHADER_FLOAT8_SPEC_VERSIONExtending
StructureType:
If VK_KHR_cooperative_matrix is supported:
New SPIR-V Capabilities
Issues
1) Resolve interactions with the changes VK_KHR_shader_float16 makes to rules for denorm flushing (always allowed by default for all FP formats). How to describe the requirement to preserve subnormals?
+ RESOLVED: Subnormals are always preserved when converting FP8 values to IEEE 754 binary 16. In all other cases, subnormals may be flushed to zero.
+
Version History
Revision 1, 2025-04-16 (Kévin Petit)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderFloat8FeaturesEXT = PhysicalDeviceShaderFloat8FeaturesEXT {}
- type EXT_SHADER_FLOAT8_SPEC_VERSION = 1
- pattern EXT_SHADER_FLOAT8_SPEC_VERSION :: Integral a => a
- type EXT_SHADER_FLOAT8_EXTENSION_NAME = "VK_EXT_shader_float8"
- pattern EXT_SHADER_FLOAT8_EXTENSION_NAME :: (Eq a, IsString a) => a
- newtype ComponentTypeKHR where
- ComponentTypeKHR Int32
- pattern COMPONENT_TYPE_BFLOAT16_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_FLOAT16_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_FLOAT32_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_FLOAT64_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_FLOAT8_E4M3_EXT :: ComponentTypeKHR
- pattern COMPONENT_TYPE_FLOAT8_E5M2_EXT :: ComponentTypeKHR
- pattern COMPONENT_TYPE_SINT16_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_SINT32_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_SINT64_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_SINT8_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_SINT8_PACKED_NV :: ComponentTypeKHR
- pattern COMPONENT_TYPE_UINT16_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_UINT32_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_UINT64_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_UINT8_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_UINT8_PACKED_NV :: ComponentTypeKHR
Documentation
data PhysicalDeviceShaderFloat8FeaturesEXT Source #
VkPhysicalDeviceShaderFloat8FeaturesEXT - Structure describing float8 features that can be supported by the implementation
Members
This structure describes the following features:
Description
If the PhysicalDeviceShaderFloat8FeaturesEXT structure is included in
the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceShaderFloat8FeaturesEXT, it must add an instance of
the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderFloat8FeaturesEXT | |
Fields | |
Instances
type EXT_SHADER_FLOAT8_SPEC_VERSION = 1 Source #
pattern EXT_SHADER_FLOAT8_SPEC_VERSION :: Integral a => a Source #
type EXT_SHADER_FLOAT8_EXTENSION_NAME = "VK_EXT_shader_float8" Source #
pattern EXT_SHADER_FLOAT8_EXTENSION_NAME :: (Eq a, IsString a) => a Source #
newtype ComponentTypeKHR Source #
VkComponentTypeKHR - Specify SPIR-V cooperative matrix component type
Description
COMPONENT_TYPE_FLOAT16_KHRcorresponds to SPIR-VOpTypeFloat16.
COMPONENT_TYPE_FLOAT32_KHRcorresponds to SPIR-VOpTypeFloat32.COMPONENT_TYPE_FLOAT64_KHRcorresponds to SPIR-VOpTypeFloat64.COMPONENT_TYPE_SINT8_KHRcorresponds to SPIR-VOpTypeInt8 0/1.COMPONENT_TYPE_SINT16_KHRcorresponds to SPIR-VOpTypeInt16 0/1.COMPONENT_TYPE_SINT32_KHRcorresponds to SPIR-VOpTypeInt32 0/1.COMPONENT_TYPE_SINT64_KHRcorresponds to SPIR-VOpTypeInt64 0/1.COMPONENT_TYPE_UINT8_KHRcorresponds to SPIR-VOpTypeInt8 0/1.COMPONENT_TYPE_UINT16_KHRcorresponds to SPIR-VOpTypeInt16 0/1.COMPONENT_TYPE_UINT32_KHRcorresponds to SPIR-VOpTypeInt32 0/1.COMPONENT_TYPE_UINT64_KHRcorresponds to SPIR-VOpTypeInt64 0/1.COMPONENT_TYPE_BFLOAT16_KHRcorresponds to SPIR-VOpTypeFloat16 BFloat16KHR.COMPONENT_TYPE_SINT8_PACKED_NVcorresponds to four 8-bit signed integers packed in a 32-bit unsigned integer.COMPONENT_TYPE_UINT8_PACKED_NVcorresponds to four 8-bit unsigned integers packed in a 32-bit unsigned integer.COMPONENT_TYPE_FLOAT_E4M3_NVcorresponds to a floating-point type with a sign bit in the most significant bit, followed by four exponent bits, followed by three mantissa bits.COMPONENT_TYPE_FLOAT_E5M2_NVcorresponds to a floating-point type with a sign bit in the most significant bit, followed by five exponent bits, followed by two mantissa bits.COMPONENT_TYPE_FLOAT8_E4M3_EXTcorresponds to SPIR-VOpTypeFloat8 Float8E4M3EXT.COMPONENT_TYPE_FLOAT8_E5M2_EXTcorresponds to SPIR-VOpTypeFloat8 Float8E5M2EXT.
See Also
VK_KHR_cooperative_matrix,
VK_NV_cooperative_matrix,
VK_NV_cooperative_vector,
ConvertCooperativeVectorMatrixInfoNV,
CooperativeMatrixFlexibleDimensionsPropertiesNV,
CooperativeMatrixPropertiesKHR,
CooperativeMatrixPropertiesNV,
CooperativeVectorPropertiesNV
Constructors
| ComponentTypeKHR Int32 |
Bundled Patterns
| pattern COMPONENT_TYPE_BFLOAT16_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_FLOAT16_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_FLOAT32_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_FLOAT64_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_FLOAT8_E4M3_EXT :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_FLOAT8_E5M2_EXT :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_SINT16_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_SINT32_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_SINT64_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_SINT8_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_SINT8_PACKED_NV :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_UINT16_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_UINT32_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_UINT64_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_UINT8_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_UINT8_PACKED_NV :: ComponentTypeKHR |