| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_shader_long_vector
Description
Name
VK_EXT_shader_long_vector - device extension
VK_EXT_shader_long_vector
- Name String
VK_EXT_shader_long_vector
- Extension Type
- Device extension
- Registered Extension Number
- 636
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- Vulkan Version 1.2
- API Interactions
- Interacts with VK_KHR_workgroup_memory_explicit_layout
- SPIR-V Dependencies
- Contact
- Extension Proposal
- VK_EXT_shader_long_vector
Other Extension Metadata
- Last Modified Date
- 2025-06-24
- Interactions and External Dependencies
- This extension requires SPV_EXT_long_vector
- This extension provides API support for GL_EXT_long_vector
- Contributors
- Jeff Bolz, NVIDIA
- Spencer Fricke, LunarG
Description
This extension adds support for using vector types with more than four components in SPIR-V.
Long vector types are defined by the SPV_EXT_long_vector SPIR-V extension and can be used with the GL_EXT_long_vector GLSL extension.
New Structures
New Enum Constants
New SPIR-V Capabilities
Version History
Revision 1, 2025-06-24 (Jeff Bolz)
- Initial revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderLongVectorFeaturesEXT = PhysicalDeviceShaderLongVectorFeaturesEXT {
- longVector :: Bool
- data PhysicalDeviceShaderLongVectorPropertiesEXT = PhysicalDeviceShaderLongVectorPropertiesEXT {}
- type EXT_SHADER_LONG_VECTOR_SPEC_VERSION = 1
- pattern EXT_SHADER_LONG_VECTOR_SPEC_VERSION :: Integral a => a
- type EXT_SHADER_LONG_VECTOR_EXTENSION_NAME = "VK_EXT_shader_long_vector"
- pattern EXT_SHADER_LONG_VECTOR_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderLongVectorFeaturesEXT Source #
VkPhysicalDeviceShaderLongVectorFeaturesEXT - Structure describing long vector features that can be supported by an implementation
Members
This structure describes the following features:
Description
If the PhysicalDeviceShaderLongVectorFeaturesEXT structure is included
in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceShaderLongVectorFeaturesEXT, it must add an instance
of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderLongVectorFeaturesEXT | |
Fields
| |
Instances
data PhysicalDeviceShaderLongVectorPropertiesEXT Source #
VkPhysicalDeviceShaderLongVectorPropertiesEXT - Structure describing long vector properties supported by an implementation
Description
If the PhysicalDeviceShaderLongVectorPropertiesEXT structure is
included in the pNext chain of the
PhysicalDeviceProperties2
structure passed to
getPhysicalDeviceProperties2,
it is filled in with each corresponding implementation-dependent
property.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderLongVectorPropertiesEXT | |
Fields | |
Instances
type EXT_SHADER_LONG_VECTOR_SPEC_VERSION = 1 Source #
pattern EXT_SHADER_LONG_VECTOR_SPEC_VERSION :: Integral a => a Source #
type EXT_SHADER_LONG_VECTOR_EXTENSION_NAME = "VK_EXT_shader_long_vector" Source #
pattern EXT_SHADER_LONG_VECTOR_EXTENSION_NAME :: (Eq a, IsString a) => a Source #