| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_EXT_texel_buffer_alignment
Description
Name
VK_EXT_texel_buffer_alignment - device extension
VK_EXT_texel_buffer_alignment
- Name String
VK_EXT_texel_buffer_alignment
- Extension Type
- Device extension
- Registered Extension Number
- 282
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Deprecation State
- Promoted to Vulkan 1.3
- Contact
Other Extension Metadata
- Last Modified Date
- 2019-06-06
- IP Status
- No known IP claims.
- Contributors
- Jeff Bolz, NVIDIA
Description
This extension adds more expressive alignment requirements for uniform
and storage texel buffers. Some implementations have single texel
alignment requirements that cannot be expressed via
PhysicalDeviceLimits::minTexelBufferOffsetAlignment.
New Structures
New Enum Constants
Promotion to Vulkan 1.3
Vulkan APIs in this extension are included in core Vulkan 1.3, with the
EXT suffix omitted. However, only the properties structure is promoted.
The feature structure is not promoted and texelBufferAlignment is
enabled if using a Vulkan 1.3 instance. External interactions defined by
this extension, such as SPIR-V token names, retain their original names.
The original Vulkan API name is still available as an alias of the core
functionality.
Version History
Revision 1, 2019-06-06 (Jeff Bolz)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- pattern STRUCTURE_TYPE_PHYSICAL_DEVICE_TEXEL_BUFFER_ALIGNMENT_PROPERTIES_EXT :: StructureType
- data PhysicalDeviceTexelBufferAlignmentFeaturesEXT = PhysicalDeviceTexelBufferAlignmentFeaturesEXT {}
- type PhysicalDeviceTexelBufferAlignmentPropertiesEXT = PhysicalDeviceTexelBufferAlignmentProperties
- type EXT_TEXEL_BUFFER_ALIGNMENT_SPEC_VERSION = 1
- pattern EXT_TEXEL_BUFFER_ALIGNMENT_SPEC_VERSION :: Integral a => a
- type EXT_TEXEL_BUFFER_ALIGNMENT_EXTENSION_NAME = "VK_EXT_texel_buffer_alignment"
- pattern EXT_TEXEL_BUFFER_ALIGNMENT_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
pattern STRUCTURE_TYPE_PHYSICAL_DEVICE_TEXEL_BUFFER_ALIGNMENT_PROPERTIES_EXT :: StructureType Source #
data PhysicalDeviceTexelBufferAlignmentFeaturesEXT Source #
VkPhysicalDeviceTexelBufferAlignmentFeaturesEXT - Structure describing the texel buffer alignment features that can be supported by an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceTexelBufferAlignmentFeaturesEXT structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceTexelBufferAlignmentFeaturesEXT, it must add an
instance of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceTexelBufferAlignmentFeaturesEXT | |
Fields
| |
Instances
type PhysicalDeviceTexelBufferAlignmentPropertiesEXT = PhysicalDeviceTexelBufferAlignmentProperties Source #
pattern EXT_TEXEL_BUFFER_ALIGNMENT_SPEC_VERSION :: Integral a => a Source #
type EXT_TEXEL_BUFFER_ALIGNMENT_EXTENSION_NAME = "VK_EXT_texel_buffer_alignment" Source #
pattern EXT_TEXEL_BUFFER_ALIGNMENT_EXTENSION_NAME :: (Eq a, IsString a) => a Source #