| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_HUAWEI_hdr_vivid
Description
Name
VK_HUAWEI_hdr_vivid - device extension
VK_HUAWEI_hdr_vivid
- Name String
VK_HUAWEI_hdr_vivid
- Extension Type
- Device extension
- Registered Extension Number
- 591
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or
Vulkan Version 1.1 and VK_KHR_swapchain and VK_EXT_hdr_metadata
- Contact
Other Extension Metadata
- Last Modified Date
- 2024-10-08
- IP Status
- No known IP claims.
- Contributors
- Juntao Li, Huawei
- Pan Gao, Huawei
- Xiufeng Zhang, Huawei
- Zehui Lin, Huawei
Description
This extension allows applications to assign HDR Vivid (T/UWA 005.1-2022) metadata to swapchains.
HDR Vivid is an HDR standard released by UWA (UHD World Association). It defines tone mapping from the metadata to better preserve the creator’s intentions and achieve better consistency across devices with different display capabilities.
New Structures
Extending
HdrMetadataEXT:
New Enum Constants
HUAWEI_HDR_VIVID_SPEC_VERSIONExtending
StructureType:
Version History
Revision 1, 2024-10-08 (Zehui Lin)
- Initial version
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data HdrVividDynamicMetadataHUAWEI = HdrVividDynamicMetadataHUAWEI {
- dynamicMetadataSize :: Word64
- dynamicMetadata :: Ptr ()
- data PhysicalDeviceHdrVividFeaturesHUAWEI = PhysicalDeviceHdrVividFeaturesHUAWEI {}
- type HUAWEI_HDR_VIVID_SPEC_VERSION = 1
- pattern HUAWEI_HDR_VIVID_SPEC_VERSION :: Integral a => a
- type HUAWEI_HDR_VIVID_EXTENSION_NAME = "VK_HUAWEI_hdr_vivid"
- pattern HUAWEI_HDR_VIVID_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data HdrVividDynamicMetadataHUAWEI Source #
VkHdrVividDynamicMetadataHUAWEI - specify HDR Vivid dynamic metadata
Description
The HDR Vivid metadata is intended to be used as defined in the T/UWA 005.1-2022 specification. The validity and use of this data is outside the scope of Vulkan.
Valid Usage (Implicit)
See Also
Constructors
| HdrVividDynamicMetadataHUAWEI | |
Fields
| |
Instances
data PhysicalDeviceHdrVividFeaturesHUAWEI Source #
VkPhysicalDeviceHdrVividFeaturesHUAWEI - Structure describing whether HDR Vivid metadata is supported
Description
If the PhysicalDeviceHdrVividFeaturesHUAWEI structure is included in
the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceHdrVividFeaturesHUAWEI, it must add an instance of the
structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceHdrVividFeaturesHUAWEI | |
Instances
type HUAWEI_HDR_VIVID_SPEC_VERSION = 1 Source #
pattern HUAWEI_HDR_VIVID_SPEC_VERSION :: Integral a => a Source #
type HUAWEI_HDR_VIVID_EXTENSION_NAME = "VK_HUAWEI_hdr_vivid" Source #
pattern HUAWEI_HDR_VIVID_EXTENSION_NAME :: (Eq a, IsString a) => a Source #