| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_INTEL_performance_query
Description
Name
VK_INTEL_performance_query - device extension
VK_INTEL_performance_query
- Name String
VK_INTEL_performance_query
- Extension Type
- Device extension
- Registered Extension Number
- 211
- Revision
- 2
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- None
- Special Use
- Contact
Other Extension Metadata
- Last Modified Date
- 2018-05-16
- IP Status
- No known IP claims.
- Contributors
- Lionel Landwerlin, Intel
- Piotr Maciejewski, Intel
Description
This extension allows an application to capture performance data to be interpreted by an external application or library.
Such a library is available at : https://github.com/intel/metrics-discovery
Performance analysis tools such as Graphics Performance Analyzers make use of this extension and the metrics-discovery library to present the data in a human readable way.
New Object Types
New Commands
cmdSetPerformanceMarkerINTELcmdSetPerformanceOverrideINTELcmdSetPerformanceStreamMarkerINTELgetPerformanceParameterINTELinitializePerformanceApiINTELqueueSetPerformanceConfigurationINTELreleasePerformanceConfigurationINTELuninitializePerformanceApiINTEL
New Structures
PerformanceConfigurationAcquireInfoINTELPerformanceMarkerInfoINTELPerformanceOverrideInfoINTELPerformanceStreamMarkerInfoINTELPerformanceValueINTELExtending
QueryPoolCreateInfo:
New Unions
New Enums
PerformanceOverrideTypeINTELPerformanceParameterTypeINTELPerformanceValueTypeINTELQueryPoolSamplingModeINTEL
New Enum Constants
INTEL_PERFORMANCE_QUERY_SPEC_VERSIONExtending
ObjectType:Extending
QueryType:Extending
StructureType:STRUCTURE_TYPE_INITIALIZE_PERFORMANCE_API_INFO_INTELSTRUCTURE_TYPE_PERFORMANCE_CONFIGURATION_ACQUIRE_INFO_INTELSTRUCTURE_TYPE_PERFORMANCE_MARKER_INFO_INTELSTRUCTURE_TYPE_PERFORMANCE_OVERRIDE_INFO_INTELSTRUCTURE_TYPE_PERFORMANCE_STREAM_MARKER_INFO_INTELSTRUCTURE_TYPE_QUERY_POOL_CREATE_INFO_INTELSTRUCTURE_TYPE_QUERY_POOL_PERFORMANCE_QUERY_CREATE_INFO_INTEL
Example Code
// A previously created device
VkDevice device;
// A queue derived from the device
VkQueue queue;
VkInitializePerformanceApiInfoINTEL performanceApiInfoIntel = {
VK_STRUCTURE_TYPE_INITIALIZE_PERFORMANCE_API_INFO_INTEL,
NULL,
NULL
};
vkInitializePerformanceApiINTEL(
device,
&performanceApiInfoIntel);
VkQueryPoolPerformanceQueryCreateInfoINTEL queryPoolIntel = {
VK_STRUCTURE_TYPE_QUERY_POOL_CREATE_INFO_INTEL,
NULL,
VK_QUERY_POOL_SAMPLING_MODE_MANUAL_INTEL,
};
VkQueryPoolCreateInfo queryPoolCreateInfo = {
VK_STRUCTURE_TYPE_QUERY_POOL_CREATE_INFO,
&queryPoolIntel,
0,
VK_QUERY_TYPE_PERFORMANCE_QUERY_INTEL,
1,
0
};
VkQueryPool queryPool;
VkResult result = vkCreateQueryPool(
device,
&queryPoolCreateInfo,
NULL,
&queryPool);
assert(VK_SUCCESS == result);
// A command buffer we want to record counters on
VkCommandBuffer commandBuffer;
VkCommandBufferBeginInfo commandBufferBeginInfo = {
VK_STRUCTURE_TYPE_COMMAND_BUFFER_BEGIN_INFO,
NULL,
VK_COMMAND_BUFFER_USAGE_ONE_TIME_SUBMIT_BIT,
NULL
};
result = vkBeginCommandBuffer(commandBuffer, &commandBufferBeginInfo);
assert(VK_SUCCESS == result);
vkCmdResetQueryPool(
commandBuffer,
queryPool,
0,
1);
vkCmdBeginQuery(
commandBuffer,
queryPool,
0,
0);
// Perform the commands you want to get performance information on
// ...
// Perform a barrier to ensure all previous commands were complete before
// ending the query
vkCmdPipelineBarrier(commandBuffer,
VK_PIPELINE_STAGE_BOTTOM_OF_PIPE_BIT,
VK_PIPELINE_STAGE_BOTTOM_OF_PIPE_BIT,
0,
0,
NULL,
0,
NULL,
0,
NULL);
vkCmdEndQuery(
commandBuffer,
queryPool,
0);
result = vkEndCommandBuffer(commandBuffer);
assert(VK_SUCCESS == result);
VkPerformanceConfigurationAcquireInfoINTEL performanceConfigurationAcquireInfo = {
VK_STRUCTURE_TYPE_PERFORMANCE_CONFIGURATION_ACQUIRE_INFO_INTEL,
NULL,
VK_PERFORMANCE_CONFIGURATION_TYPE_COMMAND_QUEUE_METRICS_DISCOVERY_ACTIVATED_INTEL
};
VkPerformanceConfigurationINTEL performanceConfigurationIntel;
result = vkAcquirePerformanceConfigurationINTEL(
device,
&performanceConfigurationAcquireInfo,
&performanceConfigurationIntel);
vkQueueSetPerformanceConfigurationINTEL(queue, performanceConfigurationIntel);
assert(VK_SUCCESS == result);
// Submit the command buffer and wait for its completion
// ...
result = vkReleasePerformanceConfigurationINTEL(
device,
performanceConfigurationIntel);
assert(VK_SUCCESS == result);
// Get the report size from metrics-discovery's QueryReportSize
result = vkGetQueryPoolResults(
device,
queryPool,
0, 1, QueryReportSize,
data, QueryReportSize, 0);
assert(VK_SUCCESS == result);
// The data can then be passed back to metrics-discovery from which
// human readable values can be queried.Version History
Revision 2, 2020-03-06 (Lionel Landwerlin)
- Rename VkQueryPoolCreateInfoINTEL in VkQueryPoolPerformanceQueryCreateInfoINTEL
Revision 1, 2018-05-16 (Lionel Landwerlin)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- initializePerformanceApiINTEL :: MonadIO io => Device -> ("initializeInfo" ::: InitializePerformanceApiInfoINTEL) -> io ()
- uninitializePerformanceApiINTEL :: MonadIO io => Device -> io ()
- cmdSetPerformanceMarkerINTEL :: MonadIO io => CommandBuffer -> PerformanceMarkerInfoINTEL -> io ()
- cmdSetPerformanceStreamMarkerINTEL :: MonadIO io => CommandBuffer -> PerformanceStreamMarkerInfoINTEL -> io ()
- cmdSetPerformanceOverrideINTEL :: MonadIO io => CommandBuffer -> PerformanceOverrideInfoINTEL -> io ()
- acquirePerformanceConfigurationINTEL :: MonadIO io => Device -> PerformanceConfigurationAcquireInfoINTEL -> io PerformanceConfigurationINTEL
- releasePerformanceConfigurationINTEL :: MonadIO io => Device -> PerformanceConfigurationINTEL -> io ()
- queueSetPerformanceConfigurationINTEL :: MonadIO io => Queue -> PerformanceConfigurationINTEL -> io ()
- getPerformanceParameterINTEL :: MonadIO io => Device -> PerformanceParameterTypeINTEL -> io PerformanceValueINTEL
- pattern STRUCTURE_TYPE_QUERY_POOL_CREATE_INFO_INTEL :: StructureType
- data PerformanceValueINTEL = PerformanceValueINTEL {}
- data InitializePerformanceApiInfoINTEL = InitializePerformanceApiInfoINTEL {}
- data QueryPoolPerformanceQueryCreateInfoINTEL = QueryPoolPerformanceQueryCreateInfoINTEL {}
- data PerformanceMarkerInfoINTEL = PerformanceMarkerInfoINTEL {}
- data PerformanceStreamMarkerInfoINTEL = PerformanceStreamMarkerInfoINTEL {}
- data PerformanceOverrideInfoINTEL = PerformanceOverrideInfoINTEL {}
- data PerformanceConfigurationAcquireInfoINTEL = PerformanceConfigurationAcquireInfoINTEL {}
- data PerformanceValueDataINTEL
- peekPerformanceValueDataINTEL :: PerformanceValueTypeINTEL -> Ptr PerformanceValueDataINTEL -> IO PerformanceValueDataINTEL
- newtype PerformanceConfigurationTypeINTEL where
- newtype QueryPoolSamplingModeINTEL where
- newtype PerformanceOverrideTypeINTEL where
- newtype PerformanceParameterTypeINTEL where
- newtype PerformanceValueTypeINTEL where
- PerformanceValueTypeINTEL Int32
- pattern PERFORMANCE_VALUE_TYPE_UINT32_INTEL :: PerformanceValueTypeINTEL
- pattern PERFORMANCE_VALUE_TYPE_UINT64_INTEL :: PerformanceValueTypeINTEL
- pattern PERFORMANCE_VALUE_TYPE_FLOAT_INTEL :: PerformanceValueTypeINTEL
- pattern PERFORMANCE_VALUE_TYPE_BOOL_INTEL :: PerformanceValueTypeINTEL
- pattern PERFORMANCE_VALUE_TYPE_STRING_INTEL :: PerformanceValueTypeINTEL
- type QueryPoolCreateInfoINTEL = QueryPoolPerformanceQueryCreateInfoINTEL
- type INTEL_PERFORMANCE_QUERY_SPEC_VERSION = 2
- pattern INTEL_PERFORMANCE_QUERY_SPEC_VERSION :: Integral a => a
- type INTEL_PERFORMANCE_QUERY_EXTENSION_NAME = "VK_INTEL_performance_query"
- pattern INTEL_PERFORMANCE_QUERY_EXTENSION_NAME :: (Eq a, IsString a) => a
- newtype PerformanceConfigurationINTEL = PerformanceConfigurationINTEL Word64
Documentation
initializePerformanceApiINTEL Source #
Arguments
| :: MonadIO io | |
| => Device |
|
| -> ("initializeInfo" ::: InitializePerformanceApiInfoINTEL) |
|
| -> io () |
vkInitializePerformanceApiINTEL - Initialize a device for performance queries
Return Codes
See Also
VK_INTEL_performance_query,
Device, InitializePerformanceApiInfoINTEL
uninitializePerformanceApiINTEL Source #
Arguments
| :: MonadIO io | |
| => Device |
|
| -> io () |
vkUninitializePerformanceApiINTEL - Uninitialize a device for performance queries
Valid Usage (Implicit)
See Also
cmdSetPerformanceMarkerINTEL :: MonadIO io => CommandBuffer -> PerformanceMarkerInfoINTEL -> io () Source #
vkCmdSetPerformanceMarkerINTEL - Markers
Description
The last marker set onto a command buffer before the end of a query will be part of the query result.
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
pMarkerInfomust be a valid pointer to a validPerformanceMarkerInfoINTELstructure -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_COMPUTE_BIT,QUEUE_GRAPHICS_BIT, orQUEUE_TRANSFER_BIToperations - This command must not be called between suspended render pass instances
- This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_COMPUTE_BIT VK_QUEUE_GRAPHICS_BIT VK_QUEUE_TRANSFER_BIT | Action State |
Conditional Rendering
vkCmdSetPerformanceMarkerINTEL is not affected by conditional rendering
Return Codes
See Also
VK_INTEL_performance_query,
CommandBuffer, PerformanceMarkerInfoINTEL
cmdSetPerformanceStreamMarkerINTEL Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> PerformanceStreamMarkerInfoINTEL |
|
| -> io () |
vkCmdSetPerformanceStreamMarkerINTEL - Markers
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
pMarkerInfomust be a valid pointer to a validPerformanceStreamMarkerInfoINTELstructure -
commandBuffermust be in the recording state -
The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_COMPUTE_BIT,QUEUE_GRAPHICS_BIT, orQUEUE_TRANSFER_BIToperations - This command must not be called between suspended render pass instances
- This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_COMPUTE_BIT VK_QUEUE_GRAPHICS_BIT VK_QUEUE_TRANSFER_BIT | Action State |
Conditional Rendering
vkCmdSetPerformanceStreamMarkerINTEL is not affected by conditional rendering
Return Codes
See Also
VK_INTEL_performance_query,
CommandBuffer,
PerformanceStreamMarkerInfoINTEL
cmdSetPerformanceOverrideINTEL Source #
Arguments
| :: MonadIO io | |
| => CommandBuffer |
|
| -> PerformanceOverrideInfoINTEL |
|
| -> io () |
vkCmdSetPerformanceOverrideINTEL - Performance override settings
Valid Usage
-
pOverrideInfomust not be used with aPerformanceOverrideTypeINTELthat is not reported available bygetPerformanceParameterINTEL
Valid Usage (Implicit)
-
commandBuffermust be a validCommandBufferhandle
-
pOverrideInfomust be a valid pointer to a validPerformanceOverrideInfoINTELstructure -
commandBuffermust be in the recording state - The
CommandPoolthatcommandBufferwas allocated from must supportQUEUE_COMPUTE_BIT,QUEUE_GRAPHICS_BIT, orQUEUE_TRANSFER_BIToperations - This command must only be called outside of a video coding scope
Host Synchronization
- Host access to
commandBuffermust be externally synchronized
- Host access to the
CommandPoolthatcommandBufferwas allocated from must be externally synchronized
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| Primary Secondary | Both | Outside | VK_QUEUE_COMPUTE_BIT VK_QUEUE_GRAPHICS_BIT VK_QUEUE_TRANSFER_BIT | State |
Conditional Rendering
vkCmdSetPerformanceOverrideINTEL is not affected by conditional rendering
Return Codes
See Also
VK_INTEL_performance_query,
CommandBuffer, PerformanceOverrideInfoINTEL
acquirePerformanceConfigurationINTEL Source #
Arguments
| :: MonadIO io | |
| => Device |
|
| -> PerformanceConfigurationAcquireInfoINTEL |
|
| -> io PerformanceConfigurationINTEL |
vkAcquirePerformanceConfigurationINTEL - Acquire the performance query capability
Return Codes
See Also
VK_INTEL_performance_query,
Device,
PerformanceConfigurationAcquireInfoINTEL,
PerformanceConfigurationINTEL
releasePerformanceConfigurationINTEL Source #
Arguments
| :: MonadIO io | |
| => Device |
|
| -> PerformanceConfigurationINTEL |
|
| -> io () |
vkReleasePerformanceConfigurationINTEL - Release a configuration to capture performance data
Valid Usage
-
configurationmust not be released before all command buffers submitted while the configuration was set are in pending state
Valid Usage (Implicit)
-
devicemust be a validDevicehandle
-
If
configurationis notNULL_HANDLE,configurationmust be a validPerformanceConfigurationINTELhandle -
If
configurationis a valid handle, it must have been created, allocated, or retrieved fromdevice
Host Synchronization
- Host access to
configurationmust be externally synchronized
Return Codes
See Also
VK_INTEL_performance_query,
Device,
PerformanceConfigurationINTEL
queueSetPerformanceConfigurationINTEL Source #
Arguments
| :: MonadIO io | |
| => Queue |
|
| -> PerformanceConfigurationINTEL |
|
| -> io () |
vkQueueSetPerformanceConfigurationINTEL - Set a performance query
Valid Usage (Implicit)
-
queuemust be a validQueuehandle
-
configurationmust be a validPerformanceConfigurationINTELhandle - Both of
configuration, andqueuemust have been created, allocated, or retrieved from the sameDevice
Host Synchronization
- Host access to
queuemust be externally synchronized if it was not created withDEVICE_QUEUE_CREATE_INTERNALLY_SYNCHRONIZED_BIT_KHR
Command Properties
'
| Command Buffer Levels | Render Pass Scope | Video Coding Scope | Supported Queue Types | Command Type |
|---|---|---|---|---|
| - | - | - | Any | - |
Return Codes
See Also
VK_INTEL_performance_query,
PerformanceConfigurationINTEL,
Queue
getPerformanceParameterINTEL Source #
Arguments
| :: MonadIO io | |
| => Device |
|
| -> PerformanceParameterTypeINTEL |
|
| -> io PerformanceValueINTEL |
vkGetPerformanceParameterINTEL - Query performance capabilities of the device
Return Codes
See Also
VK_INTEL_performance_query,
Device, PerformanceParameterTypeINTEL,
PerformanceValueINTEL
data PerformanceValueINTEL Source #
VkPerformanceValueINTEL - Container for value and types of parameters that can be queried
See Also
VK_INTEL_performance_query,
PerformanceValueDataINTEL, PerformanceValueTypeINTEL,
getPerformanceParameterINTEL
Constructors
| PerformanceValueINTEL | |
Fields
| |
Instances
| Show PerformanceValueINTEL Source # | |
Defined in Vulkan.Extensions.VK_INTEL_performance_query Methods showsPrec :: Int -> PerformanceValueINTEL -> ShowS # show :: PerformanceValueINTEL -> String # showList :: [PerformanceValueINTEL] -> ShowS # | |
| FromCStruct PerformanceValueINTEL Source # | |
Defined in Vulkan.Extensions.VK_INTEL_performance_query Methods peekCStruct :: Ptr PerformanceValueINTEL -> IO PerformanceValueINTEL Source # | |
| ToCStruct PerformanceValueINTEL Source # | |
Defined in Vulkan.Extensions.VK_INTEL_performance_query Methods withCStruct :: PerformanceValueINTEL -> (Ptr PerformanceValueINTEL -> IO b) -> IO b Source # pokeCStruct :: Ptr PerformanceValueINTEL -> PerformanceValueINTEL -> IO b -> IO b Source # withZeroCStruct :: (Ptr PerformanceValueINTEL -> IO b) -> IO b Source # pokeZeroCStruct :: Ptr PerformanceValueINTEL -> IO b -> IO b Source # cStructSize :: Int Source # | |
| Zero PerformanceValueINTEL Source # | |
Defined in Vulkan.Extensions.VK_INTEL_performance_query Methods | |
data InitializePerformanceApiInfoINTEL Source #
VkInitializePerformanceApiInfoINTEL - Structure specifying parameters of initialize of the device
Valid Usage (Implicit)
See Also
VK_INTEL_performance_query,
StructureType,
initializePerformanceApiINTEL
Constructors
| InitializePerformanceApiInfoINTEL | |
Instances
data QueryPoolPerformanceQueryCreateInfoINTEL Source #
VkQueryPoolPerformanceQueryCreateInfoINTEL - Structure specifying parameters to create a pool of performance queries
Members
To create a pool for Intel performance queries, set
QueryPoolCreateInfo::queryType to
QUERY_TYPE_PERFORMANCE_QUERY_INTEL and
add a QueryPoolPerformanceQueryCreateInfoINTEL structure to the
pNext chain of the QueryPoolCreateInfo
structure.
Valid Usage (Implicit)
See Also
VK_INTEL_performance_query,
QueryPoolSamplingModeINTEL,
StructureType
Constructors
| QueryPoolPerformanceQueryCreateInfoINTEL | |
Fields
| |
Instances
data PerformanceMarkerInfoINTEL Source #
VkPerformanceMarkerInfoINTEL - Structure specifying performance markers
Valid Usage (Implicit)
See Also
VK_INTEL_performance_query,
StructureType,
cmdSetPerformanceMarkerINTEL
Constructors
| PerformanceMarkerInfoINTEL | |
Instances
data PerformanceStreamMarkerInfoINTEL Source #
VkPerformanceStreamMarkerInfoINTEL - Structure specifying stream performance markers
Valid Usage
- The value
written by the application into
markermust only used the valid bits as reported bygetPerformanceParameterINTELwith thePERFORMANCE_PARAMETER_TYPE_STREAM_MARKER_VALID_BITS_INTEL
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_PERFORMANCE_STREAM_MARKER_INFO_INTEL
See Also
VK_INTEL_performance_query,
StructureType,
cmdSetPerformanceStreamMarkerINTEL
Constructors
| PerformanceStreamMarkerInfoINTEL | |
Instances
data PerformanceOverrideInfoINTEL Source #
VkPerformanceOverrideInfoINTEL - Performance override information
Valid Usage (Implicit)
See Also
VK_INTEL_performance_query,
Bool32, PerformanceOverrideTypeINTEL,
StructureType,
cmdSetPerformanceOverrideINTEL
Constructors
| PerformanceOverrideInfoINTEL | |
Fields
| |
Instances
data PerformanceConfigurationAcquireInfoINTEL Source #
VkPerformanceConfigurationAcquireInfoINTEL - Acquire a configuration to capture performance data
Valid Usage (Implicit)
See Also
VK_INTEL_performance_query,
PerformanceConfigurationTypeINTEL,
StructureType,
acquirePerformanceConfigurationINTEL
Constructors
| PerformanceConfigurationAcquireInfoINTEL | |
Fields
| |
Instances
data PerformanceValueDataINTEL Source #
Constructors
| Value32 Word32 | |
| Value64 Word64 | |
| ValueFloat Float | |
| ValueBool Bool | |
| ValueString ByteString |
Instances
| Show PerformanceValueDataINTEL Source # | |
Defined in Vulkan.Extensions.VK_INTEL_performance_query Methods showsPrec :: Int -> PerformanceValueDataINTEL -> ShowS # show :: PerformanceValueDataINTEL -> String # showList :: [PerformanceValueDataINTEL] -> ShowS # | |
| ToCStruct PerformanceValueDataINTEL Source # | |
Defined in Vulkan.Extensions.VK_INTEL_performance_query Methods withCStruct :: PerformanceValueDataINTEL -> (Ptr PerformanceValueDataINTEL -> IO b) -> IO b Source # pokeCStruct :: Ptr PerformanceValueDataINTEL -> PerformanceValueDataINTEL -> IO b -> IO b Source # withZeroCStruct :: (Ptr PerformanceValueDataINTEL -> IO b) -> IO b Source # pokeZeroCStruct :: Ptr PerformanceValueDataINTEL -> IO b -> IO b Source # cStructSize :: Int Source # | |
| Zero PerformanceValueDataINTEL Source # | |
Defined in Vulkan.Extensions.VK_INTEL_performance_query Methods | |
peekPerformanceValueDataINTEL :: PerformanceValueTypeINTEL -> Ptr PerformanceValueDataINTEL -> IO PerformanceValueDataINTEL Source #
newtype PerformanceConfigurationTypeINTEL Source #
VkPerformanceConfigurationTypeINTEL - Type of performance configuration
See Also
VK_INTEL_performance_query,
PerformanceConfigurationAcquireInfoINTEL
Constructors
| PerformanceConfigurationTypeINTEL Int32 |
Bundled Patterns
| pattern PERFORMANCE_CONFIGURATION_TYPE_COMMAND_QUEUE_METRICS_DISCOVERY_ACTIVATED_INTEL :: PerformanceConfigurationTypeINTEL |
Instances
newtype QueryPoolSamplingModeINTEL Source #
VkQueryPoolSamplingModeINTEL - Enum specifying how performance queries should be captured
Description
QUERY_POOL_SAMPLING_MODE_MANUAL_INTELis the default mode in which the application callscmdBeginQueryandcmdEndQueryto record performance data.
See Also
VK_INTEL_performance_query,
QueryPoolPerformanceQueryCreateInfoINTEL
Constructors
| QueryPoolSamplingModeINTEL Int32 |
Bundled Patterns
| pattern QUERY_POOL_SAMPLING_MODE_MANUAL_INTEL :: QueryPoolSamplingModeINTEL |
Instances
newtype PerformanceOverrideTypeINTEL Source #
VkPerformanceOverrideTypeINTEL - Performance override type
Description
PERFORMANCE_OVERRIDE_TYPE_NULL_HARDWARE_INTELturns all rendering operations into noop.
PERFORMANCE_OVERRIDE_TYPE_FLUSH_GPU_CACHES_INTELstalls the stream of commands until all previously emitted commands have completed and all caches been flushed and invalidated.
See Also
Constructors
| PerformanceOverrideTypeINTEL Int32 |
Bundled Patterns
| pattern PERFORMANCE_OVERRIDE_TYPE_NULL_HARDWARE_INTEL :: PerformanceOverrideTypeINTEL | |
| pattern PERFORMANCE_OVERRIDE_TYPE_FLUSH_GPU_CACHES_INTEL :: PerformanceOverrideTypeINTEL |
Instances
newtype PerformanceParameterTypeINTEL Source #
VkPerformanceParameterTypeINTEL - Parameters that can be queried
Description
PERFORMANCE_PARAMETER_TYPE_HW_COUNTERS_SUPPORTED_INTELhas a boolean result which tells whether hardware counters can be captured.
PERFORMANCE_PARAMETER_TYPE_STREAM_MARKER_VALID_BITS_INTELhas a 32 bits integer result which tells how many bits can be written into thePerformanceValueINTELvalue.
See Also
Constructors
| PerformanceParameterTypeINTEL Int32 |
Bundled Patterns
| pattern PERFORMANCE_PARAMETER_TYPE_HW_COUNTERS_SUPPORTED_INTEL :: PerformanceParameterTypeINTEL | |
| pattern PERFORMANCE_PARAMETER_TYPE_STREAM_MARKER_VALID_BITS_INTEL :: PerformanceParameterTypeINTEL |
Instances
newtype PerformanceValueTypeINTEL Source #
VkPerformanceValueTypeINTEL - Type of the parameters that can be queried
See Also
Constructors
| PerformanceValueTypeINTEL Int32 |
Bundled Patterns
Instances
type INTEL_PERFORMANCE_QUERY_SPEC_VERSION = 2 Source #
pattern INTEL_PERFORMANCE_QUERY_SPEC_VERSION :: Integral a => a Source #
type INTEL_PERFORMANCE_QUERY_EXTENSION_NAME = "VK_INTEL_performance_query" Source #
pattern INTEL_PERFORMANCE_QUERY_EXTENSION_NAME :: (Eq a, IsString a) => a Source #
newtype PerformanceConfigurationINTEL Source #
VkPerformanceConfigurationINTEL - Device configuration for performance queries
See Also
VK_DEFINE_NON_DISPATCHABLE_HANDLE,
VK_INTEL_performance_query,
acquirePerformanceConfigurationINTEL,
queueSetPerformanceConfigurationINTEL,
releasePerformanceConfigurationINTEL
Constructors
| PerformanceConfigurationINTEL Word64 |