| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_INTEL_shader_integer_functions2
Description
Name
VK_INTEL_shader_integer_functions2 - device extension
VK_INTEL_shader_integer_functions2
- Name String
VK_INTEL_shader_integer_functions2
- Extension Type
- Device extension
- Registered Extension Number
- 210
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- SPIR-V Dependencies
- Contact
Other Extension Metadata
- Last Modified Date
- 2019-04-30
- IP Status
- No known IP claims.
- Interactions and External Dependencies
- This extension provides API support for GL_INTEL_shader_integer_functions2.
- Contributors
- Ian Romanick, Intel
- Ben Ashbaugh, Intel
Description
This extension adds support for several new integer instructions in SPIR-V for use in graphics shaders. Many of these instructions have pre-existing counterparts in the Kernel environment.
The added integer functions are defined by the
SPV_INTEL_shader_integer_functions2
SPIR-V extension and can be used with the
GL_INTEL_shader_integer_functions2 GLSL extension.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
New SPIR-V Capabilities
Version History
Revision 1, 2019-04-30 (Ian Romanick)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL = PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL {}
- type INTEL_SHADER_INTEGER_FUNCTIONS_2_SPEC_VERSION = 1
- pattern INTEL_SHADER_INTEGER_FUNCTIONS_2_SPEC_VERSION :: Integral a => a
- type INTEL_SHADER_INTEGER_FUNCTIONS_2_EXTENSION_NAME = "VK_INTEL_shader_integer_functions2"
- pattern INTEL_SHADER_INTEGER_FUNCTIONS_2_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL Source #
VkPhysicalDeviceShaderIntegerFunctions2FeaturesINTEL - Structure describing shader integer functions that can be supported by an implementation
Members
This structure describes the following feature:
Description
If the VkPhysicalDeviceShaderIntegerFunctions2FeaturesINTELfeatures.
structure is included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
VkPhysicalDeviceShaderIntegerFunctions2FeaturesINTELfeatures., it
must add an instance of the structure, with the desired feature
members set to TRUE, to the pNext
chain of DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderIntegerFunctions2FeaturesINTEL | |
Fields | |
Instances
pattern INTEL_SHADER_INTEGER_FUNCTIONS_2_SPEC_VERSION :: Integral a => a Source #
type INTEL_SHADER_INTEGER_FUNCTIONS_2_EXTENSION_NAME = "VK_INTEL_shader_integer_functions2" Source #
pattern INTEL_SHADER_INTEGER_FUNCTIONS_2_EXTENSION_NAME :: (Eq a, IsString a) => a Source #