vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_copy_commands2

Description

Name

VK_KHR_copy_commands2 - device extension

VK_KHR_copy_commands2

Name String
VK_KHR_copy_commands2
Extension Type
Device extension
Registered Extension Number
338
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
Deprecation State
Contact

Other Extension Metadata

Last Modified Date
2020-07-06
Contributors
  • Jeff Leger, Qualcomm
  • Tobias Hector, AMD
  • Jan-Harald Fredriksen, ARM
  • Tom Olson, ARM

Description

This extension provides extensible versions of the Vulkan buffer and image copy commands. The new commands are functionally identical to the core commands, except that their copy parameters are specified using extensible structures that can be used to pass extension-specific information.

The following extensible copy commands are introduced with this extension: cmdCopyBuffer2KHR, cmdCopyImage2KHR, cmdCopyBufferToImage2KHR, cmdCopyImageToBuffer2KHR, cmdBlitImage2KHR, and cmdResolveImage2KHR. Each command contains an *Info2KHR structure parameter that includes sType/pNext members. Lower level structures describing each region to be copied are also extended with sType/pNext members.

New Commands

New Structures

New Enum Constants

Promotion to Vulkan 1.3

Vulkan APIs in this extension are included in core Vulkan 1.3, with the KHR suffix omitted. External interactions defined by this extension, such as SPIR-V token names, retain their original names. The original Vulkan API names are still available as aliases of the core functionality.

Version History

  • Revision 1, 2020-07-06 (Jeff Leger)

    • Internal revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Documentation

cmdBlitImage2KHR :: forall {a :: [Type]} {io}. (Extendss BlitImageInfo2 a, PokeChain a, MonadIO io) => CommandBuffer -> BlitImageInfo2 a -> io () Source #

type KHR_COPY_COMMANDS_2_EXTENSION_NAME = "VK_KHR_copy_commands2" Source #