| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_depth_clamp_zero_one
Description
Name
VK_KHR_depth_clamp_zero_one - device extension
VK_KHR_depth_clamp_zero_one
- Name String
VK_KHR_depth_clamp_zero_one
- Extension Type
- Device extension
- Registered Extension Number
- 605
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Contact
Other Extension Metadata
- Last Modified Date
- 2024-09-10
- Contributors
- Graeme Leese, Broadcom
Description
This extension is based on the VK_EXT_depth_clamp_zero_one extension.
This extension gives defined behavior to fragment depth values which end
up outside the conventional [0, 1] range. It can be used to ensure
portability in edge cases of features like depthBias. The particular
behavior is chosen to match OpenGL to aid porting or emulation.
New Structures
New Enum Constants
Version History
Revision 1, 2024-09-10 (Graeme Leese)
- Internal revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceDepthClampZeroOneFeaturesKHR = PhysicalDeviceDepthClampZeroOneFeaturesKHR {}
- type KHR_DEPTH_CLAMP_ZERO_ONE_SPEC_VERSION = 1
- pattern KHR_DEPTH_CLAMP_ZERO_ONE_SPEC_VERSION :: Integral a => a
- type KHR_DEPTH_CLAMP_ZERO_ONE_EXTENSION_NAME = "VK_KHR_depth_clamp_zero_one"
- pattern KHR_DEPTH_CLAMP_ZERO_ONE_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceDepthClampZeroOneFeaturesKHR Source #
VkPhysicalDeviceDepthClampZeroOneFeaturesKHR - Structure describing feature to control zero to one depth clamping
Members
This structure describes the following feature:
Description
If the PhysicalDeviceDepthClampZeroOneFeaturesKHR structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceDepthClampZeroOneFeaturesKHR, it must add an instance
of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
VK_EXT_depth_clamp_zero_one,
VK_KHR_depth_clamp_zero_one,
Bool32,
StructureType
Constructors
| PhysicalDeviceDepthClampZeroOneFeaturesKHR | |
Fields | |
Instances
type KHR_DEPTH_CLAMP_ZERO_ONE_SPEC_VERSION = 1 Source #
pattern KHR_DEPTH_CLAMP_ZERO_ONE_SPEC_VERSION :: Integral a => a Source #
type KHR_DEPTH_CLAMP_ZERO_ONE_EXTENSION_NAME = "VK_KHR_depth_clamp_zero_one" Source #
pattern KHR_DEPTH_CLAMP_ZERO_ONE_EXTENSION_NAME :: (Eq a, IsString a) => a Source #