vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_dynamic_rendering_local_read

Description

Name

VK_KHR_dynamic_rendering_local_read - device extension

VK_KHR_dynamic_rendering_local_read

Name String
VK_KHR_dynamic_rendering_local_read
Extension Type
Device extension
Registered Extension Number
233
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
VK_KHR_dynamic_rendering or Vulkan Version 1.3
Deprecation State
Contact
Extension Proposal
VK_KHR_dynamic_rendering_local_read

Other Extension Metadata

Last Modified Date
2023-11-03
Contributors
  • Tobias Hector, AMD
  • Hans-Kristian Arntzen, Valve
  • Connor Abbott, Valve
  • Pan Gao, Huawei
  • Lionel Landwerlin, Intel
  • Shahbaz Youssefi, Google
  • Alyssa Rosenzweig, Valve
  • Jan-Harald Fredriksen, Arm
  • Mike Blumenkrantz, Valve
  • Graeme Leese, Broadcom
  • Piers Daniell, Nvidia
  • Stuart Smith, AMD
  • Daniel Story, Nintendo
  • James Fitzpatrick, Imagination
  • Piotr Byszewski, Mobica
  • Spencer Fricke, LunarG
  • Tom Olson, Arm
  • Michal Pietrasiuk, Intel
  • Matthew Netsch, Qualcomm
  • Marty Johnson, Khronos
  • Wyvern Wang, Huawei
  • Jeff Bolz, Nvidia
  • Samuel (Sheng-Wen) Huang, MediaTek

Description

This extension enables reads from attachments and resources written by previous fragment shaders within a dynamic render pass.

New Commands

New Structures

New Enum Constants

Promotion to Vulkan 1.4

Functionality in this extension is included in core Vulkan 1.4, with the KHR suffix omitted. However, Vulkan 1.4 implementations only have to support local read for storage resources and single sampled color attachments.

Support for reading depth/stencil attachments and multi-sampled attachments are respectively gated behind the new boolean dynamicRenderingLocalReadDepthStencilAttachments and dynamicRenderingLocalReadMultisampledAttachments properties, as described in the Version 1.4 appendix.

The original type, enum, and command names are still available as aliases of the core functionality.

Version History

  • Revision 1, 2023-11-03 (Tobias Hector)

    • Initial revision

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Documentation

type KHR_DYNAMIC_RENDERING_LOCAL_READ_EXTENSION_NAME = "VK_KHR_dynamic_rendering_local_read" Source #