vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_imageless_framebuffer

Description

Name

VK_KHR_imageless_framebuffer - device extension

VK_KHR_imageless_framebuffer

Name String
VK_KHR_imageless_framebuffer
Extension Type
Device extension
Registered Extension Number
109
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies

VK_KHR_get_physical_device_properties2              and

VK_KHR_maintenance2          or

Vulkan Version 1.1      and

VK_KHR_image_format_list or Vulkan Version 1.2

Deprecation State
Contact

Other Extension Metadata

Last Modified Date
2018-12-14
Contributors
  • Tobias Hector
  • Graham Wihlidal

Description

This extension allows framebuffers to be created without the need for creating images first, allowing more flexibility in how they are used, and avoiding the need for many of the confusing compatibility rules.

Framebuffers are now created with a small amount of additional metadata about the image views that will be used in FramebufferAttachmentsCreateInfoKHR, and the actual image views are provided at render pass begin time via RenderPassAttachmentBeginInfoKHR.

Promotion to Vulkan 1.2

All functionality in this extension is included in core Vulkan 1.2, with the KHR suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.

New Structures

New Enum Constants

Version History

  • Revision 1, 2018-12-14 (Tobias Hector)

    • Internal revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Documentation

type KHR_IMAGELESS_FRAMEBUFFER_EXTENSION_NAME = "VK_KHR_imageless_framebuffer" Source #