| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_index_type_uint8
Description
Name
VK_KHR_index_type_uint8 - device extension
VK_KHR_index_type_uint8
- Name String
VK_KHR_index_type_uint8
- Extension Type
- Device extension
- Registered Extension Number
- 534
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Contact
Other Extension Metadata
- Last Modified Date
- 2023-06-06
- IP Status
- No known IP claims.
- Contributors
- Jeff Bolz, NVIDIA
Description
This extension allows uint8_t indices to be used with
cmdBindIndexBuffer.
New Structures
New Enum Constants
KHR_INDEX_TYPE_UINT8_SPEC_VERSIONExtending
IndexType:Extending
StructureType:
Version History
Revision 1, 2023-06-06 (Piers Daniell)
- Internal revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceIndexTypeUint8FeaturesKHR = PhysicalDeviceIndexTypeUint8FeaturesKHR {}
- type KHR_INDEX_TYPE_UINT8_SPEC_VERSION = 1
- pattern KHR_INDEX_TYPE_UINT8_SPEC_VERSION :: forall a. Integral a => a
- type KHR_INDEX_TYPE_UINT8_EXTENSION_NAME = "VK_KHR_index_type_uint8"
- pattern KHR_INDEX_TYPE_UINT8_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a
Documentation
data PhysicalDeviceIndexTypeUint8FeaturesKHR Source #
VkPhysicalDeviceIndexTypeUint8FeaturesKHR - Structure describing whether uint8 index type can be used
Members
This structure describes the following feature:
Description
If the PhysicalDeviceIndexTypeUint8FeaturesKHR structure is included
in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. PhysicalDeviceIndexTypeUint8FeaturesKHR can also be used
in the pNext chain of DeviceCreateInfo to
selectively enable these features.
Valid Usage (Implicit)
See Also
VK_EXT_index_type_uint8,
VK_KHR_index_type_uint8,
Bool32,
StructureType
Constructors
| PhysicalDeviceIndexTypeUint8FeaturesKHR | |
Fields
| |
Instances
type KHR_INDEX_TYPE_UINT8_SPEC_VERSION = 1 Source #
pattern KHR_INDEX_TYPE_UINT8_SPEC_VERSION :: forall a. Integral a => a Source #
type KHR_INDEX_TYPE_UINT8_EXTENSION_NAME = "VK_KHR_index_type_uint8" Source #
pattern KHR_INDEX_TYPE_UINT8_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a Source #