| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_internally_synchronized_queues
Description
Name
VK_KHR_internally_synchronized_queues - device extension
VK_KHR_internally_synchronized_queues
- Name String
VK_KHR_internally_synchronized_queues
- Extension Type
- Device extension
- Registered Extension Number
- 505
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- Vulkan Version 1.1
- Contact
- Extension Proposal
- VK_KHR_internally_synchronized_queues
Other Extension Metadata
- Last Modified Date
- 2025-02-04
- Contributors
- Shahbaz Youssefi, Google
- Daniel Rakos, RasterGrid
- Jeff Bolz, Nvidia
- Hans-Kristian Arntzen, Valve
Description
VK_KHR_internally_synchronized_queues
allows queues to opt into being internally synchronized via the
DEVICE_QUEUE_CREATE_INTERNALLY_SYNCHRONIZED_BIT_KHR
flag.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
KHR_INTERNALLY_SYNCHRONIZED_QUEUES_SPEC_VERSIONExtending
DeviceQueueCreateFlagBits:Extending
StructureType:
Issues
None.
Version History
Revision 0, 2025-01-07 (Daniel Rakos)
- Initial proposal
Revision 1, 2025-02-04 (Shahbaz Youssefi)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceInternallySynchronizedQueuesFeaturesKHR = PhysicalDeviceInternallySynchronizedQueuesFeaturesKHR {}
- type KHR_INTERNALLY_SYNCHRONIZED_QUEUES_SPEC_VERSION = 1
- pattern KHR_INTERNALLY_SYNCHRONIZED_QUEUES_SPEC_VERSION :: Integral a => a
- type KHR_INTERNALLY_SYNCHRONIZED_QUEUES_EXTENSION_NAME = "VK_KHR_internally_synchronized_queues"
- pattern KHR_INTERNALLY_SYNCHRONIZED_QUEUES_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceInternallySynchronizedQueuesFeaturesKHR Source #
VkPhysicalDeviceInternallySynchronizedQueuesFeaturesKHR - Structure indicating support for queues that are internally synchronized
Members
This structure describes the following feature:
Description
If the PhysicalDeviceInternallySynchronizedQueuesFeaturesKHR structure
is included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceInternallySynchronizedQueuesFeaturesKHR, it must add
an instance of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
VK_KHR_internally_synchronized_queues,
Bool32,
StructureType
Constructors
| PhysicalDeviceInternallySynchronizedQueuesFeaturesKHR | |
Fields
| |
Instances
pattern KHR_INTERNALLY_SYNCHRONIZED_QUEUES_SPEC_VERSION :: Integral a => a Source #
type KHR_INTERNALLY_SYNCHRONIZED_QUEUES_EXTENSION_NAME = "VK_KHR_internally_synchronized_queues" Source #
pattern KHR_INTERNALLY_SYNCHRONIZED_QUEUES_EXTENSION_NAME :: (Eq a, IsString a) => a Source #