| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_load_store_op_none
Description
Name
VK_KHR_load_store_op_none - device extension
VK_KHR_load_store_op_none
- Name String
VK_KHR_load_store_op_none
- Extension Type
- Device extension
- Registered Extension Number
- 527
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- None
- Deprecation State
- Promoted to Vulkan 1.4
- Contact
- Extension Proposal
- VK_KHR_load_store_op_none
Other Extension Metadata
- Last Modified Date
- 2023-05-16
- Contributors
- Shahbaz Youssefi, Google
- Bill Licea-Kane, Qualcomm Technologies, Inc.
- Tobias Hector, AMD
Description
This extension provides ATTACHMENT_LOAD_OP_NONE_KHR and
ATTACHMENT_STORE_OP_NONE_KHR,
which are identically promoted from the VK_EXT_load_store_op_none
extension.
New Enum Constants
KHR_LOAD_STORE_OP_NONE_SPEC_VERSIONExtending
AttachmentLoadOp:Extending
AttachmentStoreOp:
Promotion to Vulkan 1.4
Functionality in this extension is included in core Vulkan 1.4 with the KHR suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.
While ATTACHMENT_STORE_OP_NONE
is part of Vulkan 1.3, this extension was not promoted to core Vulkan
1.3 either in whole or in part. This functionality was promoted from
VK_KHR_dynamic_rendering.
Version History
Revision 1, 2023-05-16 (Shahbaz Youssefi)
- Initial revision, based on VK_EXT_load_store_op_none.
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
pattern ATTACHMENT_LOAD_OP_NONE_KHR :: AttachmentLoadOp Source #
type KHR_LOAD_STORE_OP_NONE_SPEC_VERSION = 1 Source #
pattern KHR_LOAD_STORE_OP_NONE_SPEC_VERSION :: Integral a => a Source #
type KHR_LOAD_STORE_OP_NONE_EXTENSION_NAME = "VK_KHR_load_store_op_none" Source #
pattern KHR_LOAD_STORE_OP_NONE_EXTENSION_NAME :: (Eq a, IsString a) => a Source #
pattern ATTACHMENT_STORE_OP_NONE_KHR :: AttachmentStoreOp Source #