vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_maintenance6

Description

Name

VK_KHR_maintenance6 - device extension

VK_KHR_maintenance6

Name String
VK_KHR_maintenance6
Extension Type
Device extension
Registered Extension Number
546
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
Vulkan Version 1.1
API Interactions
  • Interacts with VK_EXT_descriptor_buffer
  • Interacts with VK_KHR_push_descriptor
Deprecation State
Contact
Extension Proposal
VK_KHR_maintenance6

Other Extension Metadata

Last Modified Date
2023-08-03
Interactions and External Dependencies
  • Interacts with VK_EXT_robustness2
Contributors
  • Jon Leech, Khronos
  • Stu Smith, AMD
  • Mike Blumenkrantz, Valve
  • Ralph Potter, Samsung
  • James Fitzpatrick, Imagination Technologies
  • Piers Daniell, NVIDIA
  • Daniel Story, Nintendo

Description

VK_KHR_maintenance6 adds a collection of minor features, none of which would warrant an entire extension of their own.

The new features are as follows:

New Commands

If VK_EXT_descriptor_buffer is supported:

If VK_KHR_push_descriptor is supported:

New Structures

If VK_EXT_descriptor_buffer is supported:

If VK_KHR_push_descriptor is supported:

New Enum Constants

If VK_EXT_descriptor_buffer is supported:

If VK_KHR_push_descriptor is supported:

Promotion to Vulkan 1.4

Functionality in this extension is included in core Vulkan 1.4 with the KHR suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.

Version History

  • Revision 1, 2023-08-01 (Jon Leech)

    • Initial revision

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

cmdSetDescriptorBufferOffsets2EXT Source #

Arguments

:: forall (a :: [Type]) io. (Extendss SetDescriptorBufferOffsetsInfoEXT a, PokeChain a, MonadIO io) 
=> CommandBuffer

commandBuffer is the command buffer in which the descriptor buffer offsets will be set.

-> SetDescriptorBufferOffsetsInfoEXT a

pSetDescriptorBufferOffsetsInfo is a pointer to a SetDescriptorBufferOffsetsInfoEXT structure.

-> io () 

vkCmdSetDescriptorBufferOffsets2EXT - Setting descriptor buffer offsets in a command buffer

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary Secondary Both Outside VK_QUEUE_COMPUTE_BIT VK_QUEUE_DATA_GRAPH_BIT_ARM VK_QUEUE_GRAPHICS_BITState

Conditional Rendering

vkCmdSetDescriptorBufferOffsets2EXT is not affected by conditional rendering

See Also

VK_EXT_descriptor_buffer, VK_KHR_maintenance6, CommandBuffer, SetDescriptorBufferOffsetsInfoEXT

cmdBindDescriptorBufferEmbeddedSamplers2EXT Source #

Arguments

:: forall (a :: [Type]) io. (Extendss BindDescriptorBufferEmbeddedSamplersInfoEXT a, PokeChain a, MonadIO io) 
=> CommandBuffer

commandBuffer is the command buffer that the embedded immutable samplers will be bound to.

-> BindDescriptorBufferEmbeddedSamplersInfoEXT a

pBindDescriptorBufferEmbeddedSamplersInfo is a pointer to a BindDescriptorBufferEmbeddedSamplersInfoEXT structure.

-> io () 

vkCmdBindDescriptorBufferEmbeddedSamplers2EXT - Setting embedded immutable samplers offsets in a command buffer

Valid Usage

Valid Usage (Implicit)

Host Synchronization

  • Host access to commandBuffer must be externally synchronized
  • Host access to the CommandPool that commandBuffer was allocated from must be externally synchronized

Command Properties

'

Command Buffer LevelsRender Pass ScopeVideo Coding ScopeSupported Queue TypesCommand Type
Primary SecondaryBoth Outside VK_QUEUE_COMPUTE_BIT VK_QUEUE_GRAPHICS_BITState

Conditional Rendering

vkCmdBindDescriptorBufferEmbeddedSamplers2EXT is not affected by conditional rendering

See Also

VK_EXT_descriptor_buffer, VK_KHR_maintenance6, BindDescriptorBufferEmbeddedSamplersInfoEXT, CommandBuffer

data SetDescriptorBufferOffsetsInfoEXT (es :: [Type]) Source #

VkSetDescriptorBufferOffsetsInfoEXT - Structure specifying descriptor buffer offsets to set in a command buffer

Description

If stageFlags specifies a subset of all stages corresponding to one or more pipeline bind points, the binding operation still affects all stages corresponding to the given pipeline bind point(s) as if the equivalent original version of this command had been called with the same parameters. For example, specifying a stageFlags value of SHADER_STAGE_VERTEX_BIT | SHADER_STAGE_FRAGMENT_BIT | SHADER_STAGE_COMPUTE_BIT is equivalent to calling the original version of this command once with PIPELINE_BIND_POINT_GRAPHICS and once with PIPELINE_BIND_POINT_COMPUTE.

Valid Usage

Valid Usage (Implicit)

  • pNext must be NULL or a pointer to a valid instance of PipelineLayoutCreateInfo
  • The sType value of each structure in the pNext chain must be unique
  • stageFlags must be a valid combination of ShaderStageFlagBits values
  • stageFlags must not be 0
  • If layout is not NULL_HANDLE, layout must be a valid PipelineLayout handle
  • pBufferIndices must be a valid pointer to an array of setCount uint32_t values
  • pOffsets must be a valid pointer to an array of setCount DeviceSize values
  • setCount must be greater than 0

See Also

VK_EXT_descriptor_buffer, VK_KHR_maintenance6, DeviceSize, PipelineLayout, ShaderStageFlags, StructureType, cmdSetDescriptorBufferOffsets2EXT

Constructors

SetDescriptorBufferOffsetsInfoEXT 

Fields

Instances

Instances details
Extensible SetDescriptorBufferOffsetsInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Show (Chain es) => Show (SetDescriptorBufferOffsetsInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss SetDescriptorBufferOffsetsInfoEXT es, PeekChain es) => FromCStruct (SetDescriptorBufferOffsetsInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss SetDescriptorBufferOffsetsInfoEXT es, PokeChain es) => ToCStruct (SetDescriptorBufferOffsetsInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

es ~ ('[] :: [Type]) => Zero (SetDescriptorBufferOffsetsInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

data BindDescriptorBufferEmbeddedSamplersInfoEXT (es :: [Type]) Source #

VkBindDescriptorBufferEmbeddedSamplersInfoEXT - Structure specifying embedded immutable sampler offsets to set in a command buffer

Description

If stageFlags specifies a subset of all stages corresponding to one or more pipeline bind points, the binding operation still affects all stages corresponding to the given pipeline bind point(s) as if the equivalent original version of this command had been called with the same parameters. For example, specifying a stageFlags value of SHADER_STAGE_VERTEX_BIT | SHADER_STAGE_FRAGMENT_BIT | SHADER_STAGE_COMPUTE_BIT is equivalent to calling the original version of this command once with PIPELINE_BIND_POINT_GRAPHICS and once with PIPELINE_BIND_POINT_COMPUTE.

Valid Usage

Valid Usage (Implicit)

See Also

VK_EXT_descriptor_buffer, VK_KHR_maintenance6, PipelineLayout, ShaderStageFlags, StructureType, cmdBindDescriptorBufferEmbeddedSamplers2EXT

Constructors

BindDescriptorBufferEmbeddedSamplersInfoEXT 

Fields

Instances

Instances details
Extensible BindDescriptorBufferEmbeddedSamplersInfoEXT Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

Show (Chain es) => Show (BindDescriptorBufferEmbeddedSamplersInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss BindDescriptorBufferEmbeddedSamplersInfoEXT es, PeekChain es) => FromCStruct (BindDescriptorBufferEmbeddedSamplersInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

(Extendss BindDescriptorBufferEmbeddedSamplersInfoEXT es, PokeChain es) => ToCStruct (BindDescriptorBufferEmbeddedSamplersInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

es ~ ('[] :: [Type]) => Zero (BindDescriptorBufferEmbeddedSamplersInfoEXT es) Source # 
Instance details

Defined in Vulkan.Extensions.VK_KHR_maintenance6

type KHR_MAINTENANCE_6_EXTENSION_NAME = "VK_KHR_maintenance6" Source #