| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_maintenance9
Description
Name
VK_KHR_maintenance9 - device extension
VK_KHR_maintenance9
- Name String
VK_KHR_maintenance9
- Extension Type
- Device extension
- Registered Extension Number
- 585
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Contact
- Extension Proposal
- VK_KHR_maintenance9
Other Extension Metadata
- Last Modified Date
- 2025-05-29
- Interactions and External Dependencies; Contributors
- Mike Blumenkrantz, Valve
- Shahbaz Youssefi, Google
- Hans-Kristian Arntzen, Valve
- Piers Daniell, NVIDIA
- Daniel Story, Nintendo
- Jeff Bolz, NVIDIA
Description
VK_KHR_maintenance9 adds a collection of minor features, none of which would warrant an entire extension of their own.
The new features are as follows:
- Support VkDevice with no queues. These can be used as effectively an offline compiler to prepopulate pipeline caches, without expensive queue creation or internal memory allocations.
- Allow
cmdSetEvent2to not provide a dependency, providingcmdSetEvent-style usage using enums fromVK_KHR_synchronization2 - Add a
QueryPoolCreateFlagBits::QUERY_POOL_CREATE_RESET_BIT_KHRflag to create a query pool with all queries initialized to the reset state. - Allow any integer bit width for specific bit-wise operations.
- Add a property to enable sparse support with
VK_EXT_image_2d_view_of_3d. - Add a property to indicate the implementation will return (0,0,0,0) or (0,0,0,1) to vertex shaders that read unassigned attributes.
- The effects of image memory barriers and image layout transitions on 3D images created with VK_IMAGE_CREATE_2D_ARRAY_COMPATIBLE_BIT are scoped to the slices specified by the user-provided VkImageSubresourceRange.
- Queue family ownership transfers are no longer required for buffers and linear images, and a new physical device queue family property is exposed to indicate whether queue family ownership transfers are required for optimal images.
New Structures
Extending
PhysicalDeviceProperties2:Extending
QueueFamilyProperties2:
New Enums
New Enum Constants
KHR_MAINTENANCE_9_SPEC_VERSIONExtending
DependencyFlagBits:Extending
QueryPoolCreateFlagBits:Extending
StructureType:
Issues
None.
Version History
Revision 1, 2025-05-29 (Contributors)
- Internal revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceMaintenance9FeaturesKHR = PhysicalDeviceMaintenance9FeaturesKHR {
- maintenance9 :: Bool
- data PhysicalDeviceMaintenance9PropertiesKHR = PhysicalDeviceMaintenance9PropertiesKHR {}
- data QueueFamilyOwnershipTransferPropertiesKHR = QueueFamilyOwnershipTransferPropertiesKHR {}
- newtype DefaultVertexAttributeValueKHR where
- type KHR_MAINTENANCE_9_SPEC_VERSION = 1
- pattern KHR_MAINTENANCE_9_SPEC_VERSION :: Integral a => a
- type KHR_MAINTENANCE_9_EXTENSION_NAME = "VK_KHR_maintenance9"
- pattern KHR_MAINTENANCE_9_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceMaintenance9FeaturesKHR Source #
VkPhysicalDeviceMaintenance9FeaturesKHR - Structure describing whether the implementation supports maintenance9 functionality
Members
This structure describes the following feature:
Description
If the PhysicalDeviceMaintenance9FeaturesKHR structure is included in
the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceMaintenance9FeaturesKHR, it must add an instance of
the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceMaintenance9FeaturesKHR | |
Fields
| |
Instances
data PhysicalDeviceMaintenance9PropertiesKHR Source #
VkPhysicalDeviceMaintenance9PropertiesKHR - Structure describing various implementation-defined properties introduced with VK_KHR_maintenance9
Members
sTypeis aStructureTypevalue identifying this structure.
pNextisNULLor a pointer to a structure extending this structure.- If the
image2DViewOf3D
feature is enabled,
image2DViewOf3DSparseindicates whether the implementation supports binding a slice of a sparse 3D image to a 2D image view. -
defaultVertexAttributeValueis aDefaultVertexAttributeValueKHRthat indicates what value the implementation will return when the vertex shader reads unbound vertex attributes. Unbound attributes are those that have no correspondingVertexInputAttributeDescription::locationdefined in the bound graphics pipeline or no correspondingVertexInputAttributeDescription2EXT::locationset by the most recent call tocmdSetVertexInputEXTwhen the state is dynamic .
Description
If the PhysicalDeviceMaintenance9PropertiesKHR structure is included
in the pNext chain of the
PhysicalDeviceProperties2
structure passed to
getPhysicalDeviceProperties2,
it is filled in with each corresponding implementation-dependent
property.
Valid Usage (Implicit)
See Also
VK_KHR_maintenance9,
Bool32,
DefaultVertexAttributeValueKHR,
StructureType
Constructors
| PhysicalDeviceMaintenance9PropertiesKHR | |
Instances
data QueueFamilyOwnershipTransferPropertiesKHR Source #
VkQueueFamilyOwnershipTransferPropertiesKHR - Structure describing queue family ownership transfer properties
Description
If this structure is included in the pNext chain of the
QueueFamilyProperties2
structure passed to
getPhysicalDeviceQueueFamilyProperties2,
then it is filled with the queue family ownership properties for the
specified queue family.
Valid Usage (Implicit)
See Also
Constructors
| QueueFamilyOwnershipTransferPropertiesKHR | |
Fields
| |
Instances
newtype DefaultVertexAttributeValueKHR Source #
VkDefaultVertexAttributeValueKHR - Values returned for unbound vertex attributes
Description
DEFAULT_VERTEX_ATTRIBUTE_VALUE_ZERO_ZERO_ZERO_ZERO_KHR- the value read for an unbound vertex attribute is (0,0,0,0).
DEFAULT_VERTEX_ATTRIBUTE_VALUE_ZERO_ZERO_ZERO_ONE_KHR- the value read for an unbound vertex attribute is (0,0,0,1).
See Also
VK_KHR_maintenance9,
PhysicalDeviceMaintenance9PropertiesKHR
Constructors
| DefaultVertexAttributeValueKHR Int32 |
Bundled Patterns
| pattern DEFAULT_VERTEX_ATTRIBUTE_VALUE_ZERO_ZERO_ZERO_ZERO_KHR :: DefaultVertexAttributeValueKHR | |
| pattern DEFAULT_VERTEX_ATTRIBUTE_VALUE_ZERO_ZERO_ZERO_ONE_KHR :: DefaultVertexAttributeValueKHR |
Instances
type KHR_MAINTENANCE_9_SPEC_VERSION = 1 Source #
pattern KHR_MAINTENANCE_9_SPEC_VERSION :: Integral a => a Source #
type KHR_MAINTENANCE_9_EXTENSION_NAME = "VK_KHR_maintenance9" Source #
pattern KHR_MAINTENANCE_9_EXTENSION_NAME :: (Eq a, IsString a) => a Source #