| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_map_memory2
Description
Name
VK_KHR_map_memory2 - device extension
VK_KHR_map_memory2
- Name String
VK_KHR_map_memory2
- Extension Type
- Device extension
- Registered Extension Number
- 272
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- None
- Deprecation State
- Promoted to Vulkan 1.4
- Contact
- Extension Proposal
- VK_KHR_map_memory2
Other Extension Metadata
- Last Modified Date
- 2023-03-14
- Interactions and External Dependencies
- None
- Contributors
- Faith Ekstrand, Collabora
- Tobias Hector, AMD
Description
This extension provides extensible versions of the Vulkan memory map and unmap commands. The new commands are functionally identical to the core commands, except that their parameters are specified using extensible structures that can be used to pass extension-specific information.
New Commands
New Structures
New Enums
New Bitmasks
New Enum Constants
KHR_MAP_MEMORY_2_SPEC_VERSIONExtending
StructureType:
Promotion to Vulkan 1.4
Functionality in this extension is included in core Vulkan 1.4 with the KHR suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.
Version History
Revision 0, 2022-08-03 (Faith Ekstrand)
- Internal revisions
Revision 1, 2023-03-14
- Public release
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
pattern STRUCTURE_TYPE_MEMORY_MAP_INFO_KHR :: StructureType Source #
pattern STRUCTURE_TYPE_MEMORY_UNMAP_INFO_KHR :: StructureType Source #
mapMemory2KHR :: forall {a :: [Type]} {io}. (Extendss MemoryMapInfo a, PokeChain a, MonadIO io) => Device -> MemoryMapInfo a -> io ("data" ::: Ptr ()) Source #
unmapMemory2KHR :: MonadIO io => Device -> MemoryUnmapInfo -> io () Source #
type MemoryMapInfoKHR = MemoryMapInfo Source #
type MemoryUnmapInfoKHR = MemoryUnmapInfo Source #
type KHR_MAP_MEMORY_2_SPEC_VERSION = 1 Source #
pattern KHR_MAP_MEMORY_2_SPEC_VERSION :: Integral a => a Source #
type KHR_MAP_MEMORY_2_EXTENSION_NAME = "VK_KHR_map_memory2" Source #
pattern KHR_MAP_MEMORY_2_EXTENSION_NAME :: (Eq a, IsString a) => a Source #