vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_separate_depth_stencil_layouts

Description

Name

VK_KHR_separate_depth_stencil_layouts - device extension

VK_KHR_separate_depth_stencil_layouts

Name String
VK_KHR_separate_depth_stencil_layouts
Extension Type
Device extension
Registered Extension Number
242
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies

VK_KHR_get_physical_device_properties2          or

Vulkan Version 1.1      and

VK_KHR_create_renderpass2 or Vulkan Version 1.2

Deprecation State
Contact

Other Extension Metadata

Last Modified Date
2019-06-25
Contributors
  • Daniel Koch, NVIDIA
  • Jeff Bolz, NVIDIA
  • Jesse Barker, Unity
  • Tobias Hector, AMD

Description

This extension allows image memory barriers for depth/stencil images to have just one of the IMAGE_ASPECT_DEPTH_BIT or IMAGE_ASPECT_STENCIL_BIT aspect bits set, rather than require both. This allows their layouts to be set independently. To support depth/stencil images with different layouts for the depth and stencil aspects, the depth/stencil attachment interface has been updated to support a separate layout for stencil.

Promotion to Vulkan 1.2

All functionality in this extension is included in core Vulkan 1.2, with the KHR suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.

New Structures

New Enum Constants

Version History

  • Revision 1, 2019-06-25 (Piers Daniell)

    • Internal revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Documentation

type KHR_SEPARATE_DEPTH_STENCIL_LAYOUTS_EXTENSION_NAME = "VK_KHR_separate_depth_stencil_layouts" Source #