| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_shader_bfloat16
Description
Name
VK_KHR_shader_bfloat16 - device extension
VK_KHR_shader_bfloat16
- Name String
VK_KHR_shader_bfloat16
- Extension Type
- Device extension
- Registered Extension Number
- 142
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- API Interactions
- Interacts with VK_KHR_cooperative_matrix
- SPIR-V Dependencies
- Contact
- Extension Proposal
- VK_KHR_shader_bfloat16
Other Extension Metadata
- Last Modified Date
- 2024-04-09
- IP Status
- No known IP claims.
- Contributors
- Tobias Hector, AMD
- Stu Smith, AMD
- Jeff Bolz, Nvidia
- Kévin Petit, Arm
- David Neto, Google
- Graeme Leese, Broadcom
- Ruihao Zhang, Qualcomm
- Mark Sheppard, Imagination
- Ben Ashbaugh, Intel
- Dmitry Sidorov, Intel
- Victor Mustya, Intel
Description
This extension enables support for bfloat16 (“brain float”) operations
in shaders as defined in SPV_KHR_bfloat16.
New Structures
New Enum Constants
If VK_KHR_cooperative_matrix is supported:
Extending
ComponentTypeKHR:
New SPIR-V Capabilities
Version History
Revision 1, 2024-04-09 (Stu Smith)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderBfloat16FeaturesKHR = PhysicalDeviceShaderBfloat16FeaturesKHR {}
- type KHR_SHADER_BFLOAT16_SPEC_VERSION = 1
- pattern KHR_SHADER_BFLOAT16_SPEC_VERSION :: Integral a => a
- type KHR_SHADER_BFLOAT16_EXTENSION_NAME = "VK_KHR_shader_bfloat16"
- pattern KHR_SHADER_BFLOAT16_EXTENSION_NAME :: (Eq a, IsString a) => a
- newtype ComponentTypeKHR where
- ComponentTypeKHR Int32
- pattern COMPONENT_TYPE_BFLOAT16_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_FLOAT16_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_FLOAT32_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_FLOAT64_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_FLOAT8_E4M3_EXT :: ComponentTypeKHR
- pattern COMPONENT_TYPE_FLOAT8_E5M2_EXT :: ComponentTypeKHR
- pattern COMPONENT_TYPE_SINT16_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_SINT32_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_SINT64_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_SINT8_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_SINT8_PACKED_NV :: ComponentTypeKHR
- pattern COMPONENT_TYPE_UINT16_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_UINT32_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_UINT64_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_UINT8_KHR :: ComponentTypeKHR
- pattern COMPONENT_TYPE_UINT8_PACKED_NV :: ComponentTypeKHR
Documentation
data PhysicalDeviceShaderBfloat16FeaturesKHR Source #
VkPhysicalDeviceShaderBfloat16FeaturesKHR - Structure describing bfloat16 features that can be supported by the implementation
Members
This structure describes the following features:
Description
If the PhysicalDeviceShaderBfloat16FeaturesKHR structure is included
in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceShaderBfloat16FeaturesKHR, it must add an instance of
the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderBfloat16FeaturesKHR | |
Fields | |
Instances
type KHR_SHADER_BFLOAT16_SPEC_VERSION = 1 Source #
pattern KHR_SHADER_BFLOAT16_SPEC_VERSION :: Integral a => a Source #
type KHR_SHADER_BFLOAT16_EXTENSION_NAME = "VK_KHR_shader_bfloat16" Source #
pattern KHR_SHADER_BFLOAT16_EXTENSION_NAME :: (Eq a, IsString a) => a Source #
newtype ComponentTypeKHR Source #
VkComponentTypeKHR - Specify SPIR-V cooperative matrix component type
Description
COMPONENT_TYPE_FLOAT16_KHRcorresponds to SPIR-VOpTypeFloat16.
COMPONENT_TYPE_FLOAT32_KHRcorresponds to SPIR-VOpTypeFloat32.COMPONENT_TYPE_FLOAT64_KHRcorresponds to SPIR-VOpTypeFloat64.COMPONENT_TYPE_SINT8_KHRcorresponds to SPIR-VOpTypeInt8 0/1.COMPONENT_TYPE_SINT16_KHRcorresponds to SPIR-VOpTypeInt16 0/1.COMPONENT_TYPE_SINT32_KHRcorresponds to SPIR-VOpTypeInt32 0/1.COMPONENT_TYPE_SINT64_KHRcorresponds to SPIR-VOpTypeInt64 0/1.COMPONENT_TYPE_UINT8_KHRcorresponds to SPIR-VOpTypeInt8 0/1.COMPONENT_TYPE_UINT16_KHRcorresponds to SPIR-VOpTypeInt16 0/1.COMPONENT_TYPE_UINT32_KHRcorresponds to SPIR-VOpTypeInt32 0/1.COMPONENT_TYPE_UINT64_KHRcorresponds to SPIR-VOpTypeInt64 0/1.COMPONENT_TYPE_BFLOAT16_KHRcorresponds to SPIR-VOpTypeFloat16 BFloat16KHR.COMPONENT_TYPE_SINT8_PACKED_NVcorresponds to four 8-bit signed integers packed in a 32-bit unsigned integer.COMPONENT_TYPE_UINT8_PACKED_NVcorresponds to four 8-bit unsigned integers packed in a 32-bit unsigned integer.COMPONENT_TYPE_FLOAT_E4M3_NVcorresponds to a floating-point type with a sign bit in the most significant bit, followed by four exponent bits, followed by three mantissa bits.COMPONENT_TYPE_FLOAT_E5M2_NVcorresponds to a floating-point type with a sign bit in the most significant bit, followed by five exponent bits, followed by two mantissa bits.COMPONENT_TYPE_FLOAT8_E4M3_EXTcorresponds to SPIR-VOpTypeFloat8 Float8E4M3EXT.COMPONENT_TYPE_FLOAT8_E5M2_EXTcorresponds to SPIR-VOpTypeFloat8 Float8E5M2EXT.
See Also
VK_KHR_cooperative_matrix,
VK_NV_cooperative_matrix,
VK_NV_cooperative_vector,
ConvertCooperativeVectorMatrixInfoNV,
CooperativeMatrixFlexibleDimensionsPropertiesNV,
CooperativeMatrixPropertiesKHR,
CooperativeMatrixPropertiesNV,
CooperativeVectorPropertiesNV
Constructors
| ComponentTypeKHR Int32 |
Bundled Patterns
| pattern COMPONENT_TYPE_BFLOAT16_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_FLOAT16_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_FLOAT32_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_FLOAT64_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_FLOAT8_E4M3_EXT :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_FLOAT8_E5M2_EXT :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_SINT16_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_SINT32_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_SINT64_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_SINT8_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_SINT8_PACKED_NV :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_UINT16_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_UINT32_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_UINT64_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_UINT8_KHR :: ComponentTypeKHR | |
| pattern COMPONENT_TYPE_UINT8_PACKED_NV :: ComponentTypeKHR |