| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_shader_expect_assume
Description
Name
VK_KHR_shader_expect_assume - device extension
VK_KHR_shader_expect_assume
- Name String
VK_KHR_shader_expect_assume
- Extension Type
- Device extension
- Registered Extension Number
- 545
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- SPIR-V Dependencies
- Deprecation State
- Promoted to Vulkan 1.4
- Contact
- Extension Proposal
- VK_KHR_shader_expect_assume
Other Extension Metadata
- Last Modified Date
- 2023-12-06
- IP Status
- No known IP claims.
- Contributors
- Kevin Petit, Arm
- Tobias Hector, AMD
- James Fitzpatrick, Imagination Technologies
Description
This extension allows the use of the SPV_KHR_expect_assume extension
in SPIR-V shader modules which enables SPIR-V producers to provide
optimization hints to the Vulkan implementation.
New Structures
New Enum Constants
New SPIR-V Capabilities
Promotion to Vulkan 1.4
Functionality in this extension is included in core Vulkan 1.4 with the KHR suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.
Version History
Revision 1, 2023-12-06 (Kevin Petit)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
type PhysicalDeviceShaderExpectAssumeFeaturesKHR = PhysicalDeviceShaderExpectAssumeFeatures Source #
type KHR_SHADER_EXPECT_ASSUME_SPEC_VERSION = 1 Source #
pattern KHR_SHADER_EXPECT_ASSUME_SPEC_VERSION :: Integral a => a Source #
type KHR_SHADER_EXPECT_ASSUME_EXTENSION_NAME = "VK_KHR_shader_expect_assume" Source #
pattern KHR_SHADER_EXPECT_ASSUME_EXTENSION_NAME :: (Eq a, IsString a) => a Source #