| Safe Haskell | Safe-Inferred |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_shader_float_controls2
Description
Name
VK_KHR_shader_float_controls2 - device extension
VK_KHR_shader_float_controls2
- Name String
VK_KHR_shader_float_controls2
- Extension Type
- Device extension
- Registered Extension Number
- 529
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- Vulkan Version 1.1 and VK_KHR_shader_float_controls
- SPIR-V Dependencies
- Contact
- Extension Proposal
- VK_KHR_shader_float_controls2
Other Extension Metadata
- Last Modified Date
- 2023-05-16
- Interactions and External Dependencies
- This extension requires SPV_KHR_float_controls2.
- Contributors
- Graeme Leese, Broadcom
Description
This extension enables use of the more expressive fast floating-point math flags in the SPV_KHR_float_controls2 extension. These flags give finer- grained control over which optimizations compilers may apply, potentially speeding up execution while retaining correct results.
The extension also adds control over the fast-math modes to the GLSL extended instruction set, making these operations more consistent with SPIR-V and allowing their use in situations where floating-point conformance is important.
New Structures
New Enum Constants
New SPIR-V Capabilities
Version History
Revision 1, 2023-05-16 (Graeme Leese)
- Initial draft
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderFloatControls2FeaturesKHR = PhysicalDeviceShaderFloatControls2FeaturesKHR {}
- type KHR_SHADER_FLOAT_CONTROLS_2_SPEC_VERSION = 1
- pattern KHR_SHADER_FLOAT_CONTROLS_2_SPEC_VERSION :: forall a. Integral a => a
- type KHR_SHADER_FLOAT_CONTROLS_2_EXTENSION_NAME = "VK_KHR_shader_float_controls2"
- pattern KHR_SHADER_FLOAT_CONTROLS_2_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderFloatControls2FeaturesKHR Source #
VkPhysicalDeviceShaderFloatControls2FeaturesKHR - Structure describing shader float controls 2 features that can be supported by an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceShaderFloatControls2FeaturesKHR structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. PhysicalDeviceShaderFloatControls2FeaturesKHR can also be
used in the pNext chain of DeviceCreateInfo to
selectively enable these features.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderFloatControls2FeaturesKHR | |
Fields | |
Instances
pattern KHR_SHADER_FLOAT_CONTROLS_2_SPEC_VERSION :: forall a. Integral a => a Source #
type KHR_SHADER_FLOAT_CONTROLS_2_EXTENSION_NAME = "VK_KHR_shader_float_controls2" Source #
pattern KHR_SHADER_FLOAT_CONTROLS_2_EXTENSION_NAME :: forall a. (Eq a, IsString a) => a Source #