vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_KHR_shader_float_controls2

Description

Name

VK_KHR_shader_float_controls2 - device extension

VK_KHR_shader_float_controls2

Name String
VK_KHR_shader_float_controls2
Extension Type
Device extension
Registered Extension Number
529
Revision
1
Ratification Status
Ratified
Extension and Version Dependencies
Vulkan Version 1.1 and VK_KHR_shader_float_controls
SPIR-V Dependencies
Deprecation State
Contact
Extension Proposal
VK_KHR_shader_float_controls2

Other Extension Metadata

Last Modified Date
2023-05-16
Interactions and External Dependencies
Contributors
  • Graeme Leese, Broadcom

Description

This extension enables use of the more expressive fast floating-point math flags in the SPV_KHR_float_controls2 extension. These flags give finer- grained control over which optimizations compilers may apply, potentially speeding up execution while retaining correct results.

The extension also adds control over the fast-math modes to the GLSL extended instruction set, making these operations more consistent with SPIR-V and allowing their use in situations where floating-point conformance is important.

New Structures

New Enum Constants

New SPIR-V Capabilities

Promotion to Vulkan 1.4

Functionality in this extension is included in core Vulkan 1.4 with the KHR suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.

Version History

  • Revision 1, 2023-05-16 (Graeme Leese)

    • Initial draft

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Documentation

type KHR_SHADER_FLOAT_CONTROLS_2_EXTENSION_NAME = "VK_KHR_shader_float_controls2" Source #