| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_shader_maximal_reconvergence
Description
Name
VK_KHR_shader_maximal_reconvergence - device extension
VK_KHR_shader_maximal_reconvergence
- Name String
VK_KHR_shader_maximal_reconvergence
- Extension Type
- Device extension
- Registered Extension Number
- 435
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- Vulkan Version 1.1
- SPIR-V Dependencies
- Contact
- Extension Proposal
- VK_KHR_shader_maximal_reconvergence
Other Extension Metadata
- Last Modified Date
- 2021-11-12
- IP Status
- No known IP claims.
- Interactions and External Dependencies
- Requires SPIR-V 1.3.
- This extension requires SPV_KHR_maximal_reconvergence
- Contributors
- Alan Baker, Google
Description
This extension allows the use of the SPV_KHR_maximal_reconvergence
SPIR-V extension in shader modules. SPV_KHR_maximal_reconvergence
provides stronger guarantees that diverged subgroups will reconverge.
These guarantees should match shader author intuition about divergence
and reconvergence of invocations based on the structure of the code in
the HLL.
Developers should utilize this extension if they require stronger guarantees about reconvergence than either the core spec or SPV_KHR_subgroup_uniform_control_flow. This extension will define the rules that govern how invocations diverge and reconverge in a way that should match developer intuition. It allows robust programs to be written relying on subgroup operations and other tangled instructions.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
Version History
Revision 1, 2021-11-12 (Alan Baker)
- Internal draft version
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR = PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR {}
- type KHR_SHADER_MAXIMAL_RECONVERGENCE_SPEC_VERSION = 1
- pattern KHR_SHADER_MAXIMAL_RECONVERGENCE_SPEC_VERSION :: Integral a => a
- type KHR_SHADER_MAXIMAL_RECONVERGENCE_EXTENSION_NAME = "VK_KHR_shader_maximal_reconvergence"
- pattern KHR_SHADER_MAXIMAL_RECONVERGENCE_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR Source #
VkPhysicalDeviceShaderMaximalReconvergenceFeaturesKHR - Structure describing support for shader maximal reconvergence by an implementation
Members
This structure describes the following feature:
Description
If the
PhysicalDevicePrivateDataFeaturesEXT
structure is included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDevicePrivateDataFeaturesEXT,
it must add an instance of the structure, with the desired feature
members set to TRUE, to the pNext
chain of DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceShaderMaximalReconvergenceFeaturesKHR | |
Fields | |
Instances
pattern KHR_SHADER_MAXIMAL_RECONVERGENCE_SPEC_VERSION :: Integral a => a Source #
type KHR_SHADER_MAXIMAL_RECONVERGENCE_EXTENSION_NAME = "VK_KHR_shader_maximal_reconvergence" Source #
pattern KHR_SHADER_MAXIMAL_RECONVERGENCE_EXTENSION_NAME :: (Eq a, IsString a) => a Source #