| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_shader_relaxed_extended_instruction
Description
Name
VK_KHR_shader_relaxed_extended_instruction - device extension
VK_KHR_shader_relaxed_extended_instruction
- Name String
VK_KHR_shader_relaxed_extended_instruction
- Extension Type
- Device extension
- Registered Extension Number
- 559
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- SPIR-V Dependencies
- Contact
- Extension Proposal
- VK_KHR_shader_relaxed_extended_instruction
Other Extension Metadata
- Last Modified Date
- 2024-01-24
- IP Status
- No known IP claims.
- Contributors
- Alan Baker, Google LLC
- Nathan Gauër, Google LLC
Description
This extension allows the use of the
SPV_KHR_relaxed_extended_instruction extension in SPIR-V shader
modules.
It adds a new SPIR-V instruction, which allows some usage of forward
references in non-semantic instruction sets. This extensions interacts
with the SPV_KHR_non_semantic_info extension, hence with
VK_KHR_shader_non_semantic_info.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
New Enum Constants
Version History
Revision 1, 2024-01-24 (Nathan Gauër)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceShaderRelaxedExtendedInstructionFeaturesKHR = PhysicalDeviceShaderRelaxedExtendedInstructionFeaturesKHR {}
- type KHR_SHADER_RELAXED_EXTENDED_INSTRUCTION_SPEC_VERSION = 1
- pattern KHR_SHADER_RELAXED_EXTENDED_INSTRUCTION_SPEC_VERSION :: Integral a => a
- type KHR_SHADER_RELAXED_EXTENDED_INSTRUCTION_EXTENSION_NAME = "VK_KHR_shader_relaxed_extended_instruction"
- pattern KHR_SHADER_RELAXED_EXTENDED_INSTRUCTION_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceShaderRelaxedExtendedInstructionFeaturesKHR Source #
VkPhysicalDeviceShaderRelaxedExtendedInstructionFeaturesKHR - Structure describing support for VK_KHR_shader_relaxed_extended_instruction an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceShaderRelaxedExtendedInstructionFeaturesKHR
structure is included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceShaderRelaxedExtendedInstructionFeaturesKHR, it must
add an instance of the structure, with the desired feature members set
to TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
VK_KHR_shader_relaxed_extended_instruction,
Bool32,
StructureType
Constructors
| PhysicalDeviceShaderRelaxedExtendedInstructionFeaturesKHR | |
Fields | |
Instances
pattern KHR_SHADER_RELAXED_EXTENDED_INSTRUCTION_SPEC_VERSION :: Integral a => a Source #
type KHR_SHADER_RELAXED_EXTENDED_INSTRUCTION_EXTENSION_NAME = "VK_KHR_shader_relaxed_extended_instruction" Source #
pattern KHR_SHADER_RELAXED_EXTENDED_INSTRUCTION_EXTENSION_NAME :: (Eq a, IsString a) => a Source #