| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_shader_subgroup_rotate
Description
Name
VK_KHR_shader_subgroup_rotate - device extension
VK_KHR_shader_subgroup_rotate
- Name String
VK_KHR_shader_subgroup_rotate
- Extension Type
- Device extension
- Registered Extension Number
- 417
- Revision
- 2
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- SPIR-V Dependencies
- Deprecation State
- Promoted to Vulkan 1.4
- Contact
- Extension Proposal
- VK_KHR_shader_subgroup_rotate
- Last Modified Date
- 2024-01-29
- IP Status
- No known IP claims.
- Contributors
- Kévin Petit, Arm Ltd.
- Tobias Hector, AMD
- Jon Leech, Khronos
- Matthew Netsch, Qualcomm
- Jan-Harald Fredriksen, Arm Ltd.
- Graeme Leese, Broadcom
- Tom Olson, Arm Ltd.
- Spencer Fricke, LunarG Inc.
This extension adds support for the subgroup rotate instruction defined in SPV_KHR_subgroup_rotate.
New Structures
New Enum Constants
KHR_SHADER_SUBGROUP_ROTATE_SPEC_VERSIONExtending
StructureType:Extending
SubgroupFeatureFlagBits:
New SPIR-V Capabilities
Promotion to Vulkan 1.4
Functionality in this extension is included in core Vulkan 1.4 with the KHR suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.
Version History
Revision 2, 2024-01-29 (Kévin Petit)
Revision 1, 2023-06-20 (Kévin Petit)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
pattern STRUCTURE_TYPE_PHYSICAL_DEVICE_SHADER_SUBGROUP_ROTATE_FEATURES_KHR :: StructureType Source #
type PhysicalDeviceShaderSubgroupRotateFeaturesKHR = PhysicalDeviceShaderSubgroupRotateFeatures Source #
pattern KHR_SHADER_SUBGROUP_ROTATE_SPEC_VERSION :: Integral a => a Source #
type KHR_SHADER_SUBGROUP_ROTATE_EXTENSION_NAME = "VK_KHR_shader_subgroup_rotate" Source #
pattern KHR_SHADER_SUBGROUP_ROTATE_EXTENSION_NAME :: (Eq a, IsString a) => a Source #