| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_unified_image_layouts
Description
Name
VK_KHR_unified_image_layouts - device extension
VK_KHR_unified_image_layouts
- Name String
VK_KHR_unified_image_layouts
- Extension Type
- Device extension
- Registered Extension Number
- 528
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- API Interactions
- Interacts with VK_VERSION_1_3
- Interacts with VK_EXT_attachment_feedback_loop_layout
- Interacts with VK_KHR_dynamic_rendering
- Contact
- Extension Proposal
- VK_KHR_unified_image_layouts
Other Extension Metadata
- Last Modified Date
- 2024-10-15
- Interactions and External Dependencies
- This extension interacts with
VK_EXT_attachment_feedback_loop_layout - This extension interacts with
VK_KHR_video_decode_queue - This extension interacts with
VK_KHR_video_encode_queue - This extension interacts with
VK_KHR_video_encode_quantization_map
- This extension interacts with
- Contributors
- Ahmed Abdelkhalek, AMD
- Tobias Hector, AMD
- Jan-Harald Fredriksen, ARM
- Ting Wei, ARM
- Faith Ekstrand, Collabora
- Lina Versace, Google
- Shahbaz Youssefi, Google
- James Fitzpatrick, Imagination
- Daniel Story, Nintendo
- James Jones, NVIDIA
- Jeff Juliano, NVIDIA
- Piers Daniell, NVIDIA
- Tony Zlatinski, NVIDIA
- Matthew Netsch, Qualcomm
- Patrick Boyle, Qualcomm
- Daniel Rakos, RasterGrid
- Ralph Potter, Samsung
- Hans-Kristian Arntzen, VALVE
- Samuel Pitoiset, VALVE
Description
This extension significantly simplifies synchronization in Vulkan by
removing the need for image layout transitions in most cases. In
particular, it guarantees that using the
IMAGE_LAYOUT_GENERAL layout everywhere
possible is just as efficient as using the other layouts.
New Structures
If VK_EXT_attachment_feedback_loop_layout and Vulkan Version 1.3 or VK_KHR_dynamic_rendering is supported:
New Enum Constants
If VK_EXT_attachment_feedback_loop_layout and Vulkan Version 1.3 or VK_KHR_dynamic_rendering is supported:
Version History
Revision 1, 2024-10-15 (Shahbaz Youssefi)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceUnifiedImageLayoutsFeaturesKHR = PhysicalDeviceUnifiedImageLayoutsFeaturesKHR {}
- data AttachmentFeedbackLoopInfoEXT = AttachmentFeedbackLoopInfoEXT {}
- type KHR_UNIFIED_IMAGE_LAYOUTS_SPEC_VERSION = 1
- pattern KHR_UNIFIED_IMAGE_LAYOUTS_SPEC_VERSION :: Integral a => a
- type KHR_UNIFIED_IMAGE_LAYOUTS_EXTENSION_NAME = "VK_KHR_unified_image_layouts"
- pattern KHR_UNIFIED_IMAGE_LAYOUTS_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceUnifiedImageLayoutsFeaturesKHR Source #
VkPhysicalDeviceUnifiedImageLayoutsFeaturesKHR - Structure describing whether the implementation provides unified image layouts
Members
This structure describes the following feature:
Description
If the PhysicalDeviceUnifiedImageLayoutsFeaturesKHR structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceUnifiedImageLayoutsFeaturesKHR, it must add an
instance of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceUnifiedImageLayoutsFeaturesKHR | |
Fields
| |
Instances
data AttachmentFeedbackLoopInfoEXT Source #
VkAttachmentFeedbackLoopInfoEXT - Structure specifying whether feedback loop is enabled for an attachment
Valid Usage
- If
the
unifiedImageLayouts
feature is not enabled,
feedbackLoopEnablemust beFALSE
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_ATTACHMENT_FEEDBACK_LOOP_INFO_EXT
See Also
VK_EXT_attachment_feedback_loop_layout,
VK_KHR_dynamic_rendering,
VK_KHR_unified_image_layouts,
VK_VERSION_1_3,
Bool32,
StructureType
Constructors
| AttachmentFeedbackLoopInfoEXT | |
Fields
| |
Instances
pattern KHR_UNIFIED_IMAGE_LAYOUTS_SPEC_VERSION :: Integral a => a Source #
type KHR_UNIFIED_IMAGE_LAYOUTS_EXTENSION_NAME = "VK_KHR_unified_image_layouts" Source #
pattern KHR_UNIFIED_IMAGE_LAYOUTS_EXTENSION_NAME :: (Eq a, IsString a) => a Source #