| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_KHR_vertex_attribute_divisor
Description
Name
VK_KHR_vertex_attribute_divisor - device extension
VK_KHR_vertex_attribute_divisor
- Name String
VK_KHR_vertex_attribute_divisor
- Extension Type
- Device extension
- Registered Extension Number
- 526
- Revision
- 1
- Ratification Status
- Ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- Deprecation State
- Promoted to Vulkan 1.4
- Contact
- Extension Proposal
- VK_KHR_vertex_attribute_divisor
Other Extension Metadata
- Last Modified Date
- 2023-09-20
- IP Status
- No known IP claims.
- Contributors
- Shahbaz Youssefi, Google
- Contributors to
VK_EXT_vertex_attribute_divisor
Description
This extension is based on the VK_EXT_vertex_attribute_divisor
extension. The only difference is the new property
supportsNonZeroFirstInstance, which indicates support for non-zero
values in firstInstance. This allows the extension to be supported on
implementations that have traditionally only supported OpenGL ES.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:Extending
PhysicalDeviceProperties2:Extending
PipelineVertexInputStateCreateInfo:
New Enum Constants
Promotion to Vulkan 1.4
Functionality in this extension is included in core Vulkan 1.4 with the KHR suffix omitted. The original type, enum, and command names are still available as aliases of the core functionality.
Version History
Revision 1, 2023-09-20 (Shahbaz Youssefi)
- First Version, based on
VK_EXT_vertex_attribute_divisor
- First Version, based on
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
pattern STRUCTURE_TYPE_PHYSICAL_DEVICE_VERTEX_ATTRIBUTE_DIVISOR_PROPERTIES_KHR :: StructureType Source #
pattern STRUCTURE_TYPE_PIPELINE_VERTEX_INPUT_DIVISOR_STATE_CREATE_INFO_KHR :: StructureType Source #
pattern STRUCTURE_TYPE_PHYSICAL_DEVICE_VERTEX_ATTRIBUTE_DIVISOR_FEATURES_KHR :: StructureType Source #
type PipelineVertexInputDivisorStateCreateInfoKHR = PipelineVertexInputDivisorStateCreateInfo Source #
type PhysicalDeviceVertexAttributeDivisorPropertiesKHR = PhysicalDeviceVertexAttributeDivisorProperties Source #
type PhysicalDeviceVertexAttributeDivisorFeaturesKHR = PhysicalDeviceVertexAttributeDivisorFeatures Source #
pattern KHR_VERTEX_ATTRIBUTE_DIVISOR_SPEC_VERSION :: Integral a => a Source #
type KHR_VERTEX_ATTRIBUTE_DIVISOR_EXTENSION_NAME = "VK_KHR_vertex_attribute_divisor" Source #
pattern KHR_VERTEX_ATTRIBUTE_DIVISOR_EXTENSION_NAME :: (Eq a, IsString a) => a Source #