vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_NVX_image_view_handle

Description

Name

VK_NVX_image_view_handle - device extension

VK_NVX_image_view_handle

Name String
VK_NVX_image_view_handle
Extension Type
Device extension
Registered Extension Number
31
Revision
4
Ratification Status
Not ratified
Extension and Version Dependencies
None
Contact

Other Extension Metadata

Last Modified Date
2025-12-03
Contributors
  • Eric Werness, NVIDIA
  • Jeff Bolz, NVIDIA
  • Daniel Koch, NVIDIA
  • Liam Middlebrook, NVIDIA
  • Rodrigo Locatti, NVIDIA

Description

This extension allows applications to query an opaque handle from an image view for use as a sampled image or storage image. This provides no direct functionality itself.

New Commands

New Structures

New Enum Constants

Version History

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

getImageViewHandleNVX Source #

Arguments

:: MonadIO io 
=> Device

device is the logical device that owns the image view.

device must be a valid Device handle

-> ImageViewHandleInfoNVX

pInfo describes the image view to query and type of handle.

pInfo must be a valid pointer to a valid ImageViewHandleInfoNVX structure

-> io Word32 

vkGetImageViewHandleNVX - Get the handle for an image view for a specific descriptor type

Valid Usage (Implicit)

See Also

VK_NVX_image_view_handle, Device, ImageViewHandleInfoNVX

getImageViewHandle64NVX Source #

Arguments

:: MonadIO io 
=> Device

device is the logical device that owns the image view.

device must be a valid Device handle

-> ImageViewHandleInfoNVX

pInfo describes the image view to query and type of handle.

pInfo must be a valid pointer to a valid ImageViewHandleInfoNVX structure

-> io Word64 

vkGetImageViewHandle64NVX - Get the 64-bit handle for an image view for a specific descriptor type

Valid Usage (Implicit)

See Also

VK_NVX_image_view_handle, Device, ImageViewHandleInfoNVX

getImageViewAddressNVX Source #

Arguments

:: MonadIO io 
=> Device

device is the logical device that owns the image view.

device must be a valid Device handle

-> ImageView

imageView is a handle to the image view.

imageView must be a valid ImageView handle

imageView must have been created, allocated, or retrieved from device

-> io ImageViewAddressPropertiesNVX 

getDeviceCombinedImageSamplerIndexNVX Source #

Arguments

:: MonadIO io 
=> Device

device is the logical device that will use the result handle.

device must be a valid Device handle

-> ("imageViewIndex" ::: Word64)

imageViewIndex is the index within the resource heap.

-> ("samplerIndex" ::: Word64)

samplerIndex is the index within the sampler heap.

-> io Word64 

vkGetDeviceCombinedImageSamplerIndexNVX - Get the handle for an image view and sampler index

Description

Shaders take imageViewIndex and samplerIndex, and multiply it by PhysicalDeviceDescriptorHeapPropertiesEXT::imageDescriptorSize and PhysicalDeviceDescriptorHeapPropertiesEXT::samplerDescriptorSize respectively to obtain the descriptor offset in bytes.

Valid Usage (Implicit)

See Also

VK_NVX_image_view_handle, Device

data ImageViewHandleInfoNVX Source #

VkImageViewHandleInfoNVX - Structure specifying the image view for handle queries

Valid Usage

Valid Usage (Implicit)

  • pNext must be NULL
  • imageView must be a valid ImageView handle
  • descriptorType must be a valid DescriptorType value
  • If sampler is not NULL_HANDLE, sampler must be a valid Sampler handle
  • Both of imageView, and sampler that are valid handles of non-ignored parameters must have been created, allocated, or retrieved from the same Device

See Also

VK_NVX_image_view_handle, DescriptorType, ImageView, Sampler, StructureType, getImageViewHandle64NVX, getImageViewHandleNVX

Constructors

ImageViewHandleInfoNVX 

Fields

Instances

Instances details
Eq ImageViewHandleInfoNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

Storable ImageViewHandleInfoNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

Show ImageViewHandleInfoNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

FromCStruct ImageViewHandleInfoNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

ToCStruct ImageViewHandleInfoNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

Zero ImageViewHandleInfoNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

data ImageViewAddressPropertiesNVX Source #

VkImageViewAddressPropertiesNVX - Structure specifying the image view for handle queries

Valid Usage (Implicit)

See Also

VK_NVX_image_view_handle, DeviceAddress, DeviceSize, StructureType, getImageViewAddressNVX

Constructors

ImageViewAddressPropertiesNVX 

Fields

Instances

Instances details
Eq ImageViewAddressPropertiesNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

Storable ImageViewAddressPropertiesNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

Show ImageViewAddressPropertiesNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

FromCStruct ImageViewAddressPropertiesNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

ToCStruct ImageViewAddressPropertiesNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

Zero ImageViewAddressPropertiesNVX Source # 
Instance details

Defined in Vulkan.Extensions.VK_NVX_image_view_handle

type NVX_IMAGE_VIEW_HANDLE_EXTENSION_NAME = "VK_NVX_image_view_handle" Source #