| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_NVX_image_view_handle
Description
Name
VK_NVX_image_view_handle - device extension
VK_NVX_image_view_handle
- Name String
VK_NVX_image_view_handle
- Extension Type
- Device extension
- Registered Extension Number
- 31
- Revision
- 4
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- None
- Contact
Other Extension Metadata
- Last Modified Date
- 2025-12-03
- Contributors
- Eric Werness, NVIDIA
- Jeff Bolz, NVIDIA
- Daniel Koch, NVIDIA
- Liam Middlebrook, NVIDIA
- Rodrigo Locatti, NVIDIA
Description
This extension allows applications to query an opaque handle from an image view for use as a sampled image or storage image. This provides no direct functionality itself.
New Commands
New Structures
New Enum Constants
Version History
Revision 4, 2025-12-03 (Rodrigo Locatti)
Revision 3, 2024-11-04 (Liam Middlebrook)
Revision 2, 2020-04-03 (Piers Daniell)
Revision 1, 2018-12-07 (Eric Werness)
- Internal revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- getImageViewHandleNVX :: MonadIO io => Device -> ImageViewHandleInfoNVX -> io Word32
- getImageViewHandle64NVX :: MonadIO io => Device -> ImageViewHandleInfoNVX -> io Word64
- getImageViewAddressNVX :: MonadIO io => Device -> ImageView -> io ImageViewAddressPropertiesNVX
- getDeviceCombinedImageSamplerIndexNVX :: MonadIO io => Device -> ("imageViewIndex" ::: Word64) -> ("samplerIndex" ::: Word64) -> io Word64
- data ImageViewHandleInfoNVX = ImageViewHandleInfoNVX {}
- data ImageViewAddressPropertiesNVX = ImageViewAddressPropertiesNVX {}
- type NVX_IMAGE_VIEW_HANDLE_SPEC_VERSION = 4
- pattern NVX_IMAGE_VIEW_HANDLE_SPEC_VERSION :: Integral a => a
- type NVX_IMAGE_VIEW_HANDLE_EXTENSION_NAME = "VK_NVX_image_view_handle"
- pattern NVX_IMAGE_VIEW_HANDLE_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
getImageViewHandleNVX Source #
Arguments
| :: MonadIO io | |
| => Device |
|
| -> ImageViewHandleInfoNVX |
|
| -> io Word32 |
vkGetImageViewHandleNVX - Get the handle for an image view for a specific descriptor type
Valid Usage (Implicit)
See Also
getImageViewHandle64NVX Source #
Arguments
| :: MonadIO io | |
| => Device |
|
| -> ImageViewHandleInfoNVX |
|
| -> io Word64 |
vkGetImageViewHandle64NVX - Get the 64-bit handle for an image view for a specific descriptor type
Valid Usage (Implicit)
See Also
getImageViewAddressNVX Source #
Arguments
| :: MonadIO io | |
| => Device |
|
| -> ImageView |
|
| -> io ImageViewAddressPropertiesNVX |
vkGetImageViewAddressNVX - Get the device address of an image view
Return Codes
See Also
VK_NVX_image_view_handle,
Device, ImageView,
ImageViewAddressPropertiesNVX
getDeviceCombinedImageSamplerIndexNVX Source #
Arguments
| :: MonadIO io | |
| => Device |
|
| -> ("imageViewIndex" ::: Word64) |
|
| -> ("samplerIndex" ::: Word64) |
|
| -> io Word64 |
vkGetDeviceCombinedImageSamplerIndexNVX - Get the handle for an image view and sampler index
Description
Shaders take imageViewIndex and samplerIndex, and multiply it by
PhysicalDeviceDescriptorHeapPropertiesEXT::imageDescriptorSize
and
PhysicalDeviceDescriptorHeapPropertiesEXT::samplerDescriptorSize
respectively to obtain the descriptor offset in bytes.
Valid Usage (Implicit)
See Also
data ImageViewHandleInfoNVX Source #
VkImageViewHandleInfoNVX - Structure specifying the image view for handle queries
Valid Usage
-
descriptorTypemust beDESCRIPTOR_TYPE_SAMPLED_IMAGE,DESCRIPTOR_TYPE_STORAGE_IMAGE, orDESCRIPTOR_TYPE_COMBINED_IMAGE_SAMPLER
-
samplermust be a validSamplerifdescriptorTypeisDESCRIPTOR_TYPE_COMBINED_IMAGE_SAMPLER - If descriptorType is
DESCRIPTOR_TYPE_SAMPLED_IMAGEorDESCRIPTOR_TYPE_COMBINED_IMAGE_SAMPLER, the image thatimageViewwas created from must have been created with theIMAGE_USAGE_SAMPLED_BITusage flag set - If descriptorType is
DESCRIPTOR_TYPE_STORAGE_IMAGE, the image thatimageViewwas created from must have been created with theIMAGE_USAGE_STORAGE_BITusage flag set
Valid Usage (Implicit)
-
sTypemust beSTRUCTURE_TYPE_IMAGE_VIEW_HANDLE_INFO_NVX
-
pNextmust beNULL -
imageViewmust be a validImageViewhandle -
descriptorTypemust be a validDescriptorTypevalue - If
sampleris notNULL_HANDLE,samplermust be a validSamplerhandle - Both of
imageView, andsamplerthat are valid handles of non-ignored parameters must have been created, allocated, or retrieved from the sameDevice
See Also
VK_NVX_image_view_handle,
DescriptorType,
ImageView, Sampler,
StructureType,
getImageViewHandle64NVX, getImageViewHandleNVX
Constructors
| ImageViewHandleInfoNVX | |
Fields
| |
Instances
data ImageViewAddressPropertiesNVX Source #
VkImageViewAddressPropertiesNVX - Structure specifying the image view for handle queries
Valid Usage (Implicit)
See Also
VK_NVX_image_view_handle,
DeviceAddress,
DeviceSize,
StructureType,
getImageViewAddressNVX
Constructors
| ImageViewAddressPropertiesNVX | |
Fields
| |
Instances
type NVX_IMAGE_VIEW_HANDLE_SPEC_VERSION = 4 Source #
pattern NVX_IMAGE_VIEW_HANDLE_SPEC_VERSION :: Integral a => a Source #
type NVX_IMAGE_VIEW_HANDLE_EXTENSION_NAME = "VK_NVX_image_view_handle" Source #
pattern NVX_IMAGE_VIEW_HANDLE_EXTENSION_NAME :: (Eq a, IsString a) => a Source #