vulkan
Safe HaskellNone
LanguageHaskell2010

Vulkan.Extensions.VK_NV_dedicated_allocation_image_aliasing

Description

Name

VK_NV_dedicated_allocation_image_aliasing - device extension

VK_NV_dedicated_allocation_image_aliasing

Name String
VK_NV_dedicated_allocation_image_aliasing
Extension Type
Device extension
Registered Extension Number
241
Revision
1
Ratification Status
Not ratified
Extension and Version Dependencies

VK_KHR_dedicated_allocation      and

VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1

Contact

Other Extension Metadata

Last Modified Date
2019-01-04
Contributors
  • Nuno Subtil, NVIDIA
  • Jeff Bolz, NVIDIA
  • Eric Werness, NVIDIA
  • Axel Gneiting, id Software

Description

This extension allows applications to alias images on dedicated allocations, subject to specific restrictions: the extent and the number of layers in the image being aliased must be smaller than or equal to those of the original image for which the allocation was created, and every other image parameter must match.

New Structures

New Enum Constants

Version History

  • Revision 1, 2019-01-04 (Nuno Subtil)

    • Internal revisions

See Also

No cross-references are available

Document Notes

For more information, see the Vulkan Specification.

This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.

Synopsis

Documentation

data PhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV Source #

VkPhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV - Structure describing dedicated allocation image aliasing features that can be supported by an implementation

Members

This structure describes the following feature:

Description

If the PhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV structure is included in the pNext chain of the PhysicalDeviceFeatures2 structure passed to getPhysicalDeviceFeatures2, it is filled in to indicate whether each corresponding feature is supported. If the application wishes to use a Device with any features described by PhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV, it must add an instance of the structure, with the desired feature members set to TRUE, to the pNext chain of DeviceCreateInfo when creating the Device.

Valid Usage (Implicit)

See Also

VK_NV_dedicated_allocation_image_aliasing, Bool32, StructureType

Constructors

PhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV 

Fields

  • dedicatedAllocationImageAliasing :: Bool

    dedicatedAllocationImageAliasing indicates that the implementation supports aliasing of compatible image objects on a dedicated allocation.

Instances

Instances details
Eq PhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_dedicated_allocation_image_aliasing

Storable PhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_dedicated_allocation_image_aliasing

Show PhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_dedicated_allocation_image_aliasing

FromCStruct PhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_dedicated_allocation_image_aliasing

ToCStruct PhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_dedicated_allocation_image_aliasing

Zero PhysicalDeviceDedicatedAllocationImageAliasingFeaturesNV Source # 
Instance details

Defined in Vulkan.Extensions.VK_NV_dedicated_allocation_image_aliasing

type NV_DEDICATED_ALLOCATION_IMAGE_ALIASING_EXTENSION_NAME = "VK_NV_dedicated_allocation_image_aliasing" Source #