| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_NV_present_metering
Description
Name
VK_NV_present_metering - device extension
VK_NV_present_metering
- Name String
VK_NV_present_metering
- Extension Type
- Device extension
- Registered Extension Number
- 614
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2
or
Vulkan Version 1.1
- __This is a provisional extension and must be used with caution. See the description of provisional header files for enablement and stability details.__
- Contact
Other Extension Metadata
- Last Modified Date
- 2025-01-08
- Provisional
- *This extension is provisional and should not be used in production applications. The functionality defined by this extension may change in ways that break backwards compatibility between revisions, and before the final release of the non-provisional version of this extension.
- Contributors
- Charles Hansen, NVIDIA
- Lionel Duc, NVIDIA
Description
This extension is used to evenly meter presents.
New Structures
Extending
PresentInfoKHR:
New Enum Constants
Version History
Revision 1, 2025-01-08 (Charles Hansen)
- Internal revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data SetPresentConfigNV = SetPresentConfigNV {}
- data PhysicalDevicePresentMeteringFeaturesNV = PhysicalDevicePresentMeteringFeaturesNV {}
- type NV_PRESENT_METERING_SPEC_VERSION = 1
- pattern NV_PRESENT_METERING_SPEC_VERSION :: Integral a => a
- type NV_PRESENT_METERING_EXTENSION_NAME = "VK_NV_present_metering"
- pattern NV_PRESENT_METERING_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data SetPresentConfigNV Source #
VkSetPresentConfigNV - Structure specifying present metering configuration
Description
The metering configuration applies to all swapchains in the array in
PresentInfoKHR. The configuration
specified by SetPresentConfigNV applies to the next
numFramesPerBatch calls to
queuePresentKHR and needs to be
updated every numFramesPerBatch presents.
Valid Usage (Implicit)
See Also
Constructors
| SetPresentConfigNV | |
Fields
| |
Instances
data PhysicalDevicePresentMeteringFeaturesNV Source #
VkPhysicalDevicePresentMeteringFeaturesNV - Structure describing whether the present metering features can be supported by an implementation
Members
This structure describes the following features:
Description
If the PhysicalDevicePresentMeteringFeaturesNV structure is included
in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDevicePresentMeteringFeaturesNV, it must add an instance of
the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDevicePresentMeteringFeaturesNV | |
Fields | |
Instances
type NV_PRESENT_METERING_SPEC_VERSION = 1 Source #
pattern NV_PRESENT_METERING_SPEC_VERSION :: Integral a => a Source #
type NV_PRESENT_METERING_EXTENSION_NAME = "VK_NV_present_metering" Source #
pattern NV_PRESENT_METERING_EXTENSION_NAME :: (Eq a, IsString a) => a Source #