| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_NV_raw_access_chains
Description
Name
VK_NV_raw_access_chains - device extension
VK_NV_raw_access_chains
- Name String
VK_NV_raw_access_chains
- Extension Type
- Device extension
- Registered Extension Number
- 556
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- VK_KHR_get_physical_device_properties2 or Vulkan Version 1.1
- SPIR-V Dependencies
- Contact
Other Extension Metadata
- Last Modified Date
- 2023-12-04
- Interactions and External Dependencies
- This extension requires SPV_NV_raw_access_chains
- Contributors
- Hans-Kristian Arntzen, Valve
- Rodrigo Locatti, NVIDIA
Description
This extension allows the use of the SPV_NV_raw_access_chains
extension in SPIR-V shader modules. This enables SPIR-V producers to
efficiently implement interfaces similar to Direct3D structured buffers
and byte address buffers, allowing shaders compiled from an HLSL source
to generate more efficient code.
New SPIR-V Capabilities
Version History
Revision 1, 2023-12-04 (Rodrigo Locatti)
- Initial revision
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceRawAccessChainsFeaturesNV = PhysicalDeviceRawAccessChainsFeaturesNV {}
- type NV_RAW_ACCESS_CHAINS_SPEC_VERSION = 1
- pattern NV_RAW_ACCESS_CHAINS_SPEC_VERSION :: Integral a => a
- type NV_RAW_ACCESS_CHAINS_EXTENSION_NAME = "VK_NV_raw_access_chains"
- pattern NV_RAW_ACCESS_CHAINS_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceRawAccessChainsFeaturesNV Source #
VkPhysicalDeviceRawAccessChainsFeaturesNV - Structure describing shader raw access chains features that can be supported by an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceRawAccessChainsFeaturesNV structure is included
in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceRawAccessChainsFeaturesNV, it must add an instance of
the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceRawAccessChainsFeaturesNV | |
Fields | |
Instances
type NV_RAW_ACCESS_CHAINS_SPEC_VERSION = 1 Source #
pattern NV_RAW_ACCESS_CHAINS_SPEC_VERSION :: Integral a => a Source #
type NV_RAW_ACCESS_CHAINS_EXTENSION_NAME = "VK_NV_raw_access_chains" Source #
pattern NV_RAW_ACCESS_CHAINS_EXTENSION_NAME :: (Eq a, IsString a) => a Source #