| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_NV_shader_subgroup_partitioned
Description
Name
VK_NV_shader_subgroup_partitioned - device extension
VK_NV_shader_subgroup_partitioned
- Name String
VK_NV_shader_subgroup_partitioned
- Extension Type
- Device extension
- Registered Extension Number
- 199
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
- Vulkan Version 1.1
- SPIR-V Dependencies
- Deprecation State
- Promoted to VK_EXT_shader_subgroup_partitioned extension
- Contact
Other Extension Metadata
- Last Modified Date
- 2025-11-12
- Interactions and External Dependencies
- This extension provides API support for GL_NV_shader_subgroup_partitioned
- Contributors
- Jeff Bolz, NVIDIA
Description
This extension enables support for a new class of
group operations
on
subgroups
via the
GL_NV_shader_subgroup_partitioned
GLSL extension and
SPV_NV_shader_subgroup_partitioned
SPIR-V extension. Support for these new operations is advertised via the
SUBGROUP_FEATURE_PARTITIONED_BIT_NV bit.
This extension requires Vulkan 1.1, for general subgroup support.
Promotion to VK_EXT_shader_subgroup_partitioned
All functionality in this extension is included in
VK_EXT_shader_subgroup_partitioned, with the suffix changed to EXT.
The original type, enum, and command names are still available as
aliases of the core functionality.
New Enum Constants
Version History
Revision 1, 2018-03-17 (Jeff Bolz)
- Internal revisions
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Documentation
pattern NV_SHADER_SUBGROUP_PARTITIONED_SPEC_VERSION :: Integral a => a Source #
type NV_SHADER_SUBGROUP_PARTITIONED_EXTENSION_NAME = "VK_NV_shader_subgroup_partitioned" Source #
pattern NV_SHADER_SUBGROUP_PARTITIONED_EXTENSION_NAME :: (Eq a, IsString a) => a Source #