| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_QCOM_fragment_density_map_offset
Description
Name
VK_QCOM_fragment_density_map_offset - device extension
VK_QCOM_fragment_density_map_offset
- Name String
VK_QCOM_fragment_density_map_offset
- Extension Type
- Device extension
- Registered Extension Number
- 426
- Revision
- 3
- Ratification Status
- Not ratified
- Extension and Version Dependencies
VK_KHR_get_physical_device_properties2 or
Vulkan Version 1.1 and VK_EXT_fragment_density_map
- Deprecation State
- Promoted to VK_EXT_fragment_density_map_offset extension
- Contact
Other Extension Metadata
- Last Modified Date
- 2024-06-17
- Contributors
- Matthew Netsch, Qualcomm Technologies, Inc.
- Jonathan Wicks, Qualcomm Technologies, Inc.
- Jonathan Tinkham, Qualcomm Technologies, Inc.
- Jeff Leger, Qualcomm Technologies, Inc.
- Manan Katwala, Qualcomm Technologies, Inc.
- Connor Abbott, Valve Corporation
Description
This extension allows an application to specify offsets to a fragment density map attachment, changing the location where the fragment density map is applied to the framebuffer. This is helpful for eye-tracking use cases where the fovea needs to be moved around the framebuffer to match the eye pose.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:
Extending
PhysicalDeviceProperties2:Extending
SubpassEndInfo,RenderingEndInfoKHR:
New Enum Constants
QCOM_FRAGMENT_DENSITY_MAP_OFFSET_SPEC_VERSIONExtending
ImageCreateFlagBits:Extending
StructureType:
Version History
Revision 3, 2025-03-20 (Connor Abbott/Matthew Netsch)
- Fix clamp equation and clarify the offsets are FDM relative (editorial only)
Revision 2, 2024-06-17 (Matthew Netsch)
- Fix typo in spec regarding fragmentDensityMapOffset feature
Revision 1, 2021-09-03 (Matthew Netsch)
- Initial version
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- pattern STRUCTURE_TYPE_PHYSICAL_DEVICE_FRAGMENT_DENSITY_MAP_OFFSET_FEATURES_QCOM :: StructureType
- pattern STRUCTURE_TYPE_PHYSICAL_DEVICE_FRAGMENT_DENSITY_MAP_OFFSET_PROPERTIES_QCOM :: StructureType
- pattern STRUCTURE_TYPE_SUBPASS_FRAGMENT_DENSITY_MAP_OFFSET_END_INFO_QCOM :: StructureType
- pattern IMAGE_CREATE_FRAGMENT_DENSITY_MAP_OFFSET_BIT_QCOM :: ImageCreateFlagBits
- type PhysicalDeviceFragmentDensityMapOffsetFeaturesQCOM = PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT
- type PhysicalDeviceFragmentDensityMapOffsetPropertiesQCOM = PhysicalDeviceFragmentDensityMapOffsetPropertiesEXT
- type SubpassFragmentDensityMapOffsetEndInfoQCOM = RenderPassFragmentDensityMapOffsetEndInfoEXT
- type QCOM_FRAGMENT_DENSITY_MAP_OFFSET_SPEC_VERSION = 3
- pattern QCOM_FRAGMENT_DENSITY_MAP_OFFSET_SPEC_VERSION :: Integral a => a
- type QCOM_FRAGMENT_DENSITY_MAP_OFFSET_EXTENSION_NAME = "VK_QCOM_fragment_density_map_offset"
- pattern QCOM_FRAGMENT_DENSITY_MAP_OFFSET_EXTENSION_NAME :: (Eq a, IsString a) => a
- data PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT = PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT {}
- data PhysicalDeviceFragmentDensityMapOffsetPropertiesEXT = PhysicalDeviceFragmentDensityMapOffsetPropertiesEXT {}
- data RenderPassFragmentDensityMapOffsetEndInfoEXT = RenderPassFragmentDensityMapOffsetEndInfoEXT {}
Documentation
pattern STRUCTURE_TYPE_PHYSICAL_DEVICE_FRAGMENT_DENSITY_MAP_OFFSET_FEATURES_QCOM :: StructureType Source #
pattern STRUCTURE_TYPE_PHYSICAL_DEVICE_FRAGMENT_DENSITY_MAP_OFFSET_PROPERTIES_QCOM :: StructureType Source #
type PhysicalDeviceFragmentDensityMapOffsetFeaturesQCOM = PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT Source #
type PhysicalDeviceFragmentDensityMapOffsetPropertiesQCOM = PhysicalDeviceFragmentDensityMapOffsetPropertiesEXT Source #
type SubpassFragmentDensityMapOffsetEndInfoQCOM = RenderPassFragmentDensityMapOffsetEndInfoEXT Source #
pattern QCOM_FRAGMENT_DENSITY_MAP_OFFSET_SPEC_VERSION :: Integral a => a Source #
type QCOM_FRAGMENT_DENSITY_MAP_OFFSET_EXTENSION_NAME = "VK_QCOM_fragment_density_map_offset" Source #
pattern QCOM_FRAGMENT_DENSITY_MAP_OFFSET_EXTENSION_NAME :: (Eq a, IsString a) => a Source #
data PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT Source #
VkPhysicalDeviceFragmentDensityMapOffsetFeaturesEXT - Structure describing fragment density map offset features that can be supported by an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT structure is
included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT, it must add an
instance of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
VK_EXT_fragment_density_map_offset,
VK_QCOM_fragment_density_map_offset,
Bool32,
StructureType
Constructors
| PhysicalDeviceFragmentDensityMapOffsetFeaturesEXT | |
Fields
| |
Instances
data PhysicalDeviceFragmentDensityMapOffsetPropertiesEXT Source #
VkPhysicalDeviceFragmentDensityMapOffsetPropertiesEXT - Structure describing fragment density map offset properties that can be supported by an implementation
Description
If the PhysicalDeviceFragmentDensityMapOffsetPropertiesEXT structure
is included in the pNext chain of the
PhysicalDeviceProperties2
structure passed to
getPhysicalDeviceProperties2,
it is filled in with each corresponding implementation-dependent
property.
Valid Usage (Implicit)
See Also
VK_EXT_fragment_density_map_offset,
VK_QCOM_fragment_density_map_offset,
Extent2D,
StructureType
Constructors
| PhysicalDeviceFragmentDensityMapOffsetPropertiesEXT | |
Fields
| |
Instances
data RenderPassFragmentDensityMapOffsetEndInfoEXT Source #
VkRenderPassFragmentDensityMapOffsetEndInfoEXT - Structure specifying fragment density map offset subpass end information
Description
The array elements are given per layer as defined by
Fetch Density Value,
where index = layer. Each (x,y) offset is in framebuffer pixels and
shifts the fetch of the fragment density map by that amount. Offsets can
be positive or negative.
If neither the
SubpassEndInfo::pNext
chain for the last subpass of a render pass nor the
RenderingEndInfoEXT::pNext chain of a dynamic render pass include
RenderPassFragmentDensityMapOffsetEndInfoEXT, or if
fragmentDensityOffsetCount is zero, then the offset (0,0) is used for
Fetch Density Value.
Valid Usage
-
If the
fragmentDensityMapOffset
feature is not enabled or fragment density map is not enabled in the
render pass,
fragmentDensityOffsetCountmust equal0
-
If
RenderPassFragmentDensityMapCreateInfoEXT::fragmentDensityMapAttachmentis notATTACHMENT_UNUSEDand was not created withIMAGE_CREATE_FRAGMENT_DENSITY_MAP_OFFSET_BIT_EXT,fragmentDensityOffsetCountmust equal0 -
If the depth or stencil attachments for the render pass are used and
were not created with
IMAGE_CREATE_FRAGMENT_DENSITY_MAP_OFFSET_BIT_EXT,fragmentDensityOffsetCountmust equal0 -
If any used input attachments for the render pass were not created
with
IMAGE_CREATE_FRAGMENT_DENSITY_MAP_OFFSET_BIT_EXT,fragmentDensityOffsetCountmust equal0 -
If any used color attachments for the render pass were not created
with
IMAGE_CREATE_FRAGMENT_DENSITY_MAP_OFFSET_BIT_EXT,fragmentDensityOffsetCountmust equal0 -
If any used resolve attachments for the render pass were not created
with
IMAGE_CREATE_FRAGMENT_DENSITY_MAP_OFFSET_BIT_EXT,fragmentDensityOffsetCountmust equal0 -
If any used preserve attachments for the render pass were not
created with
IMAGE_CREATE_FRAGMENT_DENSITY_MAP_OFFSET_BIT_EXT,fragmentDensityOffsetCountmust equal0 -
If
fragmentDensityOffsetCountis not0and multiview is enabled for the render pass,fragmentDensityOffsetCountmust equal thelayerCountthat was specified in creating the fragment density map attachment view -
If
fragmentDensityOffsetCountis not0and multiview is not enabled for the render pass,fragmentDensityOffsetCountmust equal1 - The
xcomponent of each element ofpFragmentDensityOffsetsmust be an integer multiple offragmentDensityOffsetGranularity.width - The
ycomponent of each element ofpFragmentDensityOffsetsmust be an integer multiple offragmentDensityOffsetGranularity.height -
Each element of
pFragmentDensityOffsetsmust be identical for everycmdEndRendering2KHRcall made in a render pass
Valid Usage (Implicit)
-
If
fragmentDensityOffsetCountis not0,pFragmentDensityOffsetsmust be a valid pointer to an array offragmentDensityOffsetCountOffset2Dstructures
See Also
VK_EXT_fragment_density_map_offset,
VK_QCOM_fragment_density_map_offset,
Offset2D,
StructureType
Constructors
| RenderPassFragmentDensityMapOffsetEndInfoEXT | |
Fields
| |