| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Vulkan.Extensions.VK_VALVE_fragment_density_map_layered
Description
Name
VK_VALVE_fragment_density_map_layered - device extension
VK_VALVE_fragment_density_map_layered
- Name String
VK_VALVE_fragment_density_map_layered
- Extension Type
- Device extension
- Registered Extension Number
- 612
- Revision
- 1
- Ratification Status
- Not ratified
- Extension and Version Dependencies
Vulkan Version 1.4 and VK_EXT_fragment_density_map
- Contact
Other Extension Metadata
- Last Modified Date
- 2025-06-06
- Interactions and External Dependencies
- Interacts with Vulkan 1.1.
- Interacts with Vulkan 1.3.
- Interacts with Vulkan 1.4.
- Interacts with
VK_EXT_fragment_density_map.
- IP Status
- No known IP claims.
- Contributors
- Connor Abbott, VALVE
- Mike Blumenkrantz, VALVE
Description
This extension enables the use of layered fragment density maps.
New Structures
Extending
PhysicalDeviceFeatures2,DeviceCreateInfo:Extending
PhysicalDeviceProperties2:
New Enum Constants
VALVE_FRAGMENT_DENSITY_MAP_LAYERED_SPEC_VERSIONExtending
PipelineCreateFlagBits2:Extending
RenderingFlagBits:Extending
RenderPassCreateFlagBits:Extending
StructureType:
Version History
Revision 1, 2025-06-06 (Mike Blumenkrantz)
- Initial version
See Also
No cross-references are available
Document Notes
For more information, see the Vulkan Specification.
This page is a generated document. Fixes and changes should be made to the generator scripts, not directly.
Synopsis
- data PhysicalDeviceFragmentDensityMapLayeredPropertiesVALVE = PhysicalDeviceFragmentDensityMapLayeredPropertiesVALVE {}
- data PhysicalDeviceFragmentDensityMapLayeredFeaturesVALVE = PhysicalDeviceFragmentDensityMapLayeredFeaturesVALVE {}
- data PipelineFragmentDensityMapLayeredCreateInfoVALVE = PipelineFragmentDensityMapLayeredCreateInfoVALVE {}
- type VALVE_FRAGMENT_DENSITY_MAP_LAYERED_SPEC_VERSION = 1
- pattern VALVE_FRAGMENT_DENSITY_MAP_LAYERED_SPEC_VERSION :: Integral a => a
- type VALVE_FRAGMENT_DENSITY_MAP_LAYERED_EXTENSION_NAME = "VK_VALVE_fragment_density_map_layered"
- pattern VALVE_FRAGMENT_DENSITY_MAP_LAYERED_EXTENSION_NAME :: (Eq a, IsString a) => a
Documentation
data PhysicalDeviceFragmentDensityMapLayeredPropertiesVALVE Source #
VkPhysicalDeviceFragmentDensityMapLayeredPropertiesVALVE - Structure describing fragment density map layered properties that can be supported by an implementation
Description
If the PhysicalDeviceFragmentDensityMapLayeredPropertiesVALVE
structure is included in the pNext chain of the
PhysicalDeviceProperties2
structure passed to
getPhysicalDeviceProperties2,
it is filled in with each corresponding implementation-dependent
property.
Valid Usage (Implicit)
See Also
Constructors
| PhysicalDeviceFragmentDensityMapLayeredPropertiesVALVE | |
Fields | |
Instances
data PhysicalDeviceFragmentDensityMapLayeredFeaturesVALVE Source #
VkPhysicalDeviceFragmentDensityMapLayeredFeaturesVALVE - Structure describing additional layered fragment density map features that can be supported by an implementation
Members
This structure describes the following feature:
Description
If the PhysicalDeviceFragmentDensityMapLayeredFeaturesVALVE structure
is included in the pNext chain of the
PhysicalDeviceFeatures2
structure passed to
getPhysicalDeviceFeatures2,
it is filled in to indicate whether each corresponding feature is
supported. If the application wishes to use a
Device with any features described by
PhysicalDeviceFragmentDensityMapLayeredFeaturesVALVE, it must add an
instance of the structure, with the desired feature members set to
TRUE, to the pNext chain of
DeviceCreateInfo when creating the
Device.
Valid Usage (Implicit)
See Also
VK_VALVE_fragment_density_map_layered,
Bool32,
StructureType
Constructors
| PhysicalDeviceFragmentDensityMapLayeredFeaturesVALVE | |
Fields | |
Instances
data PipelineFragmentDensityMapLayeredCreateInfoVALVE Source #
VkPipelineFragmentDensityMapLayeredCreateInfoVALVE - Structure specifying layered fragment density map info
Valid Usage (Implicit)
See Also
Constructors
| PipelineFragmentDensityMapLayeredCreateInfoVALVE | |
Fields
| |
Instances
pattern VALVE_FRAGMENT_DENSITY_MAP_LAYERED_SPEC_VERSION :: Integral a => a Source #
type VALVE_FRAGMENT_DENSITY_MAP_LAYERED_EXTENSION_NAME = "VK_VALVE_fragment_density_map_layered" Source #
pattern VALVE_FRAGMENT_DENSITY_MAP_LAYERED_EXTENSION_NAME :: (Eq a, IsString a) => a Source #